 OGL_CONST_i(GLEW_ERROR_GLX_VERSION_11_ONLY)
 OGL_CONST_i(GLEW_ERROR_GL_VERSION_10_ONLY)
 OGL_CONST_i(GLEW_ERROR_NO_GLX_DISPLAY)
 OGL_CONST_i(GLEW_ERROR_NO_GL_CONTEXT)
 OGL_CONST_i(GLEW_ERROR_NO_GL_VERSION)
 OGL_CONST_i(GLEW_NO_ERROR)
 OGL_CONST_i(GLEW_OK)
 OGL_CONST_i(GLEW_VERSION_MAJOR)
 OGL_CONST_i(GLEW_VERSION_MICRO)
 OGL_CONST_i(GLEW_VERSION_MINOR)
 OGL_CONST_i(GL_1PASS_EXT)
 OGL_CONST_i(GL_1PASS_SGIS)
 OGL_CONST_i(GL_2D)
 OGL_CONST_i(GL_2PASS_0_EXT)
 OGL_CONST_i(GL_2PASS_0_SGIS)
 OGL_CONST_i(GL_2PASS_1_EXT)
 OGL_CONST_i(GL_2PASS_1_SGIS)
 OGL_CONST_i(GL_2X_BIT_ATI)
 OGL_CONST_i(GL_2_BYTES)
 OGL_CONST_i(GL_3D)
 OGL_CONST_i(GL_3DC_XY_AMD)
 OGL_CONST_i(GL_3DC_X_AMD)
 OGL_CONST_i(GL_3DVISION_STEREO_NV)
 OGL_CONST_i(GL_3D_COLOR)
 OGL_CONST_i(GL_3D_COLOR_TEXTURE)
 OGL_CONST_i(GL_3_BYTES)
 OGL_CONST_i(GL_422_AVERAGE_EXT)
 OGL_CONST_i(GL_422_EXT)
 OGL_CONST_i(GL_422_REV_AVERAGE_EXT)
 OGL_CONST_i(GL_422_REV_EXT)
 OGL_CONST_i(GL_4D_COLOR_TEXTURE)
 OGL_CONST_i(GL_4PASS_0_EXT)
 OGL_CONST_i(GL_4PASS_0_SGIS)
 OGL_CONST_i(GL_4PASS_1_EXT)
 OGL_CONST_i(GL_4PASS_1_SGIS)
 OGL_CONST_i(GL_4PASS_2_EXT)
 OGL_CONST_i(GL_4PASS_2_SGIS)
 OGL_CONST_i(GL_4PASS_3_EXT)
 OGL_CONST_i(GL_4PASS_3_SGIS)
 OGL_CONST_i(GL_4X_BIT_ATI)
 OGL_CONST_i(GL_4_BYTES)
 OGL_CONST_i(GL_8X_BIT_ATI)
 OGL_CONST_i(GL_ABGR_EXT)
 OGL_CONST_i(GL_ACCUM)
 OGL_CONST_i(GL_ACCUM_ADJACENT_PAIRS_NV)
 OGL_CONST_i(GL_ACCUM_ALPHA_BITS)
 OGL_CONST_i(GL_ACCUM_BLUE_BITS)
 OGL_CONST_i(GL_ACCUM_BUFFER_BIT)
 OGL_CONST_i(GL_ACCUM_CLEAR_VALUE)
 OGL_CONST_i(GL_ACCUM_GREEN_BITS)
 OGL_CONST_i(GL_ACCUM_RED_BITS)
 OGL_CONST_i(GL_ACTIVE_ATOMIC_COUNTER_BUFFERS)
 OGL_CONST_i(GL_ACTIVE_ATTRIBUTES)
 OGL_CONST_i(GL_ACTIVE_ATTRIBUTE_MAX_LENGTH)
 OGL_CONST_i(GL_ACTIVE_PROGRAM)
 OGL_CONST_i(GL_ACTIVE_PROGRAM_EXT)
 OGL_CONST_i(GL_ACTIVE_RESOURCES)
 OGL_CONST_i(GL_ACTIVE_STENCIL_FACE_EXT)
 OGL_CONST_i(GL_ACTIVE_SUBROUTINES)
 OGL_CONST_i(GL_ACTIVE_SUBROUTINE_MAX_LENGTH)
 OGL_CONST_i(GL_ACTIVE_SUBROUTINE_UNIFORMS)
 OGL_CONST_i(GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS)
 OGL_CONST_i(GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH)
 OGL_CONST_i(GL_ACTIVE_TEXTURE)
 OGL_CONST_i(GL_ACTIVE_TEXTURE_ARB)
 OGL_CONST_i(GL_ACTIVE_UNIFORMS)
 OGL_CONST_i(GL_ACTIVE_UNIFORM_BLOCKS)
 OGL_CONST_i(GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH)
 OGL_CONST_i(GL_ACTIVE_UNIFORM_MAX_LENGTH)
 OGL_CONST_i(GL_ACTIVE_VARIABLES)
 OGL_CONST_i(GL_ACTIVE_VARYINGS_NV)
 OGL_CONST_i(GL_ACTIVE_VARYING_MAX_LENGTH_NV)
 OGL_CONST_i(GL_ACTIVE_VERTEX_UNITS_ARB)
 OGL_CONST_i(GL_ADD)
 OGL_CONST_i(GL_ADD_ATI)
 OGL_CONST_i(GL_ADD_BLEND_IMG)
 OGL_CONST_i(GL_ADD_SIGNED)
 OGL_CONST_i(GL_ADD_SIGNED_ARB)
 OGL_CONST_i(GL_ADD_SIGNED_EXT)
 OGL_CONST_i(GL_ADJACENT_PAIRS_NV)
 OGL_CONST_i(GL_AFFINE_2D_NV)
 OGL_CONST_i(GL_AFFINE_3D_NV)
 OGL_CONST_i(GL_ALIASED_LINE_WIDTH_RANGE)
 OGL_CONST_i(GL_ALIASED_POINT_SIZE_RANGE)
 OGL_CONST_i(GL_ALLOW_DRAW_FRG_HINT_PGI)
 OGL_CONST_i(GL_ALLOW_DRAW_MEM_HINT_PGI)
 OGL_CONST_i(GL_ALLOW_DRAW_OBJ_HINT_PGI)
 OGL_CONST_i(GL_ALLOW_DRAW_WIN_HINT_PGI)
 OGL_CONST_i(GL_ALL_ATTRIB_BITS)
 OGL_CONST_i(GL_ALL_BARRIER_BITS)
 OGL_CONST_i(GL_ALL_BARRIER_BITS_EXT)
 OGL_CONST_i(GL_ALL_COMPLETED_NV)
 OGL_CONST_i(GL_ALL_PIXELS_AMD)
 OGL_CONST_i(GL_ALL_SHADER_BITS)
 OGL_CONST_i(GL_ALL_STATIC_DATA_IBM)
 OGL_CONST_i(GL_ALPHA)
 OGL_CONST_i(GL_ALPHA12)
 OGL_CONST_i(GL_ALPHA12_EXT)
 OGL_CONST_i(GL_ALPHA16)
 OGL_CONST_i(GL_ALPHA16F_ARB)
 OGL_CONST_i(GL_ALPHA16F_EXT)
 OGL_CONST_i(GL_ALPHA16I_EXT)
 OGL_CONST_i(GL_ALPHA16UI_EXT)
 OGL_CONST_i(GL_ALPHA16_EXT)
 OGL_CONST_i(GL_ALPHA16_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_ALPHA16_ICC_SGIX)
 OGL_CONST_i(GL_ALPHA16_SIGNED_SGIX)
 OGL_CONST_i(GL_ALPHA16_SNORM)
 OGL_CONST_i(GL_ALPHA32F_ARB)
 OGL_CONST_i(GL_ALPHA32F_EXT)
 OGL_CONST_i(GL_ALPHA32I_EXT)
 OGL_CONST_i(GL_ALPHA32UI_EXT)
 OGL_CONST_i(GL_ALPHA4)
 OGL_CONST_i(GL_ALPHA4_EXT)
 OGL_CONST_i(GL_ALPHA8)
 OGL_CONST_i(GL_ALPHA8I_EXT)
 OGL_CONST_i(GL_ALPHA8UI_EXT)
 OGL_CONST_i(GL_ALPHA8_EXT)
 OGL_CONST_i(GL_ALPHA8_OES)
 OGL_CONST_i(GL_ALPHA8_SNORM)
 OGL_CONST_i(GL_ALPHA_BIAS)
 OGL_CONST_i(GL_ALPHA_BITS)
 OGL_CONST_i(GL_ALPHA_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_ALPHA_FLOAT16_APPLE)
 OGL_CONST_i(GL_ALPHA_FLOAT16_ATI)
 OGL_CONST_i(GL_ALPHA_FLOAT32_APPLE)
 OGL_CONST_i(GL_ALPHA_FLOAT32_ATI)
 OGL_CONST_i(GL_ALPHA_ICC_SGIX)
 OGL_CONST_i(GL_ALPHA_INTEGER)
 OGL_CONST_i(GL_ALPHA_INTEGER_EXT)
 OGL_CONST_i(GL_ALPHA_MAX_CLAMP_INGR)
 OGL_CONST_i(GL_ALPHA_MAX_SGIX)
 OGL_CONST_i(GL_ALPHA_MIN_CLAMP_INGR)
 OGL_CONST_i(GL_ALPHA_MIN_SGIX)
 OGL_CONST_i(GL_ALPHA_REF_COMMAND_NV)
 OGL_CONST_i(GL_ALPHA_SCALE)
 OGL_CONST_i(GL_ALPHA_SIGNED_SGIX)
 OGL_CONST_i(GL_ALPHA_SNORM)
 OGL_CONST_i(GL_ALPHA_TEST)
 OGL_CONST_i(GL_ALPHA_TEST_FUNC)
 OGL_CONST_i(GL_ALPHA_TEST_FUNC_QCOM)
 OGL_CONST_i(GL_ALPHA_TEST_QCOM)
 OGL_CONST_i(GL_ALPHA_TEST_REF)
 OGL_CONST_i(GL_ALPHA_TEST_REF_QCOM)
 OGL_CONST_i(GL_ALPHA_TO_COVERAGE_DITHER_DEFAULT_NV)
 OGL_CONST_i(GL_ALPHA_TO_COVERAGE_DITHER_DISABLE_NV)
 OGL_CONST_i(GL_ALPHA_TO_COVERAGE_DITHER_ENABLE_NV)
 OGL_CONST_i(GL_ALPHA_TO_COVERAGE_DITHER_MODE_NV)
 OGL_CONST_i(GL_ALREADY_SIGNALED)
 OGL_CONST_i(GL_ALREADY_SIGNALED_APPLE)
 OGL_CONST_i(GL_ALWAYS)
 OGL_CONST_i(GL_ALWAYS_FAST_HINT_PGI)
 OGL_CONST_i(GL_ALWAYS_SOFT_HINT_PGI)
 OGL_CONST_i(GL_AMBIENT)
 OGL_CONST_i(GL_AMBIENT_AND_DIFFUSE)
 OGL_CONST_i(GL_AND)
 OGL_CONST_i(GL_AND_INVERTED)
 OGL_CONST_i(GL_AND_REVERSE)
 OGL_CONST_i(GL_ANY_SAMPLES_PASSED)
 OGL_CONST_i(GL_ANY_SAMPLES_PASSED_CONSERVATIVE)
 OGL_CONST_i(GL_ANY_SAMPLES_PASSED_CONSERVATIVE_EXT)
 OGL_CONST_i(GL_ANY_SAMPLES_PASSED_EXT)
 OGL_CONST_i(GL_ARC_TO_NV)
 OGL_CONST_i(GL_ARRAY_BUFFER)
 OGL_CONST_i(GL_ARRAY_BUFFER_ARB)
 OGL_CONST_i(GL_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_ARRAY_ELEMENT_LOCK_COUNT_EXT)
 OGL_CONST_i(GL_ARRAY_ELEMENT_LOCK_FIRST_EXT)
 OGL_CONST_i(GL_ARRAY_OBJECT_BUFFER_ATI)
 OGL_CONST_i(GL_ARRAY_OBJECT_OFFSET_ATI)
 OGL_CONST_i(GL_ARRAY_SIZE)
 OGL_CONST_i(GL_ARRAY_STRIDE)
 OGL_CONST_i(GL_ASYNC_DRAW_PIXELS_SGIX)
 OGL_CONST_i(GL_ASYNC_HISTOGRAM_SGIX)
 OGL_CONST_i(GL_ASYNC_MARKER_SGIX)
 OGL_CONST_i(GL_ASYNC_READ_PIXELS_SGIX)
 OGL_CONST_i(GL_ASYNC_TEX_IMAGE_SGIX)
 OGL_CONST_i(GL_ATC_RGBA_EXPLICIT_ALPHA_AMD)
 OGL_CONST_i(GL_ATC_RGBA_INTERPOLATED_ALPHA_AMD)
 OGL_CONST_i(GL_ATC_RGB_AMD)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BARRIER_BIT)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_BINDING)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_INDEX)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_COMPUTE_SHADER)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_MESH_SHADER_EXT)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_MESH_SHADER_NV)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TASK_SHADER_EXT)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TASK_SHADER_NV)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_SIZE)
 OGL_CONST_i(GL_ATOMIC_COUNTER_BUFFER_START)
 OGL_CONST_i(GL_ATTACHED_MEMORY_OBJECT_NV)
 OGL_CONST_i(GL_ATTACHED_MEMORY_OFFSET_NV)
 OGL_CONST_i(GL_ATTACHED_SHADERS)
 OGL_CONST_i(GL_ATTENUATION_EXT)
 OGL_CONST_i(GL_ATTRIBUTE_ADDRESS_COMMAND_NV)
 OGL_CONST_i(GL_ATTRIB_ARRAY_POINTER_NV)
 OGL_CONST_i(GL_ATTRIB_ARRAY_SIZE_NV)
 OGL_CONST_i(GL_ATTRIB_ARRAY_STRIDE_NV)
 OGL_CONST_i(GL_ATTRIB_ARRAY_TYPE_NV)
 OGL_CONST_i(GL_ATTRIB_STACK_DEPTH)
 OGL_CONST_i(GL_AUTO_GENERATE_MIPMAP)
 OGL_CONST_i(GL_AUTO_NORMAL)
 OGL_CONST_i(GL_AUX0)
 OGL_CONST_i(GL_AUX1)
 OGL_CONST_i(GL_AUX2)
 OGL_CONST_i(GL_AUX3)
 OGL_CONST_i(GL_AUX_BUFFERS)
 OGL_CONST_i(GL_AUX_DEPTH_STENCIL_APPLE)
 OGL_CONST_i(GL_AVERAGE_EXT)
 OGL_CONST_i(GL_BACK)
 OGL_CONST_i(GL_BACK_LEFT)
 OGL_CONST_i(GL_BACK_NORMALS_HINT_PGI)
 OGL_CONST_i(GL_BACK_PRIMARY_COLOR_NV)
 OGL_CONST_i(GL_BACK_RIGHT)
 OGL_CONST_i(GL_BACK_SECONDARY_COLOR_NV)
 OGL_CONST_i(GL_BALI_DEPTH_PASS_INSTRUMENT)
 OGL_CONST_i(GL_BALI_FRAGMENTS_GENERATED_INSTRUMENT)
 OGL_CONST_i(GL_BALI_NUM_PRIMS_CLIPPED_INSTRUMENT)
 OGL_CONST_i(GL_BALI_NUM_PRIMS_CLIP_RESULT_INSTRUMENT)
 OGL_CONST_i(GL_BALI_NUM_PRIMS_REJECT_INSTRUMENT)
 OGL_CONST_i(GL_BALI_NUM_TRIS_CULLED_INSTRUMENT)
 OGL_CONST_i(GL_BALI_R_CHIP_COUNT)
 OGL_CONST_i(GL_BEVEL_NV)
 OGL_CONST_i(GL_BGR)
 OGL_CONST_i(GL_BGRA)
 OGL_CONST_i(GL_BGRA8_EXT)
 OGL_CONST_i(GL_BGRA_EXT)
 OGL_CONST_i(GL_BGRA_IMG)
 OGL_CONST_i(GL_BGRA_INTEGER)
 OGL_CONST_i(GL_BGRA_INTEGER_EXT)
 OGL_CONST_i(GL_BGR_EXT)
 OGL_CONST_i(GL_BGR_INTEGER)
 OGL_CONST_i(GL_BGR_INTEGER_EXT)
 OGL_CONST_i(GL_BGR_NV)
 OGL_CONST_i(GL_BIAS_BIT_ATI)
 OGL_CONST_i(GL_BIAS_BY_NEGATIVE_ONE_HALF_NV)
 OGL_CONST_i(GL_BINNING_CONTROL_HINT_QCOM)
 OGL_CONST_i(GL_BINORMAL_ARRAY_EXT)
 OGL_CONST_i(GL_BINORMAL_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_BINORMAL_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_BINORMAL_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_BITMAP)
 OGL_CONST_i(GL_BITMAP_TOKEN)
 OGL_CONST_i(GL_BLACKHOLE_RENDER_INTEL)
 OGL_CONST_i(GL_BLEND)
 OGL_CONST_i(GL_BLEND_ADVANCED_COHERENT_KHR)
 OGL_CONST_i(GL_BLEND_ADVANCED_COHERENT_NV)
 OGL_CONST_i(GL_BLEND_COLOR)
 OGL_CONST_i(GL_BLEND_COLOR_COMMAND_NV)
 OGL_CONST_i(GL_BLEND_COLOR_EXT)
 OGL_CONST_i(GL_BLEND_DST)
 OGL_CONST_i(GL_BLEND_DST_ALPHA)
 OGL_CONST_i(GL_BLEND_DST_ALPHA_EXT)
 OGL_CONST_i(GL_BLEND_DST_ALPHA_OES)
 OGL_CONST_i(GL_BLEND_DST_RGB)
 OGL_CONST_i(GL_BLEND_DST_RGB_EXT)
 OGL_CONST_i(GL_BLEND_DST_RGB_OES)
 OGL_CONST_i(GL_BLEND_EQUATION)
 OGL_CONST_i(GL_BLEND_EQUATION_ALPHA)
 OGL_CONST_i(GL_BLEND_EQUATION_ALPHA_EXT)
 OGL_CONST_i(GL_BLEND_EQUATION_ALPHA_OES)
 OGL_CONST_i(GL_BLEND_EQUATION_EXT)
 OGL_CONST_i(GL_BLEND_EQUATION_OES)
 OGL_CONST_i(GL_BLEND_EQUATION_RGB)
 OGL_CONST_i(GL_BLEND_EQUATION_RGB_EXT)
 OGL_CONST_i(GL_BLEND_EQUATION_RGB_OES)
 OGL_CONST_i(GL_BLEND_OVERLAP_NV)
 OGL_CONST_i(GL_BLEND_PREMULTIPLIED_SRC_NV)
 OGL_CONST_i(GL_BLEND_SRC)
 OGL_CONST_i(GL_BLEND_SRC_ALPHA)
 OGL_CONST_i(GL_BLEND_SRC_ALPHA_EXT)
 OGL_CONST_i(GL_BLEND_SRC_ALPHA_OES)
 OGL_CONST_i(GL_BLEND_SRC_RGB)
 OGL_CONST_i(GL_BLEND_SRC_RGB_EXT)
 OGL_CONST_i(GL_BLEND_SRC_RGB_OES)
 OGL_CONST_i(GL_BLOCK_INDEX)
 OGL_CONST_i(GL_BLUE)
 OGL_CONST_i(GL_BLUE_BIAS)
 OGL_CONST_i(GL_BLUE_BITS)
 OGL_CONST_i(GL_BLUE_BIT_ATI)
 OGL_CONST_i(GL_BLUE_INTEGER)
 OGL_CONST_i(GL_BLUE_INTEGER_EXT)
 OGL_CONST_i(GL_BLUE_MAX_CLAMP_INGR)
 OGL_CONST_i(GL_BLUE_MIN_CLAMP_INGR)
 OGL_CONST_i(GL_BLUE_NV)
 OGL_CONST_i(GL_BLUE_SCALE)
 OGL_CONST_i(GL_BOLD_BIT_NV)
 OGL_CONST_i(GL_BOOL)
 OGL_CONST_i(GL_BOOL_ARB)
 OGL_CONST_i(GL_BOOL_VEC2)
 OGL_CONST_i(GL_BOOL_VEC2_ARB)
 OGL_CONST_i(GL_BOOL_VEC3)
 OGL_CONST_i(GL_BOOL_VEC3_ARB)
 OGL_CONST_i(GL_BOOL_VEC4)
 OGL_CONST_i(GL_BOOL_VEC4_ARB)
 OGL_CONST_i(GL_BOUNDING_BOX_NV)
 OGL_CONST_i(GL_BOUNDING_BOX_OF_BOUNDING_BOXES_NV)
 OGL_CONST_i(GL_BUFFER)
 OGL_CONST_i(GL_BUFFER_ACCESS)
 OGL_CONST_i(GL_BUFFER_ACCESS_ARB)
 OGL_CONST_i(GL_BUFFER_ACCESS_FLAGS)
 OGL_CONST_i(GL_BUFFER_ACCESS_OES)
 OGL_CONST_i(GL_BUFFER_BINDING)
 OGL_CONST_i(GL_BUFFER_DATA_SIZE)
 OGL_CONST_i(GL_BUFFER_FLUSHING_UNMAP_APPLE)
 OGL_CONST_i(GL_BUFFER_GPU_ADDRESS_NV)
 OGL_CONST_i(GL_BUFFER_IMMUTABLE_STORAGE)
 OGL_CONST_i(GL_BUFFER_IMMUTABLE_STORAGE_EXT)
 OGL_CONST_i(GL_BUFFER_MAPPED)
 OGL_CONST_i(GL_BUFFER_MAPPED_ARB)
 OGL_CONST_i(GL_BUFFER_MAPPED_OES)
 OGL_CONST_i(GL_BUFFER_MAP_LENGTH)
 OGL_CONST_i(GL_BUFFER_MAP_OFFSET)
 OGL_CONST_i(GL_BUFFER_MAP_POINTER)
 OGL_CONST_i(GL_BUFFER_MAP_POINTER_ARB)
 OGL_CONST_i(GL_BUFFER_MAP_POINTER_OES)
 OGL_CONST_i(GL_BUFFER_OBJECT_APPLE)
 OGL_CONST_i(GL_BUFFER_OBJECT_EXT)
 OGL_CONST_i(GL_BUFFER_SERIALIZED_MODIFY_APPLE)
 OGL_CONST_i(GL_BUFFER_SIZE)
 OGL_CONST_i(GL_BUFFER_SIZE_ARB)
 OGL_CONST_i(GL_BUFFER_STORAGE_FLAGS)
 OGL_CONST_i(GL_BUFFER_STORAGE_FLAGS_EXT)
 OGL_CONST_i(GL_BUFFER_UPDATE_BARRIER_BIT)
 OGL_CONST_i(GL_BUFFER_UPDATE_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_BUFFER_USAGE)
 OGL_CONST_i(GL_BUFFER_USAGE_ARB)
 OGL_CONST_i(GL_BUFFER_VARIABLE)
 OGL_CONST_i(GL_BUMP_ENVMAP_ATI)
 OGL_CONST_i(GL_BUMP_NUM_TEX_UNITS_ATI)
 OGL_CONST_i(GL_BUMP_ROT_MATRIX_ATI)
 OGL_CONST_i(GL_BUMP_ROT_MATRIX_SIZE_ATI)
 OGL_CONST_i(GL_BUMP_TARGET_ATI)
 OGL_CONST_i(GL_BUMP_TEX_UNITS_ATI)
 OGL_CONST_i(GL_BYTE)
 OGL_CONST_i(GL_C3F_V3F)
 OGL_CONST_i(GL_C4F_N3F_V3F)
 OGL_CONST_i(GL_C4UB_V2F)
 OGL_CONST_i(GL_C4UB_V3F)
 OGL_CONST_i(GL_CACHE_REGAL)
 OGL_CONST_i(GL_CAVEAT_SUPPORT)
 OGL_CONST_i(GL_CCW)
 OGL_CONST_i(GL_CG_FRAGMENT_SHADER_EXT)
 OGL_CONST_i(GL_CG_VERTEX_SHADER_EXT)
 OGL_CONST_i(GL_CIRCULAR_CCW_ARC_TO_NV)
 OGL_CONST_i(GL_CIRCULAR_CW_ARC_TO_NV)
 OGL_CONST_i(GL_CIRCULAR_TANGENT_ARC_TO_NV)
 OGL_CONST_i(GL_CLAMP)
 OGL_CONST_i(GL_CLAMP_FRAGMENT_COLOR)
 OGL_CONST_i(GL_CLAMP_FRAGMENT_COLOR_ARB)
 OGL_CONST_i(GL_CLAMP_READ_COLOR)
 OGL_CONST_i(GL_CLAMP_READ_COLOR_ARB)
 OGL_CONST_i(GL_CLAMP_TO_BORDER)
 OGL_CONST_i(GL_CLAMP_TO_BORDER_ARB)
 OGL_CONST_i(GL_CLAMP_TO_BORDER_EXT)
 OGL_CONST_i(GL_CLAMP_TO_BORDER_NV)
 OGL_CONST_i(GL_CLAMP_TO_BORDER_OES)
 OGL_CONST_i(GL_CLAMP_TO_BORDER_SGIS)
 OGL_CONST_i(GL_CLAMP_TO_EDGE)
 OGL_CONST_i(GL_CLAMP_TO_EDGE_EXT)
 OGL_CONST_i(GL_CLAMP_TO_EDGE_SGIS)
 OGL_CONST_i(GL_CLAMP_VERTEX_COLOR)
 OGL_CONST_i(GL_CLAMP_VERTEX_COLOR_ARB)
 OGL_CONST_i(GL_CLEAR)
 OGL_CONST_i(GL_CLEAR_BUFFER)
 OGL_CONST_i(GL_CLEAR_TEXTURE)
 OGL_CONST_i(GL_CLIENT_ACTIVE_TEXTURE)
 OGL_CONST_i(GL_CLIENT_ACTIVE_TEXTURE_ARB)
 OGL_CONST_i(GL_CLIENT_ALL_ATTRIB_BITS)
 OGL_CONST_i(GL_CLIENT_ATTRIB_STACK_DEPTH)
 OGL_CONST_i(GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT)
 OGL_CONST_i(GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_CLIENT_PIXEL_STORE_BIT)
 OGL_CONST_i(GL_CLIENT_STORAGE_BIT)
 OGL_CONST_i(GL_CLIENT_STORAGE_BIT_EXT)
 OGL_CONST_i(GL_CLIENT_VERTEX_ARRAY_BIT)
 OGL_CONST_i(GL_CLIPPING_INPUT_PRIMITIVES)
 OGL_CONST_i(GL_CLIPPING_INPUT_PRIMITIVES_ARB)
 OGL_CONST_i(GL_CLIPPING_OUTPUT_PRIMITIVES)
 OGL_CONST_i(GL_CLIPPING_OUTPUT_PRIMITIVES_ARB)
 OGL_CONST_i(GL_CLIP_DEPTH_MODE)
 OGL_CONST_i(GL_CLIP_DEPTH_MODE_EXT)
 OGL_CONST_i(GL_CLIP_DISTANCE0)
 OGL_CONST_i(GL_CLIP_DISTANCE0_APPLE)
 OGL_CONST_i(GL_CLIP_DISTANCE0_EXT)
 OGL_CONST_i(GL_CLIP_DISTANCE1)
 OGL_CONST_i(GL_CLIP_DISTANCE1_APPLE)
 OGL_CONST_i(GL_CLIP_DISTANCE1_EXT)
 OGL_CONST_i(GL_CLIP_DISTANCE2)
 OGL_CONST_i(GL_CLIP_DISTANCE2_APPLE)
 OGL_CONST_i(GL_CLIP_DISTANCE2_EXT)
 OGL_CONST_i(GL_CLIP_DISTANCE3)
 OGL_CONST_i(GL_CLIP_DISTANCE3_APPLE)
 OGL_CONST_i(GL_CLIP_DISTANCE3_EXT)
 OGL_CONST_i(GL_CLIP_DISTANCE4)
 OGL_CONST_i(GL_CLIP_DISTANCE4_APPLE)
 OGL_CONST_i(GL_CLIP_DISTANCE4_EXT)
 OGL_CONST_i(GL_CLIP_DISTANCE5)
 OGL_CONST_i(GL_CLIP_DISTANCE5_APPLE)
 OGL_CONST_i(GL_CLIP_DISTANCE5_EXT)
 OGL_CONST_i(GL_CLIP_DISTANCE6_APPLE)
 OGL_CONST_i(GL_CLIP_DISTANCE6_EXT)
 OGL_CONST_i(GL_CLIP_DISTANCE7_APPLE)
 OGL_CONST_i(GL_CLIP_DISTANCE7_EXT)
 OGL_CONST_i(GL_CLIP_DISTANCE_NV)
 OGL_CONST_i(GL_CLIP_FAR_HINT_PGI)
 OGL_CONST_i(GL_CLIP_NEAR_HINT_PGI)
 OGL_CONST_i(GL_CLIP_ORIGIN)
 OGL_CONST_i(GL_CLIP_ORIGIN_EXT)
 OGL_CONST_i(GL_CLIP_PLANE0)
 OGL_CONST_i(GL_CLIP_PLANE1)
 OGL_CONST_i(GL_CLIP_PLANE2)
 OGL_CONST_i(GL_CLIP_PLANE3)
 OGL_CONST_i(GL_CLIP_PLANE4)
 OGL_CONST_i(GL_CLIP_PLANE5)
 OGL_CONST_i(GL_CLIP_VOLUME_CLIPPING_HINT_EXT)
 OGL_CONST_i(GL_CLOSE_PATH_NV)
 OGL_CONST_i(GL_CMYKA_EXT)
 OGL_CONST_i(GL_CMYK_EXT)
 OGL_CONST_i(GL_CND0_ATI)
 OGL_CONST_i(GL_CND_ATI)
 OGL_CONST_i(GL_CODE_REGAL)
 OGL_CONST_i(GL_COEFF)
 OGL_CONST_i(GL_COLOR)
 OGL_CONST_i(GL_COLOR3_BIT_PGI)
 OGL_CONST_i(GL_COLOR4_BIT_PGI)
 OGL_CONST_i(GL_COLORBURN_KHR)
 OGL_CONST_i(GL_COLORBURN_NV)
 OGL_CONST_i(GL_COLORDODGE_KHR)
 OGL_CONST_i(GL_COLORDODGE_NV)
 OGL_CONST_i(GL_COLOR_ALPHA_PAIRING_ATI)
 OGL_CONST_i(GL_COLOR_ARRAY)
 OGL_CONST_i(GL_COLOR_ARRAY_ADDRESS_NV)
 OGL_CONST_i(GL_COLOR_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_COLOR_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_COLOR_ARRAY_COUNT_EXT)
 OGL_CONST_i(GL_COLOR_ARRAY_EXT)
 OGL_CONST_i(GL_COLOR_ARRAY_LENGTH_NV)
 OGL_CONST_i(GL_COLOR_ARRAY_LIST_IBM)
 OGL_CONST_i(GL_COLOR_ARRAY_LIST_STRIDE_IBM)
 OGL_CONST_i(GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL)
 OGL_CONST_i(GL_COLOR_ARRAY_POINTER)
 OGL_CONST_i(GL_COLOR_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_COLOR_ARRAY_SIZE)
 OGL_CONST_i(GL_COLOR_ARRAY_SIZE_EXT)
 OGL_CONST_i(GL_COLOR_ARRAY_STRIDE)
 OGL_CONST_i(GL_COLOR_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_COLOR_ARRAY_TYPE)
 OGL_CONST_i(GL_COLOR_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT0)
 OGL_CONST_i(GL_COLOR_ATTACHMENT0_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT0_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT0_OES)
 OGL_CONST_i(GL_COLOR_ATTACHMENT1)
 OGL_CONST_i(GL_COLOR_ATTACHMENT10)
 OGL_CONST_i(GL_COLOR_ATTACHMENT10_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT10_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT11)
 OGL_CONST_i(GL_COLOR_ATTACHMENT11_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT11_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT12)
 OGL_CONST_i(GL_COLOR_ATTACHMENT12_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT12_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT13)
 OGL_CONST_i(GL_COLOR_ATTACHMENT13_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT13_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT14)
 OGL_CONST_i(GL_COLOR_ATTACHMENT14_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT14_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT15)
 OGL_CONST_i(GL_COLOR_ATTACHMENT15_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT15_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT1_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT1_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT2)
 OGL_CONST_i(GL_COLOR_ATTACHMENT2_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT2_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT3)
 OGL_CONST_i(GL_COLOR_ATTACHMENT3_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT3_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT4)
 OGL_CONST_i(GL_COLOR_ATTACHMENT4_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT4_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT5)
 OGL_CONST_i(GL_COLOR_ATTACHMENT5_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT5_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT6)
 OGL_CONST_i(GL_COLOR_ATTACHMENT6_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT6_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT7)
 OGL_CONST_i(GL_COLOR_ATTACHMENT7_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT7_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT8)
 OGL_CONST_i(GL_COLOR_ATTACHMENT8_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT8_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT9)
 OGL_CONST_i(GL_COLOR_ATTACHMENT9_EXT)
 OGL_CONST_i(GL_COLOR_ATTACHMENT9_NV)
 OGL_CONST_i(GL_COLOR_ATTACHMENT_EXT)
 OGL_CONST_i(GL_COLOR_BUFFER_BIT)
 OGL_CONST_i(GL_COLOR_BUFFER_BIT0_QCOM)
 OGL_CONST_i(GL_COLOR_BUFFER_BIT1_QCOM)
 OGL_CONST_i(GL_COLOR_BUFFER_BIT2_QCOM)
 OGL_CONST_i(GL_COLOR_BUFFER_BIT3_QCOM)
 OGL_CONST_i(GL_COLOR_BUFFER_BIT4_QCOM)
 OGL_CONST_i(GL_COLOR_BUFFER_BIT5_QCOM)
 OGL_CONST_i(GL_COLOR_BUFFER_BIT6_QCOM)
 OGL_CONST_i(GL_COLOR_BUFFER_BIT7_QCOM)
 OGL_CONST_i(GL_COLOR_CLEAR_VALUE)
 OGL_CONST_i(GL_COLOR_COMPONENTS)
 OGL_CONST_i(GL_COLOR_ENCODING)
 OGL_CONST_i(GL_COLOR_EXT)
 OGL_CONST_i(GL_COLOR_FLOAT_APPLE)
 OGL_CONST_i(GL_COLOR_INDEX)
 OGL_CONST_i(GL_COLOR_INDEX12_EXT)
 OGL_CONST_i(GL_COLOR_INDEX16_EXT)
 OGL_CONST_i(GL_COLOR_INDEX1_EXT)
 OGL_CONST_i(GL_COLOR_INDEX2_EXT)
 OGL_CONST_i(GL_COLOR_INDEX4_EXT)
 OGL_CONST_i(GL_COLOR_INDEX8_EXT)
 OGL_CONST_i(GL_COLOR_INDEXES)
 OGL_CONST_i(GL_COLOR_LOGIC_OP)
 OGL_CONST_i(GL_COLOR_MATERIAL)
 OGL_CONST_i(GL_COLOR_MATERIAL_FACE)
 OGL_CONST_i(GL_COLOR_MATERIAL_PARAMETER)
 OGL_CONST_i(GL_COLOR_MATRIX)
 OGL_CONST_i(GL_COLOR_MATRIX_HINT)
 OGL_CONST_i(GL_COLOR_MATRIX_SGI)
 OGL_CONST_i(GL_COLOR_MATRIX_STACK_DEPTH)
 OGL_CONST_i(GL_COLOR_MATRIX_STACK_DEPTH_SGI)
 OGL_CONST_i(GL_COLOR_RENDERABLE)
 OGL_CONST_i(GL_COLOR_SAMPLES_NV)
 OGL_CONST_i(GL_COLOR_SUM)
 OGL_CONST_i(GL_COLOR_SUM_ARB)
 OGL_CONST_i(GL_COLOR_SUM_CLAMP_NV)
 OGL_CONST_i(GL_COLOR_SUM_EXT)
 OGL_CONST_i(GL_COLOR_TABLE)
 OGL_CONST_i(GL_COLOR_TABLE_ALPHA_SIZE)
 OGL_CONST_i(GL_COLOR_TABLE_ALPHA_SIZE_EXT)
 OGL_CONST_i(GL_COLOR_TABLE_ALPHA_SIZE_SGI)
 OGL_CONST_i(GL_COLOR_TABLE_BIAS)
 OGL_CONST_i(GL_COLOR_TABLE_BIAS_SGI)
 OGL_CONST_i(GL_COLOR_TABLE_BLUE_SIZE)
 OGL_CONST_i(GL_COLOR_TABLE_BLUE_SIZE_EXT)
 OGL_CONST_i(GL_COLOR_TABLE_BLUE_SIZE_SGI)
 OGL_CONST_i(GL_COLOR_TABLE_FORMAT)
 OGL_CONST_i(GL_COLOR_TABLE_FORMAT_EXT)
 OGL_CONST_i(GL_COLOR_TABLE_FORMAT_SGI)
 OGL_CONST_i(GL_COLOR_TABLE_GREEN_SIZE)
 OGL_CONST_i(GL_COLOR_TABLE_GREEN_SIZE_EXT)
 OGL_CONST_i(GL_COLOR_TABLE_GREEN_SIZE_SGI)
 OGL_CONST_i(GL_COLOR_TABLE_INTENSITY_SIZE)
 OGL_CONST_i(GL_COLOR_TABLE_INTENSITY_SIZE_EXT)
 OGL_CONST_i(GL_COLOR_TABLE_INTENSITY_SIZE_SGI)
 OGL_CONST_i(GL_COLOR_TABLE_LUMINANCE_SIZE)
 OGL_CONST_i(GL_COLOR_TABLE_LUMINANCE_SIZE_EXT)
 OGL_CONST_i(GL_COLOR_TABLE_LUMINANCE_SIZE_SGI)
 OGL_CONST_i(GL_COLOR_TABLE_RED_SIZE)
 OGL_CONST_i(GL_COLOR_TABLE_RED_SIZE_EXT)
 OGL_CONST_i(GL_COLOR_TABLE_RED_SIZE_SGI)
 OGL_CONST_i(GL_COLOR_TABLE_SCALE)
 OGL_CONST_i(GL_COLOR_TABLE_SCALE_SGI)
 OGL_CONST_i(GL_COLOR_TABLE_SGI)
 OGL_CONST_i(GL_COLOR_TABLE_WIDTH)
 OGL_CONST_i(GL_COLOR_TABLE_WIDTH_EXT)
 OGL_CONST_i(GL_COLOR_TABLE_WIDTH_SGI)
 OGL_CONST_i(GL_COLOR_WRITEMASK)
 OGL_CONST_i(GL_COMBINE)
 OGL_CONST_i(GL_COMBINE4_NV)
 OGL_CONST_i(GL_COMBINER0_NV)
 OGL_CONST_i(GL_COMBINER1_NV)
 OGL_CONST_i(GL_COMBINER2_NV)
 OGL_CONST_i(GL_COMBINER3_NV)
 OGL_CONST_i(GL_COMBINER4_NV)
 OGL_CONST_i(GL_COMBINER5_NV)
 OGL_CONST_i(GL_COMBINER6_NV)
 OGL_CONST_i(GL_COMBINER7_NV)
 OGL_CONST_i(GL_COMBINER_AB_DOT_PRODUCT_NV)
 OGL_CONST_i(GL_COMBINER_AB_OUTPUT_NV)
 OGL_CONST_i(GL_COMBINER_BIAS_NV)
 OGL_CONST_i(GL_COMBINER_CD_DOT_PRODUCT_NV)
 OGL_CONST_i(GL_COMBINER_CD_OUTPUT_NV)
 OGL_CONST_i(GL_COMBINER_COMPONENT_USAGE_NV)
 OGL_CONST_i(GL_COMBINER_INPUT_NV)
 OGL_CONST_i(GL_COMBINER_MAPPING_NV)
 OGL_CONST_i(GL_COMBINER_MUX_SUM_NV)
 OGL_CONST_i(GL_COMBINER_SCALE_NV)
 OGL_CONST_i(GL_COMBINER_SUM_OUTPUT_NV)
 OGL_CONST_i(GL_COMBINE_ALPHA)
 OGL_CONST_i(GL_COMBINE_ALPHA_ARB)
 OGL_CONST_i(GL_COMBINE_ALPHA_EXT)
 OGL_CONST_i(GL_COMBINE_ARB)
 OGL_CONST_i(GL_COMBINE_EXT)
 OGL_CONST_i(GL_COMBINE_RGB)
 OGL_CONST_i(GL_COMBINE_RGB_ARB)
 OGL_CONST_i(GL_COMBINE_RGB_EXT)
 OGL_CONST_i(GL_COMMAND_BARRIER_BIT)
 OGL_CONST_i(GL_COMMAND_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_COMPARE_REF_DEPTH_TO_TEXTURE_EXT)
 OGL_CONST_i(GL_COMPARE_REF_TO_TEXTURE)
 OGL_CONST_i(GL_COMPARE_REF_TO_TEXTURE_EXT)
 OGL_CONST_i(GL_COMPARE_R_TO_TEXTURE)
 OGL_CONST_i(GL_COMPARE_R_TO_TEXTURE_ARB)
 OGL_CONST_i(GL_COMPATIBLE_SUBROUTINES)
 OGL_CONST_i(GL_COMPILE)
 OGL_CONST_i(GL_COMPILE_AND_EXECUTE)
 OGL_CONST_i(GL_COMPILE_STATUS)
 OGL_CONST_i(GL_COMPLETION_STATUS_ARB)
 OGL_CONST_i(GL_COMPLETION_STATUS_KHR)
 OGL_CONST_i(GL_COMPLEX_BYTE_SGI)
 OGL_CONST_i(GL_COMPLEX_FLOAT_SGI)
 OGL_CONST_i(GL_COMPLEX_INT_SGI)
 OGL_CONST_i(GL_COMPLEX_SHORT_SGI)
 OGL_CONST_i(GL_COMPLEX_UNSIGNED_BYTE_SGI)
 OGL_CONST_i(GL_COMPLEX_UNSIGNED_INT_SGI)
 OGL_CONST_i(GL_COMPLEX_UNSIGNED_SHORT_SGI)
 OGL_CONST_i(GL_COMPRESSED_ALPHA)
 OGL_CONST_i(GL_COMPRESSED_ALPHA_ARB)
 OGL_CONST_i(GL_COMPRESSED_INTENSITY)
 OGL_CONST_i(GL_COMPRESSED_INTENSITY_ARB)
 OGL_CONST_i(GL_COMPRESSED_LUMINANCE)
 OGL_CONST_i(GL_COMPRESSED_LUMINANCE_ALPHA)
 OGL_CONST_i(GL_COMPRESSED_LUMINANCE_ALPHA_3DC_ATI)
 OGL_CONST_i(GL_COMPRESSED_LUMINANCE_ALPHA_ARB)
 OGL_CONST_i(GL_COMPRESSED_LUMINANCE_ALPHA_LATC2_EXT)
 OGL_CONST_i(GL_COMPRESSED_LUMINANCE_ALPHA_LATC2_NV)
 OGL_CONST_i(GL_COMPRESSED_LUMINANCE_ARB)
 OGL_CONST_i(GL_COMPRESSED_LUMINANCE_LATC1_EXT)
 OGL_CONST_i(GL_COMPRESSED_LUMINANCE_LATC1_NV)
 OGL_CONST_i(GL_COMPRESSED_R11_EAC)
 OGL_CONST_i(GL_COMPRESSED_RED)
 OGL_CONST_i(GL_COMPRESSED_RED_GREEN_RGTC2_EXT)
 OGL_CONST_i(GL_COMPRESSED_RED_RGTC1)
 OGL_CONST_i(GL_COMPRESSED_RED_RGTC1_EXT)
 OGL_CONST_i(GL_COMPRESSED_RG)
 OGL_CONST_i(GL_COMPRESSED_RG11_EAC)
 OGL_CONST_i(GL_COMPRESSED_RGB)
 OGL_CONST_i(GL_COMPRESSED_RGB8_ETC2)
 OGL_CONST_i(GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2)
 OGL_CONST_i(GL_COMPRESSED_RGBA)
 OGL_CONST_i(GL_COMPRESSED_RGBA8_ETC2_EAC)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ARB)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_10x10_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_10x5_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_10x6_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_10x8_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_12x10_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_12x12_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_3x3x3_OES)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_4x3x3_OES)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_4x4_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_4x4x3_OES)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_4x4x4_OES)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_5x4_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_5x4x4_OES)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_5x5_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_5x5x4_OES)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_5x5x5_OES)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_6x5_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_6x5x5_OES)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_6x6_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_6x6x5_OES)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_6x6x6_OES)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_8x5_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_8x6_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_ASTC_8x8_KHR)
 OGL_CONST_i(GL_COMPRESSED_RGBA_BPTC_UNORM)
 OGL_CONST_i(GL_COMPRESSED_RGBA_BPTC_UNORM_ARB)
 OGL_CONST_i(GL_COMPRESSED_RGBA_BPTC_UNORM_EXT)
 OGL_CONST_i(GL_COMPRESSED_RGBA_FXT1_3DFX)
 OGL_CONST_i(GL_COMPRESSED_RGBA_PVRTC_2BPPV1_IMG)
 OGL_CONST_i(GL_COMPRESSED_RGBA_PVRTC_2BPPV2_IMG)
 OGL_CONST_i(GL_COMPRESSED_RGBA_PVRTC_4BPPV1_IMG)
 OGL_CONST_i(GL_COMPRESSED_RGBA_PVRTC_4BPPV2_IMG)
 OGL_CONST_i(GL_COMPRESSED_RGBA_S3TC_DXT1_ANGLE)
 OGL_CONST_i(GL_COMPRESSED_RGBA_S3TC_DXT1_EXT)
 OGL_CONST_i(GL_COMPRESSED_RGBA_S3TC_DXT1_NV)
 OGL_CONST_i(GL_COMPRESSED_RGBA_S3TC_DXT3_ANGLE)
 OGL_CONST_i(GL_COMPRESSED_RGBA_S3TC_DXT3_EXT)
 OGL_CONST_i(GL_COMPRESSED_RGBA_S3TC_DXT3_NV)
 OGL_CONST_i(GL_COMPRESSED_RGBA_S3TC_DXT5_ANGLE)
 OGL_CONST_i(GL_COMPRESSED_RGBA_S3TC_DXT5_EXT)
 OGL_CONST_i(GL_COMPRESSED_RGBA_S3TC_DXT5_NV)
 OGL_CONST_i(GL_COMPRESSED_RGB_ARB)
 OGL_CONST_i(GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT)
 OGL_CONST_i(GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT_ARB)
 OGL_CONST_i(GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT_EXT)
 OGL_CONST_i(GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT)
 OGL_CONST_i(GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT_ARB)
 OGL_CONST_i(GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT_EXT)
 OGL_CONST_i(GL_COMPRESSED_RGB_FXT1_3DFX)
 OGL_CONST_i(GL_COMPRESSED_RGB_PVRTC_2BPPV1_IMG)
 OGL_CONST_i(GL_COMPRESSED_RGB_PVRTC_4BPPV1_IMG)
 OGL_CONST_i(GL_COMPRESSED_RGB_S3TC_DXT1_ANGLE)
 OGL_CONST_i(GL_COMPRESSED_RGB_S3TC_DXT1_EXT)
 OGL_CONST_i(GL_COMPRESSED_RGB_S3TC_DXT1_NV)
 OGL_CONST_i(GL_COMPRESSED_RG_RGTC2)
 OGL_CONST_i(GL_COMPRESSED_SIGNED_LUMINANCE_ALPHA_LATC2_EXT)
 OGL_CONST_i(GL_COMPRESSED_SIGNED_LUMINANCE_ALPHA_LATC2_NV)
 OGL_CONST_i(GL_COMPRESSED_SIGNED_LUMINANCE_LATC1_EXT)
 OGL_CONST_i(GL_COMPRESSED_SIGNED_LUMINANCE_LATC1_NV)
 OGL_CONST_i(GL_COMPRESSED_SIGNED_R11_EAC)
 OGL_CONST_i(GL_COMPRESSED_SIGNED_RED_GREEN_RGTC2_EXT)
 OGL_CONST_i(GL_COMPRESSED_SIGNED_RED_RGTC1)
 OGL_CONST_i(GL_COMPRESSED_SIGNED_RED_RGTC1_EXT)
 OGL_CONST_i(GL_COMPRESSED_SIGNED_RG11_EAC)
 OGL_CONST_i(GL_COMPRESSED_SIGNED_RG_RGTC2)
 OGL_CONST_i(GL_COMPRESSED_SLUMINANCE)
 OGL_CONST_i(GL_COMPRESSED_SLUMINANCE_ALPHA)
 OGL_CONST_i(GL_COMPRESSED_SLUMINANCE_ALPHA_EXT)
 OGL_CONST_i(GL_COMPRESSED_SLUMINANCE_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_3x3x3_OES)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x3x3_OES)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4x3_OES)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4x4_OES)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4x4_OES)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5x4_OES)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5x5_OES)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5x5_OES)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6x5_OES)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6x6_OES)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_ETC2)
 OGL_CONST_i(GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM_ARB)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_PVRTC_2BPPV1_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_PVRTC_4BPPV1_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV)
 OGL_CONST_i(GL_COMPRESSED_SRGB_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_PVRTC_2BPPV1_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_PVRTC_4BPPV1_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_S3TC_DXT1_EXT)
 OGL_CONST_i(GL_COMPRESSED_SRGB_S3TC_DXT1_NV)
 OGL_CONST_i(GL_COMPRESSED_TEXTURE_FORMATS)
 OGL_CONST_i(GL_COMPRESSED_TEXTURE_FORMATS_ARB)
 OGL_CONST_i(GL_COMPUTE_PROGRAM_NV)
 OGL_CONST_i(GL_COMPUTE_PROGRAM_PARAMETER_BUFFER_NV)
 OGL_CONST_i(GL_COMPUTE_SHADER)
 OGL_CONST_i(GL_COMPUTE_SHADER_BIT)
 OGL_CONST_i(GL_COMPUTE_SHADER_INVOCATIONS)
 OGL_CONST_i(GL_COMPUTE_SHADER_INVOCATIONS_ARB)
 OGL_CONST_i(GL_COMPUTE_SUBROUTINE)
 OGL_CONST_i(GL_COMPUTE_SUBROUTINE_UNIFORM)
 OGL_CONST_i(GL_COMPUTE_TEXTURE)
 OGL_CONST_i(GL_COMPUTE_WORK_GROUP_SIZE)
 OGL_CONST_i(GL_COMP_BIT_ATI)
 OGL_CONST_i(GL_CONDITION_SATISFIED)
 OGL_CONST_i(GL_CONDITION_SATISFIED_APPLE)
 OGL_CONST_i(GL_CONFORMANT_NV)
 OGL_CONST_i(GL_CONIC_CURVE_TO_NV)
 OGL_CONST_i(GL_CONJOINT_NV)
 OGL_CONST_i(GL_CONSERVATIVE_RASTERIZATION_INTEL)
 OGL_CONST_i(GL_CONSERVATIVE_RASTERIZATION_NV)
 OGL_CONST_i(GL_CONSERVATIVE_RASTER_DILATE_GRANULARITY_NV)
 OGL_CONST_i(GL_CONSERVATIVE_RASTER_DILATE_NV)
 OGL_CONST_i(GL_CONSERVATIVE_RASTER_DILATE_RANGE_NV)
 OGL_CONST_i(GL_CONSERVATIVE_RASTER_MODE_NV)
 OGL_CONST_i(GL_CONSERVATIVE_RASTER_MODE_POST_SNAP_NV)
 OGL_CONST_i(GL_CONSERVATIVE_RASTER_MODE_PRE_SNAP_NV)
 OGL_CONST_i(GL_CONSERVATIVE_RASTER_MODE_PRE_SNAP_TRIANGLES_NV)
 OGL_CONST_i(GL_CONSERVE_MEMORY_HINT_PGI)
 OGL_CONST_i(GL_CONSTANT)
 OGL_CONST_i(GL_CONSTANT_ALPHA)
 OGL_CONST_i(GL_CONSTANT_ALPHA_EXT)
 OGL_CONST_i(GL_CONSTANT_ARB)
 OGL_CONST_i(GL_CONSTANT_ATTENUATION)
 OGL_CONST_i(GL_CONSTANT_BORDER)
 OGL_CONST_i(GL_CONSTANT_COLOR)
 OGL_CONST_i(GL_CONSTANT_COLOR0_NV)
 OGL_CONST_i(GL_CONSTANT_COLOR1_NV)
 OGL_CONST_i(GL_CONSTANT_COLOR_EXT)
 OGL_CONST_i(GL_CONSTANT_EXT)
 OGL_CONST_i(GL_CONST_BW_TILING_MESA)
 OGL_CONST_i(GL_CONST_EYE_NV)
 OGL_CONST_i(GL_CONTEXT_COMPATIBILITY_PROFILE_BIT)
 OGL_CONST_i(GL_CONTEXT_CORE_PROFILE_BIT)
 OGL_CONST_i(GL_CONTEXT_FLAGS)
 OGL_CONST_i(GL_CONTEXT_FLAG_DEBUG_BIT)
 OGL_CONST_i(GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT)
 OGL_CONST_i(GL_CONTEXT_FLAG_NO_ERROR_BIT)
 OGL_CONST_i(GL_CONTEXT_FLAG_NO_ERROR_BIT_KHR)
 OGL_CONST_i(GL_CONTEXT_FLAG_PROTECTED_CONTENT_BIT_EXT)
 OGL_CONST_i(GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT)
 OGL_CONST_i(GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT_ARB)
 OGL_CONST_i(GL_CONTEXT_LOST)
 OGL_CONST_i(GL_CONTEXT_PROFILE_MASK)
 OGL_CONST_i(GL_CONTEXT_RELEASE_BEHAVIOR)
 OGL_CONST_i(GL_CONTEXT_RELEASE_BEHAVIOR_FLUSH)
 OGL_CONST_i(GL_CONTEXT_ROBUST_ACCESS)
 OGL_CONST_i(GL_CONTEXT_ROBUST_ACCESS_EXT)
 OGL_CONST_i(GL_CONTINUOUS_AMD)
 OGL_CONST_i(GL_CONTRAST_NV)
 OGL_CONST_i(GL_CONVEX_HULL_NV)
 OGL_CONST_i(GL_CONVOLUTION_1D)
 OGL_CONST_i(GL_CONVOLUTION_1D_EXT)
 OGL_CONST_i(GL_CONVOLUTION_2D)
 OGL_CONST_i(GL_CONVOLUTION_2D_EXT)
 OGL_CONST_i(GL_CONVOLUTION_BORDER_COLOR)
 OGL_CONST_i(GL_CONVOLUTION_BORDER_MODE)
 OGL_CONST_i(GL_CONVOLUTION_BORDER_MODE_EXT)
 OGL_CONST_i(GL_CONVOLUTION_FILTER_BIAS)
 OGL_CONST_i(GL_CONVOLUTION_FILTER_BIAS_EXT)
 OGL_CONST_i(GL_CONVOLUTION_FILTER_SCALE)
 OGL_CONST_i(GL_CONVOLUTION_FILTER_SCALE_EXT)
 OGL_CONST_i(GL_CONVOLUTION_FORMAT)
 OGL_CONST_i(GL_CONVOLUTION_FORMAT_EXT)
 OGL_CONST_i(GL_CONVOLUTION_HEIGHT)
 OGL_CONST_i(GL_CONVOLUTION_HEIGHT_EXT)
 OGL_CONST_i(GL_CONVOLUTION_HINT_SGIX)
 OGL_CONST_i(GL_CONVOLUTION_SGI)
 OGL_CONST_i(GL_CONVOLUTION_WIDTH)
 OGL_CONST_i(GL_CONVOLUTION_WIDTH_EXT)
 OGL_CONST_i(GL_CON_0_ATI)
 OGL_CONST_i(GL_CON_1_ATI)
 OGL_CONST_i(GL_CON_2_ATI)
 OGL_CONST_i(GL_CON_3_ATI)
 OGL_CONST_i(GL_CON_4_ATI)
 OGL_CONST_i(GL_CON_5_ATI)
 OGL_CONST_i(GL_CON_6_ATI)
 OGL_CONST_i(GL_CON_7_ATI)
 OGL_CONST_i(GL_COORD_REPLACE)
 OGL_CONST_i(GL_COORD_REPLACE_ARB)
 OGL_CONST_i(GL_COORD_REPLACE_NV)
 OGL_CONST_i(GL_COORD_REPLACE_OES)
 OGL_CONST_i(GL_COPY)
 OGL_CONST_i(GL_COPY_INVERTED)
 OGL_CONST_i(GL_COPY_PIXEL_TOKEN)
 OGL_CONST_i(GL_COPY_READ_BUFFER)
 OGL_CONST_i(GL_COPY_READ_BUFFER_BINDING)
 OGL_CONST_i(GL_COPY_READ_BUFFER_NV)
 OGL_CONST_i(GL_COPY_WRITE_BUFFER)
 OGL_CONST_i(GL_COPY_WRITE_BUFFER_BINDING)
 OGL_CONST_i(GL_COPY_WRITE_BUFFER_NV)
 OGL_CONST_i(GL_COUNTER_RANGE_AMD)
 OGL_CONST_i(GL_COUNTER_TYPE_AMD)
 OGL_CONST_i(GL_COUNT_DOWN_NV)
 OGL_CONST_i(GL_COUNT_UP_NV)
 OGL_CONST_i(GL_COVERAGE_MODULATION_NV)
 OGL_CONST_i(GL_COVERAGE_MODULATION_TABLE_NV)
 OGL_CONST_i(GL_COVERAGE_MODULATION_TABLE_SIZE_NV)
 OGL_CONST_i(GL_CPU_OPTIMIZED_QCOM)
 OGL_CONST_i(GL_CUBE_MAP_BINDING_SGIX)
 OGL_CONST_i(GL_CUBE_MAP_SGIX)
 OGL_CONST_i(GL_CUBE_MAP_XN_SGIX)
 OGL_CONST_i(GL_CUBE_MAP_XP_SGIX)
 OGL_CONST_i(GL_CUBE_MAP_YN_SGIX)
 OGL_CONST_i(GL_CUBE_MAP_YP_SGIX)
 OGL_CONST_i(GL_CUBE_MAP_ZN_SGIX)
 OGL_CONST_i(GL_CUBE_MAP_ZP_SGIX)
 OGL_CONST_i(GL_CUBIC_CURVE_TO_NV)
 OGL_CONST_i(GL_CUBIC_EXT)
 OGL_CONST_i(GL_CUBIC_IMG)
 OGL_CONST_i(GL_CUBIC_MIPMAP_LINEAR_IMG)
 OGL_CONST_i(GL_CUBIC_MIPMAP_NEAREST_IMG)
 OGL_CONST_i(GL_CULL_FACE)
 OGL_CONST_i(GL_CULL_FACE_MODE)
 OGL_CONST_i(GL_CULL_FRAGMENT_NV)
 OGL_CONST_i(GL_CULL_MODES_NV)
 OGL_CONST_i(GL_CULL_VERTEX_EXT)
 OGL_CONST_i(GL_CULL_VERTEX_EYE_POSITION_EXT)
 OGL_CONST_i(GL_CULL_VERTEX_IBM)
 OGL_CONST_i(GL_CULL_VERTEX_OBJECT_POSITION_EXT)
 OGL_CONST_i(GL_CURRENT_ATTRIB_NV)
 OGL_CONST_i(GL_CURRENT_BINORMAL_EXT)
 OGL_CONST_i(GL_CURRENT_BIT)
 OGL_CONST_i(GL_CURRENT_COLOR)
 OGL_CONST_i(GL_CURRENT_FOG_COORD)
 OGL_CONST_i(GL_CURRENT_FOG_COORDINATE)
 OGL_CONST_i(GL_CURRENT_FOG_COORDINATE_EXT)
 OGL_CONST_i(GL_CURRENT_INDEX)
 OGL_CONST_i(GL_CURRENT_MATRIX_ARB)
 OGL_CONST_i(GL_CURRENT_MATRIX_INDEX_ARB)
 OGL_CONST_i(GL_CURRENT_MATRIX_NV)
 OGL_CONST_i(GL_CURRENT_MATRIX_STACK_DEPTH_ARB)
 OGL_CONST_i(GL_CURRENT_MATRIX_STACK_DEPTH_NV)
 OGL_CONST_i(GL_CURRENT_NORMAL)
 OGL_CONST_i(GL_CURRENT_OCCLUSION_QUERY_ID_NV)
 OGL_CONST_i(GL_CURRENT_PALETTE_MATRIX_ARB)
 OGL_CONST_i(GL_CURRENT_PALETTE_MATRIX_OES)
 OGL_CONST_i(GL_CURRENT_PROGRAM)
 OGL_CONST_i(GL_CURRENT_QUERY)
 OGL_CONST_i(GL_CURRENT_QUERY_ANGLE)
 OGL_CONST_i(GL_CURRENT_QUERY_ARB)
 OGL_CONST_i(GL_CURRENT_QUERY_EXT)
 OGL_CONST_i(GL_CURRENT_RASTER_COLOR)
 OGL_CONST_i(GL_CURRENT_RASTER_DISTANCE)
 OGL_CONST_i(GL_CURRENT_RASTER_INDEX)
 OGL_CONST_i(GL_CURRENT_RASTER_NORMAL_EXT)
 OGL_CONST_i(GL_CURRENT_RASTER_POSITION)
 OGL_CONST_i(GL_CURRENT_RASTER_POSITION_VALID)
 OGL_CONST_i(GL_CURRENT_RASTER_SECONDARY_COLOR)
 OGL_CONST_i(GL_CURRENT_RASTER_TEXTURE_COORDS)
 OGL_CONST_i(GL_CURRENT_SAMPLE_COUNT_QUERY_NV)
 OGL_CONST_i(GL_CURRENT_SECONDARY_COLOR)
 OGL_CONST_i(GL_CURRENT_SECONDARY_COLOR_EXT)
 OGL_CONST_i(GL_CURRENT_TANGENT_EXT)
 OGL_CONST_i(GL_CURRENT_TEXTURE_COORDS)
 OGL_CONST_i(GL_CURRENT_TIME_NV)
 OGL_CONST_i(GL_CURRENT_VERTEX_ATTRIB)
 OGL_CONST_i(GL_CURRENT_VERTEX_ATTRIB_ARB)
 OGL_CONST_i(GL_CURRENT_VERTEX_EXT)
 OGL_CONST_i(GL_CURRENT_VERTEX_WEIGHT_EXT)
 OGL_CONST_i(GL_CURRENT_WEIGHT_ARB)
 OGL_CONST_i(GL_CW)
 OGL_CONST_i(GL_D3D12_FENCE_VALUE_EXT)
 OGL_CONST_i(GL_DARKEN_KHR)
 OGL_CONST_i(GL_DARKEN_NV)
 OGL_CONST_i(GL_DATA_BUFFER_AMD)
 OGL_CONST_i(GL_DEBUG_CALLBACK_FUNCTION)
 OGL_CONST_i(GL_DEBUG_CALLBACK_FUNCTION_ARB)
 OGL_CONST_i(GL_DEBUG_CALLBACK_USER_PARAM)
 OGL_CONST_i(GL_DEBUG_CALLBACK_USER_PARAM_ARB)
 OGL_CONST_i(GL_DEBUG_CATEGORY_API_ERROR_AMD)
 OGL_CONST_i(GL_DEBUG_CATEGORY_APPLICATION_AMD)
 OGL_CONST_i(GL_DEBUG_CATEGORY_DEPRECATION_AMD)
 OGL_CONST_i(GL_DEBUG_CATEGORY_OTHER_AMD)
 OGL_CONST_i(GL_DEBUG_CATEGORY_PERFORMANCE_AMD)
 OGL_CONST_i(GL_DEBUG_CATEGORY_SHADER_COMPILER_AMD)
 OGL_CONST_i(GL_DEBUG_CATEGORY_UNDEFINED_BEHAVIOR_AMD)
 OGL_CONST_i(GL_DEBUG_CATEGORY_WINDOW_SYSTEM_AMD)
 OGL_CONST_i(GL_DEBUG_GROUP_STACK_DEPTH)
 OGL_CONST_i(GL_DEBUG_LOGGED_MESSAGES)
 OGL_CONST_i(GL_DEBUG_LOGGED_MESSAGES_AMD)
 OGL_CONST_i(GL_DEBUG_LOGGED_MESSAGES_ARB)
 OGL_CONST_i(GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH)
 OGL_CONST_i(GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH_ARB)
 OGL_CONST_i(GL_DEBUG_OUTPUT)
 OGL_CONST_i(GL_DEBUG_OUTPUT_SYNCHRONOUS)
 OGL_CONST_i(GL_DEBUG_OUTPUT_SYNCHRONOUS_ARB)
 OGL_CONST_i(GL_DEBUG_REGAL)
 OGL_CONST_i(GL_DEBUG_SEVERITY_HIGH)
 OGL_CONST_i(GL_DEBUG_SEVERITY_HIGH_AMD)
 OGL_CONST_i(GL_DEBUG_SEVERITY_HIGH_ARB)
 OGL_CONST_i(GL_DEBUG_SEVERITY_LOW)
 OGL_CONST_i(GL_DEBUG_SEVERITY_LOW_AMD)
 OGL_CONST_i(GL_DEBUG_SEVERITY_LOW_ARB)
 OGL_CONST_i(GL_DEBUG_SEVERITY_MEDIUM)
 OGL_CONST_i(GL_DEBUG_SEVERITY_MEDIUM_AMD)
 OGL_CONST_i(GL_DEBUG_SEVERITY_MEDIUM_ARB)
 OGL_CONST_i(GL_DEBUG_SEVERITY_NOTIFICATION)
 OGL_CONST_i(GL_DEBUG_SOURCE_API)
 OGL_CONST_i(GL_DEBUG_SOURCE_API_ARB)
 OGL_CONST_i(GL_DEBUG_SOURCE_APPLICATION)
 OGL_CONST_i(GL_DEBUG_SOURCE_APPLICATION_ARB)
 OGL_CONST_i(GL_DEBUG_SOURCE_OTHER)
 OGL_CONST_i(GL_DEBUG_SOURCE_OTHER_ARB)
 OGL_CONST_i(GL_DEBUG_SOURCE_SHADER_COMPILER)
 OGL_CONST_i(GL_DEBUG_SOURCE_SHADER_COMPILER_ARB)
 OGL_CONST_i(GL_DEBUG_SOURCE_THIRD_PARTY)
 OGL_CONST_i(GL_DEBUG_SOURCE_THIRD_PARTY_ARB)
 OGL_CONST_i(GL_DEBUG_SOURCE_WINDOW_SYSTEM)
 OGL_CONST_i(GL_DEBUG_SOURCE_WINDOW_SYSTEM_ARB)
 OGL_CONST_i(GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR)
 OGL_CONST_i(GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR_ARB)
 OGL_CONST_i(GL_DEBUG_TYPE_ERROR)
 OGL_CONST_i(GL_DEBUG_TYPE_ERROR_ARB)
 OGL_CONST_i(GL_DEBUG_TYPE_MARKER)
 OGL_CONST_i(GL_DEBUG_TYPE_OTHER)
 OGL_CONST_i(GL_DEBUG_TYPE_OTHER_ARB)
 OGL_CONST_i(GL_DEBUG_TYPE_PERFORMANCE)
 OGL_CONST_i(GL_DEBUG_TYPE_PERFORMANCE_ARB)
 OGL_CONST_i(GL_DEBUG_TYPE_POP_GROUP)
 OGL_CONST_i(GL_DEBUG_TYPE_PORTABILITY)
 OGL_CONST_i(GL_DEBUG_TYPE_PORTABILITY_ARB)
 OGL_CONST_i(GL_DEBUG_TYPE_PUSH_GROUP)
 OGL_CONST_i(GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR)
 OGL_CONST_i(GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR_ARB)
 OGL_CONST_i(GL_DECAL)
 OGL_CONST_i(GL_DECODE_EXT)
 OGL_CONST_i(GL_DECR)
 OGL_CONST_i(GL_DECR_WRAP)
 OGL_CONST_i(GL_DECR_WRAP_EXT)
 OGL_CONST_i(GL_DEDICATED_MEMORY_OBJECT_EXT)
 OGL_CONST_i(GL_DELETE_STATUS)
 OGL_CONST_i(GL_DEPENDENT_AR_TEXTURE_2D_NV)
 OGL_CONST_i(GL_DEPENDENT_GB_TEXTURE_2D_NV)
 OGL_CONST_i(GL_DEPENDENT_HILO_TEXTURE_2D_NV)
 OGL_CONST_i(GL_DEPENDENT_RGB_TEXTURE_3D_NV)
 OGL_CONST_i(GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV)
 OGL_CONST_i(GL_DEPTH)
 OGL_CONST_i(GL_DEPTH24_STENCIL8)
 OGL_CONST_i(GL_DEPTH24_STENCIL8_EXT)
 OGL_CONST_i(GL_DEPTH24_STENCIL8_OES)
 OGL_CONST_i(GL_DEPTH32F_STENCIL8)
 OGL_CONST_i(GL_DEPTH32F_STENCIL8_NV)
 OGL_CONST_i(GL_DEPTH_ATTACHMENT)
 OGL_CONST_i(GL_DEPTH_ATTACHMENT_EXT)
 OGL_CONST_i(GL_DEPTH_ATTACHMENT_OES)
 OGL_CONST_i(GL_DEPTH_BIAS)
 OGL_CONST_i(GL_DEPTH_BITS)
 OGL_CONST_i(GL_DEPTH_BOUNDS_EXT)
 OGL_CONST_i(GL_DEPTH_BOUNDS_TEST_EXT)
 OGL_CONST_i(GL_DEPTH_BUFFER)
 OGL_CONST_i(GL_DEPTH_BUFFER_BIT)
 OGL_CONST_i(GL_DEPTH_BUFFER_BIT0_QCOM)
 OGL_CONST_i(GL_DEPTH_BUFFER_BIT1_QCOM)
 OGL_CONST_i(GL_DEPTH_BUFFER_BIT2_QCOM)
 OGL_CONST_i(GL_DEPTH_BUFFER_BIT3_QCOM)
 OGL_CONST_i(GL_DEPTH_BUFFER_BIT4_QCOM)
 OGL_CONST_i(GL_DEPTH_BUFFER_BIT5_QCOM)
 OGL_CONST_i(GL_DEPTH_BUFFER_BIT6_QCOM)
 OGL_CONST_i(GL_DEPTH_BUFFER_BIT7_QCOM)
 OGL_CONST_i(GL_DEPTH_BUFFER_FLOAT_MODE_NV)
 OGL_CONST_i(GL_DEPTH_CLAMP)
 OGL_CONST_i(GL_DEPTH_CLAMP_EXT)
 OGL_CONST_i(GL_DEPTH_CLAMP_FAR_AMD)
 OGL_CONST_i(GL_DEPTH_CLAMP_NEAR_AMD)
 OGL_CONST_i(GL_DEPTH_CLAMP_NV)
 OGL_CONST_i(GL_DEPTH_CLEAR_VALUE)
 OGL_CONST_i(GL_DEPTH_COMPONENT)
 OGL_CONST_i(GL_DEPTH_COMPONENT16)
 OGL_CONST_i(GL_DEPTH_COMPONENT16_ARB)
 OGL_CONST_i(GL_DEPTH_COMPONENT16_NONLINEAR_NV)
 OGL_CONST_i(GL_DEPTH_COMPONENT16_OES)
 OGL_CONST_i(GL_DEPTH_COMPONENT16_SGIX)
 OGL_CONST_i(GL_DEPTH_COMPONENT24)
 OGL_CONST_i(GL_DEPTH_COMPONENT24_ARB)
 OGL_CONST_i(GL_DEPTH_COMPONENT24_OES)
 OGL_CONST_i(GL_DEPTH_COMPONENT24_SGIX)
 OGL_CONST_i(GL_DEPTH_COMPONENT32)
 OGL_CONST_i(GL_DEPTH_COMPONENT32F)
 OGL_CONST_i(GL_DEPTH_COMPONENT32F_NV)
 OGL_CONST_i(GL_DEPTH_COMPONENT32_ARB)
 OGL_CONST_i(GL_DEPTH_COMPONENT32_OES)
 OGL_CONST_i(GL_DEPTH_COMPONENT32_SGIX)
 OGL_CONST_i(GL_DEPTH_COMPONENTS)
 OGL_CONST_i(GL_DEPTH_EXT)
 OGL_CONST_i(GL_DEPTH_FUNC)
 OGL_CONST_i(GL_DEPTH_PASS_INSTRUMENT_COUNTERS_SGIX)
 OGL_CONST_i(GL_DEPTH_PASS_INSTRUMENT_MAX_SGIX)
 OGL_CONST_i(GL_DEPTH_PASS_INSTRUMENT_SGIX)
 OGL_CONST_i(GL_DEPTH_RANGE)
 OGL_CONST_i(GL_DEPTH_RENDERABLE)
 OGL_CONST_i(GL_DEPTH_SAMPLES_NV)
 OGL_CONST_i(GL_DEPTH_SCALE)
 OGL_CONST_i(GL_DEPTH_STENCIL)
 OGL_CONST_i(GL_DEPTH_STENCIL_ATTACHMENT)
 OGL_CONST_i(GL_DEPTH_STENCIL_EXT)
 OGL_CONST_i(GL_DEPTH_STENCIL_NV)
 OGL_CONST_i(GL_DEPTH_STENCIL_OES)
 OGL_CONST_i(GL_DEPTH_STENCIL_TEXTURE_MODE)
 OGL_CONST_i(GL_DEPTH_STENCIL_TO_BGRA_NV)
 OGL_CONST_i(GL_DEPTH_STENCIL_TO_RGBA_NV)
 OGL_CONST_i(GL_DEPTH_TEST)
 OGL_CONST_i(GL_DEPTH_TEXTURE_MODE)
 OGL_CONST_i(GL_DEPTH_TEXTURE_MODE_ARB)
 OGL_CONST_i(GL_DEPTH_WRITEMASK)
 OGL_CONST_i(GL_DETACHED_BUFFERS_NV)
 OGL_CONST_i(GL_DETACHED_MEMORY_INCARNATION_NV)
 OGL_CONST_i(GL_DETACHED_TEXTURES_NV)
 OGL_CONST_i(GL_DEVICE_LUID_EXT)
 OGL_CONST_i(GL_DEVICE_NODE_MASK_EXT)
 OGL_CONST_i(GL_DEVICE_UUID_EXT)
 OGL_CONST_i(GL_DIFFERENCE_KHR)
 OGL_CONST_i(GL_DIFFERENCE_NV)
 OGL_CONST_i(GL_DIFFUSE)
 OGL_CONST_i(GL_DISCARD_ATI)
 OGL_CONST_i(GL_DISCARD_NV)
 OGL_CONST_i(GL_DISCRETE_AMD)
 OGL_CONST_i(GL_DISJOINT_NV)
 OGL_CONST_i(GL_DISPATCH_INDIRECT_BUFFER)
 OGL_CONST_i(GL_DISPATCH_INDIRECT_BUFFER_BINDING)
 OGL_CONST_i(GL_DISPLAY_LIST)
 OGL_CONST_i(GL_DISTANCE_ATTENUATION_EXT)
 OGL_CONST_i(GL_DITHER)
 OGL_CONST_i(GL_DMP_PROGRAM_BINARY_DMP)
 OGL_CONST_i(GL_DOMAIN)
 OGL_CONST_i(GL_DONT_CARE)
 OGL_CONST_i(GL_DOT2_ADD_ATI)
 OGL_CONST_i(GL_DOT3_ATI)
 OGL_CONST_i(GL_DOT3_RGB)
 OGL_CONST_i(GL_DOT3_RGBA)
 OGL_CONST_i(GL_DOT3_RGBA_ARB)
 OGL_CONST_i(GL_DOT3_RGBA_EXT)
 OGL_CONST_i(GL_DOT3_RGBA_IMG)
 OGL_CONST_i(GL_DOT3_RGB_ARB)
 OGL_CONST_i(GL_DOT3_RGB_EXT)
 OGL_CONST_i(GL_DOT4_ATI)
 OGL_CONST_i(GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_DEPTH_REPLACE_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_PASS_THROUGH_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_TEXTURE_1D_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_TEXTURE_2D_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_TEXTURE_3D_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV)
 OGL_CONST_i(GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV)
 OGL_CONST_i(GL_DOUBLE)
 OGL_CONST_i(GL_DOUBLEBUFFER)
 OGL_CONST_i(GL_DOUBLE_EXT)
 OGL_CONST_i(GL_DOUBLE_MAT2)
 OGL_CONST_i(GL_DOUBLE_MAT2_EXT)
 OGL_CONST_i(GL_DOUBLE_MAT2x3)
 OGL_CONST_i(GL_DOUBLE_MAT2x3_EXT)
 OGL_CONST_i(GL_DOUBLE_MAT2x4)
 OGL_CONST_i(GL_DOUBLE_MAT2x4_EXT)
 OGL_CONST_i(GL_DOUBLE_MAT3)
 OGL_CONST_i(GL_DOUBLE_MAT3_EXT)
 OGL_CONST_i(GL_DOUBLE_MAT3x2)
 OGL_CONST_i(GL_DOUBLE_MAT3x2_EXT)
 OGL_CONST_i(GL_DOUBLE_MAT3x4)
 OGL_CONST_i(GL_DOUBLE_MAT3x4_EXT)
 OGL_CONST_i(GL_DOUBLE_MAT4)
 OGL_CONST_i(GL_DOUBLE_MAT4_EXT)
 OGL_CONST_i(GL_DOUBLE_MAT4x2)
 OGL_CONST_i(GL_DOUBLE_MAT4x2_EXT)
 OGL_CONST_i(GL_DOUBLE_MAT4x3)
 OGL_CONST_i(GL_DOUBLE_MAT4x3_EXT)
 OGL_CONST_i(GL_DOUBLE_VEC2)
 OGL_CONST_i(GL_DOUBLE_VEC2_EXT)
 OGL_CONST_i(GL_DOUBLE_VEC3)
 OGL_CONST_i(GL_DOUBLE_VEC3_EXT)
 OGL_CONST_i(GL_DOUBLE_VEC4)
 OGL_CONST_i(GL_DOUBLE_VEC4_EXT)
 OGL_CONST_i(GL_DOWNSAMPLE_SCALES_IMG)
 OGL_CONST_i(GL_DRAW_ARRAYS_COMMAND_NV)
 OGL_CONST_i(GL_DRAW_ARRAYS_INSTANCED_COMMAND_NV)
 OGL_CONST_i(GL_DRAW_ARRAYS_STRIP_COMMAND_NV)
 OGL_CONST_i(GL_DRAW_BUFFER)
 OGL_CONST_i(GL_DRAW_BUFFER0)
 OGL_CONST_i(GL_DRAW_BUFFER0_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER0_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER0_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER0_NV)
 OGL_CONST_i(GL_DRAW_BUFFER1)
 OGL_CONST_i(GL_DRAW_BUFFER10)
 OGL_CONST_i(GL_DRAW_BUFFER10_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER10_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER10_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER10_NV)
 OGL_CONST_i(GL_DRAW_BUFFER11)
 OGL_CONST_i(GL_DRAW_BUFFER11_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER11_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER11_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER11_NV)
 OGL_CONST_i(GL_DRAW_BUFFER12)
 OGL_CONST_i(GL_DRAW_BUFFER12_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER12_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER12_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER12_NV)
 OGL_CONST_i(GL_DRAW_BUFFER13)
 OGL_CONST_i(GL_DRAW_BUFFER13_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER13_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER13_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER13_NV)
 OGL_CONST_i(GL_DRAW_BUFFER14)
 OGL_CONST_i(GL_DRAW_BUFFER14_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER14_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER14_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER14_NV)
 OGL_CONST_i(GL_DRAW_BUFFER15)
 OGL_CONST_i(GL_DRAW_BUFFER15_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER15_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER15_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER15_NV)
 OGL_CONST_i(GL_DRAW_BUFFER1_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER1_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER1_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER1_NV)
 OGL_CONST_i(GL_DRAW_BUFFER2)
 OGL_CONST_i(GL_DRAW_BUFFER2_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER2_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER2_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER2_NV)
 OGL_CONST_i(GL_DRAW_BUFFER3)
 OGL_CONST_i(GL_DRAW_BUFFER3_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER3_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER3_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER3_NV)
 OGL_CONST_i(GL_DRAW_BUFFER4)
 OGL_CONST_i(GL_DRAW_BUFFER4_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER4_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER4_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER4_NV)
 OGL_CONST_i(GL_DRAW_BUFFER5)
 OGL_CONST_i(GL_DRAW_BUFFER5_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER5_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER5_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER5_NV)
 OGL_CONST_i(GL_DRAW_BUFFER6)
 OGL_CONST_i(GL_DRAW_BUFFER6_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER6_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER6_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER6_NV)
 OGL_CONST_i(GL_DRAW_BUFFER7)
 OGL_CONST_i(GL_DRAW_BUFFER7_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER7_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER7_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER7_NV)
 OGL_CONST_i(GL_DRAW_BUFFER8)
 OGL_CONST_i(GL_DRAW_BUFFER8_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER8_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER8_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER8_NV)
 OGL_CONST_i(GL_DRAW_BUFFER9)
 OGL_CONST_i(GL_DRAW_BUFFER9_ARB)
 OGL_CONST_i(GL_DRAW_BUFFER9_ATI)
 OGL_CONST_i(GL_DRAW_BUFFER9_EXT)
 OGL_CONST_i(GL_DRAW_BUFFER9_NV)
 OGL_CONST_i(GL_DRAW_BUFFER_EXT)
 OGL_CONST_i(GL_DRAW_ELEMENTS_COMMAND_NV)
 OGL_CONST_i(GL_DRAW_ELEMENTS_INSTANCED_COMMAND_NV)
 OGL_CONST_i(GL_DRAW_ELEMENTS_STRIP_COMMAND_NV)
 OGL_CONST_i(GL_DRAW_FRAMEBUFFER)
 OGL_CONST_i(GL_DRAW_FRAMEBUFFER_ANGLE)
 OGL_CONST_i(GL_DRAW_FRAMEBUFFER_APPLE)
 OGL_CONST_i(GL_DRAW_FRAMEBUFFER_BINDING)
 OGL_CONST_i(GL_DRAW_FRAMEBUFFER_BINDING_ANGLE)
 OGL_CONST_i(GL_DRAW_FRAMEBUFFER_BINDING_APPLE)
 OGL_CONST_i(GL_DRAW_FRAMEBUFFER_BINDING_EXT)
 OGL_CONST_i(GL_DRAW_FRAMEBUFFER_BINDING_NV)
 OGL_CONST_i(GL_DRAW_FRAMEBUFFER_EXT)
 OGL_CONST_i(GL_DRAW_FRAMEBUFFER_NV)
 OGL_CONST_i(GL_DRAW_INDIRECT_ADDRESS_NV)
 OGL_CONST_i(GL_DRAW_INDIRECT_BUFFER)
 OGL_CONST_i(GL_DRAW_INDIRECT_BUFFER_BINDING)
 OGL_CONST_i(GL_DRAW_INDIRECT_LENGTH_NV)
 OGL_CONST_i(GL_DRAW_INDIRECT_UNIFIED_NV)
 OGL_CONST_i(GL_DRAW_PIXELS_APPLE)
 OGL_CONST_i(GL_DRAW_PIXEL_TOKEN)
 OGL_CONST_i(GL_DRIVER_REGAL)
 OGL_CONST_i(GL_DRIVER_UUID_EXT)
 OGL_CONST_i(GL_DSDT8_MAG8_INTENSITY8_NV)
 OGL_CONST_i(GL_DSDT8_MAG8_NV)
 OGL_CONST_i(GL_DSDT8_NV)
 OGL_CONST_i(GL_DSDT_MAG_INTENSITY_NV)
 OGL_CONST_i(GL_DSDT_MAG_NV)
 OGL_CONST_i(GL_DSDT_MAG_VIB_NV)
 OGL_CONST_i(GL_DSDT_NV)
 OGL_CONST_i(GL_DST_ALPHA)
 OGL_CONST_i(GL_DST_ATOP_NV)
 OGL_CONST_i(GL_DST_COLOR)
 OGL_CONST_i(GL_DST_IN_NV)
 OGL_CONST_i(GL_DST_NV)
 OGL_CONST_i(GL_DST_OUT_NV)
 OGL_CONST_i(GL_DST_OVER_NV)
 OGL_CONST_i(GL_DS_BIAS_NV)
 OGL_CONST_i(GL_DS_SCALE_NV)
 OGL_CONST_i(GL_DT_BIAS_NV)
 OGL_CONST_i(GL_DT_SCALE_NV)
 OGL_CONST_i(GL_DU8DV8_ATI)
 OGL_CONST_i(GL_DUDV_ATI)
 OGL_CONST_i(GL_DUP_FIRST_CUBIC_CURVE_TO_NV)
 OGL_CONST_i(GL_DUP_LAST_CUBIC_CURVE_TO_NV)
 OGL_CONST_i(GL_DYNAMIC_ATI)
 OGL_CONST_i(GL_DYNAMIC_COPY)
 OGL_CONST_i(GL_DYNAMIC_COPY_ARB)
 OGL_CONST_i(GL_DYNAMIC_DRAW)
 OGL_CONST_i(GL_DYNAMIC_DRAW_ARB)
 OGL_CONST_i(GL_DYNAMIC_READ)
 OGL_CONST_i(GL_DYNAMIC_READ_ARB)
 OGL_CONST_i(GL_DYNAMIC_STORAGE_BIT)
 OGL_CONST_i(GL_DYNAMIC_STORAGE_BIT_EXT)
 OGL_CONST_i(GL_EDGEFLAG_BIT_PGI)
 OGL_CONST_i(GL_EDGE_FLAG)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_ADDRESS_NV)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_COUNT_EXT)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_EXT)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_LENGTH_NV)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_LIST_IBM)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_LIST_STRIDE_IBM)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_POINTER)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_STRIDE)
 OGL_CONST_i(GL_EDGE_FLAG_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_EFFECTIVE_RASTER_SAMPLES_EXT)
 OGL_CONST_i(GL_EIGHTH_BIT_ATI)
 OGL_CONST_i(GL_ELEMENT_ADDRESS_COMMAND_NV)
 OGL_CONST_i(GL_ELEMENT_ARRAY_ADDRESS_NV)
 OGL_CONST_i(GL_ELEMENT_ARRAY_APPLE)
 OGL_CONST_i(GL_ELEMENT_ARRAY_ATI)
 OGL_CONST_i(GL_ELEMENT_ARRAY_BARRIER_BIT)
 OGL_CONST_i(GL_ELEMENT_ARRAY_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_ELEMENT_ARRAY_BUFFER)
 OGL_CONST_i(GL_ELEMENT_ARRAY_BUFFER_ARB)
 OGL_CONST_i(GL_ELEMENT_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_ELEMENT_ARRAY_LENGTH_NV)
 OGL_CONST_i(GL_ELEMENT_ARRAY_POINTER_APPLE)
 OGL_CONST_i(GL_ELEMENT_ARRAY_POINTER_ATI)
 OGL_CONST_i(GL_ELEMENT_ARRAY_TYPE_APPLE)
 OGL_CONST_i(GL_ELEMENT_ARRAY_TYPE_ATI)
 OGL_CONST_i(GL_ELEMENT_ARRAY_UNIFIED_NV)
 OGL_CONST_i(GL_EMBOSS_CONSTANT_NV)
 OGL_CONST_i(GL_EMBOSS_LIGHT_NV)
 OGL_CONST_i(GL_EMBOSS_MAP_NV)
 OGL_CONST_i(GL_EMISSION)
 OGL_CONST_i(GL_EMULATION_REGAL)
 OGL_CONST_i(GL_ENABLE_BIT)
 OGL_CONST_i(GL_ENV_MAP_SGIX)
 OGL_CONST_i(GL_EQUAL)
 OGL_CONST_i(GL_EQUIV)
 OGL_CONST_i(GL_ERROR_REGAL)
 OGL_CONST_i(GL_ETC1_RGB8_OES)
 OGL_CONST_i(GL_ETC1_SRGB8_NV)
 OGL_CONST_i(GL_EVAL_2D_NV)
 OGL_CONST_i(GL_EVAL_BIT)
 OGL_CONST_i(GL_EVAL_FRACTIONAL_TESSELLATION_NV)
 OGL_CONST_i(GL_EVAL_TRIANGULAR_2D_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB0_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB10_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB11_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB12_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB13_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB14_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB15_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB1_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB2_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB3_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB4_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB5_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB6_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB7_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB8_NV)
 OGL_CONST_i(GL_EVAL_VERTEX_ATTRIB9_NV)
 OGL_CONST_i(GL_EXCLUSION_KHR)
 OGL_CONST_i(GL_EXCLUSION_NV)
 OGL_CONST_i(GL_EXCLUSIVE_EXT)
 OGL_CONST_i(GL_EXP)
 OGL_CONST_i(GL_EXP2)
 OGL_CONST_i(GL_EXPAND_NEGATE_NV)
 OGL_CONST_i(GL_EXPAND_NORMAL_NV)
 OGL_CONST_i(GL_EXTENDED_RANGE_SGIS)
 OGL_CONST_i(GL_EXTENSIONS)
 OGL_CONST_i(GL_EXTERNAL_VIRTUAL_MEMORY_BUFFER_AMD)
 OGL_CONST_i(GL_EYE_DISTANCE_TO_LINE_SGIS)
 OGL_CONST_i(GL_EYE_DISTANCE_TO_POINT_SGIS)
 OGL_CONST_i(GL_EYE_LINEAR)
 OGL_CONST_i(GL_EYE_LINE_SGIS)
 OGL_CONST_i(GL_EYE_PLANE)
 OGL_CONST_i(GL_EYE_PLANE_ABSOLUTE_NV)
 OGL_CONST_i(GL_EYE_POINT_SGIS)
 OGL_CONST_i(GL_EYE_RADIAL_NV)
 OGL_CONST_i(GL_EYE_SPACE_SGIX)
 OGL_CONST_i(GL_E_TIMES_F_NV)
 OGL_CONST_i(GL_FACTOR_ALPHA_MODULATE_IMG)
 OGL_CONST_i(GL_FACTOR_MAX_AMD)
 OGL_CONST_i(GL_FACTOR_MIN_AMD)
 OGL_CONST_i(GL_FAILURE_NV)
 OGL_CONST_i(GL_FALSE)
 OGL_CONST_i(GL_FASTEST)
 OGL_CONST_i(GL_FEEDBACK)
 OGL_CONST_i(GL_FEEDBACK_BUFFER_POINTER)
 OGL_CONST_i(GL_FEEDBACK_BUFFER_SIZE)
 OGL_CONST_i(GL_FEEDBACK_BUFFER_TYPE)
 OGL_CONST_i(GL_FENCE_APPLE)
 OGL_CONST_i(GL_FENCE_CONDITION_NV)
 OGL_CONST_i(GL_FENCE_STATUS_NV)
 OGL_CONST_i(GL_FETCH_PER_SAMPLE_ARM)
 OGL_CONST_i(GL_FFT_1D_SGI)
 OGL_CONST_i(GL_FIELDS_NV)
 OGL_CONST_i(GL_FIELD_LOWER_NV)
 OGL_CONST_i(GL_FIELD_UPPER_NV)
 OGL_CONST_i(GL_FILE_NAME_NV)
 OGL_CONST_i(GL_FILL)
 OGL_CONST_i(GL_FILL_NV)
 OGL_CONST_i(GL_FILL_RECTANGLE_NV)
 OGL_CONST_i(GL_FILTER)
 OGL_CONST_i(GL_FIRST_TO_REST_NV)
 OGL_CONST_i(GL_FIRST_VERTEX_CONVENTION)
 OGL_CONST_i(GL_FIRST_VERTEX_CONVENTION_EXT)
 OGL_CONST_i(GL_FIRST_VERTEX_CONVENTION_OES)
 OGL_CONST_i(GL_FIXED)
 OGL_CONST_i(GL_FIXED_ONLY)
 OGL_CONST_i(GL_FIXED_ONLY_ARB)
 OGL_CONST_i(GL_FLAT)
 OGL_CONST_i(GL_FLOAT)
 OGL_CONST_i(GL_FLOAT16_IMAGE_1D_AMD)
 OGL_CONST_i(GL_FLOAT16_IMAGE_1D_ARRAY_AMD)
 OGL_CONST_i(GL_FLOAT16_IMAGE_2D_AMD)
 OGL_CONST_i(GL_FLOAT16_IMAGE_2D_ARRAY_AMD)
 OGL_CONST_i(GL_FLOAT16_IMAGE_2D_MULTISAMPLE_AMD)
 OGL_CONST_i(GL_FLOAT16_IMAGE_2D_MULTISAMPLE_ARRAY_AMD)
 OGL_CONST_i(GL_FLOAT16_IMAGE_2D_RECT_AMD)
 OGL_CONST_i(GL_FLOAT16_IMAGE_3D_AMD)
 OGL_CONST_i(GL_FLOAT16_IMAGE_BUFFER_AMD)
 OGL_CONST_i(GL_FLOAT16_IMAGE_CUBE_AMD)
 OGL_CONST_i(GL_FLOAT16_IMAGE_CUBE_MAP_ARRAY_AMD)
 OGL_CONST_i(GL_FLOAT16_MAT2_AMD)
 OGL_CONST_i(GL_FLOAT16_MAT2x3_AMD)
 OGL_CONST_i(GL_FLOAT16_MAT2x4_AMD)
 OGL_CONST_i(GL_FLOAT16_MAT3_AMD)
 OGL_CONST_i(GL_FLOAT16_MAT3x2_AMD)
 OGL_CONST_i(GL_FLOAT16_MAT3x4_AMD)
 OGL_CONST_i(GL_FLOAT16_MAT4_AMD)
 OGL_CONST_i(GL_FLOAT16_MAT4x2_AMD)
 OGL_CONST_i(GL_FLOAT16_MAT4x3_AMD)
 OGL_CONST_i(GL_FLOAT16_NV)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_1D_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_1D_ARRAY_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_1D_ARRAY_SHADOW_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_1D_SHADOW_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_2D_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_2D_ARRAY_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_2D_ARRAY_SHADOW_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_2D_MULTISAMPLE_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_2D_MULTISAMPLE_ARRAY_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_2D_RECT_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_2D_RECT_SHADOW_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_2D_SHADOW_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_3D_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_BUFFER_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_CUBE_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_CUBE_MAP_ARRAY_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_CUBE_MAP_ARRAY_SHADOW_AMD)
 OGL_CONST_i(GL_FLOAT16_SAMPLER_CUBE_SHADOW_AMD)
 OGL_CONST_i(GL_FLOAT16_VEC2_NV)
 OGL_CONST_i(GL_FLOAT16_VEC3_NV)
 OGL_CONST_i(GL_FLOAT16_VEC4_NV)
 OGL_CONST_i(GL_FLOAT_32_UNSIGNED_INT_24_8_REV)
 OGL_CONST_i(GL_FLOAT_32_UNSIGNED_INT_24_8_REV_NV)
 OGL_CONST_i(GL_FLOAT_CLEAR_COLOR_VALUE_NV)
 OGL_CONST_i(GL_FLOAT_MAT2)
 OGL_CONST_i(GL_FLOAT_MAT2_ARB)
 OGL_CONST_i(GL_FLOAT_MAT2x3)
 OGL_CONST_i(GL_FLOAT_MAT2x3_NV)
 OGL_CONST_i(GL_FLOAT_MAT2x4)
 OGL_CONST_i(GL_FLOAT_MAT2x4_NV)
 OGL_CONST_i(GL_FLOAT_MAT3)
 OGL_CONST_i(GL_FLOAT_MAT3_ARB)
 OGL_CONST_i(GL_FLOAT_MAT3x2)
 OGL_CONST_i(GL_FLOAT_MAT3x2_NV)
 OGL_CONST_i(GL_FLOAT_MAT3x4)
 OGL_CONST_i(GL_FLOAT_MAT3x4_NV)
 OGL_CONST_i(GL_FLOAT_MAT4)
 OGL_CONST_i(GL_FLOAT_MAT4_ARB)
 OGL_CONST_i(GL_FLOAT_MAT4x2)
 OGL_CONST_i(GL_FLOAT_MAT4x2_NV)
 OGL_CONST_i(GL_FLOAT_MAT4x3)
 OGL_CONST_i(GL_FLOAT_MAT4x3_NV)
 OGL_CONST_i(GL_FLOAT_R16_NV)
 OGL_CONST_i(GL_FLOAT_R32_NV)
 OGL_CONST_i(GL_FLOAT_RG16_NV)
 OGL_CONST_i(GL_FLOAT_RG32_NV)
 OGL_CONST_i(GL_FLOAT_RGB16_NV)
 OGL_CONST_i(GL_FLOAT_RGB32_NV)
 OGL_CONST_i(GL_FLOAT_RGBA16_NV)
 OGL_CONST_i(GL_FLOAT_RGBA32_NV)
 OGL_CONST_i(GL_FLOAT_RGBA_MODE_NV)
 OGL_CONST_i(GL_FLOAT_RGBA_NV)
 OGL_CONST_i(GL_FLOAT_RGB_NV)
 OGL_CONST_i(GL_FLOAT_RG_NV)
 OGL_CONST_i(GL_FLOAT_R_NV)
 OGL_CONST_i(GL_FLOAT_VEC2)
 OGL_CONST_i(GL_FLOAT_VEC2_ARB)
 OGL_CONST_i(GL_FLOAT_VEC3)
 OGL_CONST_i(GL_FLOAT_VEC3_ARB)
 OGL_CONST_i(GL_FLOAT_VEC4)
 OGL_CONST_i(GL_FLOAT_VEC4_ARB)
 OGL_CONST_i(GL_FOG)
 OGL_CONST_i(GL_FOG_BIT)
 OGL_CONST_i(GL_FOG_BLEND_ALPHA_SGIX)
 OGL_CONST_i(GL_FOG_BLEND_COLOR_SGIX)
 OGL_CONST_i(GL_FOG_COLOR)
 OGL_CONST_i(GL_FOG_COORD)
 OGL_CONST_i(GL_FOG_COORDINATE)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_EXT)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_LIST_IBM)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_LIST_STRIDE_IBM)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_POINTER)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_STRIDE)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_TYPE)
 OGL_CONST_i(GL_FOG_COORDINATE_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_FOG_COORDINATE_EXT)
 OGL_CONST_i(GL_FOG_COORDINATE_SOURCE)
 OGL_CONST_i(GL_FOG_COORDINATE_SOURCE_EXT)
 OGL_CONST_i(GL_FOG_COORD_ARRAY)
 OGL_CONST_i(GL_FOG_COORD_ARRAY_ADDRESS_NV)
 OGL_CONST_i(GL_FOG_COORD_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_FOG_COORD_ARRAY_LENGTH_NV)
 OGL_CONST_i(GL_FOG_COORD_ARRAY_POINTER)
 OGL_CONST_i(GL_FOG_COORD_ARRAY_STRIDE)
 OGL_CONST_i(GL_FOG_COORD_ARRAY_TYPE)
 OGL_CONST_i(GL_FOG_COORD_SRC)
 OGL_CONST_i(GL_FOG_DENSITY)
 OGL_CONST_i(GL_FOG_DISTANCE_MODE_NV)
 OGL_CONST_i(GL_FOG_END)
 OGL_CONST_i(GL_FOG_GROUND_PLANE_SGIX)
 OGL_CONST_i(GL_FOG_HINT)
 OGL_CONST_i(GL_FOG_INDEX)
 OGL_CONST_i(GL_FOG_LAYERS_POINTS_SGIX)
 OGL_CONST_i(GL_FOG_MODE)
 OGL_CONST_i(GL_FOG_OFFSET_SGIX)
 OGL_CONST_i(GL_FOG_OFFSET_VALUE_SGIX)
 OGL_CONST_i(GL_FOG_SCALE_SGIX)
 OGL_CONST_i(GL_FOG_SCALE_VALUE_SGIX)
 OGL_CONST_i(GL_FOG_SPECULAR_TEXTURE_WIN)
 OGL_CONST_i(GL_FOG_START)
 OGL_CONST_i(GL_FOG_TYPE_SGIX)
 OGL_CONST_i(GL_FONT_ASCENDER_BIT_NV)
 OGL_CONST_i(GL_FONT_DESCENDER_BIT_NV)
 OGL_CONST_i(GL_FONT_GLYPHS_AVAILABLE_NV)
 OGL_CONST_i(GL_FONT_HAS_KERNING_BIT_NV)
 OGL_CONST_i(GL_FONT_HEIGHT_BIT_NV)
 OGL_CONST_i(GL_FONT_MAX_ADVANCE_HEIGHT_BIT_NV)
 OGL_CONST_i(GL_FONT_MAX_ADVANCE_WIDTH_BIT_NV)
 OGL_CONST_i(GL_FONT_NUM_GLYPH_INDICES_BIT_NV)
 OGL_CONST_i(GL_FONT_TARGET_UNAVAILABLE_NV)
 OGL_CONST_i(GL_FONT_UNAVAILABLE_NV)
 OGL_CONST_i(GL_FONT_UNDERLINE_POSITION_BIT_NV)
 OGL_CONST_i(GL_FONT_UNDERLINE_THICKNESS_BIT_NV)
 OGL_CONST_i(GL_FONT_UNINTELLIGIBLE_NV)
 OGL_CONST_i(GL_FONT_UNITS_PER_EM_BIT_NV)
 OGL_CONST_i(GL_FONT_X_MAX_BOUNDS_BIT_NV)
 OGL_CONST_i(GL_FONT_X_MIN_BOUNDS_BIT_NV)
 OGL_CONST_i(GL_FONT_Y_MAX_BOUNDS_BIT_NV)
 OGL_CONST_i(GL_FONT_Y_MIN_BOUNDS_BIT_NV)
 OGL_CONST_i(GL_FORCE_BLUE_TO_ONE_NV)
 OGL_CONST_i(GL_FORMAT_SUBSAMPLE_244_244_OML)
 OGL_CONST_i(GL_FORMAT_SUBSAMPLE_24_24_OML)
 OGL_CONST_i(GL_FOVEATION_ENABLE_BIT_QCOM)
 OGL_CONST_i(GL_FOVEATION_SCALED_BIN_METHOD_BIT_QCOM)
 OGL_CONST_i(GL_FOVEATION_SUBSAMPLED_LAYOUT_METHOD_BIT_QCOM)
 OGL_CONST_i(GL_FRACTIONAL_EVEN)
 OGL_CONST_i(GL_FRACTIONAL_EVEN_EXT)
 OGL_CONST_i(GL_FRACTIONAL_EVEN_OES)
 OGL_CONST_i(GL_FRACTIONAL_ODD)
 OGL_CONST_i(GL_FRACTIONAL_ODD_EXT)
 OGL_CONST_i(GL_FRACTIONAL_ODD_OES)
 OGL_CONST_i(GL_FRAGMENTS_INSTRUMENT_COUNTERS_SGIX)
 OGL_CONST_i(GL_FRAGMENTS_INSTRUMENT_MAX_SGIX)
 OGL_CONST_i(GL_FRAGMENTS_INSTRUMENT_SGIX)
 OGL_CONST_i(GL_FRAGMENT_ALPHA_MODULATE_IMG)
 OGL_CONST_i(GL_FRAGMENT_COLOR_EXT)
 OGL_CONST_i(GL_FRAGMENT_COLOR_MATERIAL_EXT)
 OGL_CONST_i(GL_FRAGMENT_COLOR_MATERIAL_FACE_EXT)
 OGL_CONST_i(GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_EXT)
 OGL_CONST_i(GL_FRAGMENT_COVERAGE_COLOR_NV)
 OGL_CONST_i(GL_FRAGMENT_COVERAGE_TO_COLOR_NV)
 OGL_CONST_i(GL_FRAGMENT_DEPTH)
 OGL_CONST_i(GL_FRAGMENT_DEPTH_EXT)
 OGL_CONST_i(GL_FRAGMENT_INPUT_NV)
 OGL_CONST_i(GL_FRAGMENT_INTERPOLATION_OFFSET_BITS)
 OGL_CONST_i(GL_FRAGMENT_INTERPOLATION_OFFSET_BITS_OES)
 OGL_CONST_i(GL_FRAGMENT_LIGHT0_EXT)
 OGL_CONST_i(GL_FRAGMENT_LIGHT7_EXT)
 OGL_CONST_i(GL_FRAGMENT_LIGHTING_EXT)
 OGL_CONST_i(GL_FRAGMENT_LIGHT_MODEL_AMBIENT_EXT)
 OGL_CONST_i(GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_EXT)
 OGL_CONST_i(GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_EXT)
 OGL_CONST_i(GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_EXT)
 OGL_CONST_i(GL_FRAGMENT_LIGHT_SPACE_SGIX)
 OGL_CONST_i(GL_FRAGMENT_MATERIAL_EXT)
 OGL_CONST_i(GL_FRAGMENT_NORMAL_EXT)
 OGL_CONST_i(GL_FRAGMENT_PROGRAM_ARB)
 OGL_CONST_i(GL_FRAGMENT_PROGRAM_BINDING_NV)
 OGL_CONST_i(GL_FRAGMENT_PROGRAM_INTERPOLATION_OFFSET_BITS_NV)
 OGL_CONST_i(GL_FRAGMENT_PROGRAM_NV)
 OGL_CONST_i(GL_FRAGMENT_PROGRAM_PARAMETER_BUFFER_NV)
 OGL_CONST_i(GL_FRAGMENT_SHADER)
 OGL_CONST_i(GL_FRAGMENT_SHADER_ARB)
 OGL_CONST_i(GL_FRAGMENT_SHADER_ATI)
 OGL_CONST_i(GL_FRAGMENT_SHADER_BIT)
 OGL_CONST_i(GL_FRAGMENT_SHADER_DERIVATIVE_HINT)
 OGL_CONST_i(GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB)
 OGL_CONST_i(GL_FRAGMENT_SHADER_DERIVATIVE_HINT_OES)
 OGL_CONST_i(GL_FRAGMENT_SHADER_DISCARDS_SAMPLES_EXT)
 OGL_CONST_i(GL_FRAGMENT_SHADER_FRAMEBUFFER_FETCH_MRT_ARM)
 OGL_CONST_i(GL_FRAGMENT_SHADER_INVOCATIONS)
 OGL_CONST_i(GL_FRAGMENT_SHADER_INVOCATIONS_ARB)
 OGL_CONST_i(GL_FRAGMENT_SHADING_RATE_ATTACHMENT_WITH_DEFAULT_FRAMEBUFFER_SUPPORTED_EXT)
 OGL_CONST_i(GL_FRAGMENT_SHADING_RATE_COMBINER_OP_KEEP_EXT)
 OGL_CONST_i(GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MAX_EXT)
 OGL_CONST_i(GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MIN_EXT)
 OGL_CONST_i(GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MUL_EXT)
 OGL_CONST_i(GL_FRAGMENT_SHADING_RATE_COMBINER_OP_REPLACE_EXT)
 OGL_CONST_i(GL_FRAGMENT_SHADING_RATE_NON_TRIVIAL_COMBINERS_SUPPORTED_EXT)
 OGL_CONST_i(GL_FRAGMENT_SHADING_RATE_PRIMITIVE_RATE_WITH_MULTI_VIEWPORT_SUPPORTED_EXT)
 OGL_CONST_i(GL_FRAGMENT_SHADING_RATE_WITH_SAMPLE_MASK_SUPPORTED_EXT)
 OGL_CONST_i(GL_FRAGMENT_SHADING_RATE_WITH_SHADER_DEPTH_STENCIL_WRITES_SUPPORTED_EXT)
 OGL_CONST_i(GL_FRAGMENT_SUBROUTINE)
 OGL_CONST_i(GL_FRAGMENT_SUBROUTINE_UNIFORM)
 OGL_CONST_i(GL_FRAGMENT_TEXTURE)
 OGL_CONST_i(GL_FRAMEBUFFER)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_ANGLE)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_LAYERED)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_LAYERED_ARB)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_LAYERED_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_LAYERED_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_BASE_VIEW_INDEX_OVR)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER_NV)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_NUM_VIEWS_OVR)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SAMPLES_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SCALE_IMG)
 OGL_CONST_i(GL_FRAMEBUFFER_BARRIER_BIT)
 OGL_CONST_i(GL_FRAMEBUFFER_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_BINDING)
 OGL_CONST_i(GL_FRAMEBUFFER_BINDING_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_BINDING_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_BLEND)
 OGL_CONST_i(GL_FRAMEBUFFER_COMPLETE)
 OGL_CONST_i(GL_FRAMEBUFFER_COMPLETE_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_COMPLETE_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_DEFAULT)
 OGL_CONST_i(GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS)
 OGL_CONST_i(GL_FRAMEBUFFER_DEFAULT_HEIGHT)
 OGL_CONST_i(GL_FRAMEBUFFER_DEFAULT_LAYERS)
 OGL_CONST_i(GL_FRAMEBUFFER_DEFAULT_LAYERS_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_DEFAULT_LAYERS_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_DEFAULT_SAMPLES)
 OGL_CONST_i(GL_FRAMEBUFFER_DEFAULT_WIDTH)
 OGL_CONST_i(GL_FRAMEBUFFER_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_FETCH_NONCOHERENT_QCOM)
 OGL_CONST_i(GL_FRAMEBUFFER_FLIP_X_MESA)
 OGL_CONST_i(GL_FRAMEBUFFER_FLIP_Y_MESA)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_FORMATS_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_FOVEATION_QCOM)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_INSUFFICIENT_SHADER_COMBINED_LOCAL_STORAGE_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_ARB)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_ARB)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_AND_DOWNSAMPLE_IMG)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_ANGLE)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_APPLE)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_IMG)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE_NV)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_INCOMPLETE_VIEW_TARGETS_OVR)
 OGL_CONST_i(GL_FRAMEBUFFER_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_PROGRAMMABLE_SAMPLE_LOCATIONS_ARB)
 OGL_CONST_i(GL_FRAMEBUFFER_PROGRAMMABLE_SAMPLE_LOCATIONS_NV)
 OGL_CONST_i(GL_FRAMEBUFFER_RENDERABLE)
 OGL_CONST_i(GL_FRAMEBUFFER_RENDERABLE_LAYERED)
 OGL_CONST_i(GL_FRAMEBUFFER_SAMPLE_LOCATION_PIXEL_GRID_ARB)
 OGL_CONST_i(GL_FRAMEBUFFER_SAMPLE_LOCATION_PIXEL_GRID_NV)
 OGL_CONST_i(GL_FRAMEBUFFER_SRGB)
 OGL_CONST_i(GL_FRAMEBUFFER_SRGB_CAPABLE_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_SRGB_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_SWAP_XY_MESA)
 OGL_CONST_i(GL_FRAMEBUFFER_UNDEFINED)
 OGL_CONST_i(GL_FRAMEBUFFER_UNDEFINED_OES)
 OGL_CONST_i(GL_FRAMEBUFFER_UNSUPPORTED)
 OGL_CONST_i(GL_FRAMEBUFFER_UNSUPPORTED_EXT)
 OGL_CONST_i(GL_FRAMEBUFFER_UNSUPPORTED_OES)
 OGL_CONST_i(GL_FRAME_NV)
 OGL_CONST_i(GL_FRONT)
 OGL_CONST_i(GL_FRONT_AND_BACK)
 OGL_CONST_i(GL_FRONT_FACE)
 OGL_CONST_i(GL_FRONT_FACE_COMMAND_NV)
 OGL_CONST_i(GL_FRONT_LEFT)
 OGL_CONST_i(GL_FRONT_RIGHT)
 OGL_CONST_i(GL_FULL_RANGE_EXT)
 OGL_CONST_i(GL_FULL_STIPPLE_HINT_PGI)
 OGL_CONST_i(GL_FULL_SUPPORT)
 OGL_CONST_i(GL_FUNC_ADD)
 OGL_CONST_i(GL_FUNC_ADD_EXT)
 OGL_CONST_i(GL_FUNC_ADD_OES)
 OGL_CONST_i(GL_FUNC_COMPLEX_ADD_EXT)
 OGL_CONST_i(GL_FUNC_COMPLEX_MULTIPLY_EXT)
 OGL_CONST_i(GL_FUNC_REVERSE_SUBTRACT)
 OGL_CONST_i(GL_FUNC_REVERSE_SUBTRACT_EXT)
 OGL_CONST_i(GL_FUNC_REVERSE_SUBTRACT_OES)
 OGL_CONST_i(GL_FUNC_SUBTRACT)
 OGL_CONST_i(GL_FUNC_SUBTRACT_EXT)
 OGL_CONST_i(GL_FUNC_SUBTRACT_OES)
 OGL_CONST_i(GL_GCCSO_SHADER_BINARY_FJ)
 OGL_CONST_i(GL_GENERATE_MIPMAP)
 OGL_CONST_i(GL_GENERATE_MIPMAP_HINT)
 OGL_CONST_i(GL_GENERATE_MIPMAP_HINT_SGIS)
 OGL_CONST_i(GL_GENERATE_MIPMAP_SGIS)
 OGL_CONST_i(GL_GENERIC_ATTRIB_NV)
 OGL_CONST_i(GL_GEOMETRY_BIT)
 OGL_CONST_i(GL_GEOMETRY_DEFORMATION_BIT_SGIX)
 OGL_CONST_i(GL_GEOMETRY_INPUT_TYPE)
 OGL_CONST_i(GL_GEOMETRY_INPUT_TYPE_ARB)
 OGL_CONST_i(GL_GEOMETRY_INPUT_TYPE_EXT)
 OGL_CONST_i(GL_GEOMETRY_LINKED_INPUT_TYPE_EXT)
 OGL_CONST_i(GL_GEOMETRY_LINKED_INPUT_TYPE_OES)
 OGL_CONST_i(GL_GEOMETRY_LINKED_OUTPUT_TYPE_EXT)
 OGL_CONST_i(GL_GEOMETRY_LINKED_OUTPUT_TYPE_OES)
 OGL_CONST_i(GL_GEOMETRY_LINKED_VERTICES_OUT_EXT)
 OGL_CONST_i(GL_GEOMETRY_LINKED_VERTICES_OUT_OES)
 OGL_CONST_i(GL_GEOMETRY_OUTPUT_TYPE)
 OGL_CONST_i(GL_GEOMETRY_OUTPUT_TYPE_ARB)
 OGL_CONST_i(GL_GEOMETRY_OUTPUT_TYPE_EXT)
 OGL_CONST_i(GL_GEOMETRY_PROGRAM_NV)
 OGL_CONST_i(GL_GEOMETRY_PROGRAM_PARAMETER_BUFFER_NV)
 OGL_CONST_i(GL_GEOMETRY_SHADER)
 OGL_CONST_i(GL_GEOMETRY_SHADER_ARB)
 OGL_CONST_i(GL_GEOMETRY_SHADER_BIT)
 OGL_CONST_i(GL_GEOMETRY_SHADER_BIT_EXT)
 OGL_CONST_i(GL_GEOMETRY_SHADER_BIT_OES)
 OGL_CONST_i(GL_GEOMETRY_SHADER_EXT)
 OGL_CONST_i(GL_GEOMETRY_SHADER_INVOCATIONS)
 OGL_CONST_i(GL_GEOMETRY_SHADER_INVOCATIONS_EXT)
 OGL_CONST_i(GL_GEOMETRY_SHADER_INVOCATIONS_OES)
 OGL_CONST_i(GL_GEOMETRY_SHADER_OES)
 OGL_CONST_i(GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED)
 OGL_CONST_i(GL_GEOMETRY_SHADER_PRIMITIVES_EMITTED_ARB)
 OGL_CONST_i(GL_GEOMETRY_SUBROUTINE)
 OGL_CONST_i(GL_GEOMETRY_SUBROUTINE_UNIFORM)
 OGL_CONST_i(GL_GEOMETRY_TEXTURE)
 OGL_CONST_i(GL_GEOMETRY_VERTICES_OUT)
 OGL_CONST_i(GL_GEOMETRY_VERTICES_OUT_ARB)
 OGL_CONST_i(GL_GEOMETRY_VERTICES_OUT_EXT)
 OGL_CONST_i(GL_GEQUAL)
 OGL_CONST_i(GL_GET_TEXTURE_IMAGE_FORMAT)
 OGL_CONST_i(GL_GET_TEXTURE_IMAGE_TYPE)
 OGL_CONST_i(GL_GLOBAL_ALPHA_FACTOR_SUN)
 OGL_CONST_i(GL_GLOBAL_ALPHA_SUN)
 OGL_CONST_i(GL_GLYPH_HAS_KERNING_BIT_NV)
 OGL_CONST_i(GL_GLYPH_HEIGHT_BIT_NV)
 OGL_CONST_i(GL_GLYPH_HORIZONTAL_BEARING_ADVANCE_BIT_NV)
 OGL_CONST_i(GL_GLYPH_HORIZONTAL_BEARING_X_BIT_NV)
 OGL_CONST_i(GL_GLYPH_HORIZONTAL_BEARING_Y_BIT_NV)
 OGL_CONST_i(GL_GLYPH_VERTICAL_BEARING_ADVANCE_BIT_NV)
 OGL_CONST_i(GL_GLYPH_VERTICAL_BEARING_X_BIT_NV)
 OGL_CONST_i(GL_GLYPH_VERTICAL_BEARING_Y_BIT_NV)
 OGL_CONST_i(GL_GLYPH_WIDTH_BIT_NV)
 OGL_CONST_i(GL_GPU_ADDRESS_NV)
 OGL_CONST_i(GL_GPU_DISJOINT_EXT)
 OGL_CONST_i(GL_GPU_MEMORY_INFO_CURRENT_AVAILABLE_VIDMEM_NVX)
 OGL_CONST_i(GL_GPU_MEMORY_INFO_DEDICATED_VIDMEM_NVX)
 OGL_CONST_i(GL_GPU_MEMORY_INFO_EVICTED_MEMORY_NVX)
 OGL_CONST_i(GL_GPU_MEMORY_INFO_EVICTION_COUNT_NVX)
 OGL_CONST_i(GL_GPU_MEMORY_INFO_TOTAL_AVAILABLE_MEMORY_NVX)
 OGL_CONST_i(GL_GPU_OPTIMIZED_QCOM)
 OGL_CONST_i(GL_GREATER)
 OGL_CONST_i(GL_GREEN)
 OGL_CONST_i(GL_GREEN_BIAS)
 OGL_CONST_i(GL_GREEN_BITS)
 OGL_CONST_i(GL_GREEN_BIT_ATI)
 OGL_CONST_i(GL_GREEN_INTEGER)
 OGL_CONST_i(GL_GREEN_INTEGER_EXT)
 OGL_CONST_i(GL_GREEN_MAX_CLAMP_INGR)
 OGL_CONST_i(GL_GREEN_MIN_CLAMP_INGR)
 OGL_CONST_i(GL_GREEN_NV)
 OGL_CONST_i(GL_GREEN_SCALE)
 OGL_CONST_i(GL_GUILTY_CONTEXT_RESET)
 OGL_CONST_i(GL_GUILTY_CONTEXT_RESET_ARB)
 OGL_CONST_i(GL_GUILTY_CONTEXT_RESET_EXT)
 OGL_CONST_i(GL_HALF_APPLE)
 OGL_CONST_i(GL_HALF_BIAS_NEGATE_NV)
 OGL_CONST_i(GL_HALF_BIAS_NORMAL_NV)
 OGL_CONST_i(GL_HALF_BIT_ATI)
 OGL_CONST_i(GL_HALF_FLOAT)
 OGL_CONST_i(GL_HALF_FLOAT_ARB)
 OGL_CONST_i(GL_HALF_FLOAT_NV)
 OGL_CONST_i(GL_HALF_FLOAT_OES)
 OGL_CONST_i(GL_HANDLE_TYPE_D3D11_IMAGE_EXT)
 OGL_CONST_i(GL_HANDLE_TYPE_D3D11_IMAGE_KMT_EXT)
 OGL_CONST_i(GL_HANDLE_TYPE_D3D12_FENCE_EXT)
 OGL_CONST_i(GL_HANDLE_TYPE_D3D12_RESOURCE_EXT)
 OGL_CONST_i(GL_HANDLE_TYPE_D3D12_TILEPOOL_EXT)
 OGL_CONST_i(GL_HANDLE_TYPE_OPAQUE_FD_EXT)
 OGL_CONST_i(GL_HANDLE_TYPE_OPAQUE_WIN32_EXT)
 OGL_CONST_i(GL_HANDLE_TYPE_OPAQUE_WIN32_KMT_EXT)
 OGL_CONST_i(GL_HARDLIGHT_KHR)
 OGL_CONST_i(GL_HARDLIGHT_NV)
 OGL_CONST_i(GL_HARDMIX_NV)
 OGL_CONST_i(GL_HIGH_FLOAT)
 OGL_CONST_i(GL_HIGH_INT)
 OGL_CONST_i(GL_HILO16_NV)
 OGL_CONST_i(GL_HILO8_NV)
 OGL_CONST_i(GL_HILO_NV)
 OGL_CONST_i(GL_HINT_BIT)
 OGL_CONST_i(GL_HISTOGRAM)
 OGL_CONST_i(GL_HISTOGRAM_ALPHA_SIZE)
 OGL_CONST_i(GL_HISTOGRAM_ALPHA_SIZE_EXT)
 OGL_CONST_i(GL_HISTOGRAM_BLUE_SIZE)
 OGL_CONST_i(GL_HISTOGRAM_BLUE_SIZE_EXT)
 OGL_CONST_i(GL_HISTOGRAM_EXT)
 OGL_CONST_i(GL_HISTOGRAM_FORMAT)
 OGL_CONST_i(GL_HISTOGRAM_FORMAT_EXT)
 OGL_CONST_i(GL_HISTOGRAM_GREEN_SIZE)
 OGL_CONST_i(GL_HISTOGRAM_GREEN_SIZE_EXT)
 OGL_CONST_i(GL_HISTOGRAM_LUMINANCE_SIZE)
 OGL_CONST_i(GL_HISTOGRAM_LUMINANCE_SIZE_EXT)
 OGL_CONST_i(GL_HISTOGRAM_RED_SIZE)
 OGL_CONST_i(GL_HISTOGRAM_RED_SIZE_EXT)
 OGL_CONST_i(GL_HISTOGRAM_SINK)
 OGL_CONST_i(GL_HISTOGRAM_SINK_EXT)
 OGL_CONST_i(GL_HISTOGRAM_WIDTH)
 OGL_CONST_i(GL_HISTOGRAM_WIDTH_EXT)
 OGL_CONST_i(GL_HI_BIAS_NV)
 OGL_CONST_i(GL_HI_SCALE_NV)
 OGL_CONST_i(GL_HORIZONTAL_LINE_TO_NV)
 OGL_CONST_i(GL_HSL_COLOR_KHR)
 OGL_CONST_i(GL_HSL_COLOR_NV)
 OGL_CONST_i(GL_HSL_HUE_KHR)
 OGL_CONST_i(GL_HSL_HUE_NV)
 OGL_CONST_i(GL_HSL_LUMINOSITY_KHR)
 OGL_CONST_i(GL_HSL_LUMINOSITY_NV)
 OGL_CONST_i(GL_HSL_SATURATION_KHR)
 OGL_CONST_i(GL_HSL_SATURATION_NV)
 OGL_CONST_i(GL_HUAWEI_PROGRAM_BINARY)
 OGL_CONST_i(GL_HUAWEI_SHADER_BINARY)
 OGL_CONST_i(GL_IDENTITY_NV)
 OGL_CONST_i(GL_IGLOO_COLORNORMAL_SGIX)
 OGL_CONST_i(GL_IGLOO_FULLSCREEN_SGIX)
 OGL_CONST_i(GL_IGLOO_IRISGL_MODE_SGIX)
 OGL_CONST_i(GL_IGLOO_LMC_COLOR_SGIX)
 OGL_CONST_i(GL_IGLOO_SWAPTMESH_SGIX)
 OGL_CONST_i(GL_IGLOO_TMESHMODE_SGIX)
 OGL_CONST_i(GL_IGLOO_VIEWPORT_OFFSET_SGIX)
 OGL_CONST_i(GL_IGNORE_BORDER)
 OGL_CONST_i(GL_IMAGE_1D)
 OGL_CONST_i(GL_IMAGE_1D_ARRAY)
 OGL_CONST_i(GL_IMAGE_1D_ARRAY_EXT)
 OGL_CONST_i(GL_IMAGE_1D_EXT)
 OGL_CONST_i(GL_IMAGE_2D)
 OGL_CONST_i(GL_IMAGE_2D_ARRAY)
 OGL_CONST_i(GL_IMAGE_2D_ARRAY_EXT)
 OGL_CONST_i(GL_IMAGE_2D_EXT)
 OGL_CONST_i(GL_IMAGE_2D_MULTISAMPLE)
 OGL_CONST_i(GL_IMAGE_2D_MULTISAMPLE_ARRAY)
 OGL_CONST_i(GL_IMAGE_2D_MULTISAMPLE_ARRAY_EXT)
 OGL_CONST_i(GL_IMAGE_2D_MULTISAMPLE_EXT)
 OGL_CONST_i(GL_IMAGE_2D_RECT)
 OGL_CONST_i(GL_IMAGE_2D_RECT_EXT)
 OGL_CONST_i(GL_IMAGE_3D)
 OGL_CONST_i(GL_IMAGE_3D_EXT)
 OGL_CONST_i(GL_IMAGE_BINDING_ACCESS)
 OGL_CONST_i(GL_IMAGE_BINDING_ACCESS_EXT)
 OGL_CONST_i(GL_IMAGE_BINDING_FORMAT)
 OGL_CONST_i(GL_IMAGE_BINDING_FORMAT_EXT)
 OGL_CONST_i(GL_IMAGE_BINDING_LAYER)
 OGL_CONST_i(GL_IMAGE_BINDING_LAYERED)
 OGL_CONST_i(GL_IMAGE_BINDING_LAYERED_EXT)
 OGL_CONST_i(GL_IMAGE_BINDING_LAYER_EXT)
 OGL_CONST_i(GL_IMAGE_BINDING_LEVEL)
 OGL_CONST_i(GL_IMAGE_BINDING_LEVEL_EXT)
 OGL_CONST_i(GL_IMAGE_BINDING_NAME)
 OGL_CONST_i(GL_IMAGE_BINDING_NAME_EXT)
 OGL_CONST_i(GL_IMAGE_BIT)
 OGL_CONST_i(GL_IMAGE_BUFFER)
 OGL_CONST_i(GL_IMAGE_BUFFER_EXT)
 OGL_CONST_i(GL_IMAGE_BUFFER_OES)
 OGL_CONST_i(GL_IMAGE_CLASS_10_10_10_2)
 OGL_CONST_i(GL_IMAGE_CLASS_11_11_10)
 OGL_CONST_i(GL_IMAGE_CLASS_1_X_16)
 OGL_CONST_i(GL_IMAGE_CLASS_1_X_32)
 OGL_CONST_i(GL_IMAGE_CLASS_1_X_8)
 OGL_CONST_i(GL_IMAGE_CLASS_2_X_16)
 OGL_CONST_i(GL_IMAGE_CLASS_2_X_32)
 OGL_CONST_i(GL_IMAGE_CLASS_2_X_8)
 OGL_CONST_i(GL_IMAGE_CLASS_4_X_16)
 OGL_CONST_i(GL_IMAGE_CLASS_4_X_32)
 OGL_CONST_i(GL_IMAGE_CLASS_4_X_8)
 OGL_CONST_i(GL_IMAGE_COMPATIBILITY_CLASS)
 OGL_CONST_i(GL_IMAGE_CUBE)
 OGL_CONST_i(GL_IMAGE_CUBE_EXT)
 OGL_CONST_i(GL_IMAGE_CUBE_MAP_ARRAY)
 OGL_CONST_i(GL_IMAGE_CUBE_MAP_ARRAY_EXT)
 OGL_CONST_i(GL_IMAGE_CUBE_MAP_ARRAY_OES)
 OGL_CONST_i(GL_IMAGE_FORMAT_COMPATIBILITY_BY_CLASS)
 OGL_CONST_i(GL_IMAGE_FORMAT_COMPATIBILITY_BY_SIZE)
 OGL_CONST_i(GL_IMAGE_FORMAT_COMPATIBILITY_TYPE)
 OGL_CONST_i(GL_IMAGE_PIXEL_FORMAT)
 OGL_CONST_i(GL_IMAGE_PIXEL_TYPE)
 OGL_CONST_i(GL_IMAGE_TEXEL_SIZE)
 OGL_CONST_i(GL_IMPLEMENTATION_COLOR_READ_FORMAT)
 OGL_CONST_i(GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES)
 OGL_CONST_i(GL_IMPLEMENTATION_COLOR_READ_TYPE)
 OGL_CONST_i(GL_IMPLEMENTATION_COLOR_READ_TYPE_OES)
 OGL_CONST_i(GL_INCLUSIVE_EXT)
 OGL_CONST_i(GL_INCR)
 OGL_CONST_i(GL_INCR_WRAP)
 OGL_CONST_i(GL_INCR_WRAP_EXT)
 OGL_CONST_i(GL_INDEX)
 OGL_CONST_i(GL_INDEX_ARRAY)
 OGL_CONST_i(GL_INDEX_ARRAY_ADDRESS_NV)
 OGL_CONST_i(GL_INDEX_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_INDEX_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_INDEX_ARRAY_COUNT_EXT)
 OGL_CONST_i(GL_INDEX_ARRAY_EXT)
 OGL_CONST_i(GL_INDEX_ARRAY_LENGTH_NV)
 OGL_CONST_i(GL_INDEX_ARRAY_LIST_IBM)
 OGL_CONST_i(GL_INDEX_ARRAY_LIST_STRIDE_IBM)
 OGL_CONST_i(GL_INDEX_ARRAY_POINTER)
 OGL_CONST_i(GL_INDEX_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_INDEX_ARRAY_STRIDE)
 OGL_CONST_i(GL_INDEX_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_INDEX_ARRAY_TYPE)
 OGL_CONST_i(GL_INDEX_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_INDEX_BITS)
 OGL_CONST_i(GL_INDEX_BIT_PGI)
 OGL_CONST_i(GL_INDEX_CLEAR_VALUE)
 OGL_CONST_i(GL_INDEX_LOGIC_OP)
 OGL_CONST_i(GL_INDEX_MODE)
 OGL_CONST_i(GL_INDEX_OFFSET)
 OGL_CONST_i(GL_INDEX_SHIFT)
 OGL_CONST_i(GL_INDEX_WRITEMASK)
 OGL_CONST_i(GL_INFO_LOG_LENGTH)
 OGL_CONST_i(GL_INNOCENT_CONTEXT_RESET)
 OGL_CONST_i(GL_INNOCENT_CONTEXT_RESET_ARB)
 OGL_CONST_i(GL_INNOCENT_CONTEXT_RESET_EXT)
 OGL_CONST_i(GL_INT)
 OGL_CONST_i(GL_INT16_NV)
 OGL_CONST_i(GL_INT16_VEC2_NV)
 OGL_CONST_i(GL_INT16_VEC3_NV)
 OGL_CONST_i(GL_INT16_VEC4_NV)
 OGL_CONST_i(GL_INT64_ARB)
 OGL_CONST_i(GL_INT64_NV)
 OGL_CONST_i(GL_INT64_VEC2_ARB)
 OGL_CONST_i(GL_INT64_VEC2_NV)
 OGL_CONST_i(GL_INT64_VEC3_ARB)
 OGL_CONST_i(GL_INT64_VEC3_NV)
 OGL_CONST_i(GL_INT64_VEC4_ARB)
 OGL_CONST_i(GL_INT64_VEC4_NV)
 OGL_CONST_i(GL_INT8_NV)
 OGL_CONST_i(GL_INT8_VEC2_NV)
 OGL_CONST_i(GL_INT8_VEC3_NV)
 OGL_CONST_i(GL_INT8_VEC4_NV)
 OGL_CONST_i(GL_INTENSITY)
 OGL_CONST_i(GL_INTENSITY12)
 OGL_CONST_i(GL_INTENSITY12_EXT)
 OGL_CONST_i(GL_INTENSITY16)
 OGL_CONST_i(GL_INTENSITY16F_ARB)
 OGL_CONST_i(GL_INTENSITY16I_EXT)
 OGL_CONST_i(GL_INTENSITY16UI_EXT)
 OGL_CONST_i(GL_INTENSITY16_EXT)
 OGL_CONST_i(GL_INTENSITY16_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_INTENSITY16_ICC_SGIX)
 OGL_CONST_i(GL_INTENSITY16_SIGNED_SGIX)
 OGL_CONST_i(GL_INTENSITY16_SNORM)
 OGL_CONST_i(GL_INTENSITY32F_ARB)
 OGL_CONST_i(GL_INTENSITY32I_EXT)
 OGL_CONST_i(GL_INTENSITY32UI_EXT)
 OGL_CONST_i(GL_INTENSITY4)
 OGL_CONST_i(GL_INTENSITY4_EXT)
 OGL_CONST_i(GL_INTENSITY8)
 OGL_CONST_i(GL_INTENSITY8I_EXT)
 OGL_CONST_i(GL_INTENSITY8UI_EXT)
 OGL_CONST_i(GL_INTENSITY8_EXT)
 OGL_CONST_i(GL_INTENSITY8_SNORM)
 OGL_CONST_i(GL_INTENSITY_EXT)
 OGL_CONST_i(GL_INTENSITY_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_INTENSITY_FLOAT16_APPLE)
 OGL_CONST_i(GL_INTENSITY_FLOAT16_ATI)
 OGL_CONST_i(GL_INTENSITY_FLOAT32_APPLE)
 OGL_CONST_i(GL_INTENSITY_FLOAT32_ATI)
 OGL_CONST_i(GL_INTENSITY_ICC_SGIX)
 OGL_CONST_i(GL_INTENSITY_SIGNED_SGIX)
 OGL_CONST_i(GL_INTENSITY_SNORM)
 OGL_CONST_i(GL_INTERLACE_OML)
 OGL_CONST_i(GL_INTERLACE_READ_INGR)
 OGL_CONST_i(GL_INTERLACE_READ_OML)
 OGL_CONST_i(GL_INTERLACE_SGIX)
 OGL_CONST_i(GL_INTERLEAVED_ATTRIBS)
 OGL_CONST_i(GL_INTERLEAVED_ATTRIBS_EXT)
 OGL_CONST_i(GL_INTERLEAVED_ATTRIBS_NV)
 OGL_CONST_i(GL_INTERNALFORMAT_ALPHA_SIZE)
 OGL_CONST_i(GL_INTERNALFORMAT_ALPHA_TYPE)
 OGL_CONST_i(GL_INTERNALFORMAT_BLUE_SIZE)
 OGL_CONST_i(GL_INTERNALFORMAT_BLUE_TYPE)
 OGL_CONST_i(GL_INTERNALFORMAT_DEPTH_SIZE)
 OGL_CONST_i(GL_INTERNALFORMAT_DEPTH_TYPE)
 OGL_CONST_i(GL_INTERNALFORMAT_GREEN_SIZE)
 OGL_CONST_i(GL_INTERNALFORMAT_GREEN_TYPE)
 OGL_CONST_i(GL_INTERNALFORMAT_PREFERRED)
 OGL_CONST_i(GL_INTERNALFORMAT_RED_SIZE)
 OGL_CONST_i(GL_INTERNALFORMAT_RED_TYPE)
 OGL_CONST_i(GL_INTERNALFORMAT_SHARED_SIZE)
 OGL_CONST_i(GL_INTERNALFORMAT_STENCIL_SIZE)
 OGL_CONST_i(GL_INTERNALFORMAT_STENCIL_TYPE)
 OGL_CONST_i(GL_INTERNALFORMAT_SUPPORTED)
 OGL_CONST_i(GL_INTERPOLATE)
 OGL_CONST_i(GL_INTERPOLATE_ARB)
 OGL_CONST_i(GL_INTERPOLATE_EXT)
 OGL_CONST_i(GL_INT_10_10_10_2_OES)
 OGL_CONST_i(GL_INT_2_10_10_10_REV)
 OGL_CONST_i(GL_INT_IMAGE_1D)
 OGL_CONST_i(GL_INT_IMAGE_1D_ARRAY)
 OGL_CONST_i(GL_INT_IMAGE_1D_ARRAY_EXT)
 OGL_CONST_i(GL_INT_IMAGE_1D_EXT)
 OGL_CONST_i(GL_INT_IMAGE_2D)
 OGL_CONST_i(GL_INT_IMAGE_2D_ARRAY)
 OGL_CONST_i(GL_INT_IMAGE_2D_ARRAY_EXT)
 OGL_CONST_i(GL_INT_IMAGE_2D_EXT)
 OGL_CONST_i(GL_INT_IMAGE_2D_MULTISAMPLE)
 OGL_CONST_i(GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY)
 OGL_CONST_i(GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY_EXT)
 OGL_CONST_i(GL_INT_IMAGE_2D_MULTISAMPLE_EXT)
 OGL_CONST_i(GL_INT_IMAGE_2D_RECT)
 OGL_CONST_i(GL_INT_IMAGE_2D_RECT_EXT)
 OGL_CONST_i(GL_INT_IMAGE_3D)
 OGL_CONST_i(GL_INT_IMAGE_3D_EXT)
 OGL_CONST_i(GL_INT_IMAGE_BUFFER)
 OGL_CONST_i(GL_INT_IMAGE_BUFFER_EXT)
 OGL_CONST_i(GL_INT_IMAGE_BUFFER_OES)
 OGL_CONST_i(GL_INT_IMAGE_CUBE)
 OGL_CONST_i(GL_INT_IMAGE_CUBE_EXT)
 OGL_CONST_i(GL_INT_IMAGE_CUBE_MAP_ARRAY)
 OGL_CONST_i(GL_INT_IMAGE_CUBE_MAP_ARRAY_EXT)
 OGL_CONST_i(GL_INT_IMAGE_CUBE_MAP_ARRAY_OES)
 OGL_CONST_i(GL_INT_SAMPLER_1D)
 OGL_CONST_i(GL_INT_SAMPLER_1D_ARRAY)
 OGL_CONST_i(GL_INT_SAMPLER_1D_ARRAY_EXT)
 OGL_CONST_i(GL_INT_SAMPLER_1D_EXT)
 OGL_CONST_i(GL_INT_SAMPLER_2D)
 OGL_CONST_i(GL_INT_SAMPLER_2D_ARRAY)
 OGL_CONST_i(GL_INT_SAMPLER_2D_ARRAY_EXT)
 OGL_CONST_i(GL_INT_SAMPLER_2D_EXT)
 OGL_CONST_i(GL_INT_SAMPLER_2D_MULTISAMPLE)
 OGL_CONST_i(GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY)
 OGL_CONST_i(GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY_OES)
 OGL_CONST_i(GL_INT_SAMPLER_2D_RECT)
 OGL_CONST_i(GL_INT_SAMPLER_2D_RECT_EXT)
 OGL_CONST_i(GL_INT_SAMPLER_3D)
 OGL_CONST_i(GL_INT_SAMPLER_3D_EXT)
 OGL_CONST_i(GL_INT_SAMPLER_BUFFER)
 OGL_CONST_i(GL_INT_SAMPLER_BUFFER_AMD)
 OGL_CONST_i(GL_INT_SAMPLER_BUFFER_EXT)
 OGL_CONST_i(GL_INT_SAMPLER_BUFFER_OES)
 OGL_CONST_i(GL_INT_SAMPLER_CUBE)
 OGL_CONST_i(GL_INT_SAMPLER_CUBE_EXT)
 OGL_CONST_i(GL_INT_SAMPLER_CUBE_MAP_ARRAY)
 OGL_CONST_i(GL_INT_SAMPLER_CUBE_MAP_ARRAY_ARB)
 OGL_CONST_i(GL_INT_SAMPLER_CUBE_MAP_ARRAY_EXT)
 OGL_CONST_i(GL_INT_SAMPLER_CUBE_MAP_ARRAY_OES)
 OGL_CONST_i(GL_INT_SAMPLER_RENDERBUFFER_NV)
 OGL_CONST_i(GL_INT_VEC2)
 OGL_CONST_i(GL_INT_VEC2_ARB)
 OGL_CONST_i(GL_INT_VEC3)
 OGL_CONST_i(GL_INT_VEC3_ARB)
 OGL_CONST_i(GL_INT_VEC4)
 OGL_CONST_i(GL_INT_VEC4_ARB)
 OGL_CONST_i(GL_INVALID_ENUM)
 OGL_CONST_i(GL_INVALID_FRAMEBUFFER_OPERATION)
 OGL_CONST_i(GL_INVALID_FRAMEBUFFER_OPERATION_EXT)
 OGL_CONST_i(GL_INVALID_FRAMEBUFFER_OPERATION_OES)
 OGL_CONST_i(GL_INVALID_INDEX)
 OGL_CONST_i(GL_INVALID_OPERATION)
 OGL_CONST_i(GL_INVALID_VALUE)
 OGL_CONST_i(GL_INVARIANT_DATATYPE_EXT)
 OGL_CONST_i(GL_INVARIANT_EXT)
 OGL_CONST_i(GL_INVARIANT_VALUE_EXT)
 OGL_CONST_i(GL_INVERSE_NV)
 OGL_CONST_i(GL_INVERSE_TRANSPOSE_NV)
 OGL_CONST_i(GL_INVERT)
 OGL_CONST_i(GL_INVERTED_SCREEN_W_REND)
 OGL_CONST_i(GL_INVERT_OVG_NV)
 OGL_CONST_i(GL_INVERT_RGB_NV)
 OGL_CONST_i(GL_ISOLINES)
 OGL_CONST_i(GL_ISOLINES_EXT)
 OGL_CONST_i(GL_ISOLINES_OES)
 OGL_CONST_i(GL_IS_PER_PATCH)
 OGL_CONST_i(GL_IS_PER_PATCH_EXT)
 OGL_CONST_i(GL_IS_PER_PATCH_OES)
 OGL_CONST_i(GL_IS_ROW_MAJOR)
 OGL_CONST_i(GL_ITALIC_BIT_NV)
 OGL_CONST_i(GL_KEEP)
 OGL_CONST_i(GL_KTX_BACK_REGION)
 OGL_CONST_i(GL_KTX_FRONT_REGION)
 OGL_CONST_i(GL_KTX_STENCIL_REGION)
 OGL_CONST_i(GL_KTX_Z_REGION)
 OGL_CONST_i(GL_LARGE_CCW_ARC_TO_NV)
 OGL_CONST_i(GL_LARGE_CW_ARC_TO_NV)
 OGL_CONST_i(GL_LAST_VERTEX_CONVENTION)
 OGL_CONST_i(GL_LAST_VERTEX_CONVENTION_EXT)
 OGL_CONST_i(GL_LAST_VERTEX_CONVENTION_OES)
 OGL_CONST_i(GL_LAST_VIDEO_CAPTURE_STATUS_NV)
 OGL_CONST_i(GL_LAYERED_SGIX)
 OGL_CONST_i(GL_LAYER_PROVOKING_VERTEX)
 OGL_CONST_i(GL_LAYER_PROVOKING_VERTEX_EXT)
 OGL_CONST_i(GL_LAYER_PROVOKING_VERTEX_OES)
 OGL_CONST_i(GL_LAYOUT_COLOR_ATTACHMENT_EXT)
 OGL_CONST_i(GL_LAYOUT_DEFAULT_INTEL)
 OGL_CONST_i(GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT)
 OGL_CONST_i(GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT)
 OGL_CONST_i(GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT)
 OGL_CONST_i(GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT)
 OGL_CONST_i(GL_LAYOUT_GENERAL_EXT)
 OGL_CONST_i(GL_LAYOUT_LINEAR_CPU_CACHED_INTEL)
 OGL_CONST_i(GL_LAYOUT_SHADER_READ_ONLY_EXT)
 OGL_CONST_i(GL_LAYOUT_TRANSFER_DST_EXT)
 OGL_CONST_i(GL_LAYOUT_TRANSFER_SRC_EXT)
 OGL_CONST_i(GL_LEFT)
 OGL_CONST_i(GL_LEQUAL)
 OGL_CONST_i(GL_LERP_ATI)
 OGL_CONST_i(GL_LESS)
 OGL_CONST_i(GL_LGPU_SEPARATE_STORAGE_BIT_NVX)
 OGL_CONST_i(GL_LIGHT0)
 OGL_CONST_i(GL_LIGHT1)
 OGL_CONST_i(GL_LIGHT2)
 OGL_CONST_i(GL_LIGHT3)
 OGL_CONST_i(GL_LIGHT31)
 OGL_CONST_i(GL_LIGHT4)
 OGL_CONST_i(GL_LIGHT5)
 OGL_CONST_i(GL_LIGHT6)
 OGL_CONST_i(GL_LIGHT7)
 OGL_CONST_i(GL_LIGHTEN_KHR)
 OGL_CONST_i(GL_LIGHTEN_NV)
 OGL_CONST_i(GL_LIGHTING)
 OGL_CONST_i(GL_LIGHTING_BIT)
 OGL_CONST_i(GL_LIGHT_ENV_MODE_EXT)
 OGL_CONST_i(GL_LIGHT_MODEL_AMBIENT)
 OGL_CONST_i(GL_LIGHT_MODEL_COLOR_CONTROL)
 OGL_CONST_i(GL_LIGHT_MODEL_COLOR_CONTROL_EXT)
 OGL_CONST_i(GL_LIGHT_MODEL_LOCAL_VIEWER)
 OGL_CONST_i(GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE)
 OGL_CONST_i(GL_LIGHT_MODEL_TWO_SIDE)
 OGL_CONST_i(GL_LINE)
 OGL_CONST_i(GL_LINEAR)
 OGL_CONST_i(GL_LINEARBURN_NV)
 OGL_CONST_i(GL_LINEARDODGE_NV)
 OGL_CONST_i(GL_LINEARLIGHT_NV)
 OGL_CONST_i(GL_LINEAR_ATTENUATION)
 OGL_CONST_i(GL_LINEAR_MIPMAP_LINEAR)
 OGL_CONST_i(GL_LINEAR_MIPMAP_NEAREST)
 OGL_CONST_i(GL_LINEAR_TILING_EXT)
 OGL_CONST_i(GL_LINES)
 OGL_CONST_i(GL_LINES_ADJACENCY)
 OGL_CONST_i(GL_LINES_ADJACENCY_ARB)
 OGL_CONST_i(GL_LINES_ADJACENCY_EXT)
 OGL_CONST_i(GL_LINES_ADJACENCY_OES)
 OGL_CONST_i(GL_LINE_BIT)
 OGL_CONST_i(GL_LINE_LOOP)
 OGL_CONST_i(GL_LINE_NV)
 OGL_CONST_i(GL_LINE_QUALITY_HINT_SGIX)
 OGL_CONST_i(GL_LINE_RESET_TOKEN)
 OGL_CONST_i(GL_LINE_SMOOTH)
 OGL_CONST_i(GL_LINE_SMOOTH_HINT)
 OGL_CONST_i(GL_LINE_STIPPLE)
 OGL_CONST_i(GL_LINE_STIPPLE_PATTERN)
 OGL_CONST_i(GL_LINE_STIPPLE_REPEAT)
 OGL_CONST_i(GL_LINE_STRIP)
 OGL_CONST_i(GL_LINE_STRIP_ADJACENCY)
 OGL_CONST_i(GL_LINE_STRIP_ADJACENCY_ARB)
 OGL_CONST_i(GL_LINE_STRIP_ADJACENCY_EXT)
 OGL_CONST_i(GL_LINE_STRIP_ADJACENCY_OES)
 OGL_CONST_i(GL_LINE_TOKEN)
 OGL_CONST_i(GL_LINE_TO_NV)
 OGL_CONST_i(GL_LINE_WIDTH)
 OGL_CONST_i(GL_LINE_WIDTH_COMMAND_NV)
 OGL_CONST_i(GL_LINE_WIDTH_GRANULARITY)
 OGL_CONST_i(GL_LINE_WIDTH_RANGE)
 OGL_CONST_i(GL_LINK_STATUS)
 OGL_CONST_i(GL_LIST_BASE)
 OGL_CONST_i(GL_LIST_BIT)
 OGL_CONST_i(GL_LIST_INDEX)
 OGL_CONST_i(GL_LIST_MODE)
 OGL_CONST_i(GL_LOAD)
 OGL_CONST_i(GL_LOCAL_CONSTANT_DATATYPE_EXT)
 OGL_CONST_i(GL_LOCAL_CONSTANT_EXT)
 OGL_CONST_i(GL_LOCAL_CONSTANT_VALUE_EXT)
 OGL_CONST_i(GL_LOCAL_EXT)
 OGL_CONST_i(GL_LOCATION)
 OGL_CONST_i(GL_LOCATION_COMPONENT)
 OGL_CONST_i(GL_LOCATION_INDEX)
 OGL_CONST_i(GL_LOCATION_INDEX_EXT)
 OGL_CONST_i(GL_LOGIC_OP)
 OGL_CONST_i(GL_LOGIC_OP_MODE)
 OGL_CONST_i(GL_LOG_APP_REGAL)
 OGL_CONST_i(GL_LOG_DEBUG_REGAL)
 OGL_CONST_i(GL_LOG_DRIVER_REGAL)
 OGL_CONST_i(GL_LOG_ERROR_REGAL)
 OGL_CONST_i(GL_LOG_HTTP_REGAL)
 OGL_CONST_i(GL_LOG_INFO_REGAL)
 OGL_CONST_i(GL_LOG_INTERNAL_REGAL)
 OGL_CONST_i(GL_LOG_REGAL)
 OGL_CONST_i(GL_LOG_STATUS_REGAL)
 OGL_CONST_i(GL_LOG_WARNING_REGAL)
 OGL_CONST_i(GL_LOSE_CONTEXT_ON_RESET)
 OGL_CONST_i(GL_LOSE_CONTEXT_ON_RESET_ARB)
 OGL_CONST_i(GL_LOSE_CONTEXT_ON_RESET_EXT)
 OGL_CONST_i(GL_LOWER_LEFT)
 OGL_CONST_i(GL_LOWER_LEFT_EXT)
 OGL_CONST_i(GL_LOW_FLOAT)
 OGL_CONST_i(GL_LOW_INT)
 OGL_CONST_i(GL_LO_BIAS_NV)
 OGL_CONST_i(GL_LO_SCALE_NV)
 OGL_CONST_i(GL_LUID_SIZE_EXT)
 OGL_CONST_i(GL_LUMINANCE)
 OGL_CONST_i(GL_LUMINANCE12)
 OGL_CONST_i(GL_LUMINANCE12_ALPHA12)
 OGL_CONST_i(GL_LUMINANCE12_ALPHA12_EXT)
 OGL_CONST_i(GL_LUMINANCE12_ALPHA4)
 OGL_CONST_i(GL_LUMINANCE12_ALPHA4_EXT)
 OGL_CONST_i(GL_LUMINANCE12_EXT)
 OGL_CONST_i(GL_LUMINANCE16)
 OGL_CONST_i(GL_LUMINANCE16F_ARB)
 OGL_CONST_i(GL_LUMINANCE16F_EXT)
 OGL_CONST_i(GL_LUMINANCE16I_EXT)
 OGL_CONST_i(GL_LUMINANCE16UI_EXT)
 OGL_CONST_i(GL_LUMINANCE16_ALPHA16)
 OGL_CONST_i(GL_LUMINANCE16_ALPHA16_EXT)
 OGL_CONST_i(GL_LUMINANCE16_ALPHA16_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_LUMINANCE16_ALPHA16_SIGNED_SGIX)
 OGL_CONST_i(GL_LUMINANCE16_ALPHA16_SNORM)
 OGL_CONST_i(GL_LUMINANCE16_ALPHA8_ICC_SGIX)
 OGL_CONST_i(GL_LUMINANCE16_EXT)
 OGL_CONST_i(GL_LUMINANCE16_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_LUMINANCE16_ICC_SGIX)
 OGL_CONST_i(GL_LUMINANCE16_SIGNED_SGIX)
 OGL_CONST_i(GL_LUMINANCE16_SNORM)
 OGL_CONST_i(GL_LUMINANCE32F_ARB)
 OGL_CONST_i(GL_LUMINANCE32F_EXT)
 OGL_CONST_i(GL_LUMINANCE32I_EXT)
 OGL_CONST_i(GL_LUMINANCE32UI_EXT)
 OGL_CONST_i(GL_LUMINANCE4)
 OGL_CONST_i(GL_LUMINANCE4_ALPHA4)
 OGL_CONST_i(GL_LUMINANCE4_ALPHA4_EXT)
 OGL_CONST_i(GL_LUMINANCE4_ALPHA4_OES)
 OGL_CONST_i(GL_LUMINANCE4_EXT)
 OGL_CONST_i(GL_LUMINANCE6_ALPHA2)
 OGL_CONST_i(GL_LUMINANCE6_ALPHA2_EXT)
 OGL_CONST_i(GL_LUMINANCE8)
 OGL_CONST_i(GL_LUMINANCE8I_EXT)
 OGL_CONST_i(GL_LUMINANCE8UI_EXT)
 OGL_CONST_i(GL_LUMINANCE8_ALPHA8)
 OGL_CONST_i(GL_LUMINANCE8_ALPHA8_EXT)
 OGL_CONST_i(GL_LUMINANCE8_ALPHA8_OES)
 OGL_CONST_i(GL_LUMINANCE8_ALPHA8_SNORM)
 OGL_CONST_i(GL_LUMINANCE8_EXT)
 OGL_CONST_i(GL_LUMINANCE8_OES)
 OGL_CONST_i(GL_LUMINANCE8_SNORM)
 OGL_CONST_i(GL_LUMINANCE_ALPHA)
 OGL_CONST_i(GL_LUMINANCE_ALPHA16F_ARB)
 OGL_CONST_i(GL_LUMINANCE_ALPHA16F_EXT)
 OGL_CONST_i(GL_LUMINANCE_ALPHA16I_EXT)
 OGL_CONST_i(GL_LUMINANCE_ALPHA16UI_EXT)
 OGL_CONST_i(GL_LUMINANCE_ALPHA32F_ARB)
 OGL_CONST_i(GL_LUMINANCE_ALPHA32F_EXT)
 OGL_CONST_i(GL_LUMINANCE_ALPHA32I_EXT)
 OGL_CONST_i(GL_LUMINANCE_ALPHA32UI_EXT)
 OGL_CONST_i(GL_LUMINANCE_ALPHA8I_EXT)
 OGL_CONST_i(GL_LUMINANCE_ALPHA8UI_EXT)
 OGL_CONST_i(GL_LUMINANCE_ALPHA_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_LUMINANCE_ALPHA_FLOAT16_APPLE)
 OGL_CONST_i(GL_LUMINANCE_ALPHA_FLOAT16_ATI)
 OGL_CONST_i(GL_LUMINANCE_ALPHA_FLOAT32_APPLE)
 OGL_CONST_i(GL_LUMINANCE_ALPHA_FLOAT32_ATI)
 OGL_CONST_i(GL_LUMINANCE_ALPHA_ICC_SGIX)
 OGL_CONST_i(GL_LUMINANCE_ALPHA_INTEGER_EXT)
 OGL_CONST_i(GL_LUMINANCE_ALPHA_SIGNED_SGIX)
 OGL_CONST_i(GL_LUMINANCE_ALPHA_SNORM)
 OGL_CONST_i(GL_LUMINANCE_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_LUMINANCE_FLOAT16_APPLE)
 OGL_CONST_i(GL_LUMINANCE_FLOAT16_ATI)
 OGL_CONST_i(GL_LUMINANCE_FLOAT32_APPLE)
 OGL_CONST_i(GL_LUMINANCE_FLOAT32_ATI)
 OGL_CONST_i(GL_LUMINANCE_ICC_SGIX)
 OGL_CONST_i(GL_LUMINANCE_INTEGER_EXT)
 OGL_CONST_i(GL_LUMINANCE_SIGNED_SGIX)
 OGL_CONST_i(GL_LUMINANCE_SNORM)
 OGL_CONST_i(GL_MAD_ATI)
 OGL_CONST_i(GL_MAGNITUDE_BIAS_NV)
 OGL_CONST_i(GL_MAGNITUDE_SCALE_NV)
 OGL_CONST_i(GL_MAJOR_VERSION)
 OGL_CONST_i(GL_MALI_PROGRAM_BINARY_ARM)
 OGL_CONST_i(GL_MALI_SHADER_BINARY_ARM)
 OGL_CONST_i(GL_MANUAL_GENERATE_MIPMAP)
 OGL_CONST_i(GL_MAP1_BINORMAL_EXT)
 OGL_CONST_i(GL_MAP1_COLOR_4)
 OGL_CONST_i(GL_MAP1_COLOR_4_NURBS_SGIX)
 OGL_CONST_i(GL_MAP1_GRID_DOMAIN)
 OGL_CONST_i(GL_MAP1_GRID_SEGMENTS)
 OGL_CONST_i(GL_MAP1_INDEX)
 OGL_CONST_i(GL_MAP1_INDEX_NURBS_SGIX)
 OGL_CONST_i(GL_MAP1_NORMAL)
 OGL_CONST_i(GL_MAP1_NORMAL_NURBS_SGIX)
 OGL_CONST_i(GL_MAP1_TANGENT_EXT)
 OGL_CONST_i(GL_MAP1_TEXTURE_COORD_1)
 OGL_CONST_i(GL_MAP1_TEXTURE_COORD_1_NURBS_SGIX)
 OGL_CONST_i(GL_MAP1_TEXTURE_COORD_2)
 OGL_CONST_i(GL_MAP1_TEXTURE_COORD_2_NURBS_SGIX)
 OGL_CONST_i(GL_MAP1_TEXTURE_COORD_3)
 OGL_CONST_i(GL_MAP1_TEXTURE_COORD_3_NURBS_SGIX)
 OGL_CONST_i(GL_MAP1_TEXTURE_COORD_4)
 OGL_CONST_i(GL_MAP1_TEXTURE_COORD_4_NURBS_SGIX)
 OGL_CONST_i(GL_MAP1_VERTEX_3)
 OGL_CONST_i(GL_MAP1_VERTEX_3_NURBS_SGIX)
 OGL_CONST_i(GL_MAP1_VERTEX_4)
 OGL_CONST_i(GL_MAP1_VERTEX_4_NURBS_SGIX)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB0_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB10_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB11_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB12_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB13_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB14_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB15_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB1_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB2_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB3_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB4_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB5_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB6_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB7_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB8_4_NV)
 OGL_CONST_i(GL_MAP1_VERTEX_ATTRIB9_4_NV)
 OGL_CONST_i(GL_MAP2_BINORMAL_EXT)
 OGL_CONST_i(GL_MAP2_COLOR_4)
 OGL_CONST_i(GL_MAP2_COLOR_4_NURBS_SGIX)
 OGL_CONST_i(GL_MAP2_GRID_DOMAIN)
 OGL_CONST_i(GL_MAP2_GRID_SEGMENTS)
 OGL_CONST_i(GL_MAP2_INDEX)
 OGL_CONST_i(GL_MAP2_INDEX_NURBS_SGIX)
 OGL_CONST_i(GL_MAP2_NORMAL)
 OGL_CONST_i(GL_MAP2_NORMAL_NURBS_SGIX)
 OGL_CONST_i(GL_MAP2_TANGENT_EXT)
 OGL_CONST_i(GL_MAP2_TEXTURE_COORD_1)
 OGL_CONST_i(GL_MAP2_TEXTURE_COORD_1_NURBS_SGIX)
 OGL_CONST_i(GL_MAP2_TEXTURE_COORD_2)
 OGL_CONST_i(GL_MAP2_TEXTURE_COORD_2_NURBS_SGIX)
 OGL_CONST_i(GL_MAP2_TEXTURE_COORD_3)
 OGL_CONST_i(GL_MAP2_TEXTURE_COORD_3_NURBS_SGIX)
 OGL_CONST_i(GL_MAP2_TEXTURE_COORD_4)
 OGL_CONST_i(GL_MAP2_TEXTURE_COORD_4_NURBS_SGIX)
 OGL_CONST_i(GL_MAP2_VERTEX_3)
 OGL_CONST_i(GL_MAP2_VERTEX_3_NURBS_SGIX)
 OGL_CONST_i(GL_MAP2_VERTEX_4)
 OGL_CONST_i(GL_MAP2_VERTEX_4_NURBS_SGIX)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB0_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB10_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB11_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB12_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB13_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB14_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB15_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB1_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB2_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB3_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB4_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB5_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB6_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB7_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB8_4_NV)
 OGL_CONST_i(GL_MAP2_VERTEX_ATTRIB9_4_NV)
 OGL_CONST_i(GL_MAP_ATTRIB_U_ORDER_NV)
 OGL_CONST_i(GL_MAP_ATTRIB_V_ORDER_NV)
 OGL_CONST_i(GL_MAP_COHERENT_BIT)
 OGL_CONST_i(GL_MAP_COHERENT_BIT_EXT)
 OGL_CONST_i(GL_MAP_COLOR)
 OGL_CONST_i(GL_MAP_FLUSH_EXPLICIT_BIT)
 OGL_CONST_i(GL_MAP_FLUSH_EXPLICIT_BIT_EXT)
 OGL_CONST_i(GL_MAP_INVALIDATE_BUFFER_BIT)
 OGL_CONST_i(GL_MAP_INVALIDATE_BUFFER_BIT_EXT)
 OGL_CONST_i(GL_MAP_INVALIDATE_RANGE_BIT)
 OGL_CONST_i(GL_MAP_INVALIDATE_RANGE_BIT_EXT)
 OGL_CONST_i(GL_MAP_PERSISTENT_BIT)
 OGL_CONST_i(GL_MAP_PERSISTENT_BIT_EXT)
 OGL_CONST_i(GL_MAP_READ_BIT)
 OGL_CONST_i(GL_MAP_READ_BIT_EXT)
 OGL_CONST_i(GL_MAP_STENCIL)
 OGL_CONST_i(GL_MAP_TESSELLATION_NV)
 OGL_CONST_i(GL_MAP_UNSYNCHRONIZED_BIT)
 OGL_CONST_i(GL_MAP_UNSYNCHRONIZED_BIT_EXT)
 OGL_CONST_i(GL_MAP_WRITE_BIT)
 OGL_CONST_i(GL_MAP_WRITE_BIT_EXT)
 OGL_CONST_i(GL_MATERIAL_SIDE_HINT_PGI)
 OGL_CONST_i(GL_MATRIX0_ARB)
 OGL_CONST_i(GL_MATRIX0_NV)
 OGL_CONST_i(GL_MATRIX10_ARB)
 OGL_CONST_i(GL_MATRIX11_ARB)
 OGL_CONST_i(GL_MATRIX12_ARB)
 OGL_CONST_i(GL_MATRIX13_ARB)
 OGL_CONST_i(GL_MATRIX14_ARB)
 OGL_CONST_i(GL_MATRIX15_ARB)
 OGL_CONST_i(GL_MATRIX16_ARB)
 OGL_CONST_i(GL_MATRIX17_ARB)
 OGL_CONST_i(GL_MATRIX18_ARB)
 OGL_CONST_i(GL_MATRIX19_ARB)
 OGL_CONST_i(GL_MATRIX1_ARB)
 OGL_CONST_i(GL_MATRIX1_NV)
 OGL_CONST_i(GL_MATRIX20_ARB)
 OGL_CONST_i(GL_MATRIX21_ARB)
 OGL_CONST_i(GL_MATRIX22_ARB)
 OGL_CONST_i(GL_MATRIX23_ARB)
 OGL_CONST_i(GL_MATRIX24_ARB)
 OGL_CONST_i(GL_MATRIX25_ARB)
 OGL_CONST_i(GL_MATRIX26_ARB)
 OGL_CONST_i(GL_MATRIX27_ARB)
 OGL_CONST_i(GL_MATRIX28_ARB)
 OGL_CONST_i(GL_MATRIX29_ARB)
 OGL_CONST_i(GL_MATRIX2_ARB)
 OGL_CONST_i(GL_MATRIX2_NV)
 OGL_CONST_i(GL_MATRIX30_ARB)
 OGL_CONST_i(GL_MATRIX31_ARB)
 OGL_CONST_i(GL_MATRIX3_ARB)
 OGL_CONST_i(GL_MATRIX3_NV)
 OGL_CONST_i(GL_MATRIX4_ARB)
 OGL_CONST_i(GL_MATRIX4_NV)
 OGL_CONST_i(GL_MATRIX5_ARB)
 OGL_CONST_i(GL_MATRIX5_NV)
 OGL_CONST_i(GL_MATRIX6_ARB)
 OGL_CONST_i(GL_MATRIX6_NV)
 OGL_CONST_i(GL_MATRIX7_ARB)
 OGL_CONST_i(GL_MATRIX7_NV)
 OGL_CONST_i(GL_MATRIX8_ARB)
 OGL_CONST_i(GL_MATRIX9_ARB)
 OGL_CONST_i(GL_MATRIX_EXT)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_ARB)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_BUFFER_BINDING_OES)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_OES)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_POINTER_ARB)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_POINTER_OES)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_SIZE_ARB)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_SIZE_OES)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_STRIDE_ARB)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_STRIDE_OES)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_TYPE_ARB)
 OGL_CONST_i(GL_MATRIX_INDEX_ARRAY_TYPE_OES)
 OGL_CONST_i(GL_MATRIX_MODE)
 OGL_CONST_i(GL_MATRIX_PALETTE_ARB)
 OGL_CONST_i(GL_MATRIX_PALETTE_OES)
 OGL_CONST_i(GL_MATRIX_STRIDE)
 OGL_CONST_i(GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI)
 OGL_CONST_i(GL_MAT_AMBIENT_BIT_PGI)
 OGL_CONST_i(GL_MAT_COLOR_INDEXES_BIT_PGI)
 OGL_CONST_i(GL_MAT_DIFFUSE_BIT_PGI)
 OGL_CONST_i(GL_MAT_EMISSION_BIT_PGI)
 OGL_CONST_i(GL_MAT_SHININESS_BIT_PGI)
 OGL_CONST_i(GL_MAT_SPECULAR_BIT_PGI)
 OGL_CONST_i(GL_MAX)
 OGL_CONST_i(GL_MAX_3D_TEXTURE_SIZE)
 OGL_CONST_i(GL_MAX_3D_TEXTURE_SIZE_EXT)
 OGL_CONST_i(GL_MAX_3D_TEXTURE_SIZE_OES)
 OGL_CONST_i(GL_MAX_ACTIVE_LIGHTS_EXT)
 OGL_CONST_i(GL_MAX_ALPHA_SGIS)
 OGL_CONST_i(GL_MAX_ARRAY_TEXTURE_LAYERS)
 OGL_CONST_i(GL_MAX_ARRAY_TEXTURE_LAYERS_EXT)
 OGL_CONST_i(GL_MAX_ARRAY_TEXTURE_LAYERS_NV)
 OGL_CONST_i(GL_MAX_ASYNC_DRAW_PIXELS_SGIX)
 OGL_CONST_i(GL_MAX_ASYNC_HISTOGRAM_SGIX)
 OGL_CONST_i(GL_MAX_ASYNC_READ_PIXELS_SGIX)
 OGL_CONST_i(GL_MAX_ASYNC_TEX_IMAGE_SGIX)
 OGL_CONST_i(GL_MAX_ATOMIC_COUNTER_BUFFER_BINDINGS)
 OGL_CONST_i(GL_MAX_ATOMIC_COUNTER_BUFFER_SIZE)
 OGL_CONST_i(GL_MAX_ATTRIB_STACK_DEPTH)
 OGL_CONST_i(GL_MAX_BINDABLE_UNIFORM_SIZE_EXT)
 OGL_CONST_i(GL_MAX_BLUE_SGIS)
 OGL_CONST_i(GL_MAX_CLIENT_ATTRIB_STACK_DEPTH)
 OGL_CONST_i(GL_MAX_CLIP_DISTANCES)
 OGL_CONST_i(GL_MAX_CLIP_DISTANCES_APPLE)
 OGL_CONST_i(GL_MAX_CLIP_DISTANCES_EXT)
 OGL_CONST_i(GL_MAX_CLIP_PLANES)
 OGL_CONST_i(GL_MAX_COARSE_FRAGMENT_SAMPLES_NV)
 OGL_CONST_i(GL_MAX_COLOR_ATTACHMENTS)
 OGL_CONST_i(GL_MAX_COLOR_ATTACHMENTS_EXT)
 OGL_CONST_i(GL_MAX_COLOR_ATTACHMENTS_NV)
 OGL_CONST_i(GL_MAX_COLOR_FRAMEBUFFER_SAMPLES_AMD)
 OGL_CONST_i(GL_MAX_COLOR_FRAMEBUFFER_STORAGE_SAMPLES_AMD)
 OGL_CONST_i(GL_MAX_COLOR_MATRIX_STACK_DEPTH)
 OGL_CONST_i(GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI)
 OGL_CONST_i(GL_MAX_COLOR_TEXTURE_SAMPLES)
 OGL_CONST_i(GL_MAX_COMBINED_ATOMIC_COUNTERS)
 OGL_CONST_i(GL_MAX_COMBINED_ATOMIC_COUNTER_BUFFERS)
 OGL_CONST_i(GL_MAX_COMBINED_CLIP_AND_CULL_DISTANCES)
 OGL_CONST_i(GL_MAX_COMBINED_CLIP_AND_CULL_DISTANCES_EXT)
 OGL_CONST_i(GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_COMBINED_DIMENSIONS)
 OGL_CONST_i(GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_COMBINED_IMAGE_UNIFORMS)
 OGL_CONST_i(GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS)
 OGL_CONST_i(GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS_EXT)
 OGL_CONST_i(GL_MAX_COMBINED_MESH_UNIFORM_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_COMBINED_MESH_UNIFORM_COMPONENTS_NV)
 OGL_CONST_i(GL_MAX_COMBINED_SHADER_OUTPUT_RESOURCES)
 OGL_CONST_i(GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS)
 OGL_CONST_i(GL_MAX_COMBINED_TASK_UNIFORM_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_COMBINED_TASK_UNIFORM_COMPONENTS_NV)
 OGL_CONST_i(GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS)
 OGL_CONST_i(GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB)
 OGL_CONST_i(GL_MAX_COMBINED_UNIFORM_BLOCKS)
 OGL_CONST_i(GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_COMPUTE_ATOMIC_COUNTERS)
 OGL_CONST_i(GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS)
 OGL_CONST_i(GL_MAX_COMPUTE_FIXED_GROUP_INVOCATIONS_ARB)
 OGL_CONST_i(GL_MAX_COMPUTE_FIXED_GROUP_SIZE_ARB)
 OGL_CONST_i(GL_MAX_COMPUTE_IMAGE_UNIFORMS)
 OGL_CONST_i(GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS)
 OGL_CONST_i(GL_MAX_COMPUTE_SHARED_MEMORY_SIZE)
 OGL_CONST_i(GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS)
 OGL_CONST_i(GL_MAX_COMPUTE_UNIFORM_BLOCKS)
 OGL_CONST_i(GL_MAX_COMPUTE_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_COMPUTE_VARIABLE_GROUP_INVOCATIONS_ARB)
 OGL_CONST_i(GL_MAX_COMPUTE_VARIABLE_GROUP_SIZE_ARB)
 OGL_CONST_i(GL_MAX_COMPUTE_WORK_GROUP_COUNT)
 OGL_CONST_i(GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS)
 OGL_CONST_i(GL_MAX_COMPUTE_WORK_GROUP_SIZE)
 OGL_CONST_i(GL_MAX_CONVOLUTION_HEIGHT)
 OGL_CONST_i(GL_MAX_CONVOLUTION_HEIGHT_EXT)
 OGL_CONST_i(GL_MAX_CONVOLUTION_WIDTH)
 OGL_CONST_i(GL_MAX_CONVOLUTION_WIDTH_EXT)
 OGL_CONST_i(GL_MAX_CUBE_MAP_TEXTURE_SIZE)
 OGL_CONST_i(GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB)
 OGL_CONST_i(GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT)
 OGL_CONST_i(GL_MAX_CUBE_MAP_TEXTURE_SIZE_OES)
 OGL_CONST_i(GL_MAX_CULL_DISTANCES)
 OGL_CONST_i(GL_MAX_CULL_DISTANCES_EXT)
 OGL_CONST_i(GL_MAX_DEBUG_GROUP_STACK_DEPTH)
 OGL_CONST_i(GL_MAX_DEBUG_LOGGED_MESSAGES)
 OGL_CONST_i(GL_MAX_DEBUG_LOGGED_MESSAGES_AMD)
 OGL_CONST_i(GL_MAX_DEBUG_LOGGED_MESSAGES_ARB)
 OGL_CONST_i(GL_MAX_DEBUG_MESSAGE_LENGTH)
 OGL_CONST_i(GL_MAX_DEBUG_MESSAGE_LENGTH_AMD)
 OGL_CONST_i(GL_MAX_DEBUG_MESSAGE_LENGTH_ARB)
 OGL_CONST_i(GL_MAX_DEEP_3D_TEXTURE_DEPTH_NV)
 OGL_CONST_i(GL_MAX_DEEP_3D_TEXTURE_WIDTH_HEIGHT_NV)
 OGL_CONST_i(GL_MAX_DEPTH)
 OGL_CONST_i(GL_MAX_DEPTH_STENCIL_FRAMEBUFFER_SAMPLES_AMD)
 OGL_CONST_i(GL_MAX_DEPTH_TEXTURE_SAMPLES)
 OGL_CONST_i(GL_MAX_DETACHED_BUFFERS_NV)
 OGL_CONST_i(GL_MAX_DETACHED_TEXTURES_NV)
 OGL_CONST_i(GL_MAX_DRAW_BUFFERS)
 OGL_CONST_i(GL_MAX_DRAW_BUFFERS_ARB)
 OGL_CONST_i(GL_MAX_DRAW_BUFFERS_ATI)
 OGL_CONST_i(GL_MAX_DRAW_BUFFERS_EXT)
 OGL_CONST_i(GL_MAX_DRAW_BUFFERS_NV)
 OGL_CONST_i(GL_MAX_DRAW_MESH_TASKS_COUNT_NV)
 OGL_CONST_i(GL_MAX_DUAL_SOURCE_DRAW_BUFFERS)
 OGL_CONST_i(GL_MAX_DUAL_SOURCE_DRAW_BUFFERS_EXT)
 OGL_CONST_i(GL_MAX_ELEMENTS_INDICES)
 OGL_CONST_i(GL_MAX_ELEMENTS_INDICES_EXT)
 OGL_CONST_i(GL_MAX_ELEMENTS_VERTICES)
 OGL_CONST_i(GL_MAX_ELEMENTS_VERTICES_EXT)
 OGL_CONST_i(GL_MAX_ELEMENT_INDEX)
 OGL_CONST_i(GL_MAX_EVAL_ORDER)
 OGL_CONST_i(GL_MAX_EXT)
 OGL_CONST_i(GL_MAX_FFT_WIDTH_SGI)
 OGL_CONST_i(GL_MAX_FOG_LAYERS_POINTS_SGIX)
 OGL_CONST_i(GL_MAX_FRAGMENT_ATOMIC_COUNTERS)
 OGL_CONST_i(GL_MAX_FRAGMENT_ATOMIC_COUNTER_BUFFERS)
 OGL_CONST_i(GL_MAX_FRAGMENT_BINDABLE_UNIFORMS_EXT)
 OGL_CONST_i(GL_MAX_FRAGMENT_IMAGE_UNIFORMS)
 OGL_CONST_i(GL_MAX_FRAGMENT_INPUT_COMPONENTS)
 OGL_CONST_i(GL_MAX_FRAGMENT_INTERPOLATION_OFFSET)
 OGL_CONST_i(GL_MAX_FRAGMENT_INTERPOLATION_OFFSET_NV)
 OGL_CONST_i(GL_MAX_FRAGMENT_INTERPOLATION_OFFSET_OES)
 OGL_CONST_i(GL_MAX_FRAGMENT_LIGHTS_EXT)
 OGL_CONST_i(GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV)
 OGL_CONST_i(GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS)
 OGL_CONST_i(GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_LAYERS_EXT)
 OGL_CONST_i(GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_ASPECT_RATIO_EXT)
 OGL_CONST_i(GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT)
 OGL_CONST_i(GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT)
 OGL_CONST_i(GL_MAX_FRAGMENT_UNIFORM_BLOCKS)
 OGL_CONST_i(GL_MAX_FRAGMENT_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB)
 OGL_CONST_i(GL_MAX_FRAGMENT_UNIFORM_VECTORS)
 OGL_CONST_i(GL_MAX_FRAMEBUFFER_HEIGHT)
 OGL_CONST_i(GL_MAX_FRAMEBUFFER_LAYERS)
 OGL_CONST_i(GL_MAX_FRAMEBUFFER_LAYERS_EXT)
 OGL_CONST_i(GL_MAX_FRAMEBUFFER_LAYERS_OES)
 OGL_CONST_i(GL_MAX_FRAMEBUFFER_SAMPLES)
 OGL_CONST_i(GL_MAX_FRAMEBUFFER_WIDTH)
 OGL_CONST_i(GL_MAX_GENERAL_COMBINERS_NV)
 OGL_CONST_i(GL_MAX_GEOMETRY_ATOMIC_COUNTERS)
 OGL_CONST_i(GL_MAX_GEOMETRY_ATOMIC_COUNTERS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_ATOMIC_COUNTERS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS)
 OGL_CONST_i(GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_BINDABLE_UNIFORMS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_IMAGE_UNIFORMS)
 OGL_CONST_i(GL_MAX_GEOMETRY_IMAGE_UNIFORMS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_IMAGE_UNIFORMS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_INPUT_COMPONENTS)
 OGL_CONST_i(GL_MAX_GEOMETRY_INPUT_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_INPUT_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_OUTPUT_COMPONENTS)
 OGL_CONST_i(GL_MAX_GEOMETRY_OUTPUT_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_OUTPUT_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_OUTPUT_VERTICES)
 OGL_CONST_i(GL_MAX_GEOMETRY_OUTPUT_VERTICES_ARB)
 OGL_CONST_i(GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_OUTPUT_VERTICES_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_PROGRAM_INVOCATIONS_NV)
 OGL_CONST_i(GL_MAX_GEOMETRY_SHADER_INVOCATIONS)
 OGL_CONST_i(GL_MAX_GEOMETRY_SHADER_INVOCATIONS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_SHADER_INVOCATIONS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS)
 OGL_CONST_i(GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS)
 OGL_CONST_i(GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_ARB)
 OGL_CONST_i(GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS)
 OGL_CONST_i(GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_ARB)
 OGL_CONST_i(GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_UNIFORM_BLOCKS)
 OGL_CONST_i(GL_MAX_GEOMETRY_UNIFORM_BLOCKS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_UNIFORM_BLOCKS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_ARB)
 OGL_CONST_i(GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_GEOMETRY_VARYING_COMPONENTS_ARB)
 OGL_CONST_i(GL_MAX_GEOMETRY_VARYING_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_GREEN_SGIS)
 OGL_CONST_i(GL_MAX_HEIGHT)
 OGL_CONST_i(GL_MAX_IMAGE_SAMPLES)
 OGL_CONST_i(GL_MAX_IMAGE_SAMPLES_EXT)
 OGL_CONST_i(GL_MAX_IMAGE_UNITS)
 OGL_CONST_i(GL_MAX_IMAGE_UNITS_EXT)
 OGL_CONST_i(GL_MAX_INTEGER_SAMPLES)
 OGL_CONST_i(GL_MAX_INTENSITY_SGIS)
 OGL_CONST_i(GL_MAX_LABEL_LENGTH)
 OGL_CONST_i(GL_MAX_LAYERS)
 OGL_CONST_i(GL_MAX_LGPU_GPUS_NVX)
 OGL_CONST_i(GL_MAX_LIGHTS)
 OGL_CONST_i(GL_MAX_LIST_NESTING)
 OGL_CONST_i(GL_MAX_LUMINANCE_SGIS)
 OGL_CONST_i(GL_MAX_MAP_TESSELLATION_NV)
 OGL_CONST_i(GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB)
 OGL_CONST_i(GL_MAX_MESH_ATOMIC_COUNTERS_EXT)
 OGL_CONST_i(GL_MAX_MESH_ATOMIC_COUNTERS_NV)
 OGL_CONST_i(GL_MAX_MESH_ATOMIC_COUNTER_BUFFERS_EXT)
 OGL_CONST_i(GL_MAX_MESH_ATOMIC_COUNTER_BUFFERS_NV)
 OGL_CONST_i(GL_MAX_MESH_IMAGE_UNIFORMS_EXT)
 OGL_CONST_i(GL_MAX_MESH_IMAGE_UNIFORMS_NV)
 OGL_CONST_i(GL_MAX_MESH_MULTIVIEW_VIEW_COUNT_EXT)
 OGL_CONST_i(GL_MAX_MESH_OUTPUT_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_MESH_OUTPUT_LAYERS_EXT)
 OGL_CONST_i(GL_MAX_MESH_OUTPUT_MEMORY_SIZE_EXT)
 OGL_CONST_i(GL_MAX_MESH_OUTPUT_PRIMITIVES_EXT)
 OGL_CONST_i(GL_MAX_MESH_OUTPUT_PRIMITIVES_NV)
 OGL_CONST_i(GL_MAX_MESH_OUTPUT_VERTICES_EXT)
 OGL_CONST_i(GL_MAX_MESH_OUTPUT_VERTICES_NV)
 OGL_CONST_i(GL_MAX_MESH_PAYLOAD_AND_OUTPUT_MEMORY_SIZE_EXT)
 OGL_CONST_i(GL_MAX_MESH_PAYLOAD_AND_SHARED_MEMORY_SIZE_EXT)
 OGL_CONST_i(GL_MAX_MESH_SHADER_STORAGE_BLOCKS_EXT)
 OGL_CONST_i(GL_MAX_MESH_SHADER_STORAGE_BLOCKS_NV)
 OGL_CONST_i(GL_MAX_MESH_SHARED_MEMORY_SIZE_EXT)
 OGL_CONST_i(GL_MAX_MESH_TEXTURE_IMAGE_UNITS_EXT)
 OGL_CONST_i(GL_MAX_MESH_TEXTURE_IMAGE_UNITS_NV)
 OGL_CONST_i(GL_MAX_MESH_TOTAL_MEMORY_SIZE_NV)
 OGL_CONST_i(GL_MAX_MESH_UNIFORM_BLOCKS_EXT)
 OGL_CONST_i(GL_MAX_MESH_UNIFORM_BLOCKS_NV)
 OGL_CONST_i(GL_MAX_MESH_UNIFORM_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_MESH_UNIFORM_COMPONENTS_NV)
 OGL_CONST_i(GL_MAX_MESH_VIEWS_NV)
 OGL_CONST_i(GL_MAX_MESH_WORK_GROUP_COUNT_EXT)
 OGL_CONST_i(GL_MAX_MESH_WORK_GROUP_INVOCATIONS_EXT)
 OGL_CONST_i(GL_MAX_MESH_WORK_GROUP_INVOCATIONS_NV)
 OGL_CONST_i(GL_MAX_MESH_WORK_GROUP_SIZE_EXT)
 OGL_CONST_i(GL_MAX_MESH_WORK_GROUP_SIZE_NV)
 OGL_CONST_i(GL_MAX_MESH_WORK_GROUP_TOTAL_COUNT_EXT)
 OGL_CONST_i(GL_MAX_MIPMAP_ANISOTROPY_SGIX)
 OGL_CONST_i(GL_MAX_MODELVIEW_STACK_DEPTH)
 OGL_CONST_i(GL_MAX_MULTISAMPLE_COVERAGE_MODES_NV)
 OGL_CONST_i(GL_MAX_MULTIVIEW_BUFFERS_EXT)
 OGL_CONST_i(GL_MAX_NAME_LENGTH)
 OGL_CONST_i(GL_MAX_NAME_STACK_DEPTH)
 OGL_CONST_i(GL_MAX_NUM_ACTIVE_VARIABLES)
 OGL_CONST_i(GL_MAX_NUM_COMPATIBLE_SUBROUTINES)
 OGL_CONST_i(GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT)
 OGL_CONST_i(GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT)
 OGL_CONST_i(GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT)
 OGL_CONST_i(GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT)
 OGL_CONST_i(GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT)
 OGL_CONST_i(GL_MAX_PALETTE_MATRICES_ARB)
 OGL_CONST_i(GL_MAX_PALETTE_MATRICES_OES)
 OGL_CONST_i(GL_MAX_PATCH_VERTICES)
 OGL_CONST_i(GL_MAX_PATCH_VERTICES_EXT)
 OGL_CONST_i(GL_MAX_PATCH_VERTICES_OES)
 OGL_CONST_i(GL_MAX_PIXEL_MAP_TABLE)
 OGL_CONST_i(GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT)
 OGL_CONST_i(GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI)
 OGL_CONST_i(GL_MAX_PREFERRED_MESH_WORK_GROUP_INVOCATIONS_EXT)
 OGL_CONST_i(GL_MAX_PREFERRED_TASK_WORK_GROUP_INVOCATIONS_EXT)
 OGL_CONST_i(GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_ATTRIBS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_ATTRIB_COMPONENTS_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_CALL_DEPTH_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_ENV_PARAMETERS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_GENERIC_ATTRIBS_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_GENERIC_RESULTS_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_IF_DEPTH_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_LOOP_COUNT_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_LOOP_DEPTH_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_MATRICES_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_OUTPUT_VERTICES_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_PARAMETERS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_PARAMETER_BUFFER_BINDINGS_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_PARAMETER_BUFFER_SIZE_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_PATCH_ATTRIBS_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_RESULT_COMPONENTS_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_TEMPORARIES_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_TEXEL_OFFSET)
 OGL_CONST_i(GL_MAX_PROGRAM_TEXEL_OFFSET_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_TEXTURE_GATHER_COMPONENTS)
 OGL_CONST_i(GL_MAX_PROGRAM_TEXTURE_GATHER_COMPONENTS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET)
 OGL_CONST_i(GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET_NV)
 OGL_CONST_i(GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_MAX_PROGRAM_TOTAL_OUTPUT_COMPONENTS_NV)
 OGL_CONST_i(GL_MAX_PROJECTION_STACK_DEPTH)
 OGL_CONST_i(GL_MAX_RASTER_SAMPLES_EXT)
 OGL_CONST_i(GL_MAX_RATIONAL_EVAL_ORDER_NV)
 OGL_CONST_i(GL_MAX_RECTANGLE_TEXTURE_SIZE)
 OGL_CONST_i(GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB)
 OGL_CONST_i(GL_MAX_RECTANGLE_TEXTURE_SIZE_EXT)
 OGL_CONST_i(GL_MAX_RECTANGLE_TEXTURE_SIZE_NV)
 OGL_CONST_i(GL_MAX_RED_SGIS)
 OGL_CONST_i(GL_MAX_RENDERBUFFER_SIZE)
 OGL_CONST_i(GL_MAX_RENDERBUFFER_SIZE_EXT)
 OGL_CONST_i(GL_MAX_RENDERBUFFER_SIZE_OES)
 OGL_CONST_i(GL_MAX_SAMPLES)
 OGL_CONST_i(GL_MAX_SAMPLES_ANGLE)
 OGL_CONST_i(GL_MAX_SAMPLES_APPLE)
 OGL_CONST_i(GL_MAX_SAMPLES_EXT)
 OGL_CONST_i(GL_MAX_SAMPLES_IMG)
 OGL_CONST_i(GL_MAX_SAMPLES_NV)
 OGL_CONST_i(GL_MAX_SAMPLE_MASK_WORDS)
 OGL_CONST_i(GL_MAX_SAMPLE_MASK_WORDS_NV)
 OGL_CONST_i(GL_MAX_SERVER_WAIT_TIMEOUT)
 OGL_CONST_i(GL_MAX_SERVER_WAIT_TIMEOUT_APPLE)
 OGL_CONST_i(GL_MAX_SHADER_BUFFER_ADDRESS_NV)
 OGL_CONST_i(GL_MAX_SHADER_COMBINED_LOCAL_STORAGE_FAST_SIZE_EXT)
 OGL_CONST_i(GL_MAX_SHADER_COMBINED_LOCAL_STORAGE_SIZE_EXT)
 OGL_CONST_i(GL_MAX_SHADER_COMPILER_THREADS_ARB)
 OGL_CONST_i(GL_MAX_SHADER_COMPILER_THREADS_KHR)
 OGL_CONST_i(GL_MAX_SHADER_PIXEL_LOCAL_STORAGE_FAST_SIZE_EXT)
 OGL_CONST_i(GL_MAX_SHADER_PIXEL_LOCAL_STORAGE_SIZE_EXT)
 OGL_CONST_i(GL_MAX_SHADER_STORAGE_BLOCK_SIZE)
 OGL_CONST_i(GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS)
 OGL_CONST_i(GL_MAX_SHADER_SUBSAMPLED_IMAGE_UNITS_QCOM)
 OGL_CONST_i(GL_MAX_SHININESS_NV)
 OGL_CONST_i(GL_MAX_SPARSE_3D_TEXTURE_SIZE_AMD)
 OGL_CONST_i(GL_MAX_SPARSE_3D_TEXTURE_SIZE_ARB)
 OGL_CONST_i(GL_MAX_SPARSE_3D_TEXTURE_SIZE_EXT)
 OGL_CONST_i(GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS)
 OGL_CONST_i(GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS_ARB)
 OGL_CONST_i(GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS_EXT)
 OGL_CONST_i(GL_MAX_SPARSE_TEXTURE_SIZE_AMD)
 OGL_CONST_i(GL_MAX_SPARSE_TEXTURE_SIZE_ARB)
 OGL_CONST_i(GL_MAX_SPARSE_TEXTURE_SIZE_EXT)
 OGL_CONST_i(GL_MAX_SPOT_EXPONENT_NV)
 OGL_CONST_i(GL_MAX_SUBPIXEL_PRECISION_BIAS_BITS_NV)
 OGL_CONST_i(GL_MAX_SUBROUTINES)
 OGL_CONST_i(GL_MAX_SUBROUTINE_UNIFORM_LOCATIONS)
 OGL_CONST_i(GL_MAX_TASK_ATOMIC_COUNTERS_EXT)
 OGL_CONST_i(GL_MAX_TASK_ATOMIC_COUNTERS_NV)
 OGL_CONST_i(GL_MAX_TASK_ATOMIC_COUNTER_BUFFERS_EXT)
 OGL_CONST_i(GL_MAX_TASK_ATOMIC_COUNTER_BUFFERS_NV)
 OGL_CONST_i(GL_MAX_TASK_IMAGE_UNIFORMS_EXT)
 OGL_CONST_i(GL_MAX_TASK_IMAGE_UNIFORMS_NV)
 OGL_CONST_i(GL_MAX_TASK_OUTPUT_COUNT_NV)
 OGL_CONST_i(GL_MAX_TASK_PAYLOAD_AND_SHARED_MEMORY_SIZE_EXT)
 OGL_CONST_i(GL_MAX_TASK_PAYLOAD_SIZE_EXT)
 OGL_CONST_i(GL_MAX_TASK_SHADER_STORAGE_BLOCKS_EXT)
 OGL_CONST_i(GL_MAX_TASK_SHADER_STORAGE_BLOCKS_NV)
 OGL_CONST_i(GL_MAX_TASK_SHARED_MEMORY_SIZE_EXT)
 OGL_CONST_i(GL_MAX_TASK_TEXTURE_IMAGE_UNITS_EXT)
 OGL_CONST_i(GL_MAX_TASK_TEXTURE_IMAGE_UNITS_NV)
 OGL_CONST_i(GL_MAX_TASK_TOTAL_MEMORY_SIZE_NV)
 OGL_CONST_i(GL_MAX_TASK_UNIFORM_BLOCKS_EXT)
 OGL_CONST_i(GL_MAX_TASK_UNIFORM_BLOCKS_NV)
 OGL_CONST_i(GL_MAX_TASK_UNIFORM_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TASK_UNIFORM_COMPONENTS_NV)
 OGL_CONST_i(GL_MAX_TASK_WORK_GROUP_COUNT_EXT)
 OGL_CONST_i(GL_MAX_TASK_WORK_GROUP_INVOCATIONS_EXT)
 OGL_CONST_i(GL_MAX_TASK_WORK_GROUP_INVOCATIONS_NV)
 OGL_CONST_i(GL_MAX_TASK_WORK_GROUP_SIZE_EXT)
 OGL_CONST_i(GL_MAX_TASK_WORK_GROUP_SIZE_NV)
 OGL_CONST_i(GL_MAX_TASK_WORK_GROUP_TOTAL_COUNT_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS_OES)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS_OES)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS_OES)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_INPUT_COMPONENTS)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_INPUT_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_INPUT_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS_OES)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS_OES)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS_OES)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS_EXT)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS_OES)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS_EXT)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS_OES)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS_EXT)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS_OES)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS_EXT)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS_OES)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS_EXT)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS_OES)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS_EXT)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS_OES)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_TESS_GEN_LEVEL)
 OGL_CONST_i(GL_MAX_TESS_GEN_LEVEL_EXT)
 OGL_CONST_i(GL_MAX_TESS_GEN_LEVEL_OES)
 OGL_CONST_i(GL_MAX_TESS_PATCH_COMPONENTS)
 OGL_CONST_i(GL_MAX_TESS_PATCH_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TESS_PATCH_COMPONENTS_OES)
 OGL_CONST_i(GL_MAX_TEXTURES_SGIS)
 OGL_CONST_i(GL_MAX_TEXTURE_BUFFER_SIZE)
 OGL_CONST_i(GL_MAX_TEXTURE_BUFFER_SIZE_ARB)
 OGL_CONST_i(GL_MAX_TEXTURE_BUFFER_SIZE_EXT)
 OGL_CONST_i(GL_MAX_TEXTURE_BUFFER_SIZE_OES)
 OGL_CONST_i(GL_MAX_TEXTURE_COORDS)
 OGL_CONST_i(GL_MAX_TEXTURE_COORDS_ARB)
 OGL_CONST_i(GL_MAX_TEXTURE_COORDS_NV)
 OGL_CONST_i(GL_MAX_TEXTURE_COORD_SETS_SGIS)
 OGL_CONST_i(GL_MAX_TEXTURE_IMAGE_UNITS)
 OGL_CONST_i(GL_MAX_TEXTURE_IMAGE_UNITS_ARB)
 OGL_CONST_i(GL_MAX_TEXTURE_IMAGE_UNITS_NV)
 OGL_CONST_i(GL_MAX_TEXTURE_LOD_BIAS)
 OGL_CONST_i(GL_MAX_TEXTURE_LOD_BIAS_EXT)
 OGL_CONST_i(GL_MAX_TEXTURE_MAX_ANISOTROPY)
 OGL_CONST_i(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT)
 OGL_CONST_i(GL_MAX_TEXTURE_SIZE)
 OGL_CONST_i(GL_MAX_TEXTURE_STACK_DEPTH)
 OGL_CONST_i(GL_MAX_TEXTURE_UNITS)
 OGL_CONST_i(GL_MAX_TEXTURE_UNITS_ARB)
 OGL_CONST_i(GL_MAX_TIMELINE_SEMAPHORE_VALUE_DIFFERENCE_NV)
 OGL_CONST_i(GL_MAX_TRACK_MATRICES_NV)
 OGL_CONST_i(GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV)
 OGL_CONST_i(GL_MAX_TRANSFORM_FEEDBACK_BUFFERS)
 OGL_CONST_i(GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS)
 OGL_CONST_i(GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_NV)
 OGL_CONST_i(GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS)
 OGL_CONST_i(GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_EXT)
 OGL_CONST_i(GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_NV)
 OGL_CONST_i(GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS)
 OGL_CONST_i(GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_NV)
 OGL_CONST_i(GL_MAX_UNIFORM_BLOCK_SIZE)
 OGL_CONST_i(GL_MAX_UNIFORM_BUFFER_BINDINGS)
 OGL_CONST_i(GL_MAX_UNIFORM_LOCATIONS)
 OGL_CONST_i(GL_MAX_VARYING_COMPONENTS)
 OGL_CONST_i(GL_MAX_VARYING_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_VARYING_FLOATS)
 OGL_CONST_i(GL_MAX_VARYING_FLOATS_ARB)
 OGL_CONST_i(GL_MAX_VARYING_VECTORS)
 OGL_CONST_i(GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_APPLE)
 OGL_CONST_i(GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV)
 OGL_CONST_i(GL_MAX_VERTEX_ATOMIC_COUNTERS)
 OGL_CONST_i(GL_MAX_VERTEX_ATOMIC_COUNTER_BUFFERS)
 OGL_CONST_i(GL_MAX_VERTEX_ATTRIBS)
 OGL_CONST_i(GL_MAX_VERTEX_ATTRIBS_ARB)
 OGL_CONST_i(GL_MAX_VERTEX_ATTRIB_BINDINGS)
 OGL_CONST_i(GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET)
 OGL_CONST_i(GL_MAX_VERTEX_ATTRIB_STRIDE)
 OGL_CONST_i(GL_MAX_VERTEX_BINDABLE_UNIFORMS_EXT)
 OGL_CONST_i(GL_MAX_VERTEX_HINT_PGI)
 OGL_CONST_i(GL_MAX_VERTEX_IMAGE_UNIFORMS)
 OGL_CONST_i(GL_MAX_VERTEX_OUTPUT_COMPONENTS)
 OGL_CONST_i(GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT)
 OGL_CONST_i(GL_MAX_VERTEX_SHADER_INVARIANTS_EXT)
 OGL_CONST_i(GL_MAX_VERTEX_SHADER_LOCALS_EXT)
 OGL_CONST_i(GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT)
 OGL_CONST_i(GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS)
 OGL_CONST_i(GL_MAX_VERTEX_SHADER_VARIANTS_EXT)
 OGL_CONST_i(GL_MAX_VERTEX_STREAMS)
 OGL_CONST_i(GL_MAX_VERTEX_STREAMS_ATI)
 OGL_CONST_i(GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS)
 OGL_CONST_i(GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB)
 OGL_CONST_i(GL_MAX_VERTEX_UNIFORM_BLOCKS)
 OGL_CONST_i(GL_MAX_VERTEX_UNIFORM_COMPONENTS)
 OGL_CONST_i(GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB)
 OGL_CONST_i(GL_MAX_VERTEX_UNIFORM_VECTORS)
 OGL_CONST_i(GL_MAX_VERTEX_UNITS_ARB)
 OGL_CONST_i(GL_MAX_VERTEX_UNITS_OES)
 OGL_CONST_i(GL_MAX_VERTEX_VARYING_COMPONENTS_ARB)
 OGL_CONST_i(GL_MAX_VERTEX_VARYING_COMPONENTS_EXT)
 OGL_CONST_i(GL_MAX_VIEWPORTS)
 OGL_CONST_i(GL_MAX_VIEWPORTS_NV)
 OGL_CONST_i(GL_MAX_VIEWPORT_DIMS)
 OGL_CONST_i(GL_MAX_VIEWS_OVR)
 OGL_CONST_i(GL_MAX_WIDTH)
 OGL_CONST_i(GL_MAX_WINDOW_RECTANGLES_EXT)
 OGL_CONST_i(GL_MEDIUM_FLOAT)
 OGL_CONST_i(GL_MEDIUM_INT)
 OGL_CONST_i(GL_MEMORY_ATTACHABLE_ALIGNMENT_NV)
 OGL_CONST_i(GL_MEMORY_ATTACHABLE_NV)
 OGL_CONST_i(GL_MEMORY_ATTACHABLE_SIZE_NV)
 OGL_CONST_i(GL_MESH_OUTPUT_PER_PRIMITIVE_GRANULARITY_EXT)
 OGL_CONST_i(GL_MESH_OUTPUT_PER_PRIMITIVE_GRANULARITY_NV)
 OGL_CONST_i(GL_MESH_OUTPUT_PER_VERTEX_GRANULARITY_EXT)
 OGL_CONST_i(GL_MESH_OUTPUT_PER_VERTEX_GRANULARITY_NV)
 OGL_CONST_i(GL_MESH_OUTPUT_TYPE_EXT)
 OGL_CONST_i(GL_MESH_OUTPUT_TYPE_NV)
 OGL_CONST_i(GL_MESH_PREFERS_COMPACT_PRIMITIVE_OUTPUT_EXT)
 OGL_CONST_i(GL_MESH_PREFERS_COMPACT_VERTEX_OUTPUT_EXT)
 OGL_CONST_i(GL_MESH_PREFERS_LOCAL_INVOCATION_PRIMITIVE_OUTPUT_EXT)
 OGL_CONST_i(GL_MESH_PREFERS_LOCAL_INVOCATION_VERTEX_OUTPUT_EXT)
 OGL_CONST_i(GL_MESH_PRIMITIVES_GENERATED_EXT)
 OGL_CONST_i(GL_MESH_PRIMITIVES_OUT_EXT)
 OGL_CONST_i(GL_MESH_PRIMITIVES_OUT_NV)
 OGL_CONST_i(GL_MESH_SHADER_BIT_EXT)
 OGL_CONST_i(GL_MESH_SHADER_BIT_NV)
 OGL_CONST_i(GL_MESH_SHADER_EXT)
 OGL_CONST_i(GL_MESH_SHADER_INVOCATIONS_EXT)
 OGL_CONST_i(GL_MESH_SHADER_NV)
 OGL_CONST_i(GL_MESH_SUBROUTINE_EXT)
 OGL_CONST_i(GL_MESH_SUBROUTINE_NV)
 OGL_CONST_i(GL_MESH_SUBROUTINE_UNIFORM_EXT)
 OGL_CONST_i(GL_MESH_SUBROUTINE_UNIFORM_NV)
 OGL_CONST_i(GL_MESH_VERTICES_OUT_EXT)
 OGL_CONST_i(GL_MESH_VERTICES_OUT_NV)
 OGL_CONST_i(GL_MESH_WORK_GROUP_SIZE_EXT)
 OGL_CONST_i(GL_MESH_WORK_GROUP_SIZE_NV)
 OGL_CONST_i(GL_MIN)
 OGL_CONST_i(GL_MINMAX)
 OGL_CONST_i(GL_MINMAX_EXT)
 OGL_CONST_i(GL_MINMAX_FORMAT)
 OGL_CONST_i(GL_MINMAX_FORMAT_EXT)
 OGL_CONST_i(GL_MINMAX_SINK)
 OGL_CONST_i(GL_MINMAX_SINK_EXT)
 OGL_CONST_i(GL_MINOR_VERSION)
 OGL_CONST_i(GL_MINUS_CLAMPED_NV)
 OGL_CONST_i(GL_MINUS_NV)
 OGL_CONST_i(GL_MIN_ALPHA_SGIS)
 OGL_CONST_i(GL_MIN_BLUE_SGIS)
 OGL_CONST_i(GL_MIN_EXT)
 OGL_CONST_i(GL_MIN_FRAGMENT_INTERPOLATION_OFFSET)
 OGL_CONST_i(GL_MIN_FRAGMENT_INTERPOLATION_OFFSET_NV)
 OGL_CONST_i(GL_MIN_FRAGMENT_INTERPOLATION_OFFSET_OES)
 OGL_CONST_i(GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT)
 OGL_CONST_i(GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT)
 OGL_CONST_i(GL_MIN_GREEN_SGIS)
 OGL_CONST_i(GL_MIN_INTENSITY_SGIS)
 OGL_CONST_i(GL_MIN_LOD_WARNING_AMD)
 OGL_CONST_i(GL_MIN_LUMINANCE_SGIS)
 OGL_CONST_i(GL_MIN_MAP_BUFFER_ALIGNMENT)
 OGL_CONST_i(GL_MIN_PBUFFER_VIEWPORT_DIMS_APPLE)
 OGL_CONST_i(GL_MIN_PROGRAM_TEXEL_OFFSET)
 OGL_CONST_i(GL_MIN_PROGRAM_TEXEL_OFFSET_NV)
 OGL_CONST_i(GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET)
 OGL_CONST_i(GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET_ARB)
 OGL_CONST_i(GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET_NV)
 OGL_CONST_i(GL_MIN_RED_SGIS)
 OGL_CONST_i(GL_MIN_SAMPLE_SHADING_VALUE)
 OGL_CONST_i(GL_MIN_SAMPLE_SHADING_VALUE_ARB)
 OGL_CONST_i(GL_MIN_SAMPLE_SHADING_VALUE_OES)
 OGL_CONST_i(GL_MIN_SPARSE_LEVEL_AMD)
 OGL_CONST_i(GL_MIPMAP)
 OGL_CONST_i(GL_MIRRORED_REPEAT)
 OGL_CONST_i(GL_MIRRORED_REPEAT_ARB)
 OGL_CONST_i(GL_MIRRORED_REPEAT_IBM)
 OGL_CONST_i(GL_MIRROR_CLAMP_ATI)
 OGL_CONST_i(GL_MIRROR_CLAMP_EXT)
 OGL_CONST_i(GL_MIRROR_CLAMP_TO_BORDER_EXT)
 OGL_CONST_i(GL_MIRROR_CLAMP_TO_EDGE)
 OGL_CONST_i(GL_MIRROR_CLAMP_TO_EDGE_ATI)
 OGL_CONST_i(GL_MIRROR_CLAMP_TO_EDGE_EXT)
 OGL_CONST_i(GL_MISSING_REGAL)
 OGL_CONST_i(GL_MITER_REVERT_NV)
 OGL_CONST_i(GL_MITER_TRUNCATE_NV)
 OGL_CONST_i(GL_MIXED_DEPTH_SAMPLES_SUPPORTED_NV)
 OGL_CONST_i(GL_MIXED_STENCIL_SAMPLES_SUPPORTED_NV)
 OGL_CONST_i(GL_MODELVIEW)
 OGL_CONST_i(GL_MODELVIEW0_ARB)
 OGL_CONST_i(GL_MODELVIEW0_EXT)
 OGL_CONST_i(GL_MODELVIEW0_MATRIX_EXT)
 OGL_CONST_i(GL_MODELVIEW0_STACK_DEPTH_EXT)
 OGL_CONST_i(GL_MODELVIEW10_ARB)
 OGL_CONST_i(GL_MODELVIEW11_ARB)
 OGL_CONST_i(GL_MODELVIEW12_ARB)
 OGL_CONST_i(GL_MODELVIEW13_ARB)
 OGL_CONST_i(GL_MODELVIEW14_ARB)
 OGL_CONST_i(GL_MODELVIEW15_ARB)
 OGL_CONST_i(GL_MODELVIEW16_ARB)
 OGL_CONST_i(GL_MODELVIEW17_ARB)
 OGL_CONST_i(GL_MODELVIEW18_ARB)
 OGL_CONST_i(GL_MODELVIEW19_ARB)
 OGL_CONST_i(GL_MODELVIEW1_ARB)
 OGL_CONST_i(GL_MODELVIEW1_EXT)
 OGL_CONST_i(GL_MODELVIEW1_MATRIX_EXT)
 OGL_CONST_i(GL_MODELVIEW1_STACK_DEPTH_EXT)
 OGL_CONST_i(GL_MODELVIEW20_ARB)
 OGL_CONST_i(GL_MODELVIEW21_ARB)
 OGL_CONST_i(GL_MODELVIEW22_ARB)
 OGL_CONST_i(GL_MODELVIEW23_ARB)
 OGL_CONST_i(GL_MODELVIEW24_ARB)
 OGL_CONST_i(GL_MODELVIEW25_ARB)
 OGL_CONST_i(GL_MODELVIEW26_ARB)
 OGL_CONST_i(GL_MODELVIEW27_ARB)
 OGL_CONST_i(GL_MODELVIEW28_ARB)
 OGL_CONST_i(GL_MODELVIEW29_ARB)
 OGL_CONST_i(GL_MODELVIEW2_ARB)
 OGL_CONST_i(GL_MODELVIEW30_ARB)
 OGL_CONST_i(GL_MODELVIEW31_ARB)
 OGL_CONST_i(GL_MODELVIEW3_ARB)
 OGL_CONST_i(GL_MODELVIEW4_ARB)
 OGL_CONST_i(GL_MODELVIEW5_ARB)
 OGL_CONST_i(GL_MODELVIEW6_ARB)
 OGL_CONST_i(GL_MODELVIEW7_ARB)
 OGL_CONST_i(GL_MODELVIEW8_ARB)
 OGL_CONST_i(GL_MODELVIEW9_ARB)
 OGL_CONST_i(GL_MODELVIEW_MATRIX)
 OGL_CONST_i(GL_MODELVIEW_MATRIX_FLOAT_AS_INT_BITS_OES)
 OGL_CONST_i(GL_MODELVIEW_PROJECTION_NV)
 OGL_CONST_i(GL_MODELVIEW_STACK_DEPTH)
 OGL_CONST_i(GL_MODULATE)
 OGL_CONST_i(GL_MODULATE_ADD_ATI)
 OGL_CONST_i(GL_MODULATE_ADD_ATIX)
 OGL_CONST_i(GL_MODULATE_COLOR_IMG)
 OGL_CONST_i(GL_MODULATE_SIGNED_ADD_ATI)
 OGL_CONST_i(GL_MODULATE_SIGNED_ADD_ATIX)
 OGL_CONST_i(GL_MODULATE_SUBTRACT_ATI)
 OGL_CONST_i(GL_MODULATE_SUBTRACT_ATIX)
 OGL_CONST_i(GL_MOTION_ESTIMATION_SEARCH_BLOCK_X_QCOM)
 OGL_CONST_i(GL_MOTION_ESTIMATION_SEARCH_BLOCK_Y_QCOM)
 OGL_CONST_i(GL_MOVE_TO_CONTINUES_NV)
 OGL_CONST_i(GL_MOVE_TO_NV)
 OGL_CONST_i(GL_MOVE_TO_RESETS_NV)
 OGL_CONST_i(GL_MOV_ATI)
 OGL_CONST_i(GL_MULT)
 OGL_CONST_i(GL_MULTICAST_GPUS_NV)
 OGL_CONST_i(GL_MULTICAST_PROGRAMMABLE_SAMPLE_LOCATION_NV)
 OGL_CONST_i(GL_MULTIPLY_KHR)
 OGL_CONST_i(GL_MULTIPLY_NV)
 OGL_CONST_i(GL_MULTISAMPLE)
 OGL_CONST_i(GL_MULTISAMPLES_NV)
 OGL_CONST_i(GL_MULTISAMPLE_3DFX)
 OGL_CONST_i(GL_MULTISAMPLE_ARB)
 OGL_CONST_i(GL_MULTISAMPLE_BIT)
 OGL_CONST_i(GL_MULTISAMPLE_BIT_3DFX)
 OGL_CONST_i(GL_MULTISAMPLE_BIT_ARB)
 OGL_CONST_i(GL_MULTISAMPLE_BIT_EXT)
 OGL_CONST_i(GL_MULTISAMPLE_BUFFER_BIT0_QCOM)
 OGL_CONST_i(GL_MULTISAMPLE_BUFFER_BIT1_QCOM)
 OGL_CONST_i(GL_MULTISAMPLE_BUFFER_BIT2_QCOM)
 OGL_CONST_i(GL_MULTISAMPLE_BUFFER_BIT3_QCOM)
 OGL_CONST_i(GL_MULTISAMPLE_BUFFER_BIT4_QCOM)
 OGL_CONST_i(GL_MULTISAMPLE_BUFFER_BIT5_QCOM)
 OGL_CONST_i(GL_MULTISAMPLE_BUFFER_BIT6_QCOM)
 OGL_CONST_i(GL_MULTISAMPLE_BUFFER_BIT7_QCOM)
 OGL_CONST_i(GL_MULTISAMPLE_COVERAGE_MODES_NV)
 OGL_CONST_i(GL_MULTISAMPLE_EXT)
 OGL_CONST_i(GL_MULTISAMPLE_FILTER_HINT_NV)
 OGL_CONST_i(GL_MULTISAMPLE_LINE_WIDTH_GRANULARITY_ARB)
 OGL_CONST_i(GL_MULTISAMPLE_LINE_WIDTH_RANGE_ARB)
 OGL_CONST_i(GL_MULTISAMPLE_RASTERIZATION_ALLOWED_EXT)
 OGL_CONST_i(GL_MULTISAMPLE_SGIS)
 OGL_CONST_i(GL_MULTIVIEW_EXT)
 OGL_CONST_i(GL_MUL_ATI)
 OGL_CONST_i(GL_MVP_MATRIX_EXT)
 OGL_CONST_i(GL_N3F_V3F)
 OGL_CONST_i(GL_NAMED_STRING_LENGTH_ARB)
 OGL_CONST_i(GL_NAMED_STRING_TYPE_ARB)
 OGL_CONST_i(GL_NAME_LENGTH)
 OGL_CONST_i(GL_NAME_STACK_DEPTH)
 OGL_CONST_i(GL_NAND)
 OGL_CONST_i(GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI)
 OGL_CONST_i(GL_NATIVE_GRAPHICS_END_HINT_PGI)
 OGL_CONST_i(GL_NATIVE_GRAPHICS_HANDLE_PGI)
 OGL_CONST_i(GL_NEAREST)
 OGL_CONST_i(GL_NEAREST_MIPMAP_LINEAR)
 OGL_CONST_i(GL_NEAREST_MIPMAP_NEAREST)
 OGL_CONST_i(GL_NEGATE_BIT_ATI)
 OGL_CONST_i(GL_NEGATIVE_ONE_EXT)
 OGL_CONST_i(GL_NEGATIVE_ONE_TO_ONE)
 OGL_CONST_i(GL_NEGATIVE_ONE_TO_ONE_EXT)
 OGL_CONST_i(GL_NEGATIVE_W_EXT)
 OGL_CONST_i(GL_NEGATIVE_X_EXT)
 OGL_CONST_i(GL_NEGATIVE_Y_EXT)
 OGL_CONST_i(GL_NEGATIVE_Z_EXT)
 OGL_CONST_i(GL_NEVER)
 OGL_CONST_i(GL_NEXT_VIDEO_CAPTURE_BUFFER_STATUS_NV)
 OGL_CONST_i(GL_NICEST)
 OGL_CONST_i(GL_NONE)
 OGL_CONST_i(GL_NONE_OES)
 OGL_CONST_i(GL_NOOP)
 OGL_CONST_i(GL_NOP_COMMAND_NV)
 OGL_CONST_i(GL_NOR)
 OGL_CONST_i(GL_NORMALIZE)
 OGL_CONST_i(GL_NORMALIZED_RANGE_EXT)
 OGL_CONST_i(GL_NORMAL_ARRAY)
 OGL_CONST_i(GL_NORMAL_ARRAY_ADDRESS_NV)
 OGL_CONST_i(GL_NORMAL_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_NORMAL_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_NORMAL_ARRAY_COUNT_EXT)
 OGL_CONST_i(GL_NORMAL_ARRAY_EXT)
 OGL_CONST_i(GL_NORMAL_ARRAY_LENGTH_NV)
 OGL_CONST_i(GL_NORMAL_ARRAY_LIST_IBM)
 OGL_CONST_i(GL_NORMAL_ARRAY_LIST_STRIDE_IBM)
 OGL_CONST_i(GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL)
 OGL_CONST_i(GL_NORMAL_ARRAY_POINTER)
 OGL_CONST_i(GL_NORMAL_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_NORMAL_ARRAY_STRIDE)
 OGL_CONST_i(GL_NORMAL_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_NORMAL_ARRAY_TYPE)
 OGL_CONST_i(GL_NORMAL_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_NORMAL_BIT_PGI)
 OGL_CONST_i(GL_NORMAL_MAP)
 OGL_CONST_i(GL_NORMAL_MAP_ARB)
 OGL_CONST_i(GL_NORMAL_MAP_EXT)
 OGL_CONST_i(GL_NORMAL_MAP_NV)
 OGL_CONST_i(GL_NORMAL_MAP_OES)
 OGL_CONST_i(GL_NOTEQUAL)
 OGL_CONST_i(GL_NO_ERROR)
 OGL_CONST_i(GL_NO_RESET_NOTIFICATION)
 OGL_CONST_i(GL_NO_RESET_NOTIFICATION_ARB)
 OGL_CONST_i(GL_NO_RESET_NOTIFICATION_EXT)
 OGL_CONST_i(GL_NUM_ACTIVE_VARIABLES)
 OGL_CONST_i(GL_NUM_COMPATIBLE_SUBROUTINES)
 OGL_CONST_i(GL_NUM_COMPRESSED_TEXTURE_FORMATS)
 OGL_CONST_i(GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB)
 OGL_CONST_i(GL_NUM_DEVICE_UUIDS_EXT)
 OGL_CONST_i(GL_NUM_DOWNSAMPLE_SCALES_IMG)
 OGL_CONST_i(GL_NUM_EXTENSIONS)
 OGL_CONST_i(GL_NUM_FILL_STREAMS_NV)
 OGL_CONST_i(GL_NUM_FRAGMENT_CONSTANTS_ATI)
 OGL_CONST_i(GL_NUM_FRAGMENT_REGISTERS_ATI)
 OGL_CONST_i(GL_NUM_GENERAL_COMBINERS_NV)
 OGL_CONST_i(GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI)
 OGL_CONST_i(GL_NUM_INSTRUCTIONS_PER_PASS_ATI)
 OGL_CONST_i(GL_NUM_INSTRUCTIONS_TOTAL_ATI)
 OGL_CONST_i(GL_NUM_LOOPBACK_COMPONENTS_ATI)
 OGL_CONST_i(GL_NUM_PASSES_ATI)
 OGL_CONST_i(GL_NUM_PROGRAM_BINARY_FORMATS)
 OGL_CONST_i(GL_NUM_PROGRAM_BINARY_FORMATS_OES)
 OGL_CONST_i(GL_NUM_SAMPLE_COUNTS)
 OGL_CONST_i(GL_NUM_SHADER_BINARY_FORMATS)
 OGL_CONST_i(GL_NUM_SHADING_LANGUAGE_VERSIONS)
 OGL_CONST_i(GL_NUM_SPARSE_LEVELS_ARB)
 OGL_CONST_i(GL_NUM_SPARSE_LEVELS_EXT)
 OGL_CONST_i(GL_NUM_SPIR_V_EXTENSIONS)
 OGL_CONST_i(GL_NUM_SUPPORTED_MULTISAMPLE_MODES_AMD)
 OGL_CONST_i(GL_NUM_SURFACE_COMPRESSION_FIXED_RATES_EXT)
 OGL_CONST_i(GL_NUM_TILING_TYPES_EXT)
 OGL_CONST_i(GL_NUM_VIDEO_CAPTURE_STREAMS_NV)
 OGL_CONST_i(GL_NUM_VIRTUAL_PAGE_SIZES_ARB)
 OGL_CONST_i(GL_NUM_VIRTUAL_PAGE_SIZES_EXT)
 OGL_CONST_i(GL_NUM_WINDOW_RECTANGLES_EXT)
 OGL_CONST_i(GL_NURBS_KNOT_COUNT_SGIX)
 OGL_CONST_i(GL_NURBS_KNOT_VECTOR_SGIX)
 OGL_CONST_i(GL_NVIDIA_PLATFORM_BINARY_NV)
 OGL_CONST_i(GL_OBJECT_ACTIVE_ATTRIBUTES_ARB)
 OGL_CONST_i(GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB)
 OGL_CONST_i(GL_OBJECT_ACTIVE_UNIFORMS_ARB)
 OGL_CONST_i(GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB)
 OGL_CONST_i(GL_OBJECT_ATTACHED_OBJECTS_ARB)
 OGL_CONST_i(GL_OBJECT_BUFFER_SIZE_ATI)
 OGL_CONST_i(GL_OBJECT_BUFFER_USAGE_ATI)
 OGL_CONST_i(GL_OBJECT_COMPILE_STATUS_ARB)
 OGL_CONST_i(GL_OBJECT_DELETE_STATUS_ARB)
 OGL_CONST_i(GL_OBJECT_DISTANCE_TO_LINE_SGIS)
 OGL_CONST_i(GL_OBJECT_DISTANCE_TO_POINT_SGIS)
 OGL_CONST_i(GL_OBJECT_INFO_LOG_LENGTH_ARB)
 OGL_CONST_i(GL_OBJECT_LINEAR)
 OGL_CONST_i(GL_OBJECT_LINE_SGIS)
 OGL_CONST_i(GL_OBJECT_LINK_STATUS_ARB)
 OGL_CONST_i(GL_OBJECT_PLANE)
 OGL_CONST_i(GL_OBJECT_POINT_SGIS)
 OGL_CONST_i(GL_OBJECT_SHADER_SOURCE_LENGTH_ARB)
 OGL_CONST_i(GL_OBJECT_SPACE_SGIX)
 OGL_CONST_i(GL_OBJECT_SUBTYPE_ARB)
 OGL_CONST_i(GL_OBJECT_TYPE)
 OGL_CONST_i(GL_OBJECT_TYPE_APPLE)
 OGL_CONST_i(GL_OBJECT_TYPE_ARB)
 OGL_CONST_i(GL_OBJECT_VALIDATE_STATUS_ARB)
 OGL_CONST_i(GL_OCCLUSION_INSTRUMENT_SGIX)
 OGL_CONST_i(GL_OCCLUSION_QUERY_EVENT_MASK_AMD)
 OGL_CONST_i(GL_OFFSET)
 OGL_CONST_i(GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV)
 OGL_CONST_i(GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV)
 OGL_CONST_i(GL_OFFSET_HILO_TEXTURE_2D_NV)
 OGL_CONST_i(GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV)
 OGL_CONST_i(GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV)
 OGL_CONST_i(GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV)
 OGL_CONST_i(GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV)
 OGL_CONST_i(GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV)
 OGL_CONST_i(GL_OFFSET_TEXTURE_2D_BIAS_NV)
 OGL_CONST_i(GL_OFFSET_TEXTURE_2D_MATRIX_NV)
 OGL_CONST_i(GL_OFFSET_TEXTURE_2D_NV)
 OGL_CONST_i(GL_OFFSET_TEXTURE_2D_SCALE_NV)
 OGL_CONST_i(GL_OFFSET_TEXTURE_BIAS_NV)
 OGL_CONST_i(GL_OFFSET_TEXTURE_MATRIX_NV)
 OGL_CONST_i(GL_OFFSET_TEXTURE_RECTANGLE_NV)
 OGL_CONST_i(GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV)
 OGL_CONST_i(GL_OFFSET_TEXTURE_SCALE_NV)
 OGL_CONST_i(GL_ONE)
 OGL_CONST_i(GL_ONE_EXT)
 OGL_CONST_i(GL_ONE_MINUS_CONSTANT_ALPHA)
 OGL_CONST_i(GL_ONE_MINUS_CONSTANT_ALPHA_EXT)
 OGL_CONST_i(GL_ONE_MINUS_CONSTANT_COLOR)
 OGL_CONST_i(GL_ONE_MINUS_CONSTANT_COLOR_EXT)
 OGL_CONST_i(GL_ONE_MINUS_DST_ALPHA)
 OGL_CONST_i(GL_ONE_MINUS_DST_COLOR)
 OGL_CONST_i(GL_ONE_MINUS_SRC1_ALPHA)
 OGL_CONST_i(GL_ONE_MINUS_SRC1_ALPHA_EXT)
 OGL_CONST_i(GL_ONE_MINUS_SRC1_COLOR)
 OGL_CONST_i(GL_ONE_MINUS_SRC1_COLOR_EXT)
 OGL_CONST_i(GL_ONE_MINUS_SRC_ALPHA)
 OGL_CONST_i(GL_ONE_MINUS_SRC_COLOR)
 OGL_CONST_i(GL_OPERAND0_ALPHA)
 OGL_CONST_i(GL_OPERAND0_ALPHA_ARB)
 OGL_CONST_i(GL_OPERAND0_ALPHA_EXT)
 OGL_CONST_i(GL_OPERAND0_RGB)
 OGL_CONST_i(GL_OPERAND0_RGB_ARB)
 OGL_CONST_i(GL_OPERAND0_RGB_EXT)
 OGL_CONST_i(GL_OPERAND1_ALPHA)
 OGL_CONST_i(GL_OPERAND1_ALPHA_ARB)
 OGL_CONST_i(GL_OPERAND1_ALPHA_EXT)
 OGL_CONST_i(GL_OPERAND1_RGB)
 OGL_CONST_i(GL_OPERAND1_RGB_ARB)
 OGL_CONST_i(GL_OPERAND1_RGB_EXT)
 OGL_CONST_i(GL_OPERAND2_ALPHA)
 OGL_CONST_i(GL_OPERAND2_ALPHA_ARB)
 OGL_CONST_i(GL_OPERAND2_ALPHA_EXT)
 OGL_CONST_i(GL_OPERAND2_RGB)
 OGL_CONST_i(GL_OPERAND2_RGB_ARB)
 OGL_CONST_i(GL_OPERAND2_RGB_EXT)
 OGL_CONST_i(GL_OPERAND3_ALPHA_NV)
 OGL_CONST_i(GL_OPERAND3_RGB_NV)
 OGL_CONST_i(GL_OPTIMAL_TILING_EXT)
 OGL_CONST_i(GL_OP_ADD_EXT)
 OGL_CONST_i(GL_OP_CLAMP_EXT)
 OGL_CONST_i(GL_OP_CROSS_PRODUCT_EXT)
 OGL_CONST_i(GL_OP_DOT3_EXT)
 OGL_CONST_i(GL_OP_DOT4_EXT)
 OGL_CONST_i(GL_OP_EXP_BASE_2_EXT)
 OGL_CONST_i(GL_OP_FLOOR_EXT)
 OGL_CONST_i(GL_OP_FRAC_EXT)
 OGL_CONST_i(GL_OP_INDEX_EXT)
 OGL_CONST_i(GL_OP_LOG_BASE_2_EXT)
 OGL_CONST_i(GL_OP_MADD_EXT)
 OGL_CONST_i(GL_OP_MAX_EXT)
 OGL_CONST_i(GL_OP_MIN_EXT)
 OGL_CONST_i(GL_OP_MOV_EXT)
 OGL_CONST_i(GL_OP_MULTIPLY_MATRIX_EXT)
 OGL_CONST_i(GL_OP_MUL_EXT)
 OGL_CONST_i(GL_OP_NEGATE_EXT)
 OGL_CONST_i(GL_OP_POWER_EXT)
 OGL_CONST_i(GL_OP_RECIP_EXT)
 OGL_CONST_i(GL_OP_RECIP_SQRT_EXT)
 OGL_CONST_i(GL_OP_ROUND_EXT)
 OGL_CONST_i(GL_OP_SET_GE_EXT)
 OGL_CONST_i(GL_OP_SET_LT_EXT)
 OGL_CONST_i(GL_OP_SUB_EXT)
 OGL_CONST_i(GL_OR)
 OGL_CONST_i(GL_ORDER)
 OGL_CONST_i(GL_OR_INVERTED)
 OGL_CONST_i(GL_OR_REVERSE)
 OGL_CONST_i(GL_OUTPUT_COLOR0_EXT)
 OGL_CONST_i(GL_OUTPUT_COLOR1_EXT)
 OGL_CONST_i(GL_OUTPUT_FOG_EXT)
 OGL_CONST_i(GL_OUTPUT_POINT_SIZE_ATIX)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD0_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD10_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD11_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD12_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD13_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD14_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD15_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD16_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD17_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD18_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD19_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD1_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD20_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD21_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD22_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD23_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD24_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD25_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD26_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD27_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD28_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD29_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD2_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD30_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD31_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD3_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD4_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD5_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD6_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD7_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD8_EXT)
 OGL_CONST_i(GL_OUTPUT_TEXTURE_COORD9_EXT)
 OGL_CONST_i(GL_OUTPUT_VERTEX_EXT)
 OGL_CONST_i(GL_OUT_OF_MEMORY)
 OGL_CONST_i(GL_OVERLAY_KHR)
 OGL_CONST_i(GL_OVERLAY_NV)
 OGL_CONST_i(GL_PACK_ALIGNMENT)
 OGL_CONST_i(GL_PACK_CMYK_HINT_EXT)
 OGL_CONST_i(GL_PACK_COMPRESSED_BLOCK_DEPTH)
 OGL_CONST_i(GL_PACK_COMPRESSED_BLOCK_HEIGHT)
 OGL_CONST_i(GL_PACK_COMPRESSED_BLOCK_SIZE)
 OGL_CONST_i(GL_PACK_COMPRESSED_BLOCK_WIDTH)
 OGL_CONST_i(GL_PACK_IMAGE_HEIGHT)
 OGL_CONST_i(GL_PACK_IMAGE_HEIGHT_EXT)
 OGL_CONST_i(GL_PACK_INVERT_MESA)
 OGL_CONST_i(GL_PACK_LSB_FIRST)
 OGL_CONST_i(GL_PACK_MAX_COMPRESSED_SIZE_SGIX)
 OGL_CONST_i(GL_PACK_RESAMPLE_OML)
 OGL_CONST_i(GL_PACK_RESAMPLE_SGIX)
 OGL_CONST_i(GL_PACK_REVERSE_ROW_ORDER_ANGLE)
 OGL_CONST_i(GL_PACK_ROW_BYTES_APPLE)
 OGL_CONST_i(GL_PACK_ROW_LENGTH)
 OGL_CONST_i(GL_PACK_ROW_LENGTH_NV)
 OGL_CONST_i(GL_PACK_SKIP_IMAGES)
 OGL_CONST_i(GL_PACK_SKIP_IMAGES_EXT)
 OGL_CONST_i(GL_PACK_SKIP_PIXELS)
 OGL_CONST_i(GL_PACK_SKIP_PIXELS_NV)
 OGL_CONST_i(GL_PACK_SKIP_ROWS)
 OGL_CONST_i(GL_PACK_SKIP_ROWS_NV)
 OGL_CONST_i(GL_PACK_SUBSAMPLE_RATE_SGIX)
 OGL_CONST_i(GL_PACK_SWAP_BYTES)
 OGL_CONST_i(GL_PALETTE4_R5_G6_B5_OES)
 OGL_CONST_i(GL_PALETTE4_RGB5_A1_OES)
 OGL_CONST_i(GL_PALETTE4_RGB8_OES)
 OGL_CONST_i(GL_PALETTE4_RGBA4_OES)
 OGL_CONST_i(GL_PALETTE4_RGBA8_OES)
 OGL_CONST_i(GL_PALETTE8_R5_G6_B5_OES)
 OGL_CONST_i(GL_PALETTE8_RGB5_A1_OES)
 OGL_CONST_i(GL_PALETTE8_RGB8_OES)
 OGL_CONST_i(GL_PALETTE8_RGBA4_OES)
 OGL_CONST_i(GL_PALETTE8_RGBA8_OES)
 OGL_CONST_i(GL_PARALLEL_ARRAYS_INTEL)
 OGL_CONST_i(GL_PARAMETER_BUFFER)
 OGL_CONST_i(GL_PARAMETER_BUFFER_ARB)
 OGL_CONST_i(GL_PARAMETER_BUFFER_BINDING)
 OGL_CONST_i(GL_PARAMETER_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_PARTIAL_SUCCESS_NV)
 OGL_CONST_i(GL_PASS_THROUGH_NV)
 OGL_CONST_i(GL_PASS_THROUGH_TOKEN)
 OGL_CONST_i(GL_PATCHES)
 OGL_CONST_i(GL_PATCHES_EXT)
 OGL_CONST_i(GL_PATCHES_OES)
 OGL_CONST_i(GL_PATCH_DEFAULT_INNER_LEVEL)
 OGL_CONST_i(GL_PATCH_DEFAULT_OUTER_LEVEL)
 OGL_CONST_i(GL_PATCH_VERTICES)
 OGL_CONST_i(GL_PATCH_VERTICES_EXT)
 OGL_CONST_i(GL_PATCH_VERTICES_OES)
 OGL_CONST_i(GL_PATH_CLIENT_LENGTH_NV)
 OGL_CONST_i(GL_PATH_COMMAND_COUNT_NV)
 OGL_CONST_i(GL_PATH_COMPUTED_LENGTH_NV)
 OGL_CONST_i(GL_PATH_COORD_COUNT_NV)
 OGL_CONST_i(GL_PATH_COVER_DEPTH_FUNC_NV)
 OGL_CONST_i(GL_PATH_DASH_ARRAY_COUNT_NV)
 OGL_CONST_i(GL_PATH_DASH_CAPS_NV)
 OGL_CONST_i(GL_PATH_DASH_OFFSET_NV)
 OGL_CONST_i(GL_PATH_DASH_OFFSET_RESET_NV)
 OGL_CONST_i(GL_PATH_END_CAPS_NV)
 OGL_CONST_i(GL_PATH_ERROR_POSITION_NV)
 OGL_CONST_i(GL_PATH_FILL_BOUNDING_BOX_NV)
 OGL_CONST_i(GL_PATH_FILL_COVER_MODE_NV)
 OGL_CONST_i(GL_PATH_FILL_MASK_NV)
 OGL_CONST_i(GL_PATH_FILL_MODE_NV)
 OGL_CONST_i(GL_PATH_FOG_GEN_MODE_NV)
 OGL_CONST_i(GL_PATH_FORMAT_PS_NV)
 OGL_CONST_i(GL_PATH_FORMAT_SVG_NV)
 OGL_CONST_i(GL_PATH_GEN_COEFF_NV)
 OGL_CONST_i(GL_PATH_GEN_COLOR_FORMAT_NV)
 OGL_CONST_i(GL_PATH_GEN_COMPONENTS_NV)
 OGL_CONST_i(GL_PATH_GEN_MODE_NV)
 OGL_CONST_i(GL_PATH_INITIAL_DASH_CAP_NV)
 OGL_CONST_i(GL_PATH_INITIAL_END_CAP_NV)
 OGL_CONST_i(GL_PATH_JOIN_STYLE_NV)
 OGL_CONST_i(GL_PATH_MITER_LIMIT_NV)
 OGL_CONST_i(GL_PATH_OBJECT_BOUNDING_BOX_NV)
 OGL_CONST_i(GL_PATH_STENCIL_DEPTH_OFFSET_FACTOR_NV)
 OGL_CONST_i(GL_PATH_STENCIL_DEPTH_OFFSET_UNITS_NV)
 OGL_CONST_i(GL_PATH_STENCIL_FUNC_NV)
 OGL_CONST_i(GL_PATH_STENCIL_REF_NV)
 OGL_CONST_i(GL_PATH_STENCIL_VALUE_MASK_NV)
 OGL_CONST_i(GL_PATH_STROKE_BOUNDING_BOX_NV)
 OGL_CONST_i(GL_PATH_STROKE_BOUND_NV)
 OGL_CONST_i(GL_PATH_STROKE_COVER_MODE_NV)
 OGL_CONST_i(GL_PATH_STROKE_MASK_NV)
 OGL_CONST_i(GL_PATH_STROKE_WIDTH_NV)
 OGL_CONST_i(GL_PATH_TERMINAL_DASH_CAP_NV)
 OGL_CONST_i(GL_PATH_TERMINAL_END_CAP_NV)
 OGL_CONST_i(GL_PERCENTAGE_AMD)
 OGL_CONST_i(GL_PERFMON_GLOBAL_MODE_QCOM)
 OGL_CONST_i(GL_PERFMON_RESULT_AMD)
 OGL_CONST_i(GL_PERFMON_RESULT_AVAILABLE_AMD)
 OGL_CONST_i(GL_PERFMON_RESULT_SIZE_AMD)
 OGL_CONST_i(GL_PERFORMANCE_MONITOR_AMD)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_DATA_BOOL32_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_DATA_DOUBLE_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_DATA_FLOAT_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_DATA_UINT32_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_DATA_UINT64_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_DESC_LENGTH_MAX_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_DURATION_NORM_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_DURATION_RAW_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_EVENT_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_NAME_LENGTH_MAX_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_RAW_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_THROUGHPUT_INTEL)
 OGL_CONST_i(GL_PERFQUERY_COUNTER_TIMESTAMP_INTEL)
 OGL_CONST_i(GL_PERFQUERY_DONOT_FLUSH_INTEL)
 OGL_CONST_i(GL_PERFQUERY_FLUSH_INTEL)
 OGL_CONST_i(GL_PERFQUERY_GLOBAL_CONTEXT_INTEL)
 OGL_CONST_i(GL_PERFQUERY_GPA_EXTENDED_COUNTERS_INTEL)
 OGL_CONST_i(GL_PERFQUERY_QUERY_NAME_LENGTH_MAX_INTEL)
 OGL_CONST_i(GL_PERFQUERY_SINGLE_CONTEXT_INTEL)
 OGL_CONST_i(GL_PERFQUERY_WAIT_INTEL)
 OGL_CONST_i(GL_PERSPECTIVE_CORRECTION_HINT)
 OGL_CONST_i(GL_PERTURB_EXT)
 OGL_CONST_i(GL_PER_GPU_STORAGE_BIT_NV)
 OGL_CONST_i(GL_PER_GPU_STORAGE_NV)
 OGL_CONST_i(GL_PER_STAGE_CONSTANTS_NV)
 OGL_CONST_i(GL_PHASE_SGIX)
 OGL_CONST_i(GL_PHONG_HINT_WIN)
 OGL_CONST_i(GL_PHONG_WIN)
 OGL_CONST_i(GL_PINLIGHT_NV)
 OGL_CONST_i(GL_PIXELS_PER_SAMPLE_PATTERN_X_AMD)
 OGL_CONST_i(GL_PIXELS_PER_SAMPLE_PATTERN_Y_AMD)
 OGL_CONST_i(GL_PIXEL_BUFFER_BARRIER_BIT)
 OGL_CONST_i(GL_PIXEL_BUFFER_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_PIXEL_COUNTER_BITS_NV)
 OGL_CONST_i(GL_PIXEL_COUNT_AVAILABLE_NV)
 OGL_CONST_i(GL_PIXEL_COUNT_NV)
 OGL_CONST_i(GL_PIXEL_CUBIC_WEIGHT_EXT)
 OGL_CONST_i(GL_PIXEL_MAG_FILTER_EXT)
 OGL_CONST_i(GL_PIXEL_MAP_A_TO_A)
 OGL_CONST_i(GL_PIXEL_MAP_A_TO_A_SIZE)
 OGL_CONST_i(GL_PIXEL_MAP_B_TO_B)
 OGL_CONST_i(GL_PIXEL_MAP_B_TO_B_SIZE)
 OGL_CONST_i(GL_PIXEL_MAP_G_TO_G)
 OGL_CONST_i(GL_PIXEL_MAP_G_TO_G_SIZE)
 OGL_CONST_i(GL_PIXEL_MAP_I_TO_A)
 OGL_CONST_i(GL_PIXEL_MAP_I_TO_A_SIZE)
 OGL_CONST_i(GL_PIXEL_MAP_I_TO_B)
 OGL_CONST_i(GL_PIXEL_MAP_I_TO_B_SIZE)
 OGL_CONST_i(GL_PIXEL_MAP_I_TO_G)
 OGL_CONST_i(GL_PIXEL_MAP_I_TO_G_SIZE)
 OGL_CONST_i(GL_PIXEL_MAP_I_TO_I)
 OGL_CONST_i(GL_PIXEL_MAP_I_TO_I_SIZE)
 OGL_CONST_i(GL_PIXEL_MAP_I_TO_R)
 OGL_CONST_i(GL_PIXEL_MAP_I_TO_R_SIZE)
 OGL_CONST_i(GL_PIXEL_MAP_R_TO_R)
 OGL_CONST_i(GL_PIXEL_MAP_R_TO_R_SIZE)
 OGL_CONST_i(GL_PIXEL_MAP_S_TO_S)
 OGL_CONST_i(GL_PIXEL_MAP_S_TO_S_SIZE)
 OGL_CONST_i(GL_PIXEL_MIN_FILTER_EXT)
 OGL_CONST_i(GL_PIXEL_MODE_BIT)
 OGL_CONST_i(GL_PIXEL_PACK_BUFFER)
 OGL_CONST_i(GL_PIXEL_PACK_BUFFER_ARB)
 OGL_CONST_i(GL_PIXEL_PACK_BUFFER_BINDING)
 OGL_CONST_i(GL_PIXEL_PACK_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_PIXEL_PACK_BUFFER_BINDING_EXT)
 OGL_CONST_i(GL_PIXEL_PACK_BUFFER_BINDING_NV)
 OGL_CONST_i(GL_PIXEL_PACK_BUFFER_EXT)
 OGL_CONST_i(GL_PIXEL_PACK_BUFFER_NV)
 OGL_CONST_i(GL_PIXEL_SUBSAMPLE_2424_SGIX)
 OGL_CONST_i(GL_PIXEL_SUBSAMPLE_4242_SGIX)
 OGL_CONST_i(GL_PIXEL_SUBSAMPLE_4444_SGIX)
 OGL_CONST_i(GL_PIXEL_TRANSFORM_2D_EXT)
 OGL_CONST_i(GL_PIXEL_TRANSFORM_2D_MATRIX_EXT)
 OGL_CONST_i(GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT)
 OGL_CONST_i(GL_PIXEL_TRANSFORM_OPERATOR_SGI)
 OGL_CONST_i(GL_PIXEL_TRANSFORM_SGI)
 OGL_CONST_i(GL_PIXEL_UNPACK_BUFFER)
 OGL_CONST_i(GL_PIXEL_UNPACK_BUFFER_ARB)
 OGL_CONST_i(GL_PIXEL_UNPACK_BUFFER_BINDING)
 OGL_CONST_i(GL_PIXEL_UNPACK_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_PIXEL_UNPACK_BUFFER_BINDING_EXT)
 OGL_CONST_i(GL_PIXEL_UNPACK_BUFFER_BINDING_NV)
 OGL_CONST_i(GL_PIXEL_UNPACK_BUFFER_EXT)
 OGL_CONST_i(GL_PIXEL_UNPACK_BUFFER_NV)
 OGL_CONST_i(GL_PLUS_CLAMPED_ALPHA_NV)
 OGL_CONST_i(GL_PLUS_CLAMPED_NV)
 OGL_CONST_i(GL_PLUS_DARKER_NV)
 OGL_CONST_i(GL_PLUS_NV)
 OGL_CONST_i(GL_PN_TRIANGLES_ATI)
 OGL_CONST_i(GL_PN_TRIANGLES_NORMAL_MODE_ATI)
 OGL_CONST_i(GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI)
 OGL_CONST_i(GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI)
 OGL_CONST_i(GL_PN_TRIANGLES_POINT_MODE_ATI)
 OGL_CONST_i(GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI)
 OGL_CONST_i(GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI)
 OGL_CONST_i(GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI)
 OGL_CONST_i(GL_POINT)
 OGL_CONST_i(GL_POINTS)
 OGL_CONST_i(GL_POINT_BIT)
 OGL_CONST_i(GL_POINT_DISTANCE_ATTENUATION)
 OGL_CONST_i(GL_POINT_DISTANCE_ATTENUATION_ARB)
 OGL_CONST_i(GL_POINT_FADE_THRESHOLD_SIZE)
 OGL_CONST_i(GL_POINT_FADE_THRESHOLD_SIZE_ARB)
 OGL_CONST_i(GL_POINT_FADE_THRESHOLD_SIZE_EXT)
 OGL_CONST_i(GL_POINT_NV)
 OGL_CONST_i(GL_POINT_SIZE)
 OGL_CONST_i(GL_POINT_SIZE_ARRAY_BUFFER_BINDING_OES)
 OGL_CONST_i(GL_POINT_SIZE_ARRAY_OES)
 OGL_CONST_i(GL_POINT_SIZE_ARRAY_POINTER_OES)
 OGL_CONST_i(GL_POINT_SIZE_ARRAY_STRIDE_OES)
 OGL_CONST_i(GL_POINT_SIZE_ARRAY_TYPE_OES)
 OGL_CONST_i(GL_POINT_SIZE_GRANULARITY)
 OGL_CONST_i(GL_POINT_SIZE_MAX)
 OGL_CONST_i(GL_POINT_SIZE_MAX_ARB)
 OGL_CONST_i(GL_POINT_SIZE_MAX_EXT)
 OGL_CONST_i(GL_POINT_SIZE_MIN)
 OGL_CONST_i(GL_POINT_SIZE_MIN_ARB)
 OGL_CONST_i(GL_POINT_SIZE_MIN_EXT)
 OGL_CONST_i(GL_POINT_SIZE_RANGE)
 OGL_CONST_i(GL_POINT_SMOOTH)
 OGL_CONST_i(GL_POINT_SMOOTH_HINT)
 OGL_CONST_i(GL_POINT_SPRITE)
 OGL_CONST_i(GL_POINT_SPRITE_ARB)
 OGL_CONST_i(GL_POINT_SPRITE_COORD_ORIGIN)
 OGL_CONST_i(GL_POINT_SPRITE_CULL_CENTER_ATIX)
 OGL_CONST_i(GL_POINT_SPRITE_CULL_CLIP_ATIX)
 OGL_CONST_i(GL_POINT_SPRITE_CULL_MODE_ATIX)
 OGL_CONST_i(GL_POINT_SPRITE_NV)
 OGL_CONST_i(GL_POINT_SPRITE_OES)
 OGL_CONST_i(GL_POINT_SPRITE_R_MODE_NV)
 OGL_CONST_i(GL_POINT_TOKEN)
 OGL_CONST_i(GL_POLYGON)
 OGL_CONST_i(GL_POLYGON_BIT)
 OGL_CONST_i(GL_POLYGON_MODE)
 OGL_CONST_i(GL_POLYGON_MODE_NV)
 OGL_CONST_i(GL_POLYGON_OFFSET_BIAS_EXT)
 OGL_CONST_i(GL_POLYGON_OFFSET_CLAMP)
 OGL_CONST_i(GL_POLYGON_OFFSET_CLAMP_EXT)
 OGL_CONST_i(GL_POLYGON_OFFSET_COMMAND_NV)
 OGL_CONST_i(GL_POLYGON_OFFSET_EXT)
 OGL_CONST_i(GL_POLYGON_OFFSET_FACTOR)
 OGL_CONST_i(GL_POLYGON_OFFSET_FACTOR_EXT)
 OGL_CONST_i(GL_POLYGON_OFFSET_FILL)
 OGL_CONST_i(GL_POLYGON_OFFSET_LINE)
 OGL_CONST_i(GL_POLYGON_OFFSET_LINE_NV)
 OGL_CONST_i(GL_POLYGON_OFFSET_POINT)
 OGL_CONST_i(GL_POLYGON_OFFSET_POINT_NV)
 OGL_CONST_i(GL_POLYGON_OFFSET_UNITS)
 OGL_CONST_i(GL_POLYGON_SMOOTH)
 OGL_CONST_i(GL_POLYGON_SMOOTH_HINT)
 OGL_CONST_i(GL_POLYGON_STIPPLE)
 OGL_CONST_i(GL_POLYGON_STIPPLE_BIT)
 OGL_CONST_i(GL_POLYGON_TOKEN)
 OGL_CONST_i(GL_POSITION)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_ALPHA_BIAS)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_ALPHA_SCALE)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_BLUE_BIAS)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_BLUE_SCALE)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_COLOR_TABLE)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_GREEN_BIAS)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_GREEN_SCALE)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_RED_BIAS)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_RED_BIAS_SGI)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_RED_SCALE)
 OGL_CONST_i(GL_POST_COLOR_MATRIX_RED_SCALE_SGI)
 OGL_CONST_i(GL_POST_CONVOLUTION_ALPHA_BIAS)
 OGL_CONST_i(GL_POST_CONVOLUTION_ALPHA_BIAS_EXT)
 OGL_CONST_i(GL_POST_CONVOLUTION_ALPHA_SCALE)
 OGL_CONST_i(GL_POST_CONVOLUTION_ALPHA_SCALE_EXT)
 OGL_CONST_i(GL_POST_CONVOLUTION_BLUE_BIAS)
 OGL_CONST_i(GL_POST_CONVOLUTION_BLUE_BIAS_EXT)
 OGL_CONST_i(GL_POST_CONVOLUTION_BLUE_SCALE)
 OGL_CONST_i(GL_POST_CONVOLUTION_BLUE_SCALE_EXT)
 OGL_CONST_i(GL_POST_CONVOLUTION_COLOR_TABLE)
 OGL_CONST_i(GL_POST_CONVOLUTION_COLOR_TABLE_SGI)
 OGL_CONST_i(GL_POST_CONVOLUTION_GREEN_BIAS)
 OGL_CONST_i(GL_POST_CONVOLUTION_GREEN_BIAS_EXT)
 OGL_CONST_i(GL_POST_CONVOLUTION_GREEN_SCALE)
 OGL_CONST_i(GL_POST_CONVOLUTION_GREEN_SCALE_EXT)
 OGL_CONST_i(GL_POST_CONVOLUTION_RED_BIAS)
 OGL_CONST_i(GL_POST_CONVOLUTION_RED_BIAS_EXT)
 OGL_CONST_i(GL_POST_CONVOLUTION_RED_SCALE)
 OGL_CONST_i(GL_POST_CONVOLUTION_RED_SCALE_EXT)
 OGL_CONST_i(GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX)
 OGL_CONST_i(GL_POST_TEXTURE_FILTER_BIAS_SGIX)
 OGL_CONST_i(GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX)
 OGL_CONST_i(GL_POST_TEXTURE_FILTER_SCALE_SGIX)
 OGL_CONST_i(GL_PREFER_DOUBLEBUFFER_HINT_PGI)
 OGL_CONST_i(GL_PRESENT_DURATION_NV)
 OGL_CONST_i(GL_PRESENT_TIME_NV)
 OGL_CONST_i(GL_PRESERVE_ATI)
 OGL_CONST_i(GL_PREVIOUS)
 OGL_CONST_i(GL_PREVIOUS_ARB)
 OGL_CONST_i(GL_PREVIOUS_EXT)
 OGL_CONST_i(GL_PREVIOUS_TEXTURE_INPUT_NV)
 OGL_CONST_i(GL_PRIMARY_COLOR)
 OGL_CONST_i(GL_PRIMARY_COLOR_ARB)
 OGL_CONST_i(GL_PRIMARY_COLOR_EXT)
 OGL_CONST_i(GL_PRIMARY_COLOR_NV)
 OGL_CONST_i(GL_PRIMITIVES_GENERATED)
 OGL_CONST_i(GL_PRIMITIVES_GENERATED_EXT)
 OGL_CONST_i(GL_PRIMITIVES_GENERATED_NV)
 OGL_CONST_i(GL_PRIMITIVES_GENERATED_OES)
 OGL_CONST_i(GL_PRIMITIVES_SUBMITTED)
 OGL_CONST_i(GL_PRIMITIVES_SUBMITTED_ARB)
 OGL_CONST_i(GL_PRIMITIVE_BOUNDING_BOX_ARB)
 OGL_CONST_i(GL_PRIMITIVE_BOUNDING_BOX_EXT)
 OGL_CONST_i(GL_PRIMITIVE_ID_NV)
 OGL_CONST_i(GL_PRIMITIVE_RESTART)
 OGL_CONST_i(GL_PRIMITIVE_RESTART_FIXED_INDEX)
 OGL_CONST_i(GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED)
 OGL_CONST_i(GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED_OES)
 OGL_CONST_i(GL_PRIMITIVE_RESTART_INDEX)
 OGL_CONST_i(GL_PRIMITIVE_RESTART_INDEX_NV)
 OGL_CONST_i(GL_PRIMITIVE_RESTART_NV)
 OGL_CONST_i(GL_PROGRAM)
 OGL_CONST_i(GL_PROGRAMMABLE_SAMPLE_LOCATION_ARB)
 OGL_CONST_i(GL_PROGRAMMABLE_SAMPLE_LOCATION_NV)
 OGL_CONST_i(GL_PROGRAMMABLE_SAMPLE_LOCATION_TABLE_SIZE_ARB)
 OGL_CONST_i(GL_PROGRAMMABLE_SAMPLE_LOCATION_TABLE_SIZE_NV)
 OGL_CONST_i(GL_PROGRAM_ADDRESS_REGISTERS_ARB)
 OGL_CONST_i(GL_PROGRAM_ALU_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_PROGRAM_ATTRIBS_ARB)
 OGL_CONST_i(GL_PROGRAM_ATTRIB_COMPONENTS_NV)
 OGL_CONST_i(GL_PROGRAM_BINARY_ANGLE)
 OGL_CONST_i(GL_PROGRAM_BINARY_FORMATS)
 OGL_CONST_i(GL_PROGRAM_BINARY_FORMATS_OES)
 OGL_CONST_i(GL_PROGRAM_BINARY_FORMAT_MESA)
 OGL_CONST_i(GL_PROGRAM_BINARY_LENGTH)
 OGL_CONST_i(GL_PROGRAM_BINARY_LENGTH_OES)
 OGL_CONST_i(GL_PROGRAM_BINARY_RETRIEVABLE_HINT)
 OGL_CONST_i(GL_PROGRAM_BINDING_ARB)
 OGL_CONST_i(GL_PROGRAM_ERROR_POSITION_ARB)
 OGL_CONST_i(GL_PROGRAM_ERROR_POSITION_NV)
 OGL_CONST_i(GL_PROGRAM_ERROR_STRING_ARB)
 OGL_CONST_i(GL_PROGRAM_ERROR_STRING_NV)
 OGL_CONST_i(GL_PROGRAM_FORMAT_ARB)
 OGL_CONST_i(GL_PROGRAM_FORMAT_ASCII_ARB)
 OGL_CONST_i(GL_PROGRAM_INPUT)
 OGL_CONST_i(GL_PROGRAM_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_PROGRAM_LENGTH_ARB)
 OGL_CONST_i(GL_PROGRAM_LENGTH_NV)
 OGL_CONST_i(GL_PROGRAM_MATRIX_EXT)
 OGL_CONST_i(GL_PROGRAM_MATRIX_STACK_DEPTH_EXT)
 OGL_CONST_i(GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB)
 OGL_CONST_i(GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_PROGRAM_NATIVE_ATTRIBS_ARB)
 OGL_CONST_i(GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_PROGRAM_NATIVE_PARAMETERS_ARB)
 OGL_CONST_i(GL_PROGRAM_NATIVE_TEMPORARIES_ARB)
 OGL_CONST_i(GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB)
 OGL_CONST_i(GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_PROGRAM_OBJECT_ARB)
 OGL_CONST_i(GL_PROGRAM_OBJECT_EXT)
 OGL_CONST_i(GL_PROGRAM_OUTPUT)
 OGL_CONST_i(GL_PROGRAM_PARAMETERS_ARB)
 OGL_CONST_i(GL_PROGRAM_PARAMETER_NV)
 OGL_CONST_i(GL_PROGRAM_PIPELINE)
 OGL_CONST_i(GL_PROGRAM_PIPELINE_BINDING)
 OGL_CONST_i(GL_PROGRAM_PIPELINE_OBJECT_EXT)
 OGL_CONST_i(GL_PROGRAM_POINT_SIZE)
 OGL_CONST_i(GL_PROGRAM_POINT_SIZE_ARB)
 OGL_CONST_i(GL_PROGRAM_POINT_SIZE_EXT)
 OGL_CONST_i(GL_PROGRAM_RESIDENT_NV)
 OGL_CONST_i(GL_PROGRAM_RESULT_COMPONENTS_NV)
 OGL_CONST_i(GL_PROGRAM_SEPARABLE)
 OGL_CONST_i(GL_PROGRAM_STRING_ARB)
 OGL_CONST_i(GL_PROGRAM_STRING_NV)
 OGL_CONST_i(GL_PROGRAM_TARGET_NV)
 OGL_CONST_i(GL_PROGRAM_TEMPORARIES_ARB)
 OGL_CONST_i(GL_PROGRAM_TEX_INDIRECTIONS_ARB)
 OGL_CONST_i(GL_PROGRAM_TEX_INSTRUCTIONS_ARB)
 OGL_CONST_i(GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB)
 OGL_CONST_i(GL_PROJECTION)
 OGL_CONST_i(GL_PROJECTION_MATRIX)
 OGL_CONST_i(GL_PROJECTION_MATRIX_FLOAT_AS_INT_BITS_OES)
 OGL_CONST_i(GL_PROJECTION_STACK_DEPTH)
 OGL_CONST_i(GL_PROTECTED_MEMORY_OBJECT_EXT)
 OGL_CONST_i(GL_PROVOKING_VERTEX)
 OGL_CONST_i(GL_PROVOKING_VERTEX_EXT)
 OGL_CONST_i(GL_PROXY_COLOR_TABLE)
 OGL_CONST_i(GL_PROXY_COLOR_TABLE_SGI)
 OGL_CONST_i(GL_PROXY_HISTOGRAM)
 OGL_CONST_i(GL_PROXY_HISTOGRAM_EXT)
 OGL_CONST_i(GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE)
 OGL_CONST_i(GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI)
 OGL_CONST_i(GL_PROXY_POST_CONVOLUTION_COLOR_TABLE)
 OGL_CONST_i(GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI)
 OGL_CONST_i(GL_PROXY_TEXTURE_1D)
 OGL_CONST_i(GL_PROXY_TEXTURE_1D_ARRAY)
 OGL_CONST_i(GL_PROXY_TEXTURE_1D_ARRAY_EXT)
 OGL_CONST_i(GL_PROXY_TEXTURE_1D_EXT)
 OGL_CONST_i(GL_PROXY_TEXTURE_1D_STACK_MESAX)
 OGL_CONST_i(GL_PROXY_TEXTURE_2D)
 OGL_CONST_i(GL_PROXY_TEXTURE_2D_ARRAY)
 OGL_CONST_i(GL_PROXY_TEXTURE_2D_ARRAY_EXT)
 OGL_CONST_i(GL_PROXY_TEXTURE_2D_EXT)
 OGL_CONST_i(GL_PROXY_TEXTURE_2D_MULTISAMPLE)
 OGL_CONST_i(GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY)
 OGL_CONST_i(GL_PROXY_TEXTURE_2D_STACK_MESAX)
 OGL_CONST_i(GL_PROXY_TEXTURE_3D)
 OGL_CONST_i(GL_PROXY_TEXTURE_3D_EXT)
 OGL_CONST_i(GL_PROXY_TEXTURE_COLOR_TABLE_SGI)
 OGL_CONST_i(GL_PROXY_TEXTURE_CUBE_MAP)
 OGL_CONST_i(GL_PROXY_TEXTURE_CUBE_MAP_ARB)
 OGL_CONST_i(GL_PROXY_TEXTURE_CUBE_MAP_ARRAY)
 OGL_CONST_i(GL_PROXY_TEXTURE_CUBE_MAP_ARRAY_ARB)
 OGL_CONST_i(GL_PROXY_TEXTURE_CUBE_MAP_EXT)
 OGL_CONST_i(GL_PROXY_TEXTURE_RECTANGLE)
 OGL_CONST_i(GL_PROXY_TEXTURE_RECTANGLE_ARB)
 OGL_CONST_i(GL_PROXY_TEXTURE_RECTANGLE_EXT)
 OGL_CONST_i(GL_PROXY_TEXTURE_RECTANGLE_NV)
 OGL_CONST_i(GL_PURGEABLE_APPLE)
 OGL_CONST_i(GL_PURGED_CONTEXT_RESET_NV)
 OGL_CONST_i(GL_PVRIC_SIGNATURE_MISMATCH_IMG)
 OGL_CONST_i(GL_Q)
 OGL_CONST_i(GL_QUADRATIC_ATTENUATION)
 OGL_CONST_i(GL_QUADRATIC_CURVE_TO_NV)
 OGL_CONST_i(GL_QUADS)
 OGL_CONST_i(GL_QUADS_EXT)
 OGL_CONST_i(GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION)
 OGL_CONST_i(GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION_EXT)
 OGL_CONST_i(GL_QUADS_OES)
 OGL_CONST_i(GL_QUAD_MESH_SUN)
 OGL_CONST_i(GL_QUAD_STRIP)
 OGL_CONST_i(GL_QUARTER_BIT_ATI)
 OGL_CONST_i(GL_QUERY)
 OGL_CONST_i(GL_QUERY_ALL_EVENT_BITS_AMD)
 OGL_CONST_i(GL_QUERY_BUFFER)
 OGL_CONST_i(GL_QUERY_BUFFER_AMD)
 OGL_CONST_i(GL_QUERY_BUFFER_BARRIER_BIT)
 OGL_CONST_i(GL_QUERY_BUFFER_BINDING)
 OGL_CONST_i(GL_QUERY_BUFFER_BINDING_AMD)
 OGL_CONST_i(GL_QUERY_BY_REGION_NO_WAIT)
 OGL_CONST_i(GL_QUERY_BY_REGION_NO_WAIT_INVERTED)
 OGL_CONST_i(GL_QUERY_BY_REGION_NO_WAIT_NV)
 OGL_CONST_i(GL_QUERY_BY_REGION_WAIT)
 OGL_CONST_i(GL_QUERY_BY_REGION_WAIT_INVERTED)
 OGL_CONST_i(GL_QUERY_BY_REGION_WAIT_NV)
 OGL_CONST_i(GL_QUERY_COUNTER_BITS)
 OGL_CONST_i(GL_QUERY_COUNTER_BITS_ANGLE)
 OGL_CONST_i(GL_QUERY_COUNTER_BITS_ARB)
 OGL_CONST_i(GL_QUERY_COUNTER_BITS_EXT)
 OGL_CONST_i(GL_QUERY_DEPTH_BOUNDS_FAIL_EVENT_BIT_AMD)
 OGL_CONST_i(GL_QUERY_DEPTH_FAIL_EVENT_BIT_AMD)
 OGL_CONST_i(GL_QUERY_DEPTH_PASS_EVENT_BIT_AMD)
 OGL_CONST_i(GL_QUERY_NO_WAIT)
 OGL_CONST_i(GL_QUERY_NO_WAIT_INVERTED)
 OGL_CONST_i(GL_QUERY_NO_WAIT_NV)
 OGL_CONST_i(GL_QUERY_OBJECT_AMD)
 OGL_CONST_i(GL_QUERY_OBJECT_EXT)
 OGL_CONST_i(GL_QUERY_RESULT)
 OGL_CONST_i(GL_QUERY_RESULT_ANGLE)
 OGL_CONST_i(GL_QUERY_RESULT_ARB)
 OGL_CONST_i(GL_QUERY_RESULT_AVAILABLE)
 OGL_CONST_i(GL_QUERY_RESULT_AVAILABLE_ANGLE)
 OGL_CONST_i(GL_QUERY_RESULT_AVAILABLE_ARB)
 OGL_CONST_i(GL_QUERY_RESULT_AVAILABLE_EXT)
 OGL_CONST_i(GL_QUERY_RESULT_AVAILABLE_NV)
 OGL_CONST_i(GL_QUERY_RESULT_EXT)
 OGL_CONST_i(GL_QUERY_RESULT_NO_WAIT)
 OGL_CONST_i(GL_QUERY_RESULT_NO_WAIT_AMD)
 OGL_CONST_i(GL_QUERY_RESULT_NV)
 OGL_CONST_i(GL_QUERY_STENCIL_FAIL_EVENT_BIT_AMD)
 OGL_CONST_i(GL_QUERY_TARGET)
 OGL_CONST_i(GL_QUERY_WAIT)
 OGL_CONST_i(GL_QUERY_WAIT_INVERTED)
 OGL_CONST_i(GL_QUERY_WAIT_NV)
 OGL_CONST_i(GL_R)
 OGL_CONST_i(GL_R11F_G11F_B10F)
 OGL_CONST_i(GL_R11F_G11F_B10F_APPLE)
 OGL_CONST_i(GL_R11F_G11F_B10F_EXT)
 OGL_CONST_i(GL_R11F_G11F_B10F_NV)
 OGL_CONST_i(GL_R16)
 OGL_CONST_i(GL_R16F)
 OGL_CONST_i(GL_R16F_EXT)
 OGL_CONST_i(GL_R16I)
 OGL_CONST_i(GL_R16UI)
 OGL_CONST_i(GL_R16_EXT)
 OGL_CONST_i(GL_R16_SNORM)
 OGL_CONST_i(GL_R16_SNORM_EXT)
 OGL_CONST_i(GL_R1UI_C3F_V3F_SUN)
 OGL_CONST_i(GL_R1UI_C4F_N3F_V3F_SUN)
 OGL_CONST_i(GL_R1UI_C4UB_V3F_SUN)
 OGL_CONST_i(GL_R1UI_N3F_V3F_SUN)
 OGL_CONST_i(GL_R1UI_T2F_C4F_N3F_V3F_SUN)
 OGL_CONST_i(GL_R1UI_T2F_N3F_V3F_SUN)
 OGL_CONST_i(GL_R1UI_T2F_V3F_SUN)
 OGL_CONST_i(GL_R1UI_V3F_SUN)
 OGL_CONST_i(GL_R32F)
 OGL_CONST_i(GL_R32F_EXT)
 OGL_CONST_i(GL_R32I)
 OGL_CONST_i(GL_R32UI)
 OGL_CONST_i(GL_R3_G3_B2)
 OGL_CONST_i(GL_R5_G6_B5_A8_ICC_SGIX)
 OGL_CONST_i(GL_R5_G6_B5_ICC_SGIX)
 OGL_CONST_i(GL_R8)
 OGL_CONST_i(GL_R8I)
 OGL_CONST_i(GL_R8UI)
 OGL_CONST_i(GL_R8_EXT)
 OGL_CONST_i(GL_R8_SNORM)
 OGL_CONST_i(GL_RASTERIZER_DISCARD)
 OGL_CONST_i(GL_RASTERIZER_DISCARD_EXT)
 OGL_CONST_i(GL_RASTERIZER_DISCARD_NV)
 OGL_CONST_i(GL_RASTER_FIXED_SAMPLE_LOCATIONS_EXT)
 OGL_CONST_i(GL_RASTER_MULTISAMPLE_EXT)
 OGL_CONST_i(GL_RASTER_POSITION_UNCLIPPED_IBM)
 OGL_CONST_i(GL_RASTER_SAMPLES_EXT)
 OGL_CONST_i(GL_READ_BUFFER)
 OGL_CONST_i(GL_READ_BUFFER_EXT)
 OGL_CONST_i(GL_READ_BUFFER_NV)
 OGL_CONST_i(GL_READ_FRAMEBUFFER)
 OGL_CONST_i(GL_READ_FRAMEBUFFER_ANGLE)
 OGL_CONST_i(GL_READ_FRAMEBUFFER_APPLE)
 OGL_CONST_i(GL_READ_FRAMEBUFFER_BINDING)
 OGL_CONST_i(GL_READ_FRAMEBUFFER_BINDING_ANGLE)
 OGL_CONST_i(GL_READ_FRAMEBUFFER_BINDING_APPLE)
 OGL_CONST_i(GL_READ_FRAMEBUFFER_BINDING_EXT)
 OGL_CONST_i(GL_READ_FRAMEBUFFER_BINDING_NV)
 OGL_CONST_i(GL_READ_FRAMEBUFFER_EXT)
 OGL_CONST_i(GL_READ_FRAMEBUFFER_NV)
 OGL_CONST_i(GL_READ_ONLY)
 OGL_CONST_i(GL_READ_ONLY_ARB)
 OGL_CONST_i(GL_READ_PIXELS)
 OGL_CONST_i(GL_READ_PIXELS_FORMAT)
 OGL_CONST_i(GL_READ_PIXELS_TYPE)
 OGL_CONST_i(GL_READ_PIXEL_DATA_RANGE_LENGTH_NV)
 OGL_CONST_i(GL_READ_PIXEL_DATA_RANGE_NV)
 OGL_CONST_i(GL_READ_PIXEL_DATA_RANGE_POINTER_NV)
 OGL_CONST_i(GL_READ_WRITE)
 OGL_CONST_i(GL_READ_WRITE_ARB)
 OGL_CONST_i(GL_RECIP_ADD_SIGNED_ALPHA_IMG)
 OGL_CONST_i(GL_RECLAIM_MEMORY_HINT_PGI)
 OGL_CONST_i(GL_RECT_NV)
 OGL_CONST_i(GL_RED)
 OGL_CONST_i(GL_REDUCE)
 OGL_CONST_i(GL_REDUCE_EXT)
 OGL_CONST_i(GL_RED_BIAS)
 OGL_CONST_i(GL_RED_BITS)
 OGL_CONST_i(GL_RED_BIT_ATI)
 OGL_CONST_i(GL_RED_EXT)
 OGL_CONST_i(GL_RED_INTEGER)
 OGL_CONST_i(GL_RED_INTEGER_EXT)
 OGL_CONST_i(GL_RED_MAX_CLAMP_INGR)
 OGL_CONST_i(GL_RED_MIN_CLAMP_INGR)
 OGL_CONST_i(GL_RED_NV)
 OGL_CONST_i(GL_RED_SCALE)
 OGL_CONST_i(GL_RED_SNORM)
 OGL_CONST_i(GL_REFERENCED_BY_COMPUTE_SHADER)
 OGL_CONST_i(GL_REFERENCED_BY_FRAGMENT_SHADER)
 OGL_CONST_i(GL_REFERENCED_BY_GEOMETRY_SHADER)
 OGL_CONST_i(GL_REFERENCED_BY_GEOMETRY_SHADER_EXT)
 OGL_CONST_i(GL_REFERENCED_BY_GEOMETRY_SHADER_OES)
 OGL_CONST_i(GL_REFERENCED_BY_MESH_SHADER_EXT)
 OGL_CONST_i(GL_REFERENCED_BY_MESH_SHADER_NV)
 OGL_CONST_i(GL_REFERENCED_BY_TASK_SHADER_EXT)
 OGL_CONST_i(GL_REFERENCED_BY_TASK_SHADER_NV)
 OGL_CONST_i(GL_REFERENCED_BY_TESS_CONTROL_SHADER)
 OGL_CONST_i(GL_REFERENCED_BY_TESS_CONTROL_SHADER_EXT)
 OGL_CONST_i(GL_REFERENCED_BY_TESS_CONTROL_SHADER_OES)
 OGL_CONST_i(GL_REFERENCED_BY_TESS_EVALUATION_SHADER)
 OGL_CONST_i(GL_REFERENCED_BY_TESS_EVALUATION_SHADER_EXT)
 OGL_CONST_i(GL_REFERENCED_BY_TESS_EVALUATION_SHADER_OES)
 OGL_CONST_i(GL_REFERENCED_BY_VERTEX_SHADER)
 OGL_CONST_i(GL_REFLECTION_MAP)
 OGL_CONST_i(GL_REFLECTION_MAP_ARB)
 OGL_CONST_i(GL_REFLECTION_MAP_EXT)
 OGL_CONST_i(GL_REFLECTION_MAP_NV)
 OGL_CONST_i(GL_REFLECTION_MAP_OES)
 OGL_CONST_i(GL_REGISTER_COMBINERS_NV)
 OGL_CONST_i(GL_REG_0_ATI)
 OGL_CONST_i(GL_REG_1_ATI)
 OGL_CONST_i(GL_REG_2_ATI)
 OGL_CONST_i(GL_REG_3_ATI)
 OGL_CONST_i(GL_REG_4_ATI)
 OGL_CONST_i(GL_REG_5_ATI)
 OGL_CONST_i(GL_RELATIVE_ARC_TO_NV)
 OGL_CONST_i(GL_RELATIVE_CONIC_CURVE_TO_NV)
 OGL_CONST_i(GL_RELATIVE_CUBIC_CURVE_TO_NV)
 OGL_CONST_i(GL_RELATIVE_HORIZONTAL_LINE_TO_NV)
 OGL_CONST_i(GL_RELATIVE_LARGE_CCW_ARC_TO_NV)
 OGL_CONST_i(GL_RELATIVE_LARGE_CW_ARC_TO_NV)
 OGL_CONST_i(GL_RELATIVE_LINE_TO_NV)
 OGL_CONST_i(GL_RELATIVE_MOVE_TO_NV)
 OGL_CONST_i(GL_RELATIVE_QUADRATIC_CURVE_TO_NV)
 OGL_CONST_i(GL_RELATIVE_RECT_NV)
 OGL_CONST_i(GL_RELATIVE_ROUNDED_RECT2_NV)
 OGL_CONST_i(GL_RELATIVE_ROUNDED_RECT4_NV)
 OGL_CONST_i(GL_RELATIVE_ROUNDED_RECT8_NV)
 OGL_CONST_i(GL_RELATIVE_ROUNDED_RECT_NV)
 OGL_CONST_i(GL_RELATIVE_SMALL_CCW_ARC_TO_NV)
 OGL_CONST_i(GL_RELATIVE_SMALL_CW_ARC_TO_NV)
 OGL_CONST_i(GL_RELATIVE_SMOOTH_CUBIC_CURVE_TO_NV)
 OGL_CONST_i(GL_RELATIVE_SMOOTH_QUADRATIC_CURVE_TO_NV)
 OGL_CONST_i(GL_RELATIVE_VERTICAL_LINE_TO_NV)
 OGL_CONST_i(GL_RELEASED_APPLE)
 OGL_CONST_i(GL_RENDER)
 OGL_CONST_i(GL_RENDERBUFFER)
 OGL_CONST_i(GL_RENDERBUFFER_ALPHA_SIZE)
 OGL_CONST_i(GL_RENDERBUFFER_ALPHA_SIZE_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_ALPHA_SIZE_OES)
 OGL_CONST_i(GL_RENDERBUFFER_BINDING)
 OGL_CONST_i(GL_RENDERBUFFER_BINDING_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_BINDING_OES)
 OGL_CONST_i(GL_RENDERBUFFER_BLUE_SIZE)
 OGL_CONST_i(GL_RENDERBUFFER_BLUE_SIZE_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_BLUE_SIZE_OES)
 OGL_CONST_i(GL_RENDERBUFFER_COLOR_SAMPLES_NV)
 OGL_CONST_i(GL_RENDERBUFFER_COVERAGE_SAMPLES_NV)
 OGL_CONST_i(GL_RENDERBUFFER_DEPTH_SIZE)
 OGL_CONST_i(GL_RENDERBUFFER_DEPTH_SIZE_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_DEPTH_SIZE_OES)
 OGL_CONST_i(GL_RENDERBUFFER_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_FREE_MEMORY_ATI)
 OGL_CONST_i(GL_RENDERBUFFER_GREEN_SIZE)
 OGL_CONST_i(GL_RENDERBUFFER_GREEN_SIZE_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_GREEN_SIZE_OES)
 OGL_CONST_i(GL_RENDERBUFFER_HEIGHT)
 OGL_CONST_i(GL_RENDERBUFFER_HEIGHT_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_HEIGHT_OES)
 OGL_CONST_i(GL_RENDERBUFFER_INTERNAL_FORMAT)
 OGL_CONST_i(GL_RENDERBUFFER_INTERNAL_FORMAT_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_INTERNAL_FORMAT_OES)
 OGL_CONST_i(GL_RENDERBUFFER_OES)
 OGL_CONST_i(GL_RENDERBUFFER_RED_SIZE)
 OGL_CONST_i(GL_RENDERBUFFER_RED_SIZE_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_RED_SIZE_OES)
 OGL_CONST_i(GL_RENDERBUFFER_SAMPLES)
 OGL_CONST_i(GL_RENDERBUFFER_SAMPLES_ANGLE)
 OGL_CONST_i(GL_RENDERBUFFER_SAMPLES_APPLE)
 OGL_CONST_i(GL_RENDERBUFFER_SAMPLES_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_SAMPLES_IMG)
 OGL_CONST_i(GL_RENDERBUFFER_SAMPLES_NV)
 OGL_CONST_i(GL_RENDERBUFFER_STENCIL_SIZE)
 OGL_CONST_i(GL_RENDERBUFFER_STENCIL_SIZE_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_STENCIL_SIZE_OES)
 OGL_CONST_i(GL_RENDERBUFFER_STORAGE_SAMPLES_AMD)
 OGL_CONST_i(GL_RENDERBUFFER_WIDTH)
 OGL_CONST_i(GL_RENDERBUFFER_WIDTH_EXT)
 OGL_CONST_i(GL_RENDERBUFFER_WIDTH_OES)
 OGL_CONST_i(GL_RENDERER)
 OGL_CONST_i(GL_RENDER_DIRECT_TO_FRAMEBUFFER_QCOM)
 OGL_CONST_i(GL_RENDER_GPU_MASK_NV)
 OGL_CONST_i(GL_RENDER_MODE)
 OGL_CONST_i(GL_REPEAT)
 OGL_CONST_i(GL_REPLACE)
 OGL_CONST_i(GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN)
 OGL_CONST_i(GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN)
 OGL_CONST_i(GL_REPLACEMENT_CODE_ARRAY_SUN)
 OGL_CONST_i(GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN)
 OGL_CONST_i(GL_REPLACEMENT_CODE_SUN)
 OGL_CONST_i(GL_REPLACE_EXT)
 OGL_CONST_i(GL_REPLACE_MIDDLE_SUN)
 OGL_CONST_i(GL_REPLACE_OLDEST_SUN)
 OGL_CONST_i(GL_REPLACE_VALUE_AMD)
 OGL_CONST_i(GL_REPLICATE_BORDER)
 OGL_CONST_i(GL_REPRESENTATIVE_FRAGMENT_TEST_NV)
 OGL_CONST_i(GL_REQUIRED_TEXTURE_IMAGE_UNITS_OES)
 OGL_CONST_i(GL_RESAMPLE_AVERAGE_OML)
 OGL_CONST_i(GL_RESAMPLE_DECIMATE_OML)
 OGL_CONST_i(GL_RESAMPLE_DECIMATE_SGIX)
 OGL_CONST_i(GL_RESAMPLE_REPLICATE_OML)
 OGL_CONST_i(GL_RESAMPLE_REPLICATE_SGIX)
 OGL_CONST_i(GL_RESAMPLE_ZERO_FILL_OML)
 OGL_CONST_i(GL_RESAMPLE_ZERO_FILL_SGIX)
 OGL_CONST_i(GL_RESCALE_NORMAL)
 OGL_CONST_i(GL_RESCALE_NORMAL_EXT)
 OGL_CONST_i(GL_RESET_NOTIFICATION_STRATEGY)
 OGL_CONST_i(GL_RESET_NOTIFICATION_STRATEGY_ARB)
 OGL_CONST_i(GL_RESET_NOTIFICATION_STRATEGY_EXT)
 OGL_CONST_i(GL_RESTART_PATH_NV)
 OGL_CONST_i(GL_RESTART_SUN)
 OGL_CONST_i(GL_RETAINED_APPLE)
 OGL_CONST_i(GL_RETURN)
 OGL_CONST_i(GL_RG)
 OGL_CONST_i(GL_RG16)
 OGL_CONST_i(GL_RG16F)
 OGL_CONST_i(GL_RG16F_EXT)
 OGL_CONST_i(GL_RG16I)
 OGL_CONST_i(GL_RG16UI)
 OGL_CONST_i(GL_RG16_EXT)
 OGL_CONST_i(GL_RG16_SNORM)
 OGL_CONST_i(GL_RG16_SNORM_EXT)
 OGL_CONST_i(GL_RG32F)
 OGL_CONST_i(GL_RG32F_EXT)
 OGL_CONST_i(GL_RG32I)
 OGL_CONST_i(GL_RG32UI)
 OGL_CONST_i(GL_RG8)
 OGL_CONST_i(GL_RG8I)
 OGL_CONST_i(GL_RG8UI)
 OGL_CONST_i(GL_RG8_EXT)
 OGL_CONST_i(GL_RG8_SNORM)
 OGL_CONST_i(GL_RGB)
 OGL_CONST_i(GL_RGB10)
 OGL_CONST_i(GL_RGB10_A2)
 OGL_CONST_i(GL_RGB10_A2UI)
 OGL_CONST_i(GL_RGB10_A2_EXT)
 OGL_CONST_i(GL_RGB10_EXT)
 OGL_CONST_i(GL_RGB12)
 OGL_CONST_i(GL_RGB12_EXT)
 OGL_CONST_i(GL_RGB16)
 OGL_CONST_i(GL_RGB16F)
 OGL_CONST_i(GL_RGB16F_ARB)
 OGL_CONST_i(GL_RGB16F_EXT)
 OGL_CONST_i(GL_RGB16I)
 OGL_CONST_i(GL_RGB16I_EXT)
 OGL_CONST_i(GL_RGB16UI)
 OGL_CONST_i(GL_RGB16UI_EXT)
 OGL_CONST_i(GL_RGB16_EXT)
 OGL_CONST_i(GL_RGB16_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_RGB16_SIGNED_SGIX)
 OGL_CONST_i(GL_RGB16_SNORM)
 OGL_CONST_i(GL_RGB16_SNORM_EXT)
 OGL_CONST_i(GL_RGB2_EXT)
 OGL_CONST_i(GL_RGB32F)
 OGL_CONST_i(GL_RGB32F_ARB)
 OGL_CONST_i(GL_RGB32F_EXT)
 OGL_CONST_i(GL_RGB32I)
 OGL_CONST_i(GL_RGB32I_EXT)
 OGL_CONST_i(GL_RGB32UI)
 OGL_CONST_i(GL_RGB32UI_EXT)
 OGL_CONST_i(GL_RGB4)
 OGL_CONST_i(GL_RGB4_EXT)
 OGL_CONST_i(GL_RGB4_S3TC)
 OGL_CONST_i(GL_RGB5)
 OGL_CONST_i(GL_RGB565)
 OGL_CONST_i(GL_RGB565_OES)
 OGL_CONST_i(GL_RGB5_A1)
 OGL_CONST_i(GL_RGB5_A1_EXT)
 OGL_CONST_i(GL_RGB5_A1_OES)
 OGL_CONST_i(GL_RGB5_EXT)
 OGL_CONST_i(GL_RGB8)
 OGL_CONST_i(GL_RGB8I)
 OGL_CONST_i(GL_RGB8I_EXT)
 OGL_CONST_i(GL_RGB8UI)
 OGL_CONST_i(GL_RGB8UI_EXT)
 OGL_CONST_i(GL_RGB8_EXT)
 OGL_CONST_i(GL_RGB8_OES)
 OGL_CONST_i(GL_RGB8_SNORM)
 OGL_CONST_i(GL_RGB9_E5)
 OGL_CONST_i(GL_RGB9_E5_APPLE)
 OGL_CONST_i(GL_RGB9_E5_EXT)
 OGL_CONST_i(GL_RGBA)
 OGL_CONST_i(GL_RGBA12)
 OGL_CONST_i(GL_RGBA12_EXT)
 OGL_CONST_i(GL_RGBA16)
 OGL_CONST_i(GL_RGBA16F)
 OGL_CONST_i(GL_RGBA16F_ARB)
 OGL_CONST_i(GL_RGBA16F_EXT)
 OGL_CONST_i(GL_RGBA16I)
 OGL_CONST_i(GL_RGBA16I_EXT)
 OGL_CONST_i(GL_RGBA16UI)
 OGL_CONST_i(GL_RGBA16UI_EXT)
 OGL_CONST_i(GL_RGBA16_EXT)
 OGL_CONST_i(GL_RGBA16_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_RGBA16_SIGNED_SGIX)
 OGL_CONST_i(GL_RGBA16_SNORM)
 OGL_CONST_i(GL_RGBA16_SNORM_EXT)
 OGL_CONST_i(GL_RGBA2)
 OGL_CONST_i(GL_RGBA2_EXT)
 OGL_CONST_i(GL_RGBA32F)
 OGL_CONST_i(GL_RGBA32F_ARB)
 OGL_CONST_i(GL_RGBA32F_EXT)
 OGL_CONST_i(GL_RGBA32I)
 OGL_CONST_i(GL_RGBA32I_EXT)
 OGL_CONST_i(GL_RGBA32UI)
 OGL_CONST_i(GL_RGBA32UI_EXT)
 OGL_CONST_i(GL_RGBA4)
 OGL_CONST_i(GL_RGBA4_DXT5_S3TC)
 OGL_CONST_i(GL_RGBA4_EXT)
 OGL_CONST_i(GL_RGBA4_OES)
 OGL_CONST_i(GL_RGBA4_S3TC)
 OGL_CONST_i(GL_RGBA8)
 OGL_CONST_i(GL_RGBA8I)
 OGL_CONST_i(GL_RGBA8I_EXT)
 OGL_CONST_i(GL_RGBA8UI)
 OGL_CONST_i(GL_RGBA8UI_EXT)
 OGL_CONST_i(GL_RGBA8_EXT)
 OGL_CONST_i(GL_RGBA8_OES)
 OGL_CONST_i(GL_RGBA8_SNORM)
 OGL_CONST_i(GL_RGBA_DXT5_S3TC)
 OGL_CONST_i(GL_RGBA_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_RGBA_FLOAT16_APPLE)
 OGL_CONST_i(GL_RGBA_FLOAT16_ATI)
 OGL_CONST_i(GL_RGBA_FLOAT32_APPLE)
 OGL_CONST_i(GL_RGBA_FLOAT32_ATI)
 OGL_CONST_i(GL_RGBA_FLOAT_MODE_ARB)
 OGL_CONST_i(GL_RGBA_ICC_SGIX)
 OGL_CONST_i(GL_RGBA_INTEGER)
 OGL_CONST_i(GL_RGBA_INTEGER_EXT)
 OGL_CONST_i(GL_RGBA_INTEGER_MODE_EXT)
 OGL_CONST_i(GL_RGBA_MODE)
 OGL_CONST_i(GL_RGBA_S3TC)
 OGL_CONST_i(GL_RGBA_SIGNED_COMPONENTS_EXT)
 OGL_CONST_i(GL_RGBA_SIGNED_SGIX)
 OGL_CONST_i(GL_RGBA_SNORM)
 OGL_CONST_i(GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV)
 OGL_CONST_i(GL_RGB_422_APPLE)
 OGL_CONST_i(GL_RGB_EXTENDED_RANGE_SGIX)
 OGL_CONST_i(GL_RGB_FLOAT16_APPLE)
 OGL_CONST_i(GL_RGB_FLOAT16_ATI)
 OGL_CONST_i(GL_RGB_FLOAT32_APPLE)
 OGL_CONST_i(GL_RGB_FLOAT32_ATI)
 OGL_CONST_i(GL_RGB_ICC_SGIX)
 OGL_CONST_i(GL_RGB_INTEGER)
 OGL_CONST_i(GL_RGB_INTEGER_EXT)
 OGL_CONST_i(GL_RGB_RAW_422_APPLE)
 OGL_CONST_i(GL_RGB_S3TC)
 OGL_CONST_i(GL_RGB_SCALE)
 OGL_CONST_i(GL_RGB_SCALE_ARB)
 OGL_CONST_i(GL_RGB_SCALE_EXT)
 OGL_CONST_i(GL_RGB_SIGNED_SGIX)
 OGL_CONST_i(GL_RGB_SNORM)
 OGL_CONST_i(GL_RG_EXT)
 OGL_CONST_i(GL_RG_INTEGER)
 OGL_CONST_i(GL_RG_SNORM)
 OGL_CONST_i(GL_RIGHT)
 OGL_CONST_i(GL_ROUNDED_RECT2_NV)
 OGL_CONST_i(GL_ROUNDED_RECT4_NV)
 OGL_CONST_i(GL_ROUNDED_RECT8_NV)
 OGL_CONST_i(GL_ROUNDED_RECT_NV)
 OGL_CONST_i(GL_ROUND_NV)
 OGL_CONST_i(GL_S)
 OGL_CONST_i(GL_SAMPLER)
 OGL_CONST_i(GL_SAMPLER_1D)
 OGL_CONST_i(GL_SAMPLER_1D_ARB)
 OGL_CONST_i(GL_SAMPLER_1D_ARRAY)
 OGL_CONST_i(GL_SAMPLER_1D_ARRAY_EXT)
 OGL_CONST_i(GL_SAMPLER_1D_ARRAY_SHADOW)
 OGL_CONST_i(GL_SAMPLER_1D_ARRAY_SHADOW_EXT)
 OGL_CONST_i(GL_SAMPLER_1D_SHADOW)
 OGL_CONST_i(GL_SAMPLER_1D_SHADOW_ARB)
 OGL_CONST_i(GL_SAMPLER_2D)
 OGL_CONST_i(GL_SAMPLER_2D_ARB)
 OGL_CONST_i(GL_SAMPLER_2D_ARRAY)
 OGL_CONST_i(GL_SAMPLER_2D_ARRAY_EXT)
 OGL_CONST_i(GL_SAMPLER_2D_ARRAY_NV)
 OGL_CONST_i(GL_SAMPLER_2D_ARRAY_SHADOW)
 OGL_CONST_i(GL_SAMPLER_2D_ARRAY_SHADOW_EXT)
 OGL_CONST_i(GL_SAMPLER_2D_ARRAY_SHADOW_NV)
 OGL_CONST_i(GL_SAMPLER_2D_MULTISAMPLE)
 OGL_CONST_i(GL_SAMPLER_2D_MULTISAMPLE_ARRAY)
 OGL_CONST_i(GL_SAMPLER_2D_MULTISAMPLE_ARRAY_OES)
 OGL_CONST_i(GL_SAMPLER_2D_RECT)
 OGL_CONST_i(GL_SAMPLER_2D_RECT_ARB)
 OGL_CONST_i(GL_SAMPLER_2D_RECT_SHADOW)
 OGL_CONST_i(GL_SAMPLER_2D_RECT_SHADOW_ARB)
 OGL_CONST_i(GL_SAMPLER_2D_SHADOW)
 OGL_CONST_i(GL_SAMPLER_2D_SHADOW_ARB)
 OGL_CONST_i(GL_SAMPLER_2D_SHADOW_EXT)
 OGL_CONST_i(GL_SAMPLER_3D)
 OGL_CONST_i(GL_SAMPLER_3D_ARB)
 OGL_CONST_i(GL_SAMPLER_BINDING)
 OGL_CONST_i(GL_SAMPLER_BUFFER)
 OGL_CONST_i(GL_SAMPLER_BUFFER_AMD)
 OGL_CONST_i(GL_SAMPLER_BUFFER_EXT)
 OGL_CONST_i(GL_SAMPLER_BUFFER_OES)
 OGL_CONST_i(GL_SAMPLER_CUBE)
 OGL_CONST_i(GL_SAMPLER_CUBE_ARB)
 OGL_CONST_i(GL_SAMPLER_CUBE_MAP_ARRAY)
 OGL_CONST_i(GL_SAMPLER_CUBE_MAP_ARRAY_ARB)
 OGL_CONST_i(GL_SAMPLER_CUBE_MAP_ARRAY_EXT)
 OGL_CONST_i(GL_SAMPLER_CUBE_MAP_ARRAY_OES)
 OGL_CONST_i(GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW)
 OGL_CONST_i(GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW_ARB)
 OGL_CONST_i(GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW_EXT)
 OGL_CONST_i(GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW_OES)
 OGL_CONST_i(GL_SAMPLER_CUBE_SHADOW)
 OGL_CONST_i(GL_SAMPLER_CUBE_SHADOW_EXT)
 OGL_CONST_i(GL_SAMPLER_CUBE_SHADOW_NV)
 OGL_CONST_i(GL_SAMPLER_EXTERNAL_2D_Y2Y_EXT)
 OGL_CONST_i(GL_SAMPLER_EXTERNAL_OES)
 OGL_CONST_i(GL_SAMPLER_OBJECT_AMD)
 OGL_CONST_i(GL_SAMPLER_RENDERBUFFER_NV)
 OGL_CONST_i(GL_SAMPLES)
 OGL_CONST_i(GL_SAMPLES_3DFX)
 OGL_CONST_i(GL_SAMPLES_ARB)
 OGL_CONST_i(GL_SAMPLES_EXT)
 OGL_CONST_i(GL_SAMPLES_PASSED)
 OGL_CONST_i(GL_SAMPLES_PASSED_ARB)
 OGL_CONST_i(GL_SAMPLES_SGIS)
 OGL_CONST_i(GL_SAMPLE_ALPHA_TO_COVERAGE)
 OGL_CONST_i(GL_SAMPLE_ALPHA_TO_COVERAGE_ARB)
 OGL_CONST_i(GL_SAMPLE_ALPHA_TO_MASK_EXT)
 OGL_CONST_i(GL_SAMPLE_ALPHA_TO_MASK_SGIS)
 OGL_CONST_i(GL_SAMPLE_ALPHA_TO_ONE)
 OGL_CONST_i(GL_SAMPLE_ALPHA_TO_ONE_ARB)
 OGL_CONST_i(GL_SAMPLE_ALPHA_TO_ONE_EXT)
 OGL_CONST_i(GL_SAMPLE_ALPHA_TO_ONE_SGIS)
 OGL_CONST_i(GL_SAMPLE_BUFFERS)
 OGL_CONST_i(GL_SAMPLE_BUFFERS_3DFX)
 OGL_CONST_i(GL_SAMPLE_BUFFERS_ARB)
 OGL_CONST_i(GL_SAMPLE_BUFFERS_EXT)
 OGL_CONST_i(GL_SAMPLE_BUFFERS_SGIS)
 OGL_CONST_i(GL_SAMPLE_COUNT_BITS_NV)
 OGL_CONST_i(GL_SAMPLE_COUNT_NV)
 OGL_CONST_i(GL_SAMPLE_COVERAGE)
 OGL_CONST_i(GL_SAMPLE_COVERAGE_ARB)
 OGL_CONST_i(GL_SAMPLE_COVERAGE_INVERT)
 OGL_CONST_i(GL_SAMPLE_COVERAGE_INVERT_ARB)
 OGL_CONST_i(GL_SAMPLE_COVERAGE_VALUE)
 OGL_CONST_i(GL_SAMPLE_COVERAGE_VALUE_ARB)
 OGL_CONST_i(GL_SAMPLE_LOCATION_ARB)
 OGL_CONST_i(GL_SAMPLE_LOCATION_NV)
 OGL_CONST_i(GL_SAMPLE_LOCATION_PIXEL_GRID_HEIGHT_ARB)
 OGL_CONST_i(GL_SAMPLE_LOCATION_PIXEL_GRID_HEIGHT_NV)
 OGL_CONST_i(GL_SAMPLE_LOCATION_PIXEL_GRID_WIDTH_ARB)
 OGL_CONST_i(GL_SAMPLE_LOCATION_PIXEL_GRID_WIDTH_NV)
 OGL_CONST_i(GL_SAMPLE_LOCATION_SUBPIXEL_BITS_ARB)
 OGL_CONST_i(GL_SAMPLE_LOCATION_SUBPIXEL_BITS_NV)
 OGL_CONST_i(GL_SAMPLE_MASK)
 OGL_CONST_i(GL_SAMPLE_MASK_EXT)
 OGL_CONST_i(GL_SAMPLE_MASK_INVERT_EXT)
 OGL_CONST_i(GL_SAMPLE_MASK_INVERT_SGIS)
 OGL_CONST_i(GL_SAMPLE_MASK_NV)
 OGL_CONST_i(GL_SAMPLE_MASK_SGIS)
 OGL_CONST_i(GL_SAMPLE_MASK_VALUE)
 OGL_CONST_i(GL_SAMPLE_MASK_VALUE_EXT)
 OGL_CONST_i(GL_SAMPLE_MASK_VALUE_NV)
 OGL_CONST_i(GL_SAMPLE_MASK_VALUE_SGIS)
 OGL_CONST_i(GL_SAMPLE_PATTERN_EXT)
 OGL_CONST_i(GL_SAMPLE_PATTERN_SGIS)
 OGL_CONST_i(GL_SAMPLE_POSITION)
 OGL_CONST_i(GL_SAMPLE_POSITION_NV)
 OGL_CONST_i(GL_SAMPLE_SHADING)
 OGL_CONST_i(GL_SAMPLE_SHADING_ARB)
 OGL_CONST_i(GL_SAMPLE_SHADING_OES)
 OGL_CONST_i(GL_SATURATE_BIT_ATI)
 OGL_CONST_i(GL_SCALAR_EXT)
 OGL_CONST_i(GL_SCALEBIAS_HINT_SGIX)
 OGL_CONST_i(GL_SCALED_RESOLVE_FASTEST_EXT)
 OGL_CONST_i(GL_SCALED_RESOLVE_NICEST_EXT)
 OGL_CONST_i(GL_SCALE_BY_FOUR_NV)
 OGL_CONST_i(GL_SCALE_BY_ONE_HALF_NV)
 OGL_CONST_i(GL_SCALE_BY_TWO_NV)
 OGL_CONST_i(GL_SCISSOR_BIT)
 OGL_CONST_i(GL_SCISSOR_BOX)
 OGL_CONST_i(GL_SCISSOR_BOX_EXCLUSIVE_NV)
 OGL_CONST_i(GL_SCISSOR_COMMAND_NV)
 OGL_CONST_i(GL_SCISSOR_TEST)
 OGL_CONST_i(GL_SCISSOR_TEST_EXCLUSIVE_NV)
 OGL_CONST_i(GL_SCREEN_COORDINATES_REND)
 OGL_CONST_i(GL_SCREEN_KHR)
 OGL_CONST_i(GL_SCREEN_NV)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_ADDRESS_NV)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_EXT)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_LENGTH_NV)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_LIST_IBM)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_LIST_STRIDE_IBM)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_POINTER)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_SIZE)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_SIZE_EXT)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_STRIDE)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_TYPE)
 OGL_CONST_i(GL_SECONDARY_COLOR_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_SECONDARY_COLOR_ATIX)
 OGL_CONST_i(GL_SECONDARY_COLOR_NV)
 OGL_CONST_i(GL_SECONDARY_INTERPOLATOR_ATI)
 OGL_CONST_i(GL_SELECT)
 OGL_CONST_i(GL_SELECTED_TEXTURE_COORD_SET_SGIS)
 OGL_CONST_i(GL_SELECTED_TEXTURE_SGIS)
 OGL_CONST_i(GL_SELECTED_TEXTURE_TRANSFORM_SGIS)
 OGL_CONST_i(GL_SELECTION_BUFFER_POINTER)
 OGL_CONST_i(GL_SELECTION_BUFFER_SIZE)
 OGL_CONST_i(GL_SEMAPHORE_TYPE_BINARY_NV)
 OGL_CONST_i(GL_SEMAPHORE_TYPE_NV)
 OGL_CONST_i(GL_SEMAPHORE_TYPE_TIMELINE_NV)
 OGL_CONST_i(GL_SEPARABLE_2D)
 OGL_CONST_i(GL_SEPARABLE_2D_EXT)
 OGL_CONST_i(GL_SEPARATE_ATTRIBS)
 OGL_CONST_i(GL_SEPARATE_ATTRIBS_EXT)
 OGL_CONST_i(GL_SEPARATE_ATTRIBS_NV)
 OGL_CONST_i(GL_SEPARATE_SPECULAR_COLOR)
 OGL_CONST_i(GL_SEPARATE_SPECULAR_COLOR_EXT)
 OGL_CONST_i(GL_SET)
 OGL_CONST_i(GL_SET_AMD)
 OGL_CONST_i(GL_SGX_BINARY_IMG)
 OGL_CONST_i(GL_SGX_PROGRAM_BINARY_IMG)
 OGL_CONST_i(GL_SHADER)
 OGL_CONST_i(GL_SHADER_BINARY_DMP)
 OGL_CONST_i(GL_SHADER_BINARY_FORMATS)
 OGL_CONST_i(GL_SHADER_BINARY_FORMAT_SPIR_V)
 OGL_CONST_i(GL_SHADER_BINARY_FORMAT_SPIR_V_ARB)
 OGL_CONST_i(GL_SHADER_BINARY_VIV)
 OGL_CONST_i(GL_SHADER_COMPILER)
 OGL_CONST_i(GL_SHADER_CONSISTENT_NV)
 OGL_CONST_i(GL_SHADER_CORE_ACTIVE_COUNT_ARM)
 OGL_CONST_i(GL_SHADER_CORE_COUNT_ARM)
 OGL_CONST_i(GL_SHADER_CORE_FMA_RATE_ARM)
 OGL_CONST_i(GL_SHADER_CORE_MAX_WARP_COUNT_ARM)
 OGL_CONST_i(GL_SHADER_CORE_PIXEL_RATE_ARM)
 OGL_CONST_i(GL_SHADER_CORE_PRESENT_MASK_ARM)
 OGL_CONST_i(GL_SHADER_CORE_TEXEL_RATE_ARM)
 OGL_CONST_i(GL_SHADER_IMAGE_ACCESS_BARRIER_BIT)
 OGL_CONST_i(GL_SHADER_IMAGE_ACCESS_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_SHADER_IMAGE_ATOMIC)
 OGL_CONST_i(GL_SHADER_IMAGE_LOAD)
 OGL_CONST_i(GL_SHADER_IMAGE_STORE)
 OGL_CONST_i(GL_SHADER_INCLUDE_ARB)
 OGL_CONST_i(GL_SHADER_OBJECT_ARB)
 OGL_CONST_i(GL_SHADER_OBJECT_EXT)
 OGL_CONST_i(GL_SHADER_OPERATION_NV)
 OGL_CONST_i(GL_SHADER_PIXEL_LOCAL_STORAGE_EXT)
 OGL_CONST_i(GL_SHADER_SOURCE_LENGTH)
 OGL_CONST_i(GL_SHADER_STORAGE_BARRIER_BIT)
 OGL_CONST_i(GL_SHADER_STORAGE_BLOCK)
 OGL_CONST_i(GL_SHADER_STORAGE_BUFFER)
 OGL_CONST_i(GL_SHADER_STORAGE_BUFFER_BINDING)
 OGL_CONST_i(GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT)
 OGL_CONST_i(GL_SHADER_STORAGE_BUFFER_SIZE)
 OGL_CONST_i(GL_SHADER_STORAGE_BUFFER_START)
 OGL_CONST_i(GL_SHADER_TYPE)
 OGL_CONST_i(GL_SHADE_MODEL)
 OGL_CONST_i(GL_SHADING_LANGUAGE_VERSION)
 OGL_CONST_i(GL_SHADING_LANGUAGE_VERSION_ARB)
 OGL_CONST_i(GL_SHADING_RATE_16_INVOCATIONS_PER_PIXEL_NV)
 OGL_CONST_i(GL_SHADING_RATE_1X1_PIXELS_EXT)
 OGL_CONST_i(GL_SHADING_RATE_1X1_PIXELS_QCOM)
 OGL_CONST_i(GL_SHADING_RATE_1X2_PIXELS_EXT)
 OGL_CONST_i(GL_SHADING_RATE_1X2_PIXELS_QCOM)
 OGL_CONST_i(GL_SHADING_RATE_1X4_PIXELS_EXT)
 OGL_CONST_i(GL_SHADING_RATE_1_INVOCATION_PER_1X2_PIXELS_NV)
 OGL_CONST_i(GL_SHADING_RATE_1_INVOCATION_PER_2X1_PIXELS_NV)
 OGL_CONST_i(GL_SHADING_RATE_1_INVOCATION_PER_2X2_PIXELS_NV)
 OGL_CONST_i(GL_SHADING_RATE_1_INVOCATION_PER_2X4_PIXELS_NV)
 OGL_CONST_i(GL_SHADING_RATE_1_INVOCATION_PER_4X2_PIXELS_NV)
 OGL_CONST_i(GL_SHADING_RATE_1_INVOCATION_PER_4X4_PIXELS_NV)
 OGL_CONST_i(GL_SHADING_RATE_1_INVOCATION_PER_PIXEL_NV)
 OGL_CONST_i(GL_SHADING_RATE_2X1_PIXELS_EXT)
 OGL_CONST_i(GL_SHADING_RATE_2X1_PIXELS_QCOM)
 OGL_CONST_i(GL_SHADING_RATE_2X2_PIXELS_EXT)
 OGL_CONST_i(GL_SHADING_RATE_2X2_PIXELS_QCOM)
 OGL_CONST_i(GL_SHADING_RATE_2X4_PIXELS_EXT)
 OGL_CONST_i(GL_SHADING_RATE_2_INVOCATIONS_PER_PIXEL_NV)
 OGL_CONST_i(GL_SHADING_RATE_4X1_PIXELS_EXT)
 OGL_CONST_i(GL_SHADING_RATE_4X2_PIXELS_EXT)
 OGL_CONST_i(GL_SHADING_RATE_4X2_PIXELS_QCOM)
 OGL_CONST_i(GL_SHADING_RATE_4X4_PIXELS_EXT)
 OGL_CONST_i(GL_SHADING_RATE_4X4_PIXELS_QCOM)
 OGL_CONST_i(GL_SHADING_RATE_4_INVOCATIONS_PER_PIXEL_NV)
 OGL_CONST_i(GL_SHADING_RATE_8_INVOCATIONS_PER_PIXEL_NV)
 OGL_CONST_i(GL_SHADING_RATE_ATTACHMENT_EXT)
 OGL_CONST_i(GL_SHADING_RATE_EXT)
 OGL_CONST_i(GL_SHADING_RATE_IMAGE_BINDING_NV)
 OGL_CONST_i(GL_SHADING_RATE_IMAGE_NV)
 OGL_CONST_i(GL_SHADING_RATE_IMAGE_PALETTE_COUNT_NV)
 OGL_CONST_i(GL_SHADING_RATE_IMAGE_PALETTE_SIZE_NV)
 OGL_CONST_i(GL_SHADING_RATE_IMAGE_PER_PRIMITIVE_NV)
 OGL_CONST_i(GL_SHADING_RATE_IMAGE_TEXEL_HEIGHT_NV)
 OGL_CONST_i(GL_SHADING_RATE_IMAGE_TEXEL_WIDTH_NV)
 OGL_CONST_i(GL_SHADING_RATE_NO_INVOCATIONS_NV)
 OGL_CONST_i(GL_SHADING_RATE_PRESERVE_ASPECT_RATIO_QCOM)
 OGL_CONST_i(GL_SHADING_RATE_QCOM)
 OGL_CONST_i(GL_SHADING_RATE_SAMPLE_ORDER_DEFAULT_NV)
 OGL_CONST_i(GL_SHADING_RATE_SAMPLE_ORDER_PIXEL_MAJOR_NV)
 OGL_CONST_i(GL_SHADING_RATE_SAMPLE_ORDER_SAMPLE_MAJOR_NV)
 OGL_CONST_i(GL_SHADOW_AMBIENT_SGIX)
 OGL_CONST_i(GL_SHADOW_ATTENUATION_EXT)
 OGL_CONST_i(GL_SHARED_EDGE_NV)
 OGL_CONST_i(GL_SHARED_TEXTURE_PALETTE_EXT)
 OGL_CONST_i(GL_SHININESS)
 OGL_CONST_i(GL_SHORT)
 OGL_CONST_i(GL_SIGNALED)
 OGL_CONST_i(GL_SIGNALED_APPLE)
 OGL_CONST_i(GL_SIGNED_ALPHA8_NV)
 OGL_CONST_i(GL_SIGNED_ALPHA_NV)
 OGL_CONST_i(GL_SIGNED_HILO16_NV)
 OGL_CONST_i(GL_SIGNED_HILO8_NV)
 OGL_CONST_i(GL_SIGNED_HILO_NV)
 OGL_CONST_i(GL_SIGNED_IDENTITY_NV)
 OGL_CONST_i(GL_SIGNED_INTENSITY8_NV)
 OGL_CONST_i(GL_SIGNED_INTENSITY_NV)
 OGL_CONST_i(GL_SIGNED_LUMINANCE8_ALPHA8_NV)
 OGL_CONST_i(GL_SIGNED_LUMINANCE8_NV)
 OGL_CONST_i(GL_SIGNED_LUMINANCE_ALPHA_NV)
 OGL_CONST_i(GL_SIGNED_LUMINANCE_NV)
 OGL_CONST_i(GL_SIGNED_NEGATE_NV)
 OGL_CONST_i(GL_SIGNED_NORMALIZED)
 OGL_CONST_i(GL_SIGNED_RGB8_NV)
 OGL_CONST_i(GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV)
 OGL_CONST_i(GL_SIGNED_RGBA8_NV)
 OGL_CONST_i(GL_SIGNED_RGBA_NV)
 OGL_CONST_i(GL_SIGNED_RGB_NV)
 OGL_CONST_i(GL_SIGNED_RGB_UNSIGNED_ALPHA_NV)
 OGL_CONST_i(GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_TEST)
 OGL_CONST_i(GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_WRITE)
 OGL_CONST_i(GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_TEST)
 OGL_CONST_i(GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_WRITE)
 OGL_CONST_i(GL_SINGLE_COLOR)
 OGL_CONST_i(GL_SINGLE_COLOR_EXT)
 OGL_CONST_i(GL_SKIP_DECODE_EXT)
 OGL_CONST_i(GL_SKIP_MISSING_GLYPH_NV)
 OGL_CONST_i(GL_SLICE_ACCUM_SUN)
 OGL_CONST_i(GL_SLIM10U_SGIX)
 OGL_CONST_i(GL_SLIM12S_SGIX)
 OGL_CONST_i(GL_SLIM8U_SGIX)
 OGL_CONST_i(GL_SLUMINANCE)
 OGL_CONST_i(GL_SLUMINANCE8)
 OGL_CONST_i(GL_SLUMINANCE8_ALPHA8)
 OGL_CONST_i(GL_SLUMINANCE8_ALPHA8_EXT)
 OGL_CONST_i(GL_SLUMINANCE8_ALPHA8_NV)
 OGL_CONST_i(GL_SLUMINANCE8_EXT)
 OGL_CONST_i(GL_SLUMINANCE8_NV)
 OGL_CONST_i(GL_SLUMINANCE_ALPHA)
 OGL_CONST_i(GL_SLUMINANCE_ALPHA_EXT)
 OGL_CONST_i(GL_SLUMINANCE_ALPHA_NV)
 OGL_CONST_i(GL_SLUMINANCE_EXT)
 OGL_CONST_i(GL_SLUMINANCE_NV)
 OGL_CONST_i(GL_SMALL_CCW_ARC_TO_NV)
 OGL_CONST_i(GL_SMALL_CW_ARC_TO_NV)
 OGL_CONST_i(GL_SMAPHS30_PROGRAM_BINARY_DMP)
 OGL_CONST_i(GL_SMAPHS_PROGRAM_BINARY_DMP)
 OGL_CONST_i(GL_SMOOTH)
 OGL_CONST_i(GL_SMOOTH_CUBIC_CURVE_TO_NV)
 OGL_CONST_i(GL_SMOOTH_LINE_WIDTH_GRANULARITY)
 OGL_CONST_i(GL_SMOOTH_LINE_WIDTH_RANGE)
 OGL_CONST_i(GL_SMOOTH_POINT_SIZE_GRANULARITY)
 OGL_CONST_i(GL_SMOOTH_POINT_SIZE_RANGE)
 OGL_CONST_i(GL_SMOOTH_QUADRATIC_CURVE_TO_NV)
 OGL_CONST_i(GL_SM_COUNT_NV)
 OGL_CONST_i(GL_SOFTLIGHT_KHR)
 OGL_CONST_i(GL_SOFTLIGHT_NV)
 OGL_CONST_i(GL_SOURCE0_ALPHA)
 OGL_CONST_i(GL_SOURCE0_ALPHA_ARB)
 OGL_CONST_i(GL_SOURCE0_ALPHA_EXT)
 OGL_CONST_i(GL_SOURCE0_RGB)
 OGL_CONST_i(GL_SOURCE0_RGB_ARB)
 OGL_CONST_i(GL_SOURCE0_RGB_EXT)
 OGL_CONST_i(GL_SOURCE1_ALPHA)
 OGL_CONST_i(GL_SOURCE1_ALPHA_ARB)
 OGL_CONST_i(GL_SOURCE1_ALPHA_EXT)
 OGL_CONST_i(GL_SOURCE1_RGB)
 OGL_CONST_i(GL_SOURCE1_RGB_ARB)
 OGL_CONST_i(GL_SOURCE1_RGB_EXT)
 OGL_CONST_i(GL_SOURCE2_ALPHA)
 OGL_CONST_i(GL_SOURCE2_ALPHA_ARB)
 OGL_CONST_i(GL_SOURCE2_ALPHA_EXT)
 OGL_CONST_i(GL_SOURCE2_RGB)
 OGL_CONST_i(GL_SOURCE2_RGB_ARB)
 OGL_CONST_i(GL_SOURCE2_RGB_EXT)
 OGL_CONST_i(GL_SOURCE3_ALPHA_NV)
 OGL_CONST_i(GL_SOURCE3_RGB_NV)
 OGL_CONST_i(GL_SPARE0_NV)
 OGL_CONST_i(GL_SPARE0_PLUS_SECONDARY_COLOR_NV)
 OGL_CONST_i(GL_SPARE1_NV)
 OGL_CONST_i(GL_SPARSE_BUFFER_PAGE_SIZE_ARB)
 OGL_CONST_i(GL_SPARSE_STORAGE_BIT_ARB)
 OGL_CONST_i(GL_SPARSE_TEXTURE_FULL_ARRAY_CUBE_MIPMAPS_ARB)
 OGL_CONST_i(GL_SPARSE_TEXTURE_FULL_ARRAY_CUBE_MIPMAPS_EXT)
 OGL_CONST_i(GL_SPECULAR)
 OGL_CONST_i(GL_SPHERE_MAP)
 OGL_CONST_i(GL_SPIR_V_BINARY)
 OGL_CONST_i(GL_SPIR_V_BINARY_ARB)
 OGL_CONST_i(GL_SPIR_V_EXTENSIONS)
 OGL_CONST_i(GL_SPOT_CUTOFF)
 OGL_CONST_i(GL_SPOT_CUTOFF_DELTA_SGIX)
 OGL_CONST_i(GL_SPOT_DIRECTION)
 OGL_CONST_i(GL_SPOT_EXPONENT)
 OGL_CONST_i(GL_SQUARE_NV)
 OGL_CONST_i(GL_SR8_EXT)
 OGL_CONST_i(GL_SRC0_ALPHA)
 OGL_CONST_i(GL_SRC0_RGB)
 OGL_CONST_i(GL_SRC1_ALPHA)
 OGL_CONST_i(GL_SRC1_ALPHA_EXT)
 OGL_CONST_i(GL_SRC1_COLOR)
 OGL_CONST_i(GL_SRC1_COLOR_EXT)
 OGL_CONST_i(GL_SRC1_RGB)
 OGL_CONST_i(GL_SRC2_ALPHA)
 OGL_CONST_i(GL_SRC2_RGB)
 OGL_CONST_i(GL_SRC_ALPHA)
 OGL_CONST_i(GL_SRC_ALPHA_SATURATE)
 OGL_CONST_i(GL_SRC_ALPHA_SATURATE_EXT)
 OGL_CONST_i(GL_SRC_ATOP_NV)
 OGL_CONST_i(GL_SRC_COLOR)
 OGL_CONST_i(GL_SRC_IN_NV)
 OGL_CONST_i(GL_SRC_NV)
 OGL_CONST_i(GL_SRC_OUT_NV)
 OGL_CONST_i(GL_SRC_OVER_NV)
 OGL_CONST_i(GL_SRG8_EXT)
 OGL_CONST_i(GL_SRGB)
 OGL_CONST_i(GL_SRGB8)
 OGL_CONST_i(GL_SRGB8_ALPHA8)
 OGL_CONST_i(GL_SRGB8_ALPHA8_EXT)
 OGL_CONST_i(GL_SRGB8_EXT)
 OGL_CONST_i(GL_SRGB8_NV)
 OGL_CONST_i(GL_SRGB_ALPHA)
 OGL_CONST_i(GL_SRGB_ALPHA_EXT)
 OGL_CONST_i(GL_SRGB_DECODE_ARB)
 OGL_CONST_i(GL_SRGB_EXT)
 OGL_CONST_i(GL_SRGB_READ)
 OGL_CONST_i(GL_SRGB_WRITE)
 OGL_CONST_i(GL_STACK_OVERFLOW)
 OGL_CONST_i(GL_STACK_UNDERFLOW)
 OGL_CONST_i(GL_STANDARD_FONT_FORMAT_NV)
 OGL_CONST_i(GL_STANDARD_FONT_NAME_NV)
 OGL_CONST_i(GL_STATE_RESTORE)
 OGL_CONST_i(GL_STATIC_ATI)
 OGL_CONST_i(GL_STATIC_COPY)
 OGL_CONST_i(GL_STATIC_COPY_ARB)
 OGL_CONST_i(GL_STATIC_DRAW)
 OGL_CONST_i(GL_STATIC_DRAW_ARB)
 OGL_CONST_i(GL_STATIC_READ)
 OGL_CONST_i(GL_STATIC_READ_ARB)
 OGL_CONST_i(GL_STATIC_VERTEX_ARRAY_IBM)
 OGL_CONST_i(GL_STATISTICS_REGAL)
 OGL_CONST_i(GL_STENCIL)
 OGL_CONST_i(GL_STENCIL_ATTACHMENT)
 OGL_CONST_i(GL_STENCIL_ATTACHMENT_EXT)
 OGL_CONST_i(GL_STENCIL_ATTACHMENT_OES)
 OGL_CONST_i(GL_STENCIL_BACK_FAIL)
 OGL_CONST_i(GL_STENCIL_BACK_FAIL_ATI)
 OGL_CONST_i(GL_STENCIL_BACK_FUNC)
 OGL_CONST_i(GL_STENCIL_BACK_FUNC_ATI)
 OGL_CONST_i(GL_STENCIL_BACK_OP_VALUE_AMD)
 OGL_CONST_i(GL_STENCIL_BACK_PASS_DEPTH_FAIL)
 OGL_CONST_i(GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI)
 OGL_CONST_i(GL_STENCIL_BACK_PASS_DEPTH_PASS)
 OGL_CONST_i(GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI)
 OGL_CONST_i(GL_STENCIL_BACK_REF)
 OGL_CONST_i(GL_STENCIL_BACK_VALUE_MASK)
 OGL_CONST_i(GL_STENCIL_BACK_WRITEMASK)
 OGL_CONST_i(GL_STENCIL_BITS)
 OGL_CONST_i(GL_STENCIL_BUFFER)
 OGL_CONST_i(GL_STENCIL_BUFFER_BIT)
 OGL_CONST_i(GL_STENCIL_BUFFER_BIT0_QCOM)
 OGL_CONST_i(GL_STENCIL_BUFFER_BIT1_QCOM)
 OGL_CONST_i(GL_STENCIL_BUFFER_BIT2_QCOM)
 OGL_CONST_i(GL_STENCIL_BUFFER_BIT3_QCOM)
 OGL_CONST_i(GL_STENCIL_BUFFER_BIT4_QCOM)
 OGL_CONST_i(GL_STENCIL_BUFFER_BIT5_QCOM)
 OGL_CONST_i(GL_STENCIL_BUFFER_BIT6_QCOM)
 OGL_CONST_i(GL_STENCIL_BUFFER_BIT7_QCOM)
 OGL_CONST_i(GL_STENCIL_CLEAR_TAG_VALUE_EXT)
 OGL_CONST_i(GL_STENCIL_CLEAR_VALUE)
 OGL_CONST_i(GL_STENCIL_COMPONENTS)
 OGL_CONST_i(GL_STENCIL_EXT)
 OGL_CONST_i(GL_STENCIL_FAIL)
 OGL_CONST_i(GL_STENCIL_FUNC)
 OGL_CONST_i(GL_STENCIL_INDEX)
 OGL_CONST_i(GL_STENCIL_INDEX1)
 OGL_CONST_i(GL_STENCIL_INDEX16)
 OGL_CONST_i(GL_STENCIL_INDEX16_EXT)
 OGL_CONST_i(GL_STENCIL_INDEX1_EXT)
 OGL_CONST_i(GL_STENCIL_INDEX1_OES)
 OGL_CONST_i(GL_STENCIL_INDEX4)
 OGL_CONST_i(GL_STENCIL_INDEX4_EXT)
 OGL_CONST_i(GL_STENCIL_INDEX4_OES)
 OGL_CONST_i(GL_STENCIL_INDEX8)
 OGL_CONST_i(GL_STENCIL_INDEX8_EXT)
 OGL_CONST_i(GL_STENCIL_INDEX8_OES)
 OGL_CONST_i(GL_STENCIL_OP_VALUE_AMD)
 OGL_CONST_i(GL_STENCIL_PASS_DEPTH_FAIL)
 OGL_CONST_i(GL_STENCIL_PASS_DEPTH_PASS)
 OGL_CONST_i(GL_STENCIL_REF)
 OGL_CONST_i(GL_STENCIL_REF_COMMAND_NV)
 OGL_CONST_i(GL_STENCIL_RENDERABLE)
 OGL_CONST_i(GL_STENCIL_SAMPLES_NV)
 OGL_CONST_i(GL_STENCIL_TAG_BITS_EXT)
 OGL_CONST_i(GL_STENCIL_TEST)
 OGL_CONST_i(GL_STENCIL_TEST_TWO_SIDE_EXT)
 OGL_CONST_i(GL_STENCIL_VALUE_MASK)
 OGL_CONST_i(GL_STENCIL_WRITEMASK)
 OGL_CONST_i(GL_STEREO)
 OGL_CONST_i(GL_STEREO_CONVERGENCE_NV)
 OGL_CONST_i(GL_STEREO_CUTOFF_NV)
 OGL_CONST_i(GL_STEREO_PROJECTION_NV)
 OGL_CONST_i(GL_STEREO_PROJECTION_ORTHO_NV)
 OGL_CONST_i(GL_STEREO_PROJECTION_PERSPECTIVE_NV)
 OGL_CONST_i(GL_STEREO_SEPARATION_NV)
 OGL_CONST_i(GL_STORAGE_CACHED_APPLE)
 OGL_CONST_i(GL_STORAGE_CLIENT_APPLE)
 OGL_CONST_i(GL_STORAGE_PRIVATE_APPLE)
 OGL_CONST_i(GL_STORAGE_SHARED_APPLE)
 OGL_CONST_i(GL_STREAM_COPY)
 OGL_CONST_i(GL_STREAM_COPY_ARB)
 OGL_CONST_i(GL_STREAM_DRAW)
 OGL_CONST_i(GL_STREAM_DRAW_ARB)
 OGL_CONST_i(GL_STREAM_RASTERIZATION_AMD)
 OGL_CONST_i(GL_STREAM_READ)
 OGL_CONST_i(GL_STREAM_READ_ARB)
 OGL_CONST_i(GL_STRICT_DEPTHFUNC_HINT_PGI)
 OGL_CONST_i(GL_STRICT_LIGHTING_HINT_PGI)
 OGL_CONST_i(GL_STRICT_SCISSOR_HINT_PGI)
 OGL_CONST_i(GL_SUBGROUP_FEATURE_ARITHMETIC_BIT_KHR)
 OGL_CONST_i(GL_SUBGROUP_FEATURE_BALLOT_BIT_KHR)
 OGL_CONST_i(GL_SUBGROUP_FEATURE_BASIC_BIT_KHR)
 OGL_CONST_i(GL_SUBGROUP_FEATURE_CLUSTERED_BIT_KHR)
 OGL_CONST_i(GL_SUBGROUP_FEATURE_PARTITIONED_BIT_NV)
 OGL_CONST_i(GL_SUBGROUP_FEATURE_QUAD_BIT_KHR)
 OGL_CONST_i(GL_SUBGROUP_FEATURE_SHUFFLE_BIT_KHR)
 OGL_CONST_i(GL_SUBGROUP_FEATURE_SHUFFLE_RELATIVE_BIT_KHR)
 OGL_CONST_i(GL_SUBGROUP_FEATURE_VOTE_BIT_KHR)
 OGL_CONST_i(GL_SUBGROUP_QUAD_ALL_STAGES_KHR)
 OGL_CONST_i(GL_SUBGROUP_SIZE_KHR)
 OGL_CONST_i(GL_SUBGROUP_SUPPORTED_FEATURES_KHR)
 OGL_CONST_i(GL_SUBGROUP_SUPPORTED_STAGES_KHR)
 OGL_CONST_i(GL_SUBPIXEL_BITS)
 OGL_CONST_i(GL_SUBPIXEL_PRECISION_BIAS_X_BITS_NV)
 OGL_CONST_i(GL_SUBPIXEL_PRECISION_BIAS_Y_BITS_NV)
 OGL_CONST_i(GL_SUBSAMPLE_DISTANCE_AMD)
 OGL_CONST_i(GL_SUBTRACT)
 OGL_CONST_i(GL_SUBTRACT_ARB)
 OGL_CONST_i(GL_SUB_ATI)
 OGL_CONST_i(GL_SUCCESS_NV)
 OGL_CONST_i(GL_SUPERSAMPLE_SCALE_X_NV)
 OGL_CONST_i(GL_SUPERSAMPLE_SCALE_Y_NV)
 OGL_CONST_i(GL_SUPPORTED_MULTISAMPLE_MODES_AMD)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_10BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_11BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_12BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_1BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_2BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_3BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_4BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_5BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_6BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_7BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_8BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_9BPC_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_DEFAULT_EXT)
 OGL_CONST_i(GL_SURFACE_COMPRESSION_FIXED_RATE_NONE_EXT)
 OGL_CONST_i(GL_SURFACE_MAPPED_NV)
 OGL_CONST_i(GL_SURFACE_REGISTERED_NV)
 OGL_CONST_i(GL_SURFACE_STATE_NV)
 OGL_CONST_i(GL_SWIZZLE_STQ_ATI)
 OGL_CONST_i(GL_SWIZZLE_STQ_DQ_ATI)
 OGL_CONST_i(GL_SWIZZLE_STRQ_ATI)
 OGL_CONST_i(GL_SWIZZLE_STRQ_DQ_ATI)
 OGL_CONST_i(GL_SWIZZLE_STR_ATI)
 OGL_CONST_i(GL_SWIZZLE_STR_DR_ATI)
 OGL_CONST_i(GL_SYNC_CL_EVENT_ARB)
 OGL_CONST_i(GL_SYNC_CL_EVENT_COMPLETE_ARB)
 OGL_CONST_i(GL_SYNC_CONDITION)
 OGL_CONST_i(GL_SYNC_CONDITION_APPLE)
 OGL_CONST_i(GL_SYNC_FENCE)
 OGL_CONST_i(GL_SYNC_FENCE_APPLE)
 OGL_CONST_i(GL_SYNC_FLAGS)
 OGL_CONST_i(GL_SYNC_FLAGS_APPLE)
 OGL_CONST_i(GL_SYNC_FLUSH_COMMANDS_BIT)
 OGL_CONST_i(GL_SYNC_FLUSH_COMMANDS_BIT_APPLE)
 OGL_CONST_i(GL_SYNC_GPU_COMMANDS_COMPLETE)
 OGL_CONST_i(GL_SYNC_GPU_COMMANDS_COMPLETE_APPLE)
 OGL_CONST_i(GL_SYNC_OBJECT_APPLE)
 OGL_CONST_i(GL_SYNC_STATUS)
 OGL_CONST_i(GL_SYNC_STATUS_APPLE)
 OGL_CONST_i(GL_SYNC_X11_FENCE_EXT)
 OGL_CONST_i(GL_SYSTEM_FONT_NAME_NV)
 OGL_CONST_i(GL_T)
 OGL_CONST_i(GL_T2F_C3F_V3F)
 OGL_CONST_i(GL_T2F_C4F_N3F_V3F)
 OGL_CONST_i(GL_T2F_C4UB_V3F)
 OGL_CONST_i(GL_T2F_N3F_V3F)
 OGL_CONST_i(GL_T2F_V3F)
 OGL_CONST_i(GL_T4F_C4F_N3F_V4F)
 OGL_CONST_i(GL_T4F_V4F)
 OGL_CONST_i(GL_TABLE_TOO_LARGE)
 OGL_CONST_i(GL_TANGENT_ARRAY_EXT)
 OGL_CONST_i(GL_TANGENT_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_TANGENT_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_TANGENT_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_TANGENT_SPACE_SGIX)
 OGL_CONST_i(GL_TASK_SHADER_BIT_EXT)
 OGL_CONST_i(GL_TASK_SHADER_BIT_NV)
 OGL_CONST_i(GL_TASK_SHADER_EXT)
 OGL_CONST_i(GL_TASK_SHADER_INVOCATIONS_EXT)
 OGL_CONST_i(GL_TASK_SHADER_NV)
 OGL_CONST_i(GL_TASK_SUBROUTINE_EXT)
 OGL_CONST_i(GL_TASK_SUBROUTINE_NV)
 OGL_CONST_i(GL_TASK_SUBROUTINE_UNIFORM_EXT)
 OGL_CONST_i(GL_TASK_SUBROUTINE_UNIFORM_NV)
 OGL_CONST_i(GL_TASK_WORK_GROUP_SIZE_EXT)
 OGL_CONST_i(GL_TASK_WORK_GROUP_SIZE_NV)
 OGL_CONST_i(GL_TERMINATE_SEQUENCE_COMMAND_NV)
 OGL_CONST_i(GL_TESSELLATION_FACTOR_AMD)
 OGL_CONST_i(GL_TESSELLATION_MODE_AMD)
 OGL_CONST_i(GL_TESS_CONTROL_OUTPUT_VERTICES)
 OGL_CONST_i(GL_TESS_CONTROL_OUTPUT_VERTICES_EXT)
 OGL_CONST_i(GL_TESS_CONTROL_OUTPUT_VERTICES_OES)
 OGL_CONST_i(GL_TESS_CONTROL_PROGRAM_NV)
 OGL_CONST_i(GL_TESS_CONTROL_PROGRAM_PARAMETER_BUFFER_NV)
 OGL_CONST_i(GL_TESS_CONTROL_SHADER)
 OGL_CONST_i(GL_TESS_CONTROL_SHADER_BIT)
 OGL_CONST_i(GL_TESS_CONTROL_SHADER_BIT_EXT)
 OGL_CONST_i(GL_TESS_CONTROL_SHADER_BIT_OES)
 OGL_CONST_i(GL_TESS_CONTROL_SHADER_EXT)
 OGL_CONST_i(GL_TESS_CONTROL_SHADER_OES)
 OGL_CONST_i(GL_TESS_CONTROL_SHADER_PATCHES)
 OGL_CONST_i(GL_TESS_CONTROL_SHADER_PATCHES_ARB)
 OGL_CONST_i(GL_TESS_CONTROL_SUBROUTINE)
 OGL_CONST_i(GL_TESS_CONTROL_SUBROUTINE_UNIFORM)
 OGL_CONST_i(GL_TESS_CONTROL_TEXTURE)
 OGL_CONST_i(GL_TESS_EVALUATION_PROGRAM_NV)
 OGL_CONST_i(GL_TESS_EVALUATION_PROGRAM_PARAMETER_BUFFER_NV)
 OGL_CONST_i(GL_TESS_EVALUATION_SHADER)
 OGL_CONST_i(GL_TESS_EVALUATION_SHADER_BIT)
 OGL_CONST_i(GL_TESS_EVALUATION_SHADER_BIT_EXT)
 OGL_CONST_i(GL_TESS_EVALUATION_SHADER_BIT_OES)
 OGL_CONST_i(GL_TESS_EVALUATION_SHADER_EXT)
 OGL_CONST_i(GL_TESS_EVALUATION_SHADER_INVOCATIONS)
 OGL_CONST_i(GL_TESS_EVALUATION_SHADER_INVOCATIONS_ARB)
 OGL_CONST_i(GL_TESS_EVALUATION_SHADER_OES)
 OGL_CONST_i(GL_TESS_EVALUATION_SUBROUTINE)
 OGL_CONST_i(GL_TESS_EVALUATION_SUBROUTINE_UNIFORM)
 OGL_CONST_i(GL_TESS_EVALUATION_TEXTURE)
 OGL_CONST_i(GL_TESS_GEN_MODE)
 OGL_CONST_i(GL_TESS_GEN_MODE_EXT)
 OGL_CONST_i(GL_TESS_GEN_MODE_OES)
 OGL_CONST_i(GL_TESS_GEN_POINT_MODE)
 OGL_CONST_i(GL_TESS_GEN_POINT_MODE_EXT)
 OGL_CONST_i(GL_TESS_GEN_POINT_MODE_OES)
 OGL_CONST_i(GL_TESS_GEN_SPACING)
 OGL_CONST_i(GL_TESS_GEN_SPACING_EXT)
 OGL_CONST_i(GL_TESS_GEN_SPACING_OES)
 OGL_CONST_i(GL_TESS_GEN_VERTEX_ORDER)
 OGL_CONST_i(GL_TESS_GEN_VERTEX_ORDER_EXT)
 OGL_CONST_i(GL_TESS_GEN_VERTEX_ORDER_OES)
 OGL_CONST_i(GL_TEXCOORD1_BIT_PGI)
 OGL_CONST_i(GL_TEXCOORD2_BIT_PGI)
 OGL_CONST_i(GL_TEXCOORD3_BIT_PGI)
 OGL_CONST_i(GL_TEXCOORD4_BIT_PGI)
 OGL_CONST_i(GL_TEXTURE)
 OGL_CONST_i(GL_TEXTURE0)
 OGL_CONST_i(GL_TEXTURE0_ARB)
 OGL_CONST_i(GL_TEXTURE0_SGIS)
 OGL_CONST_i(GL_TEXTURE1)
 OGL_CONST_i(GL_TEXTURE10)
 OGL_CONST_i(GL_TEXTURE10_ARB)
 OGL_CONST_i(GL_TEXTURE11)
 OGL_CONST_i(GL_TEXTURE11_ARB)
 OGL_CONST_i(GL_TEXTURE12)
 OGL_CONST_i(GL_TEXTURE12_ARB)
 OGL_CONST_i(GL_TEXTURE13)
 OGL_CONST_i(GL_TEXTURE13_ARB)
 OGL_CONST_i(GL_TEXTURE14)
 OGL_CONST_i(GL_TEXTURE14_ARB)
 OGL_CONST_i(GL_TEXTURE15)
 OGL_CONST_i(GL_TEXTURE15_ARB)
 OGL_CONST_i(GL_TEXTURE16)
 OGL_CONST_i(GL_TEXTURE16_ARB)
 OGL_CONST_i(GL_TEXTURE17)
 OGL_CONST_i(GL_TEXTURE17_ARB)
 OGL_CONST_i(GL_TEXTURE18)
 OGL_CONST_i(GL_TEXTURE18_ARB)
 OGL_CONST_i(GL_TEXTURE19)
 OGL_CONST_i(GL_TEXTURE19_ARB)
 OGL_CONST_i(GL_TEXTURE1_ARB)
 OGL_CONST_i(GL_TEXTURE1_SGIS)
 OGL_CONST_i(GL_TEXTURE2)
 OGL_CONST_i(GL_TEXTURE20)
 OGL_CONST_i(GL_TEXTURE20_ARB)
 OGL_CONST_i(GL_TEXTURE21)
 OGL_CONST_i(GL_TEXTURE21_ARB)
 OGL_CONST_i(GL_TEXTURE22)
 OGL_CONST_i(GL_TEXTURE22_ARB)
 OGL_CONST_i(GL_TEXTURE23)
 OGL_CONST_i(GL_TEXTURE23_ARB)
 OGL_CONST_i(GL_TEXTURE24)
 OGL_CONST_i(GL_TEXTURE24_ARB)
 OGL_CONST_i(GL_TEXTURE25)
 OGL_CONST_i(GL_TEXTURE25_ARB)
 OGL_CONST_i(GL_TEXTURE26)
 OGL_CONST_i(GL_TEXTURE26_ARB)
 OGL_CONST_i(GL_TEXTURE27)
 OGL_CONST_i(GL_TEXTURE27_ARB)
 OGL_CONST_i(GL_TEXTURE28)
 OGL_CONST_i(GL_TEXTURE28_ARB)
 OGL_CONST_i(GL_TEXTURE29)
 OGL_CONST_i(GL_TEXTURE29_ARB)
 OGL_CONST_i(GL_TEXTURE2_ARB)
 OGL_CONST_i(GL_TEXTURE2_SGIS)
 OGL_CONST_i(GL_TEXTURE3)
 OGL_CONST_i(GL_TEXTURE30)
 OGL_CONST_i(GL_TEXTURE30_ARB)
 OGL_CONST_i(GL_TEXTURE31)
 OGL_CONST_i(GL_TEXTURE31_ARB)
 OGL_CONST_i(GL_TEXTURE3_ARB)
 OGL_CONST_i(GL_TEXTURE3_SGIS)
 OGL_CONST_i(GL_TEXTURE4)
 OGL_CONST_i(GL_TEXTURE4_ARB)
 OGL_CONST_i(GL_TEXTURE5)
 OGL_CONST_i(GL_TEXTURE5_ARB)
 OGL_CONST_i(GL_TEXTURE6)
 OGL_CONST_i(GL_TEXTURE6_ARB)
 OGL_CONST_i(GL_TEXTURE7)
 OGL_CONST_i(GL_TEXTURE7_ARB)
 OGL_CONST_i(GL_TEXTURE8)
 OGL_CONST_i(GL_TEXTURE8_ARB)
 OGL_CONST_i(GL_TEXTURE9)
 OGL_CONST_i(GL_TEXTURE9_ARB)
 OGL_CONST_i(GL_TEXTURE_1D)
 OGL_CONST_i(GL_TEXTURE_1D_ARRAY)
 OGL_CONST_i(GL_TEXTURE_1D_ARRAY_EXT)
 OGL_CONST_i(GL_TEXTURE_1D_BINDING_EXT)
 OGL_CONST_i(GL_TEXTURE_1D_STACK_BINDING_MESAX)
 OGL_CONST_i(GL_TEXTURE_1D_STACK_MESAX)
 OGL_CONST_i(GL_TEXTURE_2D)
 OGL_CONST_i(GL_TEXTURE_2D_ARRAY)
 OGL_CONST_i(GL_TEXTURE_2D_ARRAY_EXT)
 OGL_CONST_i(GL_TEXTURE_2D_ARRAY_NV)
 OGL_CONST_i(GL_TEXTURE_2D_BINDING_EXT)
 OGL_CONST_i(GL_TEXTURE_2D_MULTISAMPLE)
 OGL_CONST_i(GL_TEXTURE_2D_MULTISAMPLE_ARRAY)
 OGL_CONST_i(GL_TEXTURE_2D_MULTISAMPLE_ARRAY_OES)
 OGL_CONST_i(GL_TEXTURE_2D_STACK_BINDING_MESAX)
 OGL_CONST_i(GL_TEXTURE_2D_STACK_MESAX)
 OGL_CONST_i(GL_TEXTURE_3D)
 OGL_CONST_i(GL_TEXTURE_3D_BINDING_EXT)
 OGL_CONST_i(GL_TEXTURE_3D_EXT)
 OGL_CONST_i(GL_TEXTURE_3D_OES)
 OGL_CONST_i(GL_TEXTURE_ALPHA_MODULATE_IMG)
 OGL_CONST_i(GL_TEXTURE_ALPHA_SIZE)
 OGL_CONST_i(GL_TEXTURE_ALPHA_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_ALPHA_TYPE)
 OGL_CONST_i(GL_TEXTURE_ALPHA_TYPE_ARB)
 OGL_CONST_i(GL_TEXTURE_APPLICATION_MODE_EXT)
 OGL_CONST_i(GL_TEXTURE_ASTC_DECODE_PRECISION_EXT)
 OGL_CONST_i(GL_TEXTURE_BASE_LEVEL)
 OGL_CONST_i(GL_TEXTURE_BASE_LEVEL_SGIS)
 OGL_CONST_i(GL_TEXTURE_BINDING_1D)
 OGL_CONST_i(GL_TEXTURE_BINDING_1D_ARRAY)
 OGL_CONST_i(GL_TEXTURE_BINDING_1D_ARRAY_EXT)
 OGL_CONST_i(GL_TEXTURE_BINDING_2D)
 OGL_CONST_i(GL_TEXTURE_BINDING_2D_ARRAY)
 OGL_CONST_i(GL_TEXTURE_BINDING_2D_ARRAY_EXT)
 OGL_CONST_i(GL_TEXTURE_BINDING_2D_ARRAY_NV)
 OGL_CONST_i(GL_TEXTURE_BINDING_2D_MULTISAMPLE)
 OGL_CONST_i(GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY)
 OGL_CONST_i(GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY_OES)
 OGL_CONST_i(GL_TEXTURE_BINDING_3D)
 OGL_CONST_i(GL_TEXTURE_BINDING_3D_OES)
 OGL_CONST_i(GL_TEXTURE_BINDING_BUFFER)
 OGL_CONST_i(GL_TEXTURE_BINDING_BUFFER_ARB)
 OGL_CONST_i(GL_TEXTURE_BINDING_BUFFER_EXT)
 OGL_CONST_i(GL_TEXTURE_BINDING_BUFFER_OES)
 OGL_CONST_i(GL_TEXTURE_BINDING_CUBE_MAP)
 OGL_CONST_i(GL_TEXTURE_BINDING_CUBE_MAP_ARB)
 OGL_CONST_i(GL_TEXTURE_BINDING_CUBE_MAP_ARRAY)
 OGL_CONST_i(GL_TEXTURE_BINDING_CUBE_MAP_ARRAY_ARB)
 OGL_CONST_i(GL_TEXTURE_BINDING_CUBE_MAP_ARRAY_EXT)
 OGL_CONST_i(GL_TEXTURE_BINDING_CUBE_MAP_ARRAY_OES)
 OGL_CONST_i(GL_TEXTURE_BINDING_CUBE_MAP_EXT)
 OGL_CONST_i(GL_TEXTURE_BINDING_CUBE_MAP_OES)
 OGL_CONST_i(GL_TEXTURE_BINDING_EXTERNAL_OES)
 OGL_CONST_i(GL_TEXTURE_BINDING_RECTANGLE)
 OGL_CONST_i(GL_TEXTURE_BINDING_RECTANGLE_ARB)
 OGL_CONST_i(GL_TEXTURE_BINDING_RECTANGLE_EXT)
 OGL_CONST_i(GL_TEXTURE_BINDING_RECTANGLE_NV)
 OGL_CONST_i(GL_TEXTURE_BINDING_RENDERBUFFER_NV)
 OGL_CONST_i(GL_TEXTURE_BIT)
 OGL_CONST_i(GL_TEXTURE_BLUE_SIZE)
 OGL_CONST_i(GL_TEXTURE_BLUE_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_BLUE_TYPE)
 OGL_CONST_i(GL_TEXTURE_BLUE_TYPE_ARB)
 OGL_CONST_i(GL_TEXTURE_BORDER)
 OGL_CONST_i(GL_TEXTURE_BORDER_COLOR)
 OGL_CONST_i(GL_TEXTURE_BORDER_COLOR_EXT)
 OGL_CONST_i(GL_TEXTURE_BORDER_COLOR_NV)
 OGL_CONST_i(GL_TEXTURE_BORDER_COLOR_OES)
 OGL_CONST_i(GL_TEXTURE_BORDER_VALUES_NV)
 OGL_CONST_i(GL_TEXTURE_BUFFER)
 OGL_CONST_i(GL_TEXTURE_BUFFER_ARB)
 OGL_CONST_i(GL_TEXTURE_BUFFER_BINDING)
 OGL_CONST_i(GL_TEXTURE_BUFFER_BINDING_EXT)
 OGL_CONST_i(GL_TEXTURE_BUFFER_BINDING_OES)
 OGL_CONST_i(GL_TEXTURE_BUFFER_DATA_STORE_BINDING)
 OGL_CONST_i(GL_TEXTURE_BUFFER_DATA_STORE_BINDING_ARB)
 OGL_CONST_i(GL_TEXTURE_BUFFER_DATA_STORE_BINDING_EXT)
 OGL_CONST_i(GL_TEXTURE_BUFFER_DATA_STORE_BINDING_OES)
 OGL_CONST_i(GL_TEXTURE_BUFFER_EXT)
 OGL_CONST_i(GL_TEXTURE_BUFFER_FORMAT)
 OGL_CONST_i(GL_TEXTURE_BUFFER_FORMAT_ARB)
 OGL_CONST_i(GL_TEXTURE_BUFFER_FORMAT_EXT)
 OGL_CONST_i(GL_TEXTURE_BUFFER_OES)
 OGL_CONST_i(GL_TEXTURE_BUFFER_OFFSET)
 OGL_CONST_i(GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT)
 OGL_CONST_i(GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT_EXT)
 OGL_CONST_i(GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT_OES)
 OGL_CONST_i(GL_TEXTURE_BUFFER_OFFSET_EXT)
 OGL_CONST_i(GL_TEXTURE_BUFFER_OFFSET_OES)
 OGL_CONST_i(GL_TEXTURE_BUFFER_SIZE)
 OGL_CONST_i(GL_TEXTURE_BUFFER_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_BUFFER_SIZE_OES)
 OGL_CONST_i(GL_TEXTURE_CBCR_DEGAMMA_QCOM)
 OGL_CONST_i(GL_TEXTURE_COLOR_SAMPLES_NV)
 OGL_CONST_i(GL_TEXTURE_COLOR_TABLE_SGI)
 OGL_CONST_i(GL_TEXTURE_COMPARE_FAIL_VALUE_ARB)
 OGL_CONST_i(GL_TEXTURE_COMPARE_FUNC)
 OGL_CONST_i(GL_TEXTURE_COMPARE_FUNC_ARB)
 OGL_CONST_i(GL_TEXTURE_COMPARE_FUNC_EXT)
 OGL_CONST_i(GL_TEXTURE_COMPARE_MODE)
 OGL_CONST_i(GL_TEXTURE_COMPARE_MODE_ARB)
 OGL_CONST_i(GL_TEXTURE_COMPARE_MODE_EXT)
 OGL_CONST_i(GL_TEXTURE_COMPARE_OPERATOR_SGIX)
 OGL_CONST_i(GL_TEXTURE_COMPARE_SGIX)
 OGL_CONST_i(GL_TEXTURE_COMPONENTS)
 OGL_CONST_i(GL_TEXTURE_COMPRESSED)
 OGL_CONST_i(GL_TEXTURE_COMPRESSED_ARB)
 OGL_CONST_i(GL_TEXTURE_COMPRESSED_BLOCK_HEIGHT)
 OGL_CONST_i(GL_TEXTURE_COMPRESSED_BLOCK_SIZE)
 OGL_CONST_i(GL_TEXTURE_COMPRESSED_BLOCK_WIDTH)
 OGL_CONST_i(GL_TEXTURE_COMPRESSED_IMAGE_SIZE)
 OGL_CONST_i(GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB)
 OGL_CONST_i(GL_TEXTURE_COMPRESSION_HINT)
 OGL_CONST_i(GL_TEXTURE_COMPRESSION_HINT_ARB)
 OGL_CONST_i(GL_TEXTURE_CONSTANT_DATA_SUNX)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_ADDRESS_NV)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_COUNT_EXT)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_EXT)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_LENGTH_NV)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_LIST_IBM)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_LIST_STRIDE_IBM)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_POINTER)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_SIZE)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_STRIDE)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_TYPE)
 OGL_CONST_i(GL_TEXTURE_COORD_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_TEXTURE_COORD_NV)
 OGL_CONST_i(GL_TEXTURE_COORD_SET_INTERLEAVE_FACTOR_SGIS)
 OGL_CONST_i(GL_TEXTURE_COVERAGE_SAMPLES_NV)
 OGL_CONST_i(GL_TEXTURE_CROP_RECT_OES)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_ARB)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_ARRAY)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_ARRAY_ARB)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_ARRAY_EXT)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_ARRAY_OES)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_EXT)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_X)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_X_OES)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Y)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_OES)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Z)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_OES)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_OES)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_X)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_X_OES)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_Y)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_Y_OES)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_Z)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_POSITIVE_Z_OES)
 OGL_CONST_i(GL_TEXTURE_CUBE_MAP_SEAMLESS)
 OGL_CONST_i(GL_TEXTURE_DEFORMATION_BIT_SGIX)
 OGL_CONST_i(GL_TEXTURE_DEPTH)
 OGL_CONST_i(GL_TEXTURE_DEPTH_EXT)
 OGL_CONST_i(GL_TEXTURE_DEPTH_QCOM)
 OGL_CONST_i(GL_TEXTURE_DEPTH_SIZE)
 OGL_CONST_i(GL_TEXTURE_DEPTH_SIZE_ARB)
 OGL_CONST_i(GL_TEXTURE_DEPTH_TYPE)
 OGL_CONST_i(GL_TEXTURE_DEPTH_TYPE_ARB)
 OGL_CONST_i(GL_TEXTURE_DS_SIZE_NV)
 OGL_CONST_i(GL_TEXTURE_DT_SIZE_NV)
 OGL_CONST_i(GL_TEXTURE_ENV)
 OGL_CONST_i(GL_TEXTURE_ENV_COLOR)
 OGL_CONST_i(GL_TEXTURE_ENV_COORD_SET_SGIS)
 OGL_CONST_i(GL_TEXTURE_ENV_MODE)
 OGL_CONST_i(GL_TEXTURE_EXTERNAL_OES)
 OGL_CONST_i(GL_TEXTURE_FETCH_BARRIER_BIT)
 OGL_CONST_i(GL_TEXTURE_FETCH_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_TEXTURE_FILTER_CONTROL)
 OGL_CONST_i(GL_TEXTURE_FILTER_CONTROL_EXT)
 OGL_CONST_i(GL_TEXTURE_FIXED_SAMPLE_LOCATIONS)
 OGL_CONST_i(GL_TEXTURE_FLOAT_COMPONENTS_NV)
 OGL_CONST_i(GL_TEXTURE_FORMAT_QCOM)
 OGL_CONST_i(GL_TEXTURE_FORMAT_SRGB_OVERRIDE_EXT)
 OGL_CONST_i(GL_TEXTURE_FOVEATED_CUTOFF_DENSITY_QCOM)
 OGL_CONST_i(GL_TEXTURE_FOVEATED_FEATURE_BITS_QCOM)
 OGL_CONST_i(GL_TEXTURE_FOVEATED_FEATURE_QUERY_QCOM)
 OGL_CONST_i(GL_TEXTURE_FOVEATED_MIN_PIXEL_DENSITY_QCOM)
 OGL_CONST_i(GL_TEXTURE_FOVEATED_NUM_FOCAL_POINTS_QUERY_QCOM)
 OGL_CONST_i(GL_TEXTURE_FREE_MEMORY_ATI)
 OGL_CONST_i(GL_TEXTURE_GATHER)
 OGL_CONST_i(GL_TEXTURE_GATHER_SHADOW)
 OGL_CONST_i(GL_TEXTURE_GEN_MODE)
 OGL_CONST_i(GL_TEXTURE_GEN_MODE_OES)
 OGL_CONST_i(GL_TEXTURE_GEN_Q)
 OGL_CONST_i(GL_TEXTURE_GEN_R)
 OGL_CONST_i(GL_TEXTURE_GEN_S)
 OGL_CONST_i(GL_TEXTURE_GEN_STR_OES)
 OGL_CONST_i(GL_TEXTURE_GEN_T)
 OGL_CONST_i(GL_TEXTURE_GEQUAL_R_SGIX)
 OGL_CONST_i(GL_TEXTURE_GREEN_SIZE)
 OGL_CONST_i(GL_TEXTURE_GREEN_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_GREEN_TYPE)
 OGL_CONST_i(GL_TEXTURE_GREEN_TYPE_ARB)
 OGL_CONST_i(GL_TEXTURE_HEIGHT)
 OGL_CONST_i(GL_TEXTURE_HEIGHT_QCOM)
 OGL_CONST_i(GL_TEXTURE_HI_SIZE_NV)
 OGL_CONST_i(GL_TEXTURE_IMAGE_FORMAT)
 OGL_CONST_i(GL_TEXTURE_IMAGE_TYPE)
 OGL_CONST_i(GL_TEXTURE_IMAGE_VALID_QCOM)
 OGL_CONST_i(GL_TEXTURE_IMMUTABLE_FORMAT)
 OGL_CONST_i(GL_TEXTURE_IMMUTABLE_FORMAT_EXT)
 OGL_CONST_i(GL_TEXTURE_IMMUTABLE_LEVELS)
 OGL_CONST_i(GL_TEXTURE_INDEX_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_INTENSITY_SIZE)
 OGL_CONST_i(GL_TEXTURE_INTENSITY_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_INTENSITY_TYPE)
 OGL_CONST_i(GL_TEXTURE_INTENSITY_TYPE_ARB)
 OGL_CONST_i(GL_TEXTURE_INTERNAL_FORMAT)
 OGL_CONST_i(GL_TEXTURE_INTERNAL_FORMAT_QCOM)
 OGL_CONST_i(GL_TEXTURE_LEQUAL_R_SGIX)
 OGL_CONST_i(GL_TEXTURE_LIGHT_EXT)
 OGL_CONST_i(GL_TEXTURE_LOD_BIAS)
 OGL_CONST_i(GL_TEXTURE_LOD_BIAS_EXT)
 OGL_CONST_i(GL_TEXTURE_LOD_BIAS_QCOM)
 OGL_CONST_i(GL_TEXTURE_LO_SIZE_NV)
 OGL_CONST_i(GL_TEXTURE_LUMINANCE_SIZE)
 OGL_CONST_i(GL_TEXTURE_LUMINANCE_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_LUMINANCE_TYPE)
 OGL_CONST_i(GL_TEXTURE_LUMINANCE_TYPE_ARB)
 OGL_CONST_i(GL_TEXTURE_MAG_FILTER)
 OGL_CONST_i(GL_TEXTURE_MAG_SIZE_NV)
 OGL_CONST_i(GL_TEXTURE_MATERIAL_FACE_EXT)
 OGL_CONST_i(GL_TEXTURE_MATERIAL_PARAMETER_EXT)
 OGL_CONST_i(GL_TEXTURE_MATRIX)
 OGL_CONST_i(GL_TEXTURE_MATRIX_FLOAT_AS_INT_BITS_OES)
 OGL_CONST_i(GL_TEXTURE_MAX_ANISOTROPY)
 OGL_CONST_i(GL_TEXTURE_MAX_ANISOTROPY_EXT)
 OGL_CONST_i(GL_TEXTURE_MAX_CLAMP_R_SGIX)
 OGL_CONST_i(GL_TEXTURE_MAX_CLAMP_S_SGIX)
 OGL_CONST_i(GL_TEXTURE_MAX_CLAMP_T_SGIX)
 OGL_CONST_i(GL_TEXTURE_MAX_LEVEL)
 OGL_CONST_i(GL_TEXTURE_MAX_LEVEL_APPLE)
 OGL_CONST_i(GL_TEXTURE_MAX_LEVEL_SGIS)
 OGL_CONST_i(GL_TEXTURE_MAX_LOD)
 OGL_CONST_i(GL_TEXTURE_MAX_LOD_SGIS)
 OGL_CONST_i(GL_TEXTURE_MEMORY_LAYOUT_INTEL)
 OGL_CONST_i(GL_TEXTURE_MIN_FILTER)
 OGL_CONST_i(GL_TEXTURE_MIN_LOD)
 OGL_CONST_i(GL_TEXTURE_MIN_LOD_SGIS)
 OGL_CONST_i(GL_TEXTURE_MIPMAP_ANISOTROPY_SGIX)
 OGL_CONST_i(GL_TEXTURE_MULTI_BUFFER_HINT_SGIX)
 OGL_CONST_i(GL_TEXTURE_NORMAL_EXT)
 OGL_CONST_i(GL_TEXTURE_NUM_LEVELS_QCOM)
 OGL_CONST_i(GL_TEXTURE_OBJECT_VALID_QCOM)
 OGL_CONST_i(GL_TEXTURE_OUTPUT_ALPHA_ATIX)
 OGL_CONST_i(GL_TEXTURE_OUTPUT_RGB_ATIX)
 OGL_CONST_i(GL_TEXTURE_POINT_MODE_ATIX)
 OGL_CONST_i(GL_TEXTURE_POINT_ONE_COORD_ATIX)
 OGL_CONST_i(GL_TEXTURE_POINT_SPRITE_ATIX)
 OGL_CONST_i(GL_TEXTURE_PRIORITY)
 OGL_CONST_i(GL_TEXTURE_PRIORITY_EXT)
 OGL_CONST_i(GL_TEXTURE_PROTECTED_EXT)
 OGL_CONST_i(GL_TEXTURE_RANGE_LENGTH_APPLE)
 OGL_CONST_i(GL_TEXTURE_RANGE_POINTER_APPLE)
 OGL_CONST_i(GL_TEXTURE_RECTANGLE)
 OGL_CONST_i(GL_TEXTURE_RECTANGLE_ARB)
 OGL_CONST_i(GL_TEXTURE_RECTANGLE_EXT)
 OGL_CONST_i(GL_TEXTURE_RECTANGLE_NV)
 OGL_CONST_i(GL_TEXTURE_REDUCTION_MODE_ARB)
 OGL_CONST_i(GL_TEXTURE_REDUCTION_MODE_EXT)
 OGL_CONST_i(GL_TEXTURE_RED_SIZE)
 OGL_CONST_i(GL_TEXTURE_RED_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_RED_TYPE)
 OGL_CONST_i(GL_TEXTURE_RED_TYPE_ARB)
 OGL_CONST_i(GL_TEXTURE_RENDERBUFFER_DATA_STORE_BINDING_NV)
 OGL_CONST_i(GL_TEXTURE_RENDERBUFFER_NV)
 OGL_CONST_i(GL_TEXTURE_RESIDENT)
 OGL_CONST_i(GL_TEXTURE_RESIDENT_EXT)
 OGL_CONST_i(GL_TEXTURE_SAMPLES)
 OGL_CONST_i(GL_TEXTURE_SAMPLES_IMG)
 OGL_CONST_i(GL_TEXTURE_SHADER_NV)
 OGL_CONST_i(GL_TEXTURE_SHADOW)
 OGL_CONST_i(GL_TEXTURE_SHARED_SIZE)
 OGL_CONST_i(GL_TEXTURE_SHARED_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_SPARSE_ARB)
 OGL_CONST_i(GL_TEXTURE_SPARSE_EXT)
 OGL_CONST_i(GL_TEXTURE_SRGB_DECODE_EXT)
 OGL_CONST_i(GL_TEXTURE_STACK_DEPTH)
 OGL_CONST_i(GL_TEXTURE_STENCIL_SIZE)
 OGL_CONST_i(GL_TEXTURE_STENCIL_SIZE_EXT)
 OGL_CONST_i(GL_TEXTURE_STORAGE_HINT_APPLE)
 OGL_CONST_i(GL_TEXTURE_STORAGE_SPARSE_BIT_AMD)
 OGL_CONST_i(GL_TEXTURE_SWIZZLE_A)
 OGL_CONST_i(GL_TEXTURE_SWIZZLE_A_EXT)
 OGL_CONST_i(GL_TEXTURE_SWIZZLE_B)
 OGL_CONST_i(GL_TEXTURE_SWIZZLE_B_EXT)
 OGL_CONST_i(GL_TEXTURE_SWIZZLE_G)
 OGL_CONST_i(GL_TEXTURE_SWIZZLE_G_EXT)
 OGL_CONST_i(GL_TEXTURE_SWIZZLE_R)
 OGL_CONST_i(GL_TEXTURE_SWIZZLE_RGBA)
 OGL_CONST_i(GL_TEXTURE_SWIZZLE_RGBA_EXT)
 OGL_CONST_i(GL_TEXTURE_SWIZZLE_R_EXT)
 OGL_CONST_i(GL_TEXTURE_TARGET)
 OGL_CONST_i(GL_TEXTURE_TARGET_QCOM)
 OGL_CONST_i(GL_TEXTURE_TILING_EXT)
 OGL_CONST_i(GL_TEXTURE_TYPE_QCOM)
 OGL_CONST_i(GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM)
 OGL_CONST_i(GL_TEXTURE_UNSIGNED_REMAP_MODE_NV)
 OGL_CONST_i(GL_TEXTURE_UPDATE_BARRIER_BIT)
 OGL_CONST_i(GL_TEXTURE_UPDATE_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_TEXTURE_USAGE_ANGLE)
 OGL_CONST_i(GL_TEXTURE_VIEW)
 OGL_CONST_i(GL_TEXTURE_VIEW_MIN_LAYER)
 OGL_CONST_i(GL_TEXTURE_VIEW_MIN_LAYER_EXT)
 OGL_CONST_i(GL_TEXTURE_VIEW_MIN_LAYER_OES)
 OGL_CONST_i(GL_TEXTURE_VIEW_MIN_LEVEL)
 OGL_CONST_i(GL_TEXTURE_VIEW_MIN_LEVEL_EXT)
 OGL_CONST_i(GL_TEXTURE_VIEW_MIN_LEVEL_OES)
 OGL_CONST_i(GL_TEXTURE_VIEW_NUM_LAYERS)
 OGL_CONST_i(GL_TEXTURE_VIEW_NUM_LAYERS_EXT)
 OGL_CONST_i(GL_TEXTURE_VIEW_NUM_LAYERS_OES)
 OGL_CONST_i(GL_TEXTURE_VIEW_NUM_LEVELS)
 OGL_CONST_i(GL_TEXTURE_VIEW_NUM_LEVELS_EXT)
 OGL_CONST_i(GL_TEXTURE_VIEW_NUM_LEVELS_OES)
 OGL_CONST_i(GL_TEXTURE_WIDTH)
 OGL_CONST_i(GL_TEXTURE_WIDTH_QCOM)
 OGL_CONST_i(GL_TEXTURE_WRAP_R)
 OGL_CONST_i(GL_TEXTURE_WRAP_R_EXT)
 OGL_CONST_i(GL_TEXTURE_WRAP_R_OES)
 OGL_CONST_i(GL_TEXTURE_WRAP_S)
 OGL_CONST_i(GL_TEXTURE_WRAP_T)
 OGL_CONST_i(GL_TEXTURE_Y_DEGAMMA_QCOM)
 OGL_CONST_i(GL_TEXT_FRAGMENT_SHADER_ATI)
 OGL_CONST_i(GL_TILING_TYPES_EXT)
 OGL_CONST_i(GL_TIMELINE_SEMAPHORE_VALUE_NV)
 OGL_CONST_i(GL_TIMEOUT_EXPIRED)
 OGL_CONST_i(GL_TIMEOUT_EXPIRED_APPLE)
 OGL_CONST_i(GL_TIMEOUT_IGNORED)
 OGL_CONST_i(GL_TIMEOUT_IGNORED_APPLE)
 OGL_CONST_i(GL_TIMESTAMP)
 OGL_CONST_i(GL_TIMESTAMP_ANGLE)
 OGL_CONST_i(GL_TIMESTAMP_EXT)
 OGL_CONST_i(GL_TIME_ELAPSED)
 OGL_CONST_i(GL_TIME_ELAPSED_ANGLE)
 OGL_CONST_i(GL_TIME_ELAPSED_EXT)
 OGL_CONST_i(GL_TOP_LEVEL_ARRAY_SIZE)
 OGL_CONST_i(GL_TOP_LEVEL_ARRAY_STRIDE)
 OGL_CONST_i(GL_TRACE_REGAL)
 OGL_CONST_i(GL_TRACK_MATRIX_NV)
 OGL_CONST_i(GL_TRACK_MATRIX_TRANSFORM_NV)
 OGL_CONST_i(GL_TRANSFORM_BIT)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_ACTIVE)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_ATTRIBS_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BARRIER_BIT)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BINDING)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BINDING_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_BINDING)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_EXT)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_EXT)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_INDEX)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_MODE)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_MODE_EXT)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_MODE_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_SIZE)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_EXT)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_START)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_START_EXT)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_START_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_OVERFLOW)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_OVERFLOW_ARB)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_PAUSED)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_EXT)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_RECORD_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_STREAM_OVERFLOW)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_STREAM_OVERFLOW_ARB)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_VARYING)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_VARYINGS)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_VARYINGS_EXT)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_VARYINGS_NV)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH)
 OGL_CONST_i(GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH_EXT)
 OGL_CONST_i(GL_TRANSFORM_HINT_APPLE)
 OGL_CONST_i(GL_TRANSLATED_SHADER_SOURCE_LENGTH_ANGLE)
 OGL_CONST_i(GL_TRANSLATE_2D_NV)
 OGL_CONST_i(GL_TRANSLATE_3D_NV)
 OGL_CONST_i(GL_TRANSLATE_X_NV)
 OGL_CONST_i(GL_TRANSLATE_Y_NV)
 OGL_CONST_i(GL_TRANSPOSE_AFFINE_2D_NV)
 OGL_CONST_i(GL_TRANSPOSE_AFFINE_3D_NV)
 OGL_CONST_i(GL_TRANSPOSE_COLOR_MATRIX)
 OGL_CONST_i(GL_TRANSPOSE_COLOR_MATRIX_ARB)
 OGL_CONST_i(GL_TRANSPOSE_CURRENT_MATRIX_ARB)
 OGL_CONST_i(GL_TRANSPOSE_MODELVIEW_MATRIX)
 OGL_CONST_i(GL_TRANSPOSE_MODELVIEW_MATRIX_ARB)
 OGL_CONST_i(GL_TRANSPOSE_NV)
 OGL_CONST_i(GL_TRANSPOSE_PROGRAM_MATRIX_EXT)
 OGL_CONST_i(GL_TRANSPOSE_PROJECTION_MATRIX)
 OGL_CONST_i(GL_TRANSPOSE_PROJECTION_MATRIX_ARB)
 OGL_CONST_i(GL_TRANSPOSE_TEXTURE_MATRIX)
 OGL_CONST_i(GL_TRANSPOSE_TEXTURE_MATRIX_ARB)
 OGL_CONST_i(GL_TRIANGLES)
 OGL_CONST_i(GL_TRIANGLES_ADJACENCY)
 OGL_CONST_i(GL_TRIANGLES_ADJACENCY_ARB)
 OGL_CONST_i(GL_TRIANGLES_ADJACENCY_EXT)
 OGL_CONST_i(GL_TRIANGLES_ADJACENCY_OES)
 OGL_CONST_i(GL_TRIANGLE_FAN)
 OGL_CONST_i(GL_TRIANGLE_LIST_SUN)
 OGL_CONST_i(GL_TRIANGLE_MESH_SUN)
 OGL_CONST_i(GL_TRIANGLE_STRIP)
 OGL_CONST_i(GL_TRIANGLE_STRIP_ADJACENCY)
 OGL_CONST_i(GL_TRIANGLE_STRIP_ADJACENCY_ARB)
 OGL_CONST_i(GL_TRIANGLE_STRIP_ADJACENCY_EXT)
 OGL_CONST_i(GL_TRIANGLE_STRIP_ADJACENCY_OES)
 OGL_CONST_i(GL_TRIANGULAR_NV)
 OGL_CONST_i(GL_TRP_ERROR_CONTEXT_RESET_IMG)
 OGL_CONST_i(GL_TRP_IMG)
 OGL_CONST_i(GL_TRP_UNSUPPORTED_CONTEXT_IMG)
 OGL_CONST_i(GL_TRUE)
 OGL_CONST_i(GL_TYPE)
 OGL_CONST_i(GL_UNCORRELATED_NV)
 OGL_CONST_i(GL_UNDEFINED_APPLE)
 OGL_CONST_i(GL_UNDEFINED_VERTEX)
 OGL_CONST_i(GL_UNDEFINED_VERTEX_EXT)
 OGL_CONST_i(GL_UNDEFINED_VERTEX_OES)
 OGL_CONST_i(GL_UNIFORM)
 OGL_CONST_i(GL_UNIFORM_ADDRESS_COMMAND_NV)
 OGL_CONST_i(GL_UNIFORM_ARRAY_STRIDE)
 OGL_CONST_i(GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX)
 OGL_CONST_i(GL_UNIFORM_BARRIER_BIT)
 OGL_CONST_i(GL_UNIFORM_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_UNIFORM_BLOCK)
 OGL_CONST_i(GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS)
 OGL_CONST_i(GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES)
 OGL_CONST_i(GL_UNIFORM_BLOCK_BINDING)
 OGL_CONST_i(GL_UNIFORM_BLOCK_DATA_SIZE)
 OGL_CONST_i(GL_UNIFORM_BLOCK_INDEX)
 OGL_CONST_i(GL_UNIFORM_BLOCK_NAME_LENGTH)
 OGL_CONST_i(GL_UNIFORM_BLOCK_REFERENCED_BY_COMPUTE_SHADER)
 OGL_CONST_i(GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER)
 OGL_CONST_i(GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER)
 OGL_CONST_i(GL_UNIFORM_BLOCK_REFERENCED_BY_MESH_SHADER_EXT)
 OGL_CONST_i(GL_UNIFORM_BLOCK_REFERENCED_BY_MESH_SHADER_NV)
 OGL_CONST_i(GL_UNIFORM_BLOCK_REFERENCED_BY_TASK_SHADER_EXT)
 OGL_CONST_i(GL_UNIFORM_BLOCK_REFERENCED_BY_TASK_SHADER_NV)
 OGL_CONST_i(GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_CONTROL_SHADER)
 OGL_CONST_i(GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_EVALUATION_SHADER)
 OGL_CONST_i(GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER)
 OGL_CONST_i(GL_UNIFORM_BUFFER)
 OGL_CONST_i(GL_UNIFORM_BUFFER_ADDRESS_NV)
 OGL_CONST_i(GL_UNIFORM_BUFFER_BINDING)
 OGL_CONST_i(GL_UNIFORM_BUFFER_BINDING_EXT)
 OGL_CONST_i(GL_UNIFORM_BUFFER_EXT)
 OGL_CONST_i(GL_UNIFORM_BUFFER_LENGTH_NV)
 OGL_CONST_i(GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT)
 OGL_CONST_i(GL_UNIFORM_BUFFER_SIZE)
 OGL_CONST_i(GL_UNIFORM_BUFFER_START)
 OGL_CONST_i(GL_UNIFORM_BUFFER_UNIFIED_NV)
 OGL_CONST_i(GL_UNIFORM_IS_ROW_MAJOR)
 OGL_CONST_i(GL_UNIFORM_MATRIX_STRIDE)
 OGL_CONST_i(GL_UNIFORM_NAME_LENGTH)
 OGL_CONST_i(GL_UNIFORM_OFFSET)
 OGL_CONST_i(GL_UNIFORM_SGIX)
 OGL_CONST_i(GL_UNIFORM_SIZE)
 OGL_CONST_i(GL_UNIFORM_TYPE)
 OGL_CONST_i(GL_UNKNOWN_CONTEXT_RESET)
 OGL_CONST_i(GL_UNKNOWN_CONTEXT_RESET_ARB)
 OGL_CONST_i(GL_UNKNOWN_CONTEXT_RESET_EXT)
 OGL_CONST_i(GL_UNPACK_ALIGNMENT)
 OGL_CONST_i(GL_UNPACK_CLIENT_STORAGE_APPLE)
 OGL_CONST_i(GL_UNPACK_CMYK_HINT_EXT)
 OGL_CONST_i(GL_UNPACK_COMPRESSED_BLOCK_DEPTH)
 OGL_CONST_i(GL_UNPACK_COMPRESSED_BLOCK_HEIGHT)
 OGL_CONST_i(GL_UNPACK_COMPRESSED_BLOCK_SIZE)
 OGL_CONST_i(GL_UNPACK_COMPRESSED_BLOCK_WIDTH)
 OGL_CONST_i(GL_UNPACK_CONSTANT_DATA_SUNX)
 OGL_CONST_i(GL_UNPACK_IMAGE_HEIGHT)
 OGL_CONST_i(GL_UNPACK_IMAGE_HEIGHT_EXT)
 OGL_CONST_i(GL_UNPACK_IMAGE_HEIGHT_NV)
 OGL_CONST_i(GL_UNPACK_LSB_FIRST)
 OGL_CONST_i(GL_UNPACK_RESAMPLE_OML)
 OGL_CONST_i(GL_UNPACK_RESAMPLE_SGIX)
 OGL_CONST_i(GL_UNPACK_ROW_BYTES_APPLE)
 OGL_CONST_i(GL_UNPACK_ROW_LENGTH)
 OGL_CONST_i(GL_UNPACK_ROW_LENGTH_EXT)
 OGL_CONST_i(GL_UNPACK_SKIP_IMAGES)
 OGL_CONST_i(GL_UNPACK_SKIP_IMAGES_EXT)
 OGL_CONST_i(GL_UNPACK_SKIP_IMAGES_NV)
 OGL_CONST_i(GL_UNPACK_SKIP_PIXELS)
 OGL_CONST_i(GL_UNPACK_SKIP_PIXELS_EXT)
 OGL_CONST_i(GL_UNPACK_SKIP_ROWS)
 OGL_CONST_i(GL_UNPACK_SKIP_ROWS_EXT)
 OGL_CONST_i(GL_UNPACK_SUBSAMPLE_RATE_SGIX)
 OGL_CONST_i(GL_UNPACK_SWAP_BYTES)
 OGL_CONST_i(GL_UNSIGNALED)
 OGL_CONST_i(GL_UNSIGNALED_APPLE)
 OGL_CONST_i(GL_UNSIGNED_BYTE)
 OGL_CONST_i(GL_UNSIGNED_BYTE_2_3_3_REV)
 OGL_CONST_i(GL_UNSIGNED_BYTE_3_3_2)
 OGL_CONST_i(GL_UNSIGNED_BYTE_3_3_2_EXT)
 OGL_CONST_i(GL_UNSIGNED_IDENTITY_NV)
 OGL_CONST_i(GL_UNSIGNED_INT)
 OGL_CONST_i(GL_UNSIGNED_INT16_NV)
 OGL_CONST_i(GL_UNSIGNED_INT16_VEC2_NV)
 OGL_CONST_i(GL_UNSIGNED_INT16_VEC3_NV)
 OGL_CONST_i(GL_UNSIGNED_INT16_VEC4_NV)
 OGL_CONST_i(GL_UNSIGNED_INT64_AMD)
 OGL_CONST_i(GL_UNSIGNED_INT64_ARB)
 OGL_CONST_i(GL_UNSIGNED_INT64_NV)
 OGL_CONST_i(GL_UNSIGNED_INT64_VEC2_ARB)
 OGL_CONST_i(GL_UNSIGNED_INT64_VEC2_NV)
 OGL_CONST_i(GL_UNSIGNED_INT64_VEC3_ARB)
 OGL_CONST_i(GL_UNSIGNED_INT64_VEC3_NV)
 OGL_CONST_i(GL_UNSIGNED_INT64_VEC4_ARB)
 OGL_CONST_i(GL_UNSIGNED_INT64_VEC4_NV)
 OGL_CONST_i(GL_UNSIGNED_INT8_NV)
 OGL_CONST_i(GL_UNSIGNED_INT8_VEC2_NV)
 OGL_CONST_i(GL_UNSIGNED_INT8_VEC3_NV)
 OGL_CONST_i(GL_UNSIGNED_INT8_VEC4_NV)
 OGL_CONST_i(GL_UNSIGNED_INT_10F_11F_11F_REV)
 OGL_CONST_i(GL_UNSIGNED_INT_10F_11F_11F_REV_APPLE)
 OGL_CONST_i(GL_UNSIGNED_INT_10F_11F_11F_REV_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_10F_11F_11F_REV_NV)
 OGL_CONST_i(GL_UNSIGNED_INT_10_10_10_2)
 OGL_CONST_i(GL_UNSIGNED_INT_10_10_10_2_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_10_10_10_2_OES)
 OGL_CONST_i(GL_UNSIGNED_INT_24_8)
 OGL_CONST_i(GL_UNSIGNED_INT_24_8_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_24_8_NV)
 OGL_CONST_i(GL_UNSIGNED_INT_24_8_OES)
 OGL_CONST_i(GL_UNSIGNED_INT_2_10_10_10_REV)
 OGL_CONST_i(GL_UNSIGNED_INT_2_10_10_10_REV_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_5_9_9_9_REV)
 OGL_CONST_i(GL_UNSIGNED_INT_5_9_9_9_REV_APPLE)
 OGL_CONST_i(GL_UNSIGNED_INT_5_9_9_9_REV_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_8_8_8_8)
 OGL_CONST_i(GL_UNSIGNED_INT_8_8_8_8_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_8_8_8_8_REV)
 OGL_CONST_i(GL_UNSIGNED_INT_8_8_S8_S8_REV_NV)
 OGL_CONST_i(GL_UNSIGNED_INT_ATOMIC_COUNTER)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_1D)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_1D_ARRAY)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_1D_ARRAY_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_1D_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_2D)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_2D_ARRAY)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_2D_ARRAY_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_2D_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_2D_RECT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_2D_RECT_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_3D)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_3D_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_BUFFER)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_BUFFER_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_BUFFER_OES)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_CUBE)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_CUBE_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY_OES)
 OGL_CONST_i(GL_UNSIGNED_INT_S8_S8_8_8_NV)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_1D)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_1D_ARRAY)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_1D_ARRAY_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_1D_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_2D)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_2D_ARRAY)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_2D_ARRAY_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_2D_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY_OES)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_2D_RECT)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_2D_RECT_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_3D)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_3D_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_BUFFER)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_BUFFER_AMD)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_BUFFER_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_BUFFER_OES)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_CUBE)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_CUBE_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY_ARB)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY_OES)
 OGL_CONST_i(GL_UNSIGNED_INT_SAMPLER_RENDERBUFFER_NV)
 OGL_CONST_i(GL_UNSIGNED_INT_VEC2)
 OGL_CONST_i(GL_UNSIGNED_INT_VEC2_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_VEC3)
 OGL_CONST_i(GL_UNSIGNED_INT_VEC3_EXT)
 OGL_CONST_i(GL_UNSIGNED_INT_VEC4)
 OGL_CONST_i(GL_UNSIGNED_INT_VEC4_EXT)
 OGL_CONST_i(GL_UNSIGNED_INVERT_NV)
 OGL_CONST_i(GL_UNSIGNED_NORMALIZED)
 OGL_CONST_i(GL_UNSIGNED_NORMALIZED_ARB)
 OGL_CONST_i(GL_UNSIGNED_NORMALIZED_EXT)
 OGL_CONST_i(GL_UNSIGNED_SHORT)
 OGL_CONST_i(GL_UNSIGNED_SHORT_1_5_5_5_REV)
 OGL_CONST_i(GL_UNSIGNED_SHORT_1_5_5_5_REV_EXT)
 OGL_CONST_i(GL_UNSIGNED_SHORT_4_4_4_4)
 OGL_CONST_i(GL_UNSIGNED_SHORT_4_4_4_4_EXT)
 OGL_CONST_i(GL_UNSIGNED_SHORT_4_4_4_4_REV)
 OGL_CONST_i(GL_UNSIGNED_SHORT_4_4_4_4_REV_EXT)
 OGL_CONST_i(GL_UNSIGNED_SHORT_4_4_4_4_REV_IMG)
 OGL_CONST_i(GL_UNSIGNED_SHORT_5_5_5_1)
 OGL_CONST_i(GL_UNSIGNED_SHORT_5_5_5_1_EXT)
 OGL_CONST_i(GL_UNSIGNED_SHORT_5_6_5)
 OGL_CONST_i(GL_UNSIGNED_SHORT_5_6_5_REV)
 OGL_CONST_i(GL_UNSIGNED_SHORT_8_8_APPLE)
 OGL_CONST_i(GL_UNSIGNED_SHORT_8_8_MESA)
 OGL_CONST_i(GL_UNSIGNED_SHORT_8_8_REV_APPLE)
 OGL_CONST_i(GL_UNSIGNED_SHORT_8_8_REV_MESA)
 OGL_CONST_i(GL_UPLOAD_GPU_MASK_NVX)
 OGL_CONST_i(GL_UPPER_LEFT)
 OGL_CONST_i(GL_UPPER_LEFT_EXT)
 OGL_CONST_i(GL_USE_MISSING_GLYPH_NV)
 OGL_CONST_i(GL_UTF16_NV)
 OGL_CONST_i(GL_UTF8_NV)
 OGL_CONST_i(GL_UUID_SIZE_EXT)
 OGL_CONST_i(GL_V2F)
 OGL_CONST_i(GL_V3F)
 OGL_CONST_i(GL_VALIDATE_STATUS)
 OGL_CONST_i(GL_VARIABLE_A_NV)
 OGL_CONST_i(GL_VARIABLE_B_NV)
 OGL_CONST_i(GL_VARIABLE_C_NV)
 OGL_CONST_i(GL_VARIABLE_D_NV)
 OGL_CONST_i(GL_VARIABLE_E_NV)
 OGL_CONST_i(GL_VARIABLE_F_NV)
 OGL_CONST_i(GL_VARIABLE_G_NV)
 OGL_CONST_i(GL_VARIANT_ARRAY_EXT)
 OGL_CONST_i(GL_VARIANT_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_VARIANT_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_VARIANT_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_VARIANT_DATATYPE_EXT)
 OGL_CONST_i(GL_VARIANT_EXT)
 OGL_CONST_i(GL_VARIANT_VALUE_EXT)
 OGL_CONST_i(GL_VBO_FREE_MEMORY_ATI)
 OGL_CONST_i(GL_VECTOR_EXT)
 OGL_CONST_i(GL_VENDOR)
 OGL_CONST_i(GL_VERSION)
 OGL_CONST_i(GL_VERTEX23_BIT_PGI)
 OGL_CONST_i(GL_VERTEX4_BIT_PGI)
 OGL_CONST_i(GL_VERTEX_ARRAY)
 OGL_CONST_i(GL_VERTEX_ARRAY_ADDRESS_NV)
 OGL_CONST_i(GL_VERTEX_ARRAY_BINDING)
 OGL_CONST_i(GL_VERTEX_ARRAY_BINDING_APPLE)
 OGL_CONST_i(GL_VERTEX_ARRAY_BINDING_OES)
 OGL_CONST_i(GL_VERTEX_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_VERTEX_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_VERTEX_ARRAY_COUNT_EXT)
 OGL_CONST_i(GL_VERTEX_ARRAY_EXT)
 OGL_CONST_i(GL_VERTEX_ARRAY_LENGTH_NV)
 OGL_CONST_i(GL_VERTEX_ARRAY_LIST_IBM)
 OGL_CONST_i(GL_VERTEX_ARRAY_LIST_STRIDE_IBM)
 OGL_CONST_i(GL_VERTEX_ARRAY_OBJECT_AMD)
 OGL_CONST_i(GL_VERTEX_ARRAY_OBJECT_EXT)
 OGL_CONST_i(GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL)
 OGL_CONST_i(GL_VERTEX_ARRAY_POINTER)
 OGL_CONST_i(GL_VERTEX_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_VERTEX_ARRAY_RANGE_APPLE)
 OGL_CONST_i(GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE)
 OGL_CONST_i(GL_VERTEX_ARRAY_RANGE_LENGTH_NV)
 OGL_CONST_i(GL_VERTEX_ARRAY_RANGE_NV)
 OGL_CONST_i(GL_VERTEX_ARRAY_RANGE_POINTER_APPLE)
 OGL_CONST_i(GL_VERTEX_ARRAY_RANGE_POINTER_NV)
 OGL_CONST_i(GL_VERTEX_ARRAY_RANGE_VALID_NV)
 OGL_CONST_i(GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV)
 OGL_CONST_i(GL_VERTEX_ARRAY_SIZE)
 OGL_CONST_i(GL_VERTEX_ARRAY_SIZE_EXT)
 OGL_CONST_i(GL_VERTEX_ARRAY_STORAGE_HINT_APPLE)
 OGL_CONST_i(GL_VERTEX_ARRAY_STRIDE)
 OGL_CONST_i(GL_VERTEX_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_VERTEX_ARRAY_TYPE)
 OGL_CONST_i(GL_VERTEX_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY0_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY10_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY11_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY12_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY13_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY14_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY15_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY1_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY2_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY3_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY4_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY5_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY6_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY7_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY8_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY9_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_ADDRESS_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT_EXT)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_DIVISOR)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ANGLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ARB)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_DIVISOR_EXT)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_DIVISOR_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_ENABLED)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_INTEGER)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_INTEGER_EXT)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_INTEGER_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_LENGTH_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_LONG)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_NORMALIZED)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_POINTER)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_SIZE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_STRIDE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_TYPE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB)
 OGL_CONST_i(GL_VERTEX_ATTRIB_ARRAY_UNIFIED_NV)
 OGL_CONST_i(GL_VERTEX_ATTRIB_BINDING)
 OGL_CONST_i(GL_VERTEX_ATTRIB_MAP1_APPLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_MAP1_COEFF_APPLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_MAP1_DOMAIN_APPLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_MAP1_ORDER_APPLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_MAP1_SIZE_APPLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_MAP2_APPLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_MAP2_COEFF_APPLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_MAP2_DOMAIN_APPLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_MAP2_ORDER_APPLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_MAP2_SIZE_APPLE)
 OGL_CONST_i(GL_VERTEX_ATTRIB_RELATIVE_OFFSET)
 OGL_CONST_i(GL_VERTEX_BINDING_BUFFER)
 OGL_CONST_i(GL_VERTEX_BINDING_DIVISOR)
 OGL_CONST_i(GL_VERTEX_BINDING_OFFSET)
 OGL_CONST_i(GL_VERTEX_BINDING_STRIDE)
 OGL_CONST_i(GL_VERTEX_BLEND_ARB)
 OGL_CONST_i(GL_VERTEX_CONSISTENT_HINT_PGI)
 OGL_CONST_i(GL_VERTEX_DATA_HINT_PGI)
 OGL_CONST_i(GL_VERTEX_ELEMENT_SWIZZLE_AMD)
 OGL_CONST_i(GL_VERTEX_ID_NV)
 OGL_CONST_i(GL_VERTEX_ID_SWIZZLE_AMD)
 OGL_CONST_i(GL_VERTEX_PRECLIP_HINT_SGIX)
 OGL_CONST_i(GL_VERTEX_PRECLIP_SGIX)
 OGL_CONST_i(GL_VERTEX_PROGRAM_ARB)
 OGL_CONST_i(GL_VERTEX_PROGRAM_BINDING_NV)
 OGL_CONST_i(GL_VERTEX_PROGRAM_NV)
 OGL_CONST_i(GL_VERTEX_PROGRAM_PARAMETER_BUFFER_NV)
 OGL_CONST_i(GL_VERTEX_PROGRAM_POINT_SIZE)
 OGL_CONST_i(GL_VERTEX_PROGRAM_POINT_SIZE_ARB)
 OGL_CONST_i(GL_VERTEX_PROGRAM_POINT_SIZE_NV)
 OGL_CONST_i(GL_VERTEX_PROGRAM_TWO_SIDE)
 OGL_CONST_i(GL_VERTEX_PROGRAM_TWO_SIDE_ARB)
 OGL_CONST_i(GL_VERTEX_PROGRAM_TWO_SIDE_NV)
 OGL_CONST_i(GL_VERTEX_SHADER)
 OGL_CONST_i(GL_VERTEX_SHADER_ARB)
 OGL_CONST_i(GL_VERTEX_SHADER_BINDING_EXT)
 OGL_CONST_i(GL_VERTEX_SHADER_BIT)
 OGL_CONST_i(GL_VERTEX_SHADER_EXT)
 OGL_CONST_i(GL_VERTEX_SHADER_INSTRUCTIONS_EXT)
 OGL_CONST_i(GL_VERTEX_SHADER_INVARIANTS_EXT)
 OGL_CONST_i(GL_VERTEX_SHADER_INVOCATIONS)
 OGL_CONST_i(GL_VERTEX_SHADER_INVOCATIONS_ARB)
 OGL_CONST_i(GL_VERTEX_SHADER_LOCALS_EXT)
 OGL_CONST_i(GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT)
 OGL_CONST_i(GL_VERTEX_SHADER_OPTIMIZED_EXT)
 OGL_CONST_i(GL_VERTEX_SHADER_VARIANTS_EXT)
 OGL_CONST_i(GL_VERTEX_SOURCE_ATI)
 OGL_CONST_i(GL_VERTEX_STATE_PROGRAM_NV)
 OGL_CONST_i(GL_VERTEX_STREAM0_ATI)
 OGL_CONST_i(GL_VERTEX_STREAM1_ATI)
 OGL_CONST_i(GL_VERTEX_STREAM2_ATI)
 OGL_CONST_i(GL_VERTEX_STREAM3_ATI)
 OGL_CONST_i(GL_VERTEX_STREAM4_ATI)
 OGL_CONST_i(GL_VERTEX_STREAM5_ATI)
 OGL_CONST_i(GL_VERTEX_STREAM6_ATI)
 OGL_CONST_i(GL_VERTEX_STREAM7_ATI)
 OGL_CONST_i(GL_VERTEX_SUBROUTINE)
 OGL_CONST_i(GL_VERTEX_SUBROUTINE_UNIFORM)
 OGL_CONST_i(GL_VERTEX_TEXTURE)
 OGL_CONST_i(GL_VERTEX_WEIGHTING_EXT)
 OGL_CONST_i(GL_VERTEX_WEIGHT_ARRAY_EXT)
 OGL_CONST_i(GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT)
 OGL_CONST_i(GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT)
 OGL_CONST_i(GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT)
 OGL_CONST_i(GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT)
 OGL_CONST_i(GL_VERTICAL_LINE_TO_NV)
 OGL_CONST_i(GL_VERTICES_SUBMITTED)
 OGL_CONST_i(GL_VERTICES_SUBMITTED_ARB)
 OGL_CONST_i(GL_VIBRANCE_BIAS_NV)
 OGL_CONST_i(GL_VIBRANCE_SCALE_NV)
 OGL_CONST_i(GL_VIDEO_BUFFER_BINDING_NV)
 OGL_CONST_i(GL_VIDEO_BUFFER_INTERNAL_FORMAT_NV)
 OGL_CONST_i(GL_VIDEO_BUFFER_NV)
 OGL_CONST_i(GL_VIDEO_BUFFER_PITCH_NV)
 OGL_CONST_i(GL_VIDEO_CAPTURE_FIELD_LOWER_HEIGHT_NV)
 OGL_CONST_i(GL_VIDEO_CAPTURE_FIELD_UPPER_HEIGHT_NV)
 OGL_CONST_i(GL_VIDEO_CAPTURE_FRAME_HEIGHT_NV)
 OGL_CONST_i(GL_VIDEO_CAPTURE_FRAME_WIDTH_NV)
 OGL_CONST_i(GL_VIDEO_CAPTURE_SURFACE_ORIGIN_NV)
 OGL_CONST_i(GL_VIDEO_CAPTURE_TO_422_SUPPORTED_NV)
 OGL_CONST_i(GL_VIDEO_COLOR_CONVERSION_MATRIX_NV)
 OGL_CONST_i(GL_VIDEO_COLOR_CONVERSION_MAX_NV)
 OGL_CONST_i(GL_VIDEO_COLOR_CONVERSION_MIN_NV)
 OGL_CONST_i(GL_VIDEO_COLOR_CONVERSION_OFFSET_NV)
 OGL_CONST_i(GL_VIEWPORT)
 OGL_CONST_i(GL_VIEWPORT_BIT)
 OGL_CONST_i(GL_VIEWPORT_BOUNDS_RANGE)
 OGL_CONST_i(GL_VIEWPORT_BOUNDS_RANGE_NV)
 OGL_CONST_i(GL_VIEWPORT_COMMAND_NV)
 OGL_CONST_i(GL_VIEWPORT_INDEX_PROVOKING_VERTEX)
 OGL_CONST_i(GL_VIEWPORT_INDEX_PROVOKING_VERTEX_NV)
 OGL_CONST_i(GL_VIEWPORT_POSITION_W_SCALE_NV)
 OGL_CONST_i(GL_VIEWPORT_POSITION_W_SCALE_X_COEFF_NV)
 OGL_CONST_i(GL_VIEWPORT_POSITION_W_SCALE_Y_COEFF_NV)
 OGL_CONST_i(GL_VIEWPORT_SUBPIXEL_BITS)
 OGL_CONST_i(GL_VIEWPORT_SUBPIXEL_BITS_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_NEGATIVE_W_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_NEGATIVE_X_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_NEGATIVE_Y_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_NEGATIVE_Z_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_POSITIVE_W_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_POSITIVE_X_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_POSITIVE_Y_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_POSITIVE_Z_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_W_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_X_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_Y_NV)
 OGL_CONST_i(GL_VIEWPORT_SWIZZLE_Z_NV)
 OGL_CONST_i(GL_VIEW_CLASS_128_BITS)
 OGL_CONST_i(GL_VIEW_CLASS_16_BITS)
 OGL_CONST_i(GL_VIEW_CLASS_24_BITS)
 OGL_CONST_i(GL_VIEW_CLASS_32_BITS)
 OGL_CONST_i(GL_VIEW_CLASS_48_BITS)
 OGL_CONST_i(GL_VIEW_CLASS_64_BITS)
 OGL_CONST_i(GL_VIEW_CLASS_8_BITS)
 OGL_CONST_i(GL_VIEW_CLASS_96_BITS)
 OGL_CONST_i(GL_VIEW_CLASS_BPTC_FLOAT)
 OGL_CONST_i(GL_VIEW_CLASS_BPTC_UNORM)
 OGL_CONST_i(GL_VIEW_CLASS_RGTC1_RED)
 OGL_CONST_i(GL_VIEW_CLASS_RGTC2_RG)
 OGL_CONST_i(GL_VIEW_CLASS_S3TC_DXT1_RGB)
 OGL_CONST_i(GL_VIEW_CLASS_S3TC_DXT1_RGBA)
 OGL_CONST_i(GL_VIEW_CLASS_S3TC_DXT3_RGBA)
 OGL_CONST_i(GL_VIEW_CLASS_S3TC_DXT5_RGBA)
 OGL_CONST_i(GL_VIEW_COMPATIBILITY_CLASS)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_INDEX_ARB)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_INDEX_EXT)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_X_AMD)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_X_ARB)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_X_EXT)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_Y_AMD)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_Y_ARB)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_Y_EXT)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_Z_AMD)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_Z_ARB)
 OGL_CONST_i(GL_VIRTUAL_PAGE_SIZE_Z_EXT)
 OGL_CONST_i(GL_VIVIDLIGHT_NV)
 OGL_CONST_i(GL_VOLATILE_APPLE)
 OGL_CONST_i(GL_WAIT_FAILED)
 OGL_CONST_i(GL_WAIT_FAILED_APPLE)
 OGL_CONST_i(GL_WARPS_PER_SM_NV)
 OGL_CONST_i(GL_WARP_SIZE_NV)
 OGL_CONST_i(GL_WEIGHTED_AVERAGE_ARB)
 OGL_CONST_i(GL_WEIGHTED_AVERAGE_EXT)
 OGL_CONST_i(GL_WEIGHT_ARRAY_ARB)
 OGL_CONST_i(GL_WEIGHT_ARRAY_BUFFER_BINDING)
 OGL_CONST_i(GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB)
 OGL_CONST_i(GL_WEIGHT_ARRAY_BUFFER_BINDING_OES)
 OGL_CONST_i(GL_WEIGHT_ARRAY_OES)
 OGL_CONST_i(GL_WEIGHT_ARRAY_POINTER_ARB)
 OGL_CONST_i(GL_WEIGHT_ARRAY_POINTER_OES)
 OGL_CONST_i(GL_WEIGHT_ARRAY_SIZE_ARB)
 OGL_CONST_i(GL_WEIGHT_ARRAY_SIZE_OES)
 OGL_CONST_i(GL_WEIGHT_ARRAY_STRIDE_ARB)
 OGL_CONST_i(GL_WEIGHT_ARRAY_STRIDE_OES)
 OGL_CONST_i(GL_WEIGHT_ARRAY_TYPE_ARB)
 OGL_CONST_i(GL_WEIGHT_ARRAY_TYPE_OES)
 OGL_CONST_i(GL_WEIGHT_SUM_UNITY_ARB)
 OGL_CONST_i(GL_WIDE_LINE_HINT_PGI)
 OGL_CONST_i(GL_WINDOW_RECTANGLE_EXT)
 OGL_CONST_i(GL_WINDOW_RECTANGLE_MODE_EXT)
 OGL_CONST_i(GL_WRAP_BORDER)
 OGL_CONST_i(GL_WRAP_BORDER_SUN)
 OGL_CONST_i(GL_WRITEONLY_RENDERING_QCOM)
 OGL_CONST_i(GL_WRITE_DISCARD_NV)
 OGL_CONST_i(GL_WRITE_ONLY)
 OGL_CONST_i(GL_WRITE_ONLY_ARB)
 OGL_CONST_i(GL_WRITE_ONLY_OES)
 OGL_CONST_i(GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV)
 OGL_CONST_i(GL_WRITE_PIXEL_DATA_RANGE_NV)
 OGL_CONST_i(GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV)
 OGL_CONST_i(GL_W_EXT)
 OGL_CONST_i(GL_XOR)
 OGL_CONST_i(GL_XOR_NV)
 OGL_CONST_i(GL_X_EXT)
 OGL_CONST_i(GL_YCBAYCR8A_4224_NV)
 OGL_CONST_i(GL_YCBCR_422_APPLE)
 OGL_CONST_i(GL_YCBCR_MESA)
 OGL_CONST_i(GL_YCBYCR8_422_NV)
 OGL_CONST_i(GL_YCRCBA_SGIX)
 OGL_CONST_i(GL_YCRCB_SGIX)
 OGL_CONST_i(GL_Y_EXT)
 OGL_CONST_i(GL_Z400_BINARY_AMD)
 OGL_CONST_i(GL_Z4Y12Z4CB12Z4A12Z4Y12Z4CR12Z4A12_4224_NV)
 OGL_CONST_i(GL_Z4Y12Z4CB12Z4CR12_444_NV)
 OGL_CONST_i(GL_Z4Y12Z4CB12Z4Y12Z4CR12_422_NV)
 OGL_CONST_i(GL_Z6Y10Z6CB10Z6A10Z6Y10Z6CR10Z6A10_4224_NV)
 OGL_CONST_i(GL_Z6Y10Z6CB10Z6Y10Z6CR10_422_NV)
 OGL_CONST_i(GL_ZERO)
 OGL_CONST_i(GL_ZERO_EXT)
 OGL_CONST_i(GL_ZERO_TO_ONE)
 OGL_CONST_i(GL_ZERO_TO_ONE_EXT)
 OGL_CONST_i(GL_ZOOM_X)
 OGL_CONST_i(GL_ZOOM_Y)
 OGL_CONST_i(GL_Z_EXT)
