char *
enum2name(g, e)
  char *g;
  GLenum e;
CODE:
  RETVAL = NULL;
  if (!strcmp(g, "AccumOp")) {
    switch (e) {
      case GL_ACCUM: RETVAL = "GL_ACCUM"; break;
      case GL_ADD: RETVAL = "GL_ADD"; break;
      case GL_LOAD: RETVAL = "GL_LOAD"; break;
      case GL_MULT: RETVAL = "GL_MULT"; break;
      case GL_RETURN: RETVAL = "GL_RETURN"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "AlphaFunction")) {
    switch (e) {
      case GL_ALWAYS: RETVAL = "GL_ALWAYS"; break;
      case GL_EQUAL: RETVAL = "GL_EQUAL"; break;
      case GL_GEQUAL: RETVAL = "GL_GEQUAL"; break;
      case GL_GREATER: RETVAL = "GL_GREATER"; break;
      case GL_LEQUAL: RETVAL = "GL_LEQUAL"; break;
      case GL_LESS: RETVAL = "GL_LESS"; break;
      case GL_NEVER: RETVAL = "GL_NEVER"; break;
      case GL_NOTEQUAL: RETVAL = "GL_NOTEQUAL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ArrayObjectPNameATI")) {
    switch (e) {
      case GL_OBJECT_BUFFER_SIZE_ATI: RETVAL = "GL_OBJECT_BUFFER_SIZE_ATI"; break;
      case GL_OBJECT_BUFFER_USAGE_ATI: RETVAL = "GL_OBJECT_BUFFER_USAGE_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ArrayObjectUsageATI")) {
    switch (e) {
      case GL_DYNAMIC_ATI: RETVAL = "GL_DYNAMIC_ATI"; break;
      case GL_STATIC_ATI: RETVAL = "GL_STATIC_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "AtomicCounterBufferPName")) {
    switch (e) {
      case GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS"; break;
      case GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES"; break;
      case GL_ATOMIC_COUNTER_BUFFER_BINDING: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_BINDING"; break;
      case GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_COMPUTE_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_COMPUTE_SHADER"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER"; break;
      case GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "AttribMask")) {
    switch (e) {
      case GL_ACCUM_BUFFER_BIT: RETVAL = "GL_ACCUM_BUFFER_BIT"; break;
      case GL_ALL_ATTRIB_BITS: RETVAL = "GL_ALL_ATTRIB_BITS"; break;
      case GL_COLOR_BUFFER_BIT: RETVAL = "GL_COLOR_BUFFER_BIT"; break;
      case GL_CURRENT_BIT: RETVAL = "GL_CURRENT_BIT"; break;
      case GL_DEPTH_BUFFER_BIT: RETVAL = "GL_DEPTH_BUFFER_BIT"; break;
      case GL_ENABLE_BIT: RETVAL = "GL_ENABLE_BIT"; break;
      case GL_EVAL_BIT: RETVAL = "GL_EVAL_BIT"; break;
      case GL_FOG_BIT: RETVAL = "GL_FOG_BIT"; break;
      case GL_HINT_BIT: RETVAL = "GL_HINT_BIT"; break;
      case GL_LIGHTING_BIT: RETVAL = "GL_LIGHTING_BIT"; break;
      case GL_LINE_BIT: RETVAL = "GL_LINE_BIT"; break;
      case GL_LIST_BIT: RETVAL = "GL_LIST_BIT"; break;
      case GL_MULTISAMPLE_BIT: RETVAL = "GL_MULTISAMPLE_BIT"; break;
      case GL_PIXEL_MODE_BIT: RETVAL = "GL_PIXEL_MODE_BIT"; break;
      case GL_POINT_BIT: RETVAL = "GL_POINT_BIT"; break;
      case GL_POLYGON_BIT: RETVAL = "GL_POLYGON_BIT"; break;
      case GL_POLYGON_STIPPLE_BIT: RETVAL = "GL_POLYGON_STIPPLE_BIT"; break;
      case GL_SCISSOR_BIT: RETVAL = "GL_SCISSOR_BIT"; break;
      case GL_STENCIL_BUFFER_BIT: RETVAL = "GL_STENCIL_BUFFER_BIT"; break;
      case GL_TEXTURE_BIT: RETVAL = "GL_TEXTURE_BIT"; break;
      case GL_TRANSFORM_BIT: RETVAL = "GL_TRANSFORM_BIT"; break;
      case GL_VIEWPORT_BIT: RETVAL = "GL_VIEWPORT_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "AttributeType")) {
    switch (e) {
      case GL_BOOL: RETVAL = "GL_BOOL"; break;
      case GL_BOOL_VEC2: RETVAL = "GL_BOOL_VEC2"; break;
      case GL_BOOL_VEC3: RETVAL = "GL_BOOL_VEC3"; break;
      case GL_BOOL_VEC4: RETVAL = "GL_BOOL_VEC4"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_DOUBLE_MAT2: RETVAL = "GL_DOUBLE_MAT2"; break;
      case GL_DOUBLE_MAT2x3: RETVAL = "GL_DOUBLE_MAT2x3"; break;
      case GL_DOUBLE_MAT2x4: RETVAL = "GL_DOUBLE_MAT2x4"; break;
      case GL_DOUBLE_MAT3: RETVAL = "GL_DOUBLE_MAT3"; break;
      case GL_DOUBLE_MAT3x2: RETVAL = "GL_DOUBLE_MAT3x2"; break;
      case GL_DOUBLE_MAT3x4: RETVAL = "GL_DOUBLE_MAT3x4"; break;
      case GL_DOUBLE_MAT4: RETVAL = "GL_DOUBLE_MAT4"; break;
      case GL_DOUBLE_MAT4x2: RETVAL = "GL_DOUBLE_MAT4x2"; break;
      case GL_DOUBLE_MAT4x3: RETVAL = "GL_DOUBLE_MAT4x3"; break;
      case GL_DOUBLE_VEC2: RETVAL = "GL_DOUBLE_VEC2"; break;
      case GL_DOUBLE_VEC3: RETVAL = "GL_DOUBLE_VEC3"; break;
      case GL_DOUBLE_VEC4: RETVAL = "GL_DOUBLE_VEC4"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_FLOAT_MAT2: RETVAL = "GL_FLOAT_MAT2"; break;
      case GL_FLOAT_MAT2x3: RETVAL = "GL_FLOAT_MAT2x3"; break;
      case GL_FLOAT_MAT2x4: RETVAL = "GL_FLOAT_MAT2x4"; break;
      case GL_FLOAT_MAT3: RETVAL = "GL_FLOAT_MAT3"; break;
      case GL_FLOAT_MAT3x2: RETVAL = "GL_FLOAT_MAT3x2"; break;
      case GL_FLOAT_MAT3x4: RETVAL = "GL_FLOAT_MAT3x4"; break;
      case GL_FLOAT_MAT4: RETVAL = "GL_FLOAT_MAT4"; break;
      case GL_FLOAT_MAT4x2: RETVAL = "GL_FLOAT_MAT4x2"; break;
      case GL_FLOAT_MAT4x3: RETVAL = "GL_FLOAT_MAT4x3"; break;
      case GL_FLOAT_VEC2: RETVAL = "GL_FLOAT_VEC2"; break;
      case GL_FLOAT_VEC3: RETVAL = "GL_FLOAT_VEC3"; break;
      case GL_FLOAT_VEC4: RETVAL = "GL_FLOAT_VEC4"; break;
      case GL_IMAGE_1D: RETVAL = "GL_IMAGE_1D"; break;
      case GL_IMAGE_1D_ARRAY: RETVAL = "GL_IMAGE_1D_ARRAY"; break;
      case GL_IMAGE_2D: RETVAL = "GL_IMAGE_2D"; break;
      case GL_IMAGE_2D_ARRAY: RETVAL = "GL_IMAGE_2D_ARRAY"; break;
      case GL_IMAGE_2D_MULTISAMPLE: RETVAL = "GL_IMAGE_2D_MULTISAMPLE"; break;
      case GL_IMAGE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_IMAGE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_IMAGE_2D_RECT: RETVAL = "GL_IMAGE_2D_RECT"; break;
      case GL_IMAGE_3D: RETVAL = "GL_IMAGE_3D"; break;
      case GL_IMAGE_BUFFER: RETVAL = "GL_IMAGE_BUFFER"; break;
      case GL_IMAGE_CUBE: RETVAL = "GL_IMAGE_CUBE"; break;
      case GL_IMAGE_CUBE_MAP_ARRAY: RETVAL = "GL_IMAGE_CUBE_MAP_ARRAY"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_INT64_NV: RETVAL = "GL_INT64_NV"; break;
      case GL_INT64_VEC2_ARB: RETVAL = "GL_INT64_VEC2_ARB"; break;
      case GL_INT64_VEC3_ARB: RETVAL = "GL_INT64_VEC3_ARB"; break;
      case GL_INT64_VEC4_ARB: RETVAL = "GL_INT64_VEC4_ARB"; break;
      case GL_INT_IMAGE_1D: RETVAL = "GL_INT_IMAGE_1D"; break;
      case GL_INT_IMAGE_1D_ARRAY: RETVAL = "GL_INT_IMAGE_1D_ARRAY"; break;
      case GL_INT_IMAGE_2D: RETVAL = "GL_INT_IMAGE_2D"; break;
      case GL_INT_IMAGE_2D_ARRAY: RETVAL = "GL_INT_IMAGE_2D_ARRAY"; break;
      case GL_INT_IMAGE_2D_MULTISAMPLE: RETVAL = "GL_INT_IMAGE_2D_MULTISAMPLE"; break;
      case GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_INT_IMAGE_2D_RECT: RETVAL = "GL_INT_IMAGE_2D_RECT"; break;
      case GL_INT_IMAGE_3D: RETVAL = "GL_INT_IMAGE_3D"; break;
      case GL_INT_IMAGE_BUFFER: RETVAL = "GL_INT_IMAGE_BUFFER"; break;
      case GL_INT_IMAGE_CUBE: RETVAL = "GL_INT_IMAGE_CUBE"; break;
      case GL_INT_IMAGE_CUBE_MAP_ARRAY: RETVAL = "GL_INT_IMAGE_CUBE_MAP_ARRAY"; break;
      case GL_INT_SAMPLER_1D: RETVAL = "GL_INT_SAMPLER_1D"; break;
      case GL_INT_SAMPLER_1D_ARRAY: RETVAL = "GL_INT_SAMPLER_1D_ARRAY"; break;
      case GL_INT_SAMPLER_2D: RETVAL = "GL_INT_SAMPLER_2D"; break;
      case GL_INT_SAMPLER_2D_ARRAY: RETVAL = "GL_INT_SAMPLER_2D_ARRAY"; break;
      case GL_INT_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_INT_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_INT_SAMPLER_2D_RECT: RETVAL = "GL_INT_SAMPLER_2D_RECT"; break;
      case GL_INT_SAMPLER_3D: RETVAL = "GL_INT_SAMPLER_3D"; break;
      case GL_INT_SAMPLER_BUFFER: RETVAL = "GL_INT_SAMPLER_BUFFER"; break;
      case GL_INT_SAMPLER_CUBE: RETVAL = "GL_INT_SAMPLER_CUBE"; break;
      case GL_INT_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_INT_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_INT_VEC2: RETVAL = "GL_INT_VEC2"; break;
      case GL_INT_VEC3: RETVAL = "GL_INT_VEC3"; break;
      case GL_INT_VEC4: RETVAL = "GL_INT_VEC4"; break;
      case GL_SAMPLER_1D: RETVAL = "GL_SAMPLER_1D"; break;
      case GL_SAMPLER_1D_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_1D_ARRAY_SHADOW"; break;
      case GL_SAMPLER_1D_SHADOW: RETVAL = "GL_SAMPLER_1D_SHADOW"; break;
      case GL_SAMPLER_2D: RETVAL = "GL_SAMPLER_2D"; break;
      case GL_SAMPLER_2D_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_2D_ARRAY_SHADOW"; break;
      case GL_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_SAMPLER_2D_RECT: RETVAL = "GL_SAMPLER_2D_RECT"; break;
      case GL_SAMPLER_2D_RECT_SHADOW: RETVAL = "GL_SAMPLER_2D_RECT_SHADOW"; break;
      case GL_SAMPLER_2D_SHADOW: RETVAL = "GL_SAMPLER_2D_SHADOW"; break;
      case GL_SAMPLER_3D: RETVAL = "GL_SAMPLER_3D"; break;
      case GL_SAMPLER_BUFFER: RETVAL = "GL_SAMPLER_BUFFER"; break;
      case GL_SAMPLER_CUBE: RETVAL = "GL_SAMPLER_CUBE"; break;
      case GL_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW"; break;
      case GL_SAMPLER_CUBE_SHADOW: RETVAL = "GL_SAMPLER_CUBE_SHADOW"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_INT64_NV: RETVAL = "GL_UNSIGNED_INT64_NV"; break;
      case GL_UNSIGNED_INT64_VEC2_ARB: RETVAL = "GL_UNSIGNED_INT64_VEC2_ARB"; break;
      case GL_UNSIGNED_INT64_VEC3_ARB: RETVAL = "GL_UNSIGNED_INT64_VEC3_ARB"; break;
      case GL_UNSIGNED_INT64_VEC4_ARB: RETVAL = "GL_UNSIGNED_INT64_VEC4_ARB"; break;
      case GL_UNSIGNED_INT_IMAGE_1D: RETVAL = "GL_UNSIGNED_INT_IMAGE_1D"; break;
      case GL_UNSIGNED_INT_IMAGE_1D_ARRAY: RETVAL = "GL_UNSIGNED_INT_IMAGE_1D_ARRAY"; break;
      case GL_UNSIGNED_INT_IMAGE_2D: RETVAL = "GL_UNSIGNED_INT_IMAGE_2D"; break;
      case GL_UNSIGNED_INT_IMAGE_2D_ARRAY: RETVAL = "GL_UNSIGNED_INT_IMAGE_2D_ARRAY"; break;
      case GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE: RETVAL = "GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE"; break;
      case GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_UNSIGNED_INT_IMAGE_2D_RECT: RETVAL = "GL_UNSIGNED_INT_IMAGE_2D_RECT"; break;
      case GL_UNSIGNED_INT_IMAGE_3D: RETVAL = "GL_UNSIGNED_INT_IMAGE_3D"; break;
      case GL_UNSIGNED_INT_IMAGE_BUFFER: RETVAL = "GL_UNSIGNED_INT_IMAGE_BUFFER"; break;
      case GL_UNSIGNED_INT_IMAGE_CUBE: RETVAL = "GL_UNSIGNED_INT_IMAGE_CUBE"; break;
      case GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY: RETVAL = "GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_1D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_1D"; break;
      case GL_UNSIGNED_INT_SAMPLER_1D_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_1D_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_RECT: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_RECT"; break;
      case GL_UNSIGNED_INT_SAMPLER_3D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_3D"; break;
      case GL_UNSIGNED_INT_SAMPLER_BUFFER: RETVAL = "GL_UNSIGNED_INT_SAMPLER_BUFFER"; break;
      case GL_UNSIGNED_INT_SAMPLER_CUBE: RETVAL = "GL_UNSIGNED_INT_SAMPLER_CUBE"; break;
      case GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_UNSIGNED_INT_VEC2: RETVAL = "GL_UNSIGNED_INT_VEC2"; break;
      case GL_UNSIGNED_INT_VEC3: RETVAL = "GL_UNSIGNED_INT_VEC3"; break;
      case GL_UNSIGNED_INT_VEC4: RETVAL = "GL_UNSIGNED_INT_VEC4"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BindTransformFeedbackTarget")) {
    switch (e) {
      case GL_TRANSFORM_FEEDBACK: RETVAL = "GL_TRANSFORM_FEEDBACK"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BinormalPointerTypeEXT")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BlendEquationModeEXT")) {
    switch (e) {
      case GL_ALPHA_MAX_SGIX: RETVAL = "GL_ALPHA_MAX_SGIX"; break;
      case GL_ALPHA_MIN_SGIX: RETVAL = "GL_ALPHA_MIN_SGIX"; break;
      case GL_FUNC_ADD: RETVAL = "GL_FUNC_ADD"; break;
      case GL_FUNC_REVERSE_SUBTRACT: RETVAL = "GL_FUNC_REVERSE_SUBTRACT"; break;
      case GL_FUNC_SUBTRACT: RETVAL = "GL_FUNC_SUBTRACT"; break;
      case GL_MAX: RETVAL = "GL_MAX"; break;
      case GL_MIN: RETVAL = "GL_MIN"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BlendingFactor")) {
    switch (e) {
      case GL_CONSTANT_ALPHA: RETVAL = "GL_CONSTANT_ALPHA"; break;
      case GL_CONSTANT_COLOR: RETVAL = "GL_CONSTANT_COLOR"; break;
      case GL_DST_ALPHA: RETVAL = "GL_DST_ALPHA"; break;
      case GL_DST_COLOR: RETVAL = "GL_DST_COLOR"; break;
      case GL_ONE: RETVAL = "GL_ONE"; break;
      case GL_ONE_MINUS_CONSTANT_ALPHA: RETVAL = "GL_ONE_MINUS_CONSTANT_ALPHA"; break;
      case GL_ONE_MINUS_CONSTANT_COLOR: RETVAL = "GL_ONE_MINUS_CONSTANT_COLOR"; break;
      case GL_ONE_MINUS_DST_ALPHA: RETVAL = "GL_ONE_MINUS_DST_ALPHA"; break;
      case GL_ONE_MINUS_DST_COLOR: RETVAL = "GL_ONE_MINUS_DST_COLOR"; break;
      case GL_ONE_MINUS_SRC1_ALPHA: RETVAL = "GL_ONE_MINUS_SRC1_ALPHA"; break;
      case GL_ONE_MINUS_SRC1_COLOR: RETVAL = "GL_ONE_MINUS_SRC1_COLOR"; break;
      case GL_ONE_MINUS_SRC_ALPHA: RETVAL = "GL_ONE_MINUS_SRC_ALPHA"; break;
      case GL_ONE_MINUS_SRC_COLOR: RETVAL = "GL_ONE_MINUS_SRC_COLOR"; break;
      case GL_SRC1_ALPHA: RETVAL = "GL_SRC1_ALPHA"; break;
      case GL_SRC1_COLOR: RETVAL = "GL_SRC1_COLOR"; break;
      case GL_SRC_ALPHA: RETVAL = "GL_SRC_ALPHA"; break;
      case GL_SRC_ALPHA_SATURATE: RETVAL = "GL_SRC_ALPHA_SATURATE"; break;
      case GL_SRC_COLOR: RETVAL = "GL_SRC_COLOR"; break;
      case GL_ZERO: RETVAL = "GL_ZERO"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BlitFramebufferFilter")) {
    switch (e) {
      case GL_LINEAR: RETVAL = "GL_LINEAR"; break;
      case GL_NEAREST: RETVAL = "GL_NEAREST"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "Boolean")) {
    switch (e) {
      case GL_FALSE: RETVAL = "GL_FALSE"; break;
      case GL_TRUE: RETVAL = "GL_TRUE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "Buffer")) {
    switch (e) {
      case GL_COLOR: RETVAL = "GL_COLOR"; break;
      case GL_DEPTH: RETVAL = "GL_DEPTH"; break;
      case GL_STENCIL: RETVAL = "GL_STENCIL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferAccessARB")) {
    switch (e) {
      case GL_READ_ONLY: RETVAL = "GL_READ_ONLY"; break;
      case GL_READ_WRITE: RETVAL = "GL_READ_WRITE"; break;
      case GL_WRITE_ONLY: RETVAL = "GL_WRITE_ONLY"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferBitQCOM")) {
    switch (e) {
      case GL_COLOR_BUFFER_BIT0_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT0_QCOM"; break;
      case GL_COLOR_BUFFER_BIT1_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT1_QCOM"; break;
      case GL_COLOR_BUFFER_BIT2_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT2_QCOM"; break;
      case GL_COLOR_BUFFER_BIT3_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT3_QCOM"; break;
      case GL_COLOR_BUFFER_BIT4_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT4_QCOM"; break;
      case GL_COLOR_BUFFER_BIT5_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT5_QCOM"; break;
      case GL_COLOR_BUFFER_BIT6_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT6_QCOM"; break;
      case GL_COLOR_BUFFER_BIT7_QCOM: RETVAL = "GL_COLOR_BUFFER_BIT7_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT0_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT0_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT1_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT1_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT2_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT2_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT3_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT3_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT4_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT4_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT5_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT5_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT6_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT6_QCOM"; break;
      case GL_DEPTH_BUFFER_BIT7_QCOM: RETVAL = "GL_DEPTH_BUFFER_BIT7_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT0_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT0_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT1_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT1_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT2_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT2_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT3_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT3_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT4_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT4_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT5_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT5_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT6_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT6_QCOM"; break;
      case GL_MULTISAMPLE_BUFFER_BIT7_QCOM: RETVAL = "GL_MULTISAMPLE_BUFFER_BIT7_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT0_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT0_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT1_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT1_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT2_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT2_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT3_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT3_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT4_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT4_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT5_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT5_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT6_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT6_QCOM"; break;
      case GL_STENCIL_BUFFER_BIT7_QCOM: RETVAL = "GL_STENCIL_BUFFER_BIT7_QCOM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferPNameARB")) {
    switch (e) {
      case GL_BUFFER_ACCESS: RETVAL = "GL_BUFFER_ACCESS"; break;
      case GL_BUFFER_ACCESS_FLAGS: RETVAL = "GL_BUFFER_ACCESS_FLAGS"; break;
      case GL_BUFFER_IMMUTABLE_STORAGE: RETVAL = "GL_BUFFER_IMMUTABLE_STORAGE"; break;
      case GL_BUFFER_MAPPED: RETVAL = "GL_BUFFER_MAPPED"; break;
      case GL_BUFFER_MAP_LENGTH: RETVAL = "GL_BUFFER_MAP_LENGTH"; break;
      case GL_BUFFER_MAP_OFFSET: RETVAL = "GL_BUFFER_MAP_OFFSET"; break;
      case GL_BUFFER_SIZE: RETVAL = "GL_BUFFER_SIZE"; break;
      case GL_BUFFER_STORAGE_FLAGS: RETVAL = "GL_BUFFER_STORAGE_FLAGS"; break;
      case GL_BUFFER_USAGE: RETVAL = "GL_BUFFER_USAGE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferPointerNameARB")) {
    switch (e) {
      case GL_BUFFER_MAP_POINTER: RETVAL = "GL_BUFFER_MAP_POINTER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferStorageMask")) {
    switch (e) {
      case GL_CLIENT_STORAGE_BIT: RETVAL = "GL_CLIENT_STORAGE_BIT"; break;
      case GL_DYNAMIC_STORAGE_BIT: RETVAL = "GL_DYNAMIC_STORAGE_BIT"; break;
      case GL_MAP_COHERENT_BIT: RETVAL = "GL_MAP_COHERENT_BIT"; break;
      case GL_MAP_PERSISTENT_BIT: RETVAL = "GL_MAP_PERSISTENT_BIT"; break;
      case GL_MAP_READ_BIT: RETVAL = "GL_MAP_READ_BIT"; break;
      case GL_MAP_WRITE_BIT: RETVAL = "GL_MAP_WRITE_BIT"; break;
      case GL_PER_GPU_STORAGE_BIT_NV: RETVAL = "GL_PER_GPU_STORAGE_BIT_NV"; break;
      case GL_SPARSE_STORAGE_BIT_ARB: RETVAL = "GL_SPARSE_STORAGE_BIT_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferStorageTarget")) {
    switch (e) {
      case GL_ARRAY_BUFFER: RETVAL = "GL_ARRAY_BUFFER"; break;
      case GL_ATOMIC_COUNTER_BUFFER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER"; break;
      case GL_COPY_READ_BUFFER: RETVAL = "GL_COPY_READ_BUFFER"; break;
      case GL_COPY_WRITE_BUFFER: RETVAL = "GL_COPY_WRITE_BUFFER"; break;
      case GL_DISPATCH_INDIRECT_BUFFER: RETVAL = "GL_DISPATCH_INDIRECT_BUFFER"; break;
      case GL_DRAW_INDIRECT_BUFFER: RETVAL = "GL_DRAW_INDIRECT_BUFFER"; break;
      case GL_ELEMENT_ARRAY_BUFFER: RETVAL = "GL_ELEMENT_ARRAY_BUFFER"; break;
      case GL_PIXEL_PACK_BUFFER: RETVAL = "GL_PIXEL_PACK_BUFFER"; break;
      case GL_PIXEL_UNPACK_BUFFER: RETVAL = "GL_PIXEL_UNPACK_BUFFER"; break;
      case GL_QUERY_BUFFER: RETVAL = "GL_QUERY_BUFFER"; break;
      case GL_SHADER_STORAGE_BUFFER: RETVAL = "GL_SHADER_STORAGE_BUFFER"; break;
      case GL_TEXTURE_BUFFER: RETVAL = "GL_TEXTURE_BUFFER"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER"; break;
      case GL_UNIFORM_BUFFER: RETVAL = "GL_UNIFORM_BUFFER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferTargetARB")) {
    switch (e) {
      case GL_ARRAY_BUFFER: RETVAL = "GL_ARRAY_BUFFER"; break;
      case GL_ATOMIC_COUNTER_BUFFER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER"; break;
      case GL_COPY_READ_BUFFER: RETVAL = "GL_COPY_READ_BUFFER"; break;
      case GL_COPY_WRITE_BUFFER: RETVAL = "GL_COPY_WRITE_BUFFER"; break;
      case GL_DISPATCH_INDIRECT_BUFFER: RETVAL = "GL_DISPATCH_INDIRECT_BUFFER"; break;
      case GL_DRAW_INDIRECT_BUFFER: RETVAL = "GL_DRAW_INDIRECT_BUFFER"; break;
      case GL_ELEMENT_ARRAY_BUFFER: RETVAL = "GL_ELEMENT_ARRAY_BUFFER"; break;
      case GL_PARAMETER_BUFFER: RETVAL = "GL_PARAMETER_BUFFER"; break;
      case GL_PIXEL_PACK_BUFFER: RETVAL = "GL_PIXEL_PACK_BUFFER"; break;
      case GL_PIXEL_UNPACK_BUFFER: RETVAL = "GL_PIXEL_UNPACK_BUFFER"; break;
      case GL_QUERY_BUFFER: RETVAL = "GL_QUERY_BUFFER"; break;
      case GL_SHADER_STORAGE_BUFFER: RETVAL = "GL_SHADER_STORAGE_BUFFER"; break;
      case GL_TEXTURE_BUFFER: RETVAL = "GL_TEXTURE_BUFFER"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER"; break;
      case GL_UNIFORM_BUFFER: RETVAL = "GL_UNIFORM_BUFFER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "BufferUsageARB")) {
    switch (e) {
      case GL_DYNAMIC_COPY: RETVAL = "GL_DYNAMIC_COPY"; break;
      case GL_DYNAMIC_DRAW: RETVAL = "GL_DYNAMIC_DRAW"; break;
      case GL_DYNAMIC_READ: RETVAL = "GL_DYNAMIC_READ"; break;
      case GL_STATIC_COPY: RETVAL = "GL_STATIC_COPY"; break;
      case GL_STATIC_DRAW: RETVAL = "GL_STATIC_DRAW"; break;
      case GL_STATIC_READ: RETVAL = "GL_STATIC_READ"; break;
      case GL_STREAM_COPY: RETVAL = "GL_STREAM_COPY"; break;
      case GL_STREAM_DRAW: RETVAL = "GL_STREAM_DRAW"; break;
      case GL_STREAM_READ: RETVAL = "GL_STREAM_READ"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClampColorModeARB")) {
    switch (e) {
      case GL_FALSE: RETVAL = "GL_FALSE"; break;
      case GL_FIXED_ONLY: RETVAL = "GL_FIXED_ONLY"; break;
      case GL_TRUE: RETVAL = "GL_TRUE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClampColorTargetARB")) {
    switch (e) {
      case GL_CLAMP_FRAGMENT_COLOR_ARB: RETVAL = "GL_CLAMP_FRAGMENT_COLOR_ARB"; break;
      case GL_CLAMP_READ_COLOR: RETVAL = "GL_CLAMP_READ_COLOR"; break;
      case GL_CLAMP_VERTEX_COLOR_ARB: RETVAL = "GL_CLAMP_VERTEX_COLOR_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClearBufferMask")) {
    switch (e) {
      case GL_ACCUM_BUFFER_BIT: RETVAL = "GL_ACCUM_BUFFER_BIT"; break;
      case GL_COLOR_BUFFER_BIT: RETVAL = "GL_COLOR_BUFFER_BIT"; break;
      case GL_DEPTH_BUFFER_BIT: RETVAL = "GL_DEPTH_BUFFER_BIT"; break;
      case GL_STENCIL_BUFFER_BIT: RETVAL = "GL_STENCIL_BUFFER_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClientAttribMask")) {
    switch (e) {
      case GL_CLIENT_ALL_ATTRIB_BITS: RETVAL = "GL_CLIENT_ALL_ATTRIB_BITS"; break;
      case GL_CLIENT_PIXEL_STORE_BIT: RETVAL = "GL_CLIENT_PIXEL_STORE_BIT"; break;
      case GL_CLIENT_VERTEX_ARRAY_BIT: RETVAL = "GL_CLIENT_VERTEX_ARRAY_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClipControlDepth")) {
    switch (e) {
      case GL_NEGATIVE_ONE_TO_ONE: RETVAL = "GL_NEGATIVE_ONE_TO_ONE"; break;
      case GL_ZERO_TO_ONE: RETVAL = "GL_ZERO_TO_ONE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClipControlOrigin")) {
    switch (e) {
      case GL_LOWER_LEFT: RETVAL = "GL_LOWER_LEFT"; break;
      case GL_UPPER_LEFT: RETVAL = "GL_UPPER_LEFT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ClipPlaneName")) {
    switch (e) {
      case GL_CLIP_PLANE0: RETVAL = "GL_CLIP_PLANE0"; break;
      case GL_CLIP_PLANE1: RETVAL = "GL_CLIP_PLANE1"; break;
      case GL_CLIP_PLANE2: RETVAL = "GL_CLIP_PLANE2"; break;
      case GL_CLIP_PLANE3: RETVAL = "GL_CLIP_PLANE3"; break;
      case GL_CLIP_PLANE4: RETVAL = "GL_CLIP_PLANE4"; break;
      case GL_CLIP_PLANE5: RETVAL = "GL_CLIP_PLANE5"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorBuffer")) {
    switch (e) {
      case GL_BACK: RETVAL = "GL_BACK"; break;
      case GL_BACK_LEFT: RETVAL = "GL_BACK_LEFT"; break;
      case GL_BACK_RIGHT: RETVAL = "GL_BACK_RIGHT"; break;
      case GL_COLOR_ATTACHMENT0: RETVAL = "GL_COLOR_ATTACHMENT0"; break;
      case GL_COLOR_ATTACHMENT1: RETVAL = "GL_COLOR_ATTACHMENT1"; break;
      case GL_COLOR_ATTACHMENT10: RETVAL = "GL_COLOR_ATTACHMENT10"; break;
      case GL_COLOR_ATTACHMENT11: RETVAL = "GL_COLOR_ATTACHMENT11"; break;
      case GL_COLOR_ATTACHMENT12: RETVAL = "GL_COLOR_ATTACHMENT12"; break;
      case GL_COLOR_ATTACHMENT13: RETVAL = "GL_COLOR_ATTACHMENT13"; break;
      case GL_COLOR_ATTACHMENT14: RETVAL = "GL_COLOR_ATTACHMENT14"; break;
      case GL_COLOR_ATTACHMENT15: RETVAL = "GL_COLOR_ATTACHMENT15"; break;
      case GL_COLOR_ATTACHMENT2: RETVAL = "GL_COLOR_ATTACHMENT2"; break;
      case GL_COLOR_ATTACHMENT3: RETVAL = "GL_COLOR_ATTACHMENT3"; break;
      case GL_COLOR_ATTACHMENT4: RETVAL = "GL_COLOR_ATTACHMENT4"; break;
      case GL_COLOR_ATTACHMENT5: RETVAL = "GL_COLOR_ATTACHMENT5"; break;
      case GL_COLOR_ATTACHMENT6: RETVAL = "GL_COLOR_ATTACHMENT6"; break;
      case GL_COLOR_ATTACHMENT7: RETVAL = "GL_COLOR_ATTACHMENT7"; break;
      case GL_COLOR_ATTACHMENT8: RETVAL = "GL_COLOR_ATTACHMENT8"; break;
      case GL_COLOR_ATTACHMENT9: RETVAL = "GL_COLOR_ATTACHMENT9"; break;
      case GL_FRONT: RETVAL = "GL_FRONT"; break;
      case GL_FRONT_AND_BACK: RETVAL = "GL_FRONT_AND_BACK"; break;
      case GL_FRONT_LEFT: RETVAL = "GL_FRONT_LEFT"; break;
      case GL_FRONT_RIGHT: RETVAL = "GL_FRONT_RIGHT"; break;
      case GL_LEFT: RETVAL = "GL_LEFT"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RIGHT: RETVAL = "GL_RIGHT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorMaterialParameter")) {
    switch (e) {
      case GL_AMBIENT: RETVAL = "GL_AMBIENT"; break;
      case GL_AMBIENT_AND_DIFFUSE: RETVAL = "GL_AMBIENT_AND_DIFFUSE"; break;
      case GL_DIFFUSE: RETVAL = "GL_DIFFUSE"; break;
      case GL_EMISSION: RETVAL = "GL_EMISSION"; break;
      case GL_SPECULAR: RETVAL = "GL_SPECULAR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorPointerType")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorTableParameterPName")) {
    switch (e) {
      case GL_COLOR_TABLE_ALPHA_SIZE: RETVAL = "GL_COLOR_TABLE_ALPHA_SIZE"; break;
      case GL_COLOR_TABLE_BIAS: RETVAL = "GL_COLOR_TABLE_BIAS"; break;
      case GL_COLOR_TABLE_BLUE_SIZE: RETVAL = "GL_COLOR_TABLE_BLUE_SIZE"; break;
      case GL_COLOR_TABLE_FORMAT: RETVAL = "GL_COLOR_TABLE_FORMAT"; break;
      case GL_COLOR_TABLE_GREEN_SIZE: RETVAL = "GL_COLOR_TABLE_GREEN_SIZE"; break;
      case GL_COLOR_TABLE_INTENSITY_SIZE: RETVAL = "GL_COLOR_TABLE_INTENSITY_SIZE"; break;
      case GL_COLOR_TABLE_LUMINANCE_SIZE: RETVAL = "GL_COLOR_TABLE_LUMINANCE_SIZE"; break;
      case GL_COLOR_TABLE_RED_SIZE: RETVAL = "GL_COLOR_TABLE_RED_SIZE"; break;
      case GL_COLOR_TABLE_SCALE: RETVAL = "GL_COLOR_TABLE_SCALE"; break;
      case GL_COLOR_TABLE_WIDTH: RETVAL = "GL_COLOR_TABLE_WIDTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorTableTarget")) {
    switch (e) {
      case GL_COLOR_TABLE: RETVAL = "GL_COLOR_TABLE"; break;
      case GL_POST_COLOR_MATRIX_COLOR_TABLE: RETVAL = "GL_POST_COLOR_MATRIX_COLOR_TABLE"; break;
      case GL_POST_CONVOLUTION_COLOR_TABLE: RETVAL = "GL_POST_CONVOLUTION_COLOR_TABLE"; break;
      case GL_PROXY_COLOR_TABLE: RETVAL = "GL_PROXY_COLOR_TABLE"; break;
      case GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE: RETVAL = "GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE"; break;
      case GL_PROXY_POST_CONVOLUTION_COLOR_TABLE: RETVAL = "GL_PROXY_POST_CONVOLUTION_COLOR_TABLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ColorTableTargetSGI")) {
    switch (e) {
      case GL_COLOR_TABLE: RETVAL = "GL_COLOR_TABLE"; break;
      case GL_POST_COLOR_MATRIX_COLOR_TABLE: RETVAL = "GL_POST_COLOR_MATRIX_COLOR_TABLE"; break;
      case GL_POST_CONVOLUTION_COLOR_TABLE: RETVAL = "GL_POST_CONVOLUTION_COLOR_TABLE"; break;
      case GL_PROXY_COLOR_TABLE: RETVAL = "GL_PROXY_COLOR_TABLE"; break;
      case GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE: RETVAL = "GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE"; break;
      case GL_PROXY_POST_CONVOLUTION_COLOR_TABLE: RETVAL = "GL_PROXY_POST_CONVOLUTION_COLOR_TABLE"; break;
      case GL_PROXY_TEXTURE_COLOR_TABLE_SGI: RETVAL = "GL_PROXY_TEXTURE_COLOR_TABLE_SGI"; break;
      case GL_TEXTURE_COLOR_TABLE_SGI: RETVAL = "GL_TEXTURE_COLOR_TABLE_SGI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerBiasNV")) {
    switch (e) {
      case GL_BIAS_BY_NEGATIVE_ONE_HALF_NV: RETVAL = "GL_BIAS_BY_NEGATIVE_ONE_HALF_NV"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerComponentUsageNV")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_BLUE: RETVAL = "GL_BLUE"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerMappingNV")) {
    switch (e) {
      case GL_EXPAND_NEGATE_NV: RETVAL = "GL_EXPAND_NEGATE_NV"; break;
      case GL_EXPAND_NORMAL_NV: RETVAL = "GL_EXPAND_NORMAL_NV"; break;
      case GL_HALF_BIAS_NEGATE_NV: RETVAL = "GL_HALF_BIAS_NEGATE_NV"; break;
      case GL_HALF_BIAS_NORMAL_NV: RETVAL = "GL_HALF_BIAS_NORMAL_NV"; break;
      case GL_SIGNED_IDENTITY_NV: RETVAL = "GL_SIGNED_IDENTITY_NV"; break;
      case GL_SIGNED_NEGATE_NV: RETVAL = "GL_SIGNED_NEGATE_NV"; break;
      case GL_UNSIGNED_IDENTITY_NV: RETVAL = "GL_UNSIGNED_IDENTITY_NV"; break;
      case GL_UNSIGNED_INVERT_NV: RETVAL = "GL_UNSIGNED_INVERT_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerParameterNV")) {
    switch (e) {
      case GL_COMBINER_COMPONENT_USAGE_NV: RETVAL = "GL_COMBINER_COMPONENT_USAGE_NV"; break;
      case GL_COMBINER_INPUT_NV: RETVAL = "GL_COMBINER_INPUT_NV"; break;
      case GL_COMBINER_MAPPING_NV: RETVAL = "GL_COMBINER_MAPPING_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerPortionNV")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerRegisterNV")) {
    switch (e) {
      case GL_DISCARD_NV: RETVAL = "GL_DISCARD_NV"; break;
      case GL_PRIMARY_COLOR_NV: RETVAL = "GL_PRIMARY_COLOR_NV"; break;
      case GL_SECONDARY_COLOR_NV: RETVAL = "GL_SECONDARY_COLOR_NV"; break;
      case GL_SPARE0_NV: RETVAL = "GL_SPARE0_NV"; break;
      case GL_SPARE1_NV: RETVAL = "GL_SPARE1_NV"; break;
      case GL_TEXTURE0_ARB: RETVAL = "GL_TEXTURE0_ARB"; break;
      case GL_TEXTURE1_ARB: RETVAL = "GL_TEXTURE1_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerScaleNV")) {
    switch (e) {
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_SCALE_BY_FOUR_NV: RETVAL = "GL_SCALE_BY_FOUR_NV"; break;
      case GL_SCALE_BY_ONE_HALF_NV: RETVAL = "GL_SCALE_BY_ONE_HALF_NV"; break;
      case GL_SCALE_BY_TWO_NV: RETVAL = "GL_SCALE_BY_TWO_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerStageNV")) {
    switch (e) {
      case GL_COMBINER0_NV: RETVAL = "GL_COMBINER0_NV"; break;
      case GL_COMBINER1_NV: RETVAL = "GL_COMBINER1_NV"; break;
      case GL_COMBINER2_NV: RETVAL = "GL_COMBINER2_NV"; break;
      case GL_COMBINER3_NV: RETVAL = "GL_COMBINER3_NV"; break;
      case GL_COMBINER4_NV: RETVAL = "GL_COMBINER4_NV"; break;
      case GL_COMBINER5_NV: RETVAL = "GL_COMBINER5_NV"; break;
      case GL_COMBINER6_NV: RETVAL = "GL_COMBINER6_NV"; break;
      case GL_COMBINER7_NV: RETVAL = "GL_COMBINER7_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CombinerVariableNV")) {
    switch (e) {
      case GL_VARIABLE_A_NV: RETVAL = "GL_VARIABLE_A_NV"; break;
      case GL_VARIABLE_B_NV: RETVAL = "GL_VARIABLE_B_NV"; break;
      case GL_VARIABLE_C_NV: RETVAL = "GL_VARIABLE_C_NV"; break;
      case GL_VARIABLE_D_NV: RETVAL = "GL_VARIABLE_D_NV"; break;
      case GL_VARIABLE_E_NV: RETVAL = "GL_VARIABLE_E_NV"; break;
      case GL_VARIABLE_F_NV: RETVAL = "GL_VARIABLE_F_NV"; break;
      case GL_VARIABLE_G_NV: RETVAL = "GL_VARIABLE_G_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CommandOpcodesNV")) {
    switch (e) {
      case GL_ALPHA_REF_COMMAND_NV: RETVAL = "GL_ALPHA_REF_COMMAND_NV"; break;
      case GL_ATTRIBUTE_ADDRESS_COMMAND_NV: RETVAL = "GL_ATTRIBUTE_ADDRESS_COMMAND_NV"; break;
      case GL_BLEND_COLOR_COMMAND_NV: RETVAL = "GL_BLEND_COLOR_COMMAND_NV"; break;
      case GL_DRAW_ARRAYS_COMMAND_NV: RETVAL = "GL_DRAW_ARRAYS_COMMAND_NV"; break;
      case GL_DRAW_ARRAYS_INSTANCED_COMMAND_NV: RETVAL = "GL_DRAW_ARRAYS_INSTANCED_COMMAND_NV"; break;
      case GL_DRAW_ARRAYS_STRIP_COMMAND_NV: RETVAL = "GL_DRAW_ARRAYS_STRIP_COMMAND_NV"; break;
      case GL_DRAW_ELEMENTS_COMMAND_NV: RETVAL = "GL_DRAW_ELEMENTS_COMMAND_NV"; break;
      case GL_DRAW_ELEMENTS_INSTANCED_COMMAND_NV: RETVAL = "GL_DRAW_ELEMENTS_INSTANCED_COMMAND_NV"; break;
      case GL_DRAW_ELEMENTS_STRIP_COMMAND_NV: RETVAL = "GL_DRAW_ELEMENTS_STRIP_COMMAND_NV"; break;
      case GL_ELEMENT_ADDRESS_COMMAND_NV: RETVAL = "GL_ELEMENT_ADDRESS_COMMAND_NV"; break;
      case GL_FRONT_FACE_COMMAND_NV: RETVAL = "GL_FRONT_FACE_COMMAND_NV"; break;
      case GL_LINE_WIDTH_COMMAND_NV: RETVAL = "GL_LINE_WIDTH_COMMAND_NV"; break;
      case GL_NOP_COMMAND_NV: RETVAL = "GL_NOP_COMMAND_NV"; break;
      case GL_POLYGON_OFFSET_COMMAND_NV: RETVAL = "GL_POLYGON_OFFSET_COMMAND_NV"; break;
      case GL_SCISSOR_COMMAND_NV: RETVAL = "GL_SCISSOR_COMMAND_NV"; break;
      case GL_STENCIL_REF_COMMAND_NV: RETVAL = "GL_STENCIL_REF_COMMAND_NV"; break;
      case GL_TERMINATE_SEQUENCE_COMMAND_NV: RETVAL = "GL_TERMINATE_SEQUENCE_COMMAND_NV"; break;
      case GL_UNIFORM_ADDRESS_COMMAND_NV: RETVAL = "GL_UNIFORM_ADDRESS_COMMAND_NV"; break;
      case GL_VIEWPORT_COMMAND_NV: RETVAL = "GL_VIEWPORT_COMMAND_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ConditionalRenderMode")) {
    switch (e) {
      case GL_QUERY_BY_REGION_NO_WAIT: RETVAL = "GL_QUERY_BY_REGION_NO_WAIT"; break;
      case GL_QUERY_BY_REGION_NO_WAIT_INVERTED: RETVAL = "GL_QUERY_BY_REGION_NO_WAIT_INVERTED"; break;
      case GL_QUERY_BY_REGION_WAIT: RETVAL = "GL_QUERY_BY_REGION_WAIT"; break;
      case GL_QUERY_BY_REGION_WAIT_INVERTED: RETVAL = "GL_QUERY_BY_REGION_WAIT_INVERTED"; break;
      case GL_QUERY_NO_WAIT: RETVAL = "GL_QUERY_NO_WAIT"; break;
      case GL_QUERY_NO_WAIT_INVERTED: RETVAL = "GL_QUERY_NO_WAIT_INVERTED"; break;
      case GL_QUERY_WAIT: RETVAL = "GL_QUERY_WAIT"; break;
      case GL_QUERY_WAIT_INVERTED: RETVAL = "GL_QUERY_WAIT_INVERTED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ContainerType")) {
    switch (e) {
      case GL_PROGRAM_OBJECT_ARB: RETVAL = "GL_PROGRAM_OBJECT_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ContextFlagMask")) {
    switch (e) {
      case GL_CONTEXT_FLAG_DEBUG_BIT: RETVAL = "GL_CONTEXT_FLAG_DEBUG_BIT"; break;
      case GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT: RETVAL = "GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT"; break;
      case GL_CONTEXT_FLAG_NO_ERROR_BIT: RETVAL = "GL_CONTEXT_FLAG_NO_ERROR_BIT"; break;
      case GL_CONTEXT_FLAG_PROTECTED_CONTENT_BIT_EXT: RETVAL = "GL_CONTEXT_FLAG_PROTECTED_CONTENT_BIT_EXT"; break;
      case GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT: RETVAL = "GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ContextProfileMask")) {
    switch (e) {
      case GL_CONTEXT_COMPATIBILITY_PROFILE_BIT: RETVAL = "GL_CONTEXT_COMPATIBILITY_PROFILE_BIT"; break;
      case GL_CONTEXT_CORE_PROFILE_BIT: RETVAL = "GL_CONTEXT_CORE_PROFILE_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ConvolutionBorderModeEXT")) {
    switch (e) {
      case GL_REDUCE: RETVAL = "GL_REDUCE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ConvolutionParameter")) {
    switch (e) {
      case GL_CONVOLUTION_BORDER_COLOR: RETVAL = "GL_CONVOLUTION_BORDER_COLOR"; break;
      case GL_CONVOLUTION_BORDER_MODE: RETVAL = "GL_CONVOLUTION_BORDER_MODE"; break;
      case GL_CONVOLUTION_FILTER_BIAS: RETVAL = "GL_CONVOLUTION_FILTER_BIAS"; break;
      case GL_CONVOLUTION_FILTER_SCALE: RETVAL = "GL_CONVOLUTION_FILTER_SCALE"; break;
      case GL_CONVOLUTION_FORMAT: RETVAL = "GL_CONVOLUTION_FORMAT"; break;
      case GL_CONVOLUTION_HEIGHT: RETVAL = "GL_CONVOLUTION_HEIGHT"; break;
      case GL_CONVOLUTION_WIDTH: RETVAL = "GL_CONVOLUTION_WIDTH"; break;
      case GL_MAX_CONVOLUTION_HEIGHT: RETVAL = "GL_MAX_CONVOLUTION_HEIGHT"; break;
      case GL_MAX_CONVOLUTION_WIDTH: RETVAL = "GL_MAX_CONVOLUTION_WIDTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ConvolutionTarget")) {
    switch (e) {
      case GL_CONVOLUTION_1D: RETVAL = "GL_CONVOLUTION_1D"; break;
      case GL_CONVOLUTION_2D: RETVAL = "GL_CONVOLUTION_2D"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ConvolutionTargetEXT")) {
    switch (e) {
      case GL_CONVOLUTION_1D: RETVAL = "GL_CONVOLUTION_1D"; break;
      case GL_CONVOLUTION_2D: RETVAL = "GL_CONVOLUTION_2D"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CopyBufferSubDataTarget")) {
    switch (e) {
      case GL_ARRAY_BUFFER: RETVAL = "GL_ARRAY_BUFFER"; break;
      case GL_ATOMIC_COUNTER_BUFFER: RETVAL = "GL_ATOMIC_COUNTER_BUFFER"; break;
      case GL_COPY_READ_BUFFER: RETVAL = "GL_COPY_READ_BUFFER"; break;
      case GL_COPY_WRITE_BUFFER: RETVAL = "GL_COPY_WRITE_BUFFER"; break;
      case GL_DISPATCH_INDIRECT_BUFFER: RETVAL = "GL_DISPATCH_INDIRECT_BUFFER"; break;
      case GL_DRAW_INDIRECT_BUFFER: RETVAL = "GL_DRAW_INDIRECT_BUFFER"; break;
      case GL_ELEMENT_ARRAY_BUFFER: RETVAL = "GL_ELEMENT_ARRAY_BUFFER"; break;
      case GL_PIXEL_PACK_BUFFER: RETVAL = "GL_PIXEL_PACK_BUFFER"; break;
      case GL_PIXEL_UNPACK_BUFFER: RETVAL = "GL_PIXEL_UNPACK_BUFFER"; break;
      case GL_QUERY_BUFFER: RETVAL = "GL_QUERY_BUFFER"; break;
      case GL_SHADER_STORAGE_BUFFER: RETVAL = "GL_SHADER_STORAGE_BUFFER"; break;
      case GL_TEXTURE_BUFFER: RETVAL = "GL_TEXTURE_BUFFER"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER"; break;
      case GL_UNIFORM_BUFFER: RETVAL = "GL_UNIFORM_BUFFER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CopyImageSubDataTarget")) {
    switch (e) {
      case GL_RENDERBUFFER: RETVAL = "GL_RENDERBUFFER"; break;
      case GL_TEXTURE_1D: RETVAL = "GL_TEXTURE_1D"; break;
      case GL_TEXTURE_1D_ARRAY: RETVAL = "GL_TEXTURE_1D_ARRAY"; break;
      case GL_TEXTURE_2D: RETVAL = "GL_TEXTURE_2D"; break;
      case GL_TEXTURE_2D_ARRAY: RETVAL = "GL_TEXTURE_2D_ARRAY"; break;
      case GL_TEXTURE_2D_MULTISAMPLE: RETVAL = "GL_TEXTURE_2D_MULTISAMPLE"; break;
      case GL_TEXTURE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_TEXTURE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_TEXTURE_3D: RETVAL = "GL_TEXTURE_3D"; break;
      case GL_TEXTURE_CUBE_MAP: RETVAL = "GL_TEXTURE_CUBE_MAP"; break;
      case GL_TEXTURE_CUBE_MAP_ARRAY: RETVAL = "GL_TEXTURE_CUBE_MAP_ARRAY"; break;
      case GL_TEXTURE_RECTANGLE: RETVAL = "GL_TEXTURE_RECTANGLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "CullParameterEXT")) {
    switch (e) {
      case GL_CULL_VERTEX_EYE_POSITION_EXT: RETVAL = "GL_CULL_VERTEX_EYE_POSITION_EXT"; break;
      case GL_CULL_VERTEX_OBJECT_POSITION_EXT: RETVAL = "GL_CULL_VERTEX_OBJECT_POSITION_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DataTypeEXT")) {
    switch (e) {
      case GL_MATRIX_EXT: RETVAL = "GL_MATRIX_EXT"; break;
      case GL_SCALAR_EXT: RETVAL = "GL_SCALAR_EXT"; break;
      case GL_VECTOR_EXT: RETVAL = "GL_VECTOR_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DebugSeverity")) {
    switch (e) {
      case GL_DEBUG_SEVERITY_HIGH: RETVAL = "GL_DEBUG_SEVERITY_HIGH"; break;
      case GL_DEBUG_SEVERITY_LOW: RETVAL = "GL_DEBUG_SEVERITY_LOW"; break;
      case GL_DEBUG_SEVERITY_MEDIUM: RETVAL = "GL_DEBUG_SEVERITY_MEDIUM"; break;
      case GL_DEBUG_SEVERITY_NOTIFICATION: RETVAL = "GL_DEBUG_SEVERITY_NOTIFICATION"; break;
      case GL_DONT_CARE: RETVAL = "GL_DONT_CARE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DebugSource")) {
    switch (e) {
      case GL_DEBUG_SOURCE_API: RETVAL = "GL_DEBUG_SOURCE_API"; break;
      case GL_DEBUG_SOURCE_APPLICATION: RETVAL = "GL_DEBUG_SOURCE_APPLICATION"; break;
      case GL_DEBUG_SOURCE_OTHER: RETVAL = "GL_DEBUG_SOURCE_OTHER"; break;
      case GL_DEBUG_SOURCE_SHADER_COMPILER: RETVAL = "GL_DEBUG_SOURCE_SHADER_COMPILER"; break;
      case GL_DEBUG_SOURCE_THIRD_PARTY: RETVAL = "GL_DEBUG_SOURCE_THIRD_PARTY"; break;
      case GL_DEBUG_SOURCE_WINDOW_SYSTEM: RETVAL = "GL_DEBUG_SOURCE_WINDOW_SYSTEM"; break;
      case GL_DONT_CARE: RETVAL = "GL_DONT_CARE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DebugType")) {
    switch (e) {
      case GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR: RETVAL = "GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR"; break;
      case GL_DEBUG_TYPE_ERROR: RETVAL = "GL_DEBUG_TYPE_ERROR"; break;
      case GL_DEBUG_TYPE_MARKER: RETVAL = "GL_DEBUG_TYPE_MARKER"; break;
      case GL_DEBUG_TYPE_OTHER: RETVAL = "GL_DEBUG_TYPE_OTHER"; break;
      case GL_DEBUG_TYPE_PERFORMANCE: RETVAL = "GL_DEBUG_TYPE_PERFORMANCE"; break;
      case GL_DEBUG_TYPE_POP_GROUP: RETVAL = "GL_DEBUG_TYPE_POP_GROUP"; break;
      case GL_DEBUG_TYPE_PORTABILITY: RETVAL = "GL_DEBUG_TYPE_PORTABILITY"; break;
      case GL_DEBUG_TYPE_PUSH_GROUP: RETVAL = "GL_DEBUG_TYPE_PUSH_GROUP"; break;
      case GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR: RETVAL = "GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR"; break;
      case GL_DONT_CARE: RETVAL = "GL_DONT_CARE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DepthFunction")) {
    switch (e) {
      case GL_ALWAYS: RETVAL = "GL_ALWAYS"; break;
      case GL_EQUAL: RETVAL = "GL_EQUAL"; break;
      case GL_GEQUAL: RETVAL = "GL_GEQUAL"; break;
      case GL_GREATER: RETVAL = "GL_GREATER"; break;
      case GL_LEQUAL: RETVAL = "GL_LEQUAL"; break;
      case GL_LESS: RETVAL = "GL_LESS"; break;
      case GL_NEVER: RETVAL = "GL_NEVER"; break;
      case GL_NOTEQUAL: RETVAL = "GL_NOTEQUAL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DepthStencilTextureMode")) {
    switch (e) {
      case GL_DEPTH_COMPONENT: RETVAL = "GL_DEPTH_COMPONENT"; break;
      case GL_STENCIL_INDEX: RETVAL = "GL_STENCIL_INDEX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DrawBufferMode")) {
    switch (e) {
      case GL_AUX0: RETVAL = "GL_AUX0"; break;
      case GL_AUX1: RETVAL = "GL_AUX1"; break;
      case GL_AUX2: RETVAL = "GL_AUX2"; break;
      case GL_AUX3: RETVAL = "GL_AUX3"; break;
      case GL_BACK: RETVAL = "GL_BACK"; break;
      case GL_BACK_LEFT: RETVAL = "GL_BACK_LEFT"; break;
      case GL_BACK_RIGHT: RETVAL = "GL_BACK_RIGHT"; break;
      case GL_COLOR_ATTACHMENT0: RETVAL = "GL_COLOR_ATTACHMENT0"; break;
      case GL_COLOR_ATTACHMENT1: RETVAL = "GL_COLOR_ATTACHMENT1"; break;
      case GL_COLOR_ATTACHMENT10: RETVAL = "GL_COLOR_ATTACHMENT10"; break;
      case GL_COLOR_ATTACHMENT11: RETVAL = "GL_COLOR_ATTACHMENT11"; break;
      case GL_COLOR_ATTACHMENT12: RETVAL = "GL_COLOR_ATTACHMENT12"; break;
      case GL_COLOR_ATTACHMENT13: RETVAL = "GL_COLOR_ATTACHMENT13"; break;
      case GL_COLOR_ATTACHMENT14: RETVAL = "GL_COLOR_ATTACHMENT14"; break;
      case GL_COLOR_ATTACHMENT15: RETVAL = "GL_COLOR_ATTACHMENT15"; break;
      case GL_COLOR_ATTACHMENT2: RETVAL = "GL_COLOR_ATTACHMENT2"; break;
      case GL_COLOR_ATTACHMENT3: RETVAL = "GL_COLOR_ATTACHMENT3"; break;
      case GL_COLOR_ATTACHMENT4: RETVAL = "GL_COLOR_ATTACHMENT4"; break;
      case GL_COLOR_ATTACHMENT5: RETVAL = "GL_COLOR_ATTACHMENT5"; break;
      case GL_COLOR_ATTACHMENT6: RETVAL = "GL_COLOR_ATTACHMENT6"; break;
      case GL_COLOR_ATTACHMENT7: RETVAL = "GL_COLOR_ATTACHMENT7"; break;
      case GL_COLOR_ATTACHMENT8: RETVAL = "GL_COLOR_ATTACHMENT8"; break;
      case GL_COLOR_ATTACHMENT9: RETVAL = "GL_COLOR_ATTACHMENT9"; break;
      case GL_FRONT: RETVAL = "GL_FRONT"; break;
      case GL_FRONT_AND_BACK: RETVAL = "GL_FRONT_AND_BACK"; break;
      case GL_FRONT_LEFT: RETVAL = "GL_FRONT_LEFT"; break;
      case GL_FRONT_RIGHT: RETVAL = "GL_FRONT_RIGHT"; break;
      case GL_LEFT: RETVAL = "GL_LEFT"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RIGHT: RETVAL = "GL_RIGHT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "DrawElementsType")) {
    switch (e) {
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ElementPointerTypeATI")) {
    switch (e) {
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "EnableCap")) {
    switch (e) {
      case GL_ALPHA_TEST: RETVAL = "GL_ALPHA_TEST"; break;
      case GL_ASYNC_DRAW_PIXELS_SGIX: RETVAL = "GL_ASYNC_DRAW_PIXELS_SGIX"; break;
      case GL_ASYNC_HISTOGRAM_SGIX: RETVAL = "GL_ASYNC_HISTOGRAM_SGIX"; break;
      case GL_ASYNC_READ_PIXELS_SGIX: RETVAL = "GL_ASYNC_READ_PIXELS_SGIX"; break;
      case GL_ASYNC_TEX_IMAGE_SGIX: RETVAL = "GL_ASYNC_TEX_IMAGE_SGIX"; break;
      case GL_AUTO_NORMAL: RETVAL = "GL_AUTO_NORMAL"; break;
      case GL_BLEND: RETVAL = "GL_BLEND"; break;
      case GL_CLIP_PLANE0: RETVAL = "GL_CLIP_PLANE0"; break;
      case GL_CLIP_PLANE1: RETVAL = "GL_CLIP_PLANE1"; break;
      case GL_CLIP_PLANE2: RETVAL = "GL_CLIP_PLANE2"; break;
      case GL_CLIP_PLANE3: RETVAL = "GL_CLIP_PLANE3"; break;
      case GL_CLIP_PLANE4: RETVAL = "GL_CLIP_PLANE4"; break;
      case GL_CLIP_PLANE5: RETVAL = "GL_CLIP_PLANE5"; break;
      case GL_COLOR_ARRAY: RETVAL = "GL_COLOR_ARRAY"; break;
      case GL_COLOR_LOGIC_OP: RETVAL = "GL_COLOR_LOGIC_OP"; break;
      case GL_COLOR_MATERIAL: RETVAL = "GL_COLOR_MATERIAL"; break;
      case GL_COLOR_TABLE: RETVAL = "GL_COLOR_TABLE"; break;
      case GL_CONVOLUTION_1D_EXT: RETVAL = "GL_CONVOLUTION_1D_EXT"; break;
      case GL_CONVOLUTION_2D_EXT: RETVAL = "GL_CONVOLUTION_2D_EXT"; break;
      case GL_CULL_FACE: RETVAL = "GL_CULL_FACE"; break;
      case GL_DEBUG_OUTPUT: RETVAL = "GL_DEBUG_OUTPUT"; break;
      case GL_DEBUG_OUTPUT_SYNCHRONOUS: RETVAL = "GL_DEBUG_OUTPUT_SYNCHRONOUS"; break;
      case GL_DEPTH_CLAMP: RETVAL = "GL_DEPTH_CLAMP"; break;
      case GL_DEPTH_TEST: RETVAL = "GL_DEPTH_TEST"; break;
      case GL_DITHER: RETVAL = "GL_DITHER"; break;
      case GL_EDGE_FLAG_ARRAY: RETVAL = "GL_EDGE_FLAG_ARRAY"; break;
      case GL_FETCH_PER_SAMPLE_ARM: RETVAL = "GL_FETCH_PER_SAMPLE_ARM"; break;
      case GL_FOG: RETVAL = "GL_FOG"; break;
      case GL_FOG_OFFSET_SGIX: RETVAL = "GL_FOG_OFFSET_SGIX"; break;
      case GL_FRAMEBUFFER_FETCH_NONCOHERENT_QCOM: RETVAL = "GL_FRAMEBUFFER_FETCH_NONCOHERENT_QCOM"; break;
      case GL_FRAMEBUFFER_SRGB: RETVAL = "GL_FRAMEBUFFER_SRGB"; break;
      case GL_HISTOGRAM_EXT: RETVAL = "GL_HISTOGRAM_EXT"; break;
      case GL_INDEX_ARRAY: RETVAL = "GL_INDEX_ARRAY"; break;
      case GL_INDEX_LOGIC_OP: RETVAL = "GL_INDEX_LOGIC_OP"; break;
      case GL_INTERLACE_SGIX: RETVAL = "GL_INTERLACE_SGIX"; break;
      case GL_LIGHT0: RETVAL = "GL_LIGHT0"; break;
      case GL_LIGHT1: RETVAL = "GL_LIGHT1"; break;
      case GL_LIGHT2: RETVAL = "GL_LIGHT2"; break;
      case GL_LIGHT3: RETVAL = "GL_LIGHT3"; break;
      case GL_LIGHT4: RETVAL = "GL_LIGHT4"; break;
      case GL_LIGHT5: RETVAL = "GL_LIGHT5"; break;
      case GL_LIGHT6: RETVAL = "GL_LIGHT6"; break;
      case GL_LIGHT7: RETVAL = "GL_LIGHT7"; break;
      case GL_LIGHTING: RETVAL = "GL_LIGHTING"; break;
      case GL_LINE_SMOOTH: RETVAL = "GL_LINE_SMOOTH"; break;
      case GL_LINE_STIPPLE: RETVAL = "GL_LINE_STIPPLE"; break;
      case GL_MAP1_COLOR_4: RETVAL = "GL_MAP1_COLOR_4"; break;
      case GL_MAP1_INDEX: RETVAL = "GL_MAP1_INDEX"; break;
      case GL_MAP1_NORMAL: RETVAL = "GL_MAP1_NORMAL"; break;
      case GL_MAP1_TEXTURE_COORD_1: RETVAL = "GL_MAP1_TEXTURE_COORD_1"; break;
      case GL_MAP1_TEXTURE_COORD_2: RETVAL = "GL_MAP1_TEXTURE_COORD_2"; break;
      case GL_MAP1_TEXTURE_COORD_3: RETVAL = "GL_MAP1_TEXTURE_COORD_3"; break;
      case GL_MAP1_TEXTURE_COORD_4: RETVAL = "GL_MAP1_TEXTURE_COORD_4"; break;
      case GL_MAP1_VERTEX_3: RETVAL = "GL_MAP1_VERTEX_3"; break;
      case GL_MAP1_VERTEX_4: RETVAL = "GL_MAP1_VERTEX_4"; break;
      case GL_MAP2_COLOR_4: RETVAL = "GL_MAP2_COLOR_4"; break;
      case GL_MAP2_INDEX: RETVAL = "GL_MAP2_INDEX"; break;
      case GL_MAP2_NORMAL: RETVAL = "GL_MAP2_NORMAL"; break;
      case GL_MAP2_TEXTURE_COORD_1: RETVAL = "GL_MAP2_TEXTURE_COORD_1"; break;
      case GL_MAP2_TEXTURE_COORD_2: RETVAL = "GL_MAP2_TEXTURE_COORD_2"; break;
      case GL_MAP2_TEXTURE_COORD_3: RETVAL = "GL_MAP2_TEXTURE_COORD_3"; break;
      case GL_MAP2_TEXTURE_COORD_4: RETVAL = "GL_MAP2_TEXTURE_COORD_4"; break;
      case GL_MAP2_VERTEX_3: RETVAL = "GL_MAP2_VERTEX_3"; break;
      case GL_MAP2_VERTEX_4: RETVAL = "GL_MAP2_VERTEX_4"; break;
      case GL_MINMAX_EXT: RETVAL = "GL_MINMAX_EXT"; break;
      case GL_MULTISAMPLE: RETVAL = "GL_MULTISAMPLE"; break;
      case GL_NORMALIZE: RETVAL = "GL_NORMALIZE"; break;
      case GL_NORMAL_ARRAY: RETVAL = "GL_NORMAL_ARRAY"; break;
      case GL_POINT_SMOOTH: RETVAL = "GL_POINT_SMOOTH"; break;
      case GL_POLYGON_OFFSET_FILL: RETVAL = "GL_POLYGON_OFFSET_FILL"; break;
      case GL_POLYGON_OFFSET_LINE: RETVAL = "GL_POLYGON_OFFSET_LINE"; break;
      case GL_POLYGON_OFFSET_POINT: RETVAL = "GL_POLYGON_OFFSET_POINT"; break;
      case GL_POLYGON_SMOOTH: RETVAL = "GL_POLYGON_SMOOTH"; break;
      case GL_POLYGON_STIPPLE: RETVAL = "GL_POLYGON_STIPPLE"; break;
      case GL_POST_COLOR_MATRIX_COLOR_TABLE: RETVAL = "GL_POST_COLOR_MATRIX_COLOR_TABLE"; break;
      case GL_POST_CONVOLUTION_COLOR_TABLE: RETVAL = "GL_POST_CONVOLUTION_COLOR_TABLE"; break;
      case GL_PRIMITIVE_RESTART: RETVAL = "GL_PRIMITIVE_RESTART"; break;
      case GL_PRIMITIVE_RESTART_FIXED_INDEX: RETVAL = "GL_PRIMITIVE_RESTART_FIXED_INDEX"; break;
      case GL_PROGRAM_POINT_SIZE: RETVAL = "GL_PROGRAM_POINT_SIZE"; break;
      case GL_RASTERIZER_DISCARD: RETVAL = "GL_RASTERIZER_DISCARD"; break;
      case GL_RESCALE_NORMAL_EXT: RETVAL = "GL_RESCALE_NORMAL_EXT"; break;
      case GL_SAMPLE_ALPHA_TO_COVERAGE: RETVAL = "GL_SAMPLE_ALPHA_TO_COVERAGE"; break;
      case GL_SAMPLE_ALPHA_TO_ONE: RETVAL = "GL_SAMPLE_ALPHA_TO_ONE"; break;
      case GL_SAMPLE_COVERAGE: RETVAL = "GL_SAMPLE_COVERAGE"; break;
      case GL_SAMPLE_MASK: RETVAL = "GL_SAMPLE_MASK"; break;
      case GL_SAMPLE_SHADING: RETVAL = "GL_SAMPLE_SHADING"; break;
      case GL_SCISSOR_TEST: RETVAL = "GL_SCISSOR_TEST"; break;
      case GL_SEPARABLE_2D_EXT: RETVAL = "GL_SEPARABLE_2D_EXT"; break;
      case GL_SHADING_RATE_IMAGE_PER_PRIMITIVE_NV: RETVAL = "GL_SHADING_RATE_IMAGE_PER_PRIMITIVE_NV"; break;
      case GL_SHADING_RATE_PRESERVE_ASPECT_RATIO_QCOM: RETVAL = "GL_SHADING_RATE_PRESERVE_ASPECT_RATIO_QCOM"; break;
      case GL_SHARED_TEXTURE_PALETTE_EXT: RETVAL = "GL_SHARED_TEXTURE_PALETTE_EXT"; break;
      case GL_STENCIL_TEST: RETVAL = "GL_STENCIL_TEST"; break;
      case GL_TEXTURE_1D: RETVAL = "GL_TEXTURE_1D"; break;
      case GL_TEXTURE_2D: RETVAL = "GL_TEXTURE_2D"; break;
      case GL_TEXTURE_3D_EXT: RETVAL = "GL_TEXTURE_3D_EXT"; break;
      case GL_TEXTURE_COLOR_TABLE_SGI: RETVAL = "GL_TEXTURE_COLOR_TABLE_SGI"; break;
      case GL_TEXTURE_COORD_ARRAY: RETVAL = "GL_TEXTURE_COORD_ARRAY"; break;
      case GL_TEXTURE_CUBE_MAP: RETVAL = "GL_TEXTURE_CUBE_MAP"; break;
      case GL_TEXTURE_CUBE_MAP_SEAMLESS: RETVAL = "GL_TEXTURE_CUBE_MAP_SEAMLESS"; break;
      case GL_TEXTURE_GEN_Q: RETVAL = "GL_TEXTURE_GEN_Q"; break;
      case GL_TEXTURE_GEN_R: RETVAL = "GL_TEXTURE_GEN_R"; break;
      case GL_TEXTURE_GEN_S: RETVAL = "GL_TEXTURE_GEN_S"; break;
      case GL_TEXTURE_GEN_T: RETVAL = "GL_TEXTURE_GEN_T"; break;
      case GL_TEXTURE_RECTANGLE: RETVAL = "GL_TEXTURE_RECTANGLE"; break;
      case GL_VERTEX_ARRAY: RETVAL = "GL_VERTEX_ARRAY"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ErrorCode")) {
    switch (e) {
      case GL_INVALID_ENUM: RETVAL = "GL_INVALID_ENUM"; break;
      case GL_INVALID_FRAMEBUFFER_OPERATION: RETVAL = "GL_INVALID_FRAMEBUFFER_OPERATION"; break;
      case GL_INVALID_OPERATION: RETVAL = "GL_INVALID_OPERATION"; break;
      case GL_INVALID_VALUE: RETVAL = "GL_INVALID_VALUE"; break;
      case GL_NO_ERROR: RETVAL = "GL_NO_ERROR"; break;
      case GL_OUT_OF_MEMORY: RETVAL = "GL_OUT_OF_MEMORY"; break;
      case GL_STACK_OVERFLOW: RETVAL = "GL_STACK_OVERFLOW"; break;
      case GL_STACK_UNDERFLOW: RETVAL = "GL_STACK_UNDERFLOW"; break;
      case GL_TABLE_TOO_LARGE: RETVAL = "GL_TABLE_TOO_LARGE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "EvalMapsModeNV")) {
    switch (e) {
      case GL_FILL_NV: RETVAL = "GL_FILL_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "EvalTargetNV")) {
    switch (e) {
      case GL_EVAL_2D_NV: RETVAL = "GL_EVAL_2D_NV"; break;
      case GL_EVAL_TRIANGULAR_2D_NV: RETVAL = "GL_EVAL_TRIANGULAR_2D_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ExternalHandleType")) {
    switch (e) {
      case GL_HANDLE_TYPE_D3D11_IMAGE_EXT: RETVAL = "GL_HANDLE_TYPE_D3D11_IMAGE_EXT"; break;
      case GL_HANDLE_TYPE_D3D11_IMAGE_KMT_EXT: RETVAL = "GL_HANDLE_TYPE_D3D11_IMAGE_KMT_EXT"; break;
      case GL_HANDLE_TYPE_D3D12_FENCE_EXT: RETVAL = "GL_HANDLE_TYPE_D3D12_FENCE_EXT"; break;
      case GL_HANDLE_TYPE_D3D12_RESOURCE_EXT: RETVAL = "GL_HANDLE_TYPE_D3D12_RESOURCE_EXT"; break;
      case GL_HANDLE_TYPE_D3D12_TILEPOOL_EXT: RETVAL = "GL_HANDLE_TYPE_D3D12_TILEPOOL_EXT"; break;
      case GL_HANDLE_TYPE_OPAQUE_FD_EXT: RETVAL = "GL_HANDLE_TYPE_OPAQUE_FD_EXT"; break;
      case GL_HANDLE_TYPE_OPAQUE_WIN32_EXT: RETVAL = "GL_HANDLE_TYPE_OPAQUE_WIN32_EXT"; break;
      case GL_HANDLE_TYPE_OPAQUE_WIN32_KMT_EXT: RETVAL = "GL_HANDLE_TYPE_OPAQUE_WIN32_KMT_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FeedBackToken")) {
    switch (e) {
      case GL_BITMAP_TOKEN: RETVAL = "GL_BITMAP_TOKEN"; break;
      case GL_COPY_PIXEL_TOKEN: RETVAL = "GL_COPY_PIXEL_TOKEN"; break;
      case GL_DRAW_PIXEL_TOKEN: RETVAL = "GL_DRAW_PIXEL_TOKEN"; break;
      case GL_LINE_RESET_TOKEN: RETVAL = "GL_LINE_RESET_TOKEN"; break;
      case GL_LINE_TOKEN: RETVAL = "GL_LINE_TOKEN"; break;
      case GL_PASS_THROUGH_TOKEN: RETVAL = "GL_PASS_THROUGH_TOKEN"; break;
      case GL_POINT_TOKEN: RETVAL = "GL_POINT_TOKEN"; break;
      case GL_POLYGON_TOKEN: RETVAL = "GL_POLYGON_TOKEN"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FeedbackType")) {
    switch (e) {
      case GL_2D: RETVAL = "GL_2D"; break;
      case GL_3D: RETVAL = "GL_3D"; break;
      case GL_3D_COLOR: RETVAL = "GL_3D_COLOR"; break;
      case GL_3D_COLOR_TEXTURE: RETVAL = "GL_3D_COLOR_TEXTURE"; break;
      case GL_4D_COLOR_TEXTURE: RETVAL = "GL_4D_COLOR_TEXTURE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FenceConditionNV")) {
    switch (e) {
      case GL_ALL_COMPLETED_NV: RETVAL = "GL_ALL_COMPLETED_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FenceParameterNameNV")) {
    switch (e) {
      case GL_FENCE_CONDITION_NV: RETVAL = "GL_FENCE_CONDITION_NV"; break;
      case GL_FENCE_STATUS_NV: RETVAL = "GL_FENCE_STATUS_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FfdMaskSGIX")) {
    switch (e) {
      case GL_GEOMETRY_DEFORMATION_BIT_SGIX: RETVAL = "GL_GEOMETRY_DEFORMATION_BIT_SGIX"; break;
      case GL_TEXTURE_DEFORMATION_BIT_SGIX: RETVAL = "GL_TEXTURE_DEFORMATION_BIT_SGIX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogCoordSrc")) {
    switch (e) {
      case GL_FOG_COORD: RETVAL = "GL_FOG_COORD"; break;
      case GL_FRAGMENT_DEPTH: RETVAL = "GL_FRAGMENT_DEPTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogCoordinatePointerType")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogMode")) {
    switch (e) {
      case GL_EXP: RETVAL = "GL_EXP"; break;
      case GL_EXP2: RETVAL = "GL_EXP2"; break;
      case GL_LINEAR: RETVAL = "GL_LINEAR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogPName")) {
    switch (e) {
      case GL_FOG_COORD_SRC: RETVAL = "GL_FOG_COORD_SRC"; break;
      case GL_FOG_DENSITY: RETVAL = "GL_FOG_DENSITY"; break;
      case GL_FOG_END: RETVAL = "GL_FOG_END"; break;
      case GL_FOG_INDEX: RETVAL = "GL_FOG_INDEX"; break;
      case GL_FOG_MODE: RETVAL = "GL_FOG_MODE"; break;
      case GL_FOG_START: RETVAL = "GL_FOG_START"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogParameter")) {
    switch (e) {
      case GL_FOG_COLOR: RETVAL = "GL_FOG_COLOR"; break;
      case GL_FOG_DENSITY: RETVAL = "GL_FOG_DENSITY"; break;
      case GL_FOG_END: RETVAL = "GL_FOG_END"; break;
      case GL_FOG_INDEX: RETVAL = "GL_FOG_INDEX"; break;
      case GL_FOG_MODE: RETVAL = "GL_FOG_MODE"; break;
      case GL_FOG_OFFSET_VALUE_SGIX: RETVAL = "GL_FOG_OFFSET_VALUE_SGIX"; break;
      case GL_FOG_START: RETVAL = "GL_FOG_START"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogPointerTypeEXT")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FogPointerTypeIBM")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FoveationConfigBitQCOM")) {
    switch (e) {
      case GL_FOVEATION_ENABLE_BIT_QCOM: RETVAL = "GL_FOVEATION_ENABLE_BIT_QCOM"; break;
      case GL_FOVEATION_SCALED_BIN_METHOD_BIT_QCOM: RETVAL = "GL_FOVEATION_SCALED_BIN_METHOD_BIT_QCOM"; break;
      case GL_FOVEATION_SUBSAMPLED_LAYOUT_METHOD_BIT_QCOM: RETVAL = "GL_FOVEATION_SUBSAMPLED_LAYOUT_METHOD_BIT_QCOM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentLightParameterSGIX")) {
    switch (e) {
      case GL_AMBIENT: RETVAL = "GL_AMBIENT"; break;
      case GL_CONSTANT_ATTENUATION: RETVAL = "GL_CONSTANT_ATTENUATION"; break;
      case GL_DIFFUSE: RETVAL = "GL_DIFFUSE"; break;
      case GL_LINEAR_ATTENUATION: RETVAL = "GL_LINEAR_ATTENUATION"; break;
      case GL_POSITION: RETVAL = "GL_POSITION"; break;
      case GL_QUADRATIC_ATTENUATION: RETVAL = "GL_QUADRATIC_ATTENUATION"; break;
      case GL_SPECULAR: RETVAL = "GL_SPECULAR"; break;
      case GL_SPOT_CUTOFF: RETVAL = "GL_SPOT_CUTOFF"; break;
      case GL_SPOT_DIRECTION: RETVAL = "GL_SPOT_DIRECTION"; break;
      case GL_SPOT_EXPONENT: RETVAL = "GL_SPOT_EXPONENT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentOp1ATI")) {
    switch (e) {
      case GL_MOV_ATI: RETVAL = "GL_MOV_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentOp2ATI")) {
    switch (e) {
      case GL_ADD_ATI: RETVAL = "GL_ADD_ATI"; break;
      case GL_DOT3_ATI: RETVAL = "GL_DOT3_ATI"; break;
      case GL_DOT4_ATI: RETVAL = "GL_DOT4_ATI"; break;
      case GL_MUL_ATI: RETVAL = "GL_MUL_ATI"; break;
      case GL_SUB_ATI: RETVAL = "GL_SUB_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentOp3ATI")) {
    switch (e) {
      case GL_CND0_ATI: RETVAL = "GL_CND0_ATI"; break;
      case GL_CND_ATI: RETVAL = "GL_CND_ATI"; break;
      case GL_DOT2_ADD_ATI: RETVAL = "GL_DOT2_ADD_ATI"; break;
      case GL_LERP_ATI: RETVAL = "GL_LERP_ATI"; break;
      case GL_MAD_ATI: RETVAL = "GL_MAD_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderColorModMaskATI")) {
    switch (e) {
      case GL_2X_BIT_ATI: RETVAL = "GL_2X_BIT_ATI"; break;
      case GL_BIAS_BIT_ATI: RETVAL = "GL_BIAS_BIT_ATI"; break;
      case GL_COMP_BIT_ATI: RETVAL = "GL_COMP_BIT_ATI"; break;
      case GL_NEGATE_BIT_ATI: RETVAL = "GL_NEGATE_BIT_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderConATI")) {
    switch (e) {
      case GL_CON_0_ATI: RETVAL = "GL_CON_0_ATI"; break;
      case GL_CON_1_ATI: RETVAL = "GL_CON_1_ATI"; break;
      case GL_CON_2_ATI: RETVAL = "GL_CON_2_ATI"; break;
      case GL_CON_3_ATI: RETVAL = "GL_CON_3_ATI"; break;
      case GL_CON_4_ATI: RETVAL = "GL_CON_4_ATI"; break;
      case GL_CON_5_ATI: RETVAL = "GL_CON_5_ATI"; break;
      case GL_CON_6_ATI: RETVAL = "GL_CON_6_ATI"; break;
      case GL_CON_7_ATI: RETVAL = "GL_CON_7_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderDestMaskATI")) {
    switch (e) {
      case GL_BLUE_BIT_ATI: RETVAL = "GL_BLUE_BIT_ATI"; break;
      case GL_GREEN_BIT_ATI: RETVAL = "GL_GREEN_BIT_ATI"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RED_BIT_ATI: RETVAL = "GL_RED_BIT_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderDestModMaskATI")) {
    switch (e) {
      case GL_2X_BIT_ATI: RETVAL = "GL_2X_BIT_ATI"; break;
      case GL_4X_BIT_ATI: RETVAL = "GL_4X_BIT_ATI"; break;
      case GL_8X_BIT_ATI: RETVAL = "GL_8X_BIT_ATI"; break;
      case GL_EIGHTH_BIT_ATI: RETVAL = "GL_EIGHTH_BIT_ATI"; break;
      case GL_HALF_BIT_ATI: RETVAL = "GL_HALF_BIT_ATI"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_QUARTER_BIT_ATI: RETVAL = "GL_QUARTER_BIT_ATI"; break;
      case GL_SATURATE_BIT_ATI: RETVAL = "GL_SATURATE_BIT_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderGenericSourceATI")) {
    switch (e) {
      case GL_CON_0_ATI: RETVAL = "GL_CON_0_ATI"; break;
      case GL_CON_1_ATI: RETVAL = "GL_CON_1_ATI"; break;
      case GL_CON_2_ATI: RETVAL = "GL_CON_2_ATI"; break;
      case GL_CON_3_ATI: RETVAL = "GL_CON_3_ATI"; break;
      case GL_CON_4_ATI: RETVAL = "GL_CON_4_ATI"; break;
      case GL_CON_5_ATI: RETVAL = "GL_CON_5_ATI"; break;
      case GL_CON_6_ATI: RETVAL = "GL_CON_6_ATI"; break;
      case GL_CON_7_ATI: RETVAL = "GL_CON_7_ATI"; break;
      case GL_ONE: RETVAL = "GL_ONE"; break;
      case GL_PRIMARY_COLOR: RETVAL = "GL_PRIMARY_COLOR"; break;
      case GL_REG_0_ATI: RETVAL = "GL_REG_0_ATI"; break;
      case GL_REG_1_ATI: RETVAL = "GL_REG_1_ATI"; break;
      case GL_REG_2_ATI: RETVAL = "GL_REG_2_ATI"; break;
      case GL_REG_3_ATI: RETVAL = "GL_REG_3_ATI"; break;
      case GL_REG_4_ATI: RETVAL = "GL_REG_4_ATI"; break;
      case GL_REG_5_ATI: RETVAL = "GL_REG_5_ATI"; break;
      case GL_SECONDARY_INTERPOLATOR_ATI: RETVAL = "GL_SECONDARY_INTERPOLATOR_ATI"; break;
      case GL_ZERO: RETVAL = "GL_ZERO"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderRegATI")) {
    switch (e) {
      case GL_REG_0_ATI: RETVAL = "GL_REG_0_ATI"; break;
      case GL_REG_1_ATI: RETVAL = "GL_REG_1_ATI"; break;
      case GL_REG_2_ATI: RETVAL = "GL_REG_2_ATI"; break;
      case GL_REG_3_ATI: RETVAL = "GL_REG_3_ATI"; break;
      case GL_REG_4_ATI: RETVAL = "GL_REG_4_ATI"; break;
      case GL_REG_5_ATI: RETVAL = "GL_REG_5_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderTextureSourceATI")) {
    switch (e) {
      case GL_REG_0_ATI: RETVAL = "GL_REG_0_ATI"; break;
      case GL_REG_1_ATI: RETVAL = "GL_REG_1_ATI"; break;
      case GL_REG_2_ATI: RETVAL = "GL_REG_2_ATI"; break;
      case GL_REG_3_ATI: RETVAL = "GL_REG_3_ATI"; break;
      case GL_REG_4_ATI: RETVAL = "GL_REG_4_ATI"; break;
      case GL_REG_5_ATI: RETVAL = "GL_REG_5_ATI"; break;
      case GL_TEXTURE0: RETVAL = "GL_TEXTURE0"; break;
      case GL_TEXTURE1: RETVAL = "GL_TEXTURE1"; break;
      case GL_TEXTURE10: RETVAL = "GL_TEXTURE10"; break;
      case GL_TEXTURE11: RETVAL = "GL_TEXTURE11"; break;
      case GL_TEXTURE12: RETVAL = "GL_TEXTURE12"; break;
      case GL_TEXTURE13: RETVAL = "GL_TEXTURE13"; break;
      case GL_TEXTURE14: RETVAL = "GL_TEXTURE14"; break;
      case GL_TEXTURE15: RETVAL = "GL_TEXTURE15"; break;
      case GL_TEXTURE16: RETVAL = "GL_TEXTURE16"; break;
      case GL_TEXTURE17: RETVAL = "GL_TEXTURE17"; break;
      case GL_TEXTURE18: RETVAL = "GL_TEXTURE18"; break;
      case GL_TEXTURE19: RETVAL = "GL_TEXTURE19"; break;
      case GL_TEXTURE2: RETVAL = "GL_TEXTURE2"; break;
      case GL_TEXTURE20: RETVAL = "GL_TEXTURE20"; break;
      case GL_TEXTURE21: RETVAL = "GL_TEXTURE21"; break;
      case GL_TEXTURE22: RETVAL = "GL_TEXTURE22"; break;
      case GL_TEXTURE23: RETVAL = "GL_TEXTURE23"; break;
      case GL_TEXTURE24: RETVAL = "GL_TEXTURE24"; break;
      case GL_TEXTURE25: RETVAL = "GL_TEXTURE25"; break;
      case GL_TEXTURE26: RETVAL = "GL_TEXTURE26"; break;
      case GL_TEXTURE27: RETVAL = "GL_TEXTURE27"; break;
      case GL_TEXTURE28: RETVAL = "GL_TEXTURE28"; break;
      case GL_TEXTURE29: RETVAL = "GL_TEXTURE29"; break;
      case GL_TEXTURE3: RETVAL = "GL_TEXTURE3"; break;
      case GL_TEXTURE30: RETVAL = "GL_TEXTURE30"; break;
      case GL_TEXTURE31: RETVAL = "GL_TEXTURE31"; break;
      case GL_TEXTURE4: RETVAL = "GL_TEXTURE4"; break;
      case GL_TEXTURE5: RETVAL = "GL_TEXTURE5"; break;
      case GL_TEXTURE6: RETVAL = "GL_TEXTURE6"; break;
      case GL_TEXTURE7: RETVAL = "GL_TEXTURE7"; break;
      case GL_TEXTURE8: RETVAL = "GL_TEXTURE8"; break;
      case GL_TEXTURE9: RETVAL = "GL_TEXTURE9"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FragmentShaderValueRepATI")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_BLUE: RETVAL = "GL_BLUE"; break;
      case GL_GREEN: RETVAL = "GL_GREEN"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RED: RETVAL = "GL_RED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FramebufferAttachment")) {
    switch (e) {
      case GL_COLOR_ATTACHMENT0: RETVAL = "GL_COLOR_ATTACHMENT0"; break;
      case GL_COLOR_ATTACHMENT1: RETVAL = "GL_COLOR_ATTACHMENT1"; break;
      case GL_COLOR_ATTACHMENT10: RETVAL = "GL_COLOR_ATTACHMENT10"; break;
      case GL_COLOR_ATTACHMENT11: RETVAL = "GL_COLOR_ATTACHMENT11"; break;
      case GL_COLOR_ATTACHMENT12: RETVAL = "GL_COLOR_ATTACHMENT12"; break;
      case GL_COLOR_ATTACHMENT13: RETVAL = "GL_COLOR_ATTACHMENT13"; break;
      case GL_COLOR_ATTACHMENT14: RETVAL = "GL_COLOR_ATTACHMENT14"; break;
      case GL_COLOR_ATTACHMENT15: RETVAL = "GL_COLOR_ATTACHMENT15"; break;
      case GL_COLOR_ATTACHMENT2: RETVAL = "GL_COLOR_ATTACHMENT2"; break;
      case GL_COLOR_ATTACHMENT3: RETVAL = "GL_COLOR_ATTACHMENT3"; break;
      case GL_COLOR_ATTACHMENT4: RETVAL = "GL_COLOR_ATTACHMENT4"; break;
      case GL_COLOR_ATTACHMENT5: RETVAL = "GL_COLOR_ATTACHMENT5"; break;
      case GL_COLOR_ATTACHMENT6: RETVAL = "GL_COLOR_ATTACHMENT6"; break;
      case GL_COLOR_ATTACHMENT7: RETVAL = "GL_COLOR_ATTACHMENT7"; break;
      case GL_COLOR_ATTACHMENT8: RETVAL = "GL_COLOR_ATTACHMENT8"; break;
      case GL_COLOR_ATTACHMENT9: RETVAL = "GL_COLOR_ATTACHMENT9"; break;
      case GL_DEPTH_ATTACHMENT: RETVAL = "GL_DEPTH_ATTACHMENT"; break;
      case GL_DEPTH_STENCIL_ATTACHMENT: RETVAL = "GL_DEPTH_STENCIL_ATTACHMENT"; break;
      case GL_SHADING_RATE_ATTACHMENT_EXT: RETVAL = "GL_SHADING_RATE_ATTACHMENT_EXT"; break;
      case GL_STENCIL_ATTACHMENT: RETVAL = "GL_STENCIL_ATTACHMENT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FramebufferAttachmentParameterName")) {
    switch (e) {
      case GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_LAYERED: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_LAYERED"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_BASE_VIEW_INDEX_OVR: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_BASE_VIEW_INDEX_OVR"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_NUM_VIEWS_OVR: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_NUM_VIEWS_OVR"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SAMPLES_EXT: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SAMPLES_EXT"; break;
      case GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SCALE_IMG: RETVAL = "GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_SCALE_IMG"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FramebufferParameterName")) {
    switch (e) {
      case GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS: RETVAL = "GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS"; break;
      case GL_FRAMEBUFFER_DEFAULT_HEIGHT: RETVAL = "GL_FRAMEBUFFER_DEFAULT_HEIGHT"; break;
      case GL_FRAMEBUFFER_DEFAULT_LAYERS: RETVAL = "GL_FRAMEBUFFER_DEFAULT_LAYERS"; break;
      case GL_FRAMEBUFFER_DEFAULT_SAMPLES: RETVAL = "GL_FRAMEBUFFER_DEFAULT_SAMPLES"; break;
      case GL_FRAMEBUFFER_DEFAULT_WIDTH: RETVAL = "GL_FRAMEBUFFER_DEFAULT_WIDTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FramebufferStatus")) {
    switch (e) {
      case GL_FRAMEBUFFER_COMPLETE: RETVAL = "GL_FRAMEBUFFER_COMPLETE"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE"; break;
      case GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER: RETVAL = "GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER"; break;
      case GL_FRAMEBUFFER_UNDEFINED: RETVAL = "GL_FRAMEBUFFER_UNDEFINED"; break;
      case GL_FRAMEBUFFER_UNSUPPORTED: RETVAL = "GL_FRAMEBUFFER_UNSUPPORTED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FramebufferTarget")) {
    switch (e) {
      case GL_DRAW_FRAMEBUFFER: RETVAL = "GL_DRAW_FRAMEBUFFER"; break;
      case GL_FRAMEBUFFER: RETVAL = "GL_FRAMEBUFFER"; break;
      case GL_READ_FRAMEBUFFER: RETVAL = "GL_READ_FRAMEBUFFER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "FrontFaceDirection")) {
    switch (e) {
      case GL_CCW: RETVAL = "GL_CCW"; break;
      case GL_CW: RETVAL = "GL_CW"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetFramebufferParameter")) {
    switch (e) {
      case GL_DOUBLEBUFFER: RETVAL = "GL_DOUBLEBUFFER"; break;
      case GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS: RETVAL = "GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS"; break;
      case GL_FRAMEBUFFER_DEFAULT_HEIGHT: RETVAL = "GL_FRAMEBUFFER_DEFAULT_HEIGHT"; break;
      case GL_FRAMEBUFFER_DEFAULT_LAYERS: RETVAL = "GL_FRAMEBUFFER_DEFAULT_LAYERS"; break;
      case GL_FRAMEBUFFER_DEFAULT_SAMPLES: RETVAL = "GL_FRAMEBUFFER_DEFAULT_SAMPLES"; break;
      case GL_FRAMEBUFFER_DEFAULT_WIDTH: RETVAL = "GL_FRAMEBUFFER_DEFAULT_WIDTH"; break;
      case GL_IMPLEMENTATION_COLOR_READ_FORMAT: RETVAL = "GL_IMPLEMENTATION_COLOR_READ_FORMAT"; break;
      case GL_IMPLEMENTATION_COLOR_READ_TYPE: RETVAL = "GL_IMPLEMENTATION_COLOR_READ_TYPE"; break;
      case GL_SAMPLES: RETVAL = "GL_SAMPLES"; break;
      case GL_SAMPLE_BUFFERS: RETVAL = "GL_SAMPLE_BUFFERS"; break;
      case GL_STEREO: RETVAL = "GL_STEREO"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetHistogramParameterPNameEXT")) {
    switch (e) {
      case GL_HISTOGRAM_ALPHA_SIZE: RETVAL = "GL_HISTOGRAM_ALPHA_SIZE"; break;
      case GL_HISTOGRAM_BLUE_SIZE: RETVAL = "GL_HISTOGRAM_BLUE_SIZE"; break;
      case GL_HISTOGRAM_FORMAT: RETVAL = "GL_HISTOGRAM_FORMAT"; break;
      case GL_HISTOGRAM_GREEN_SIZE: RETVAL = "GL_HISTOGRAM_GREEN_SIZE"; break;
      case GL_HISTOGRAM_LUMINANCE_SIZE: RETVAL = "GL_HISTOGRAM_LUMINANCE_SIZE"; break;
      case GL_HISTOGRAM_RED_SIZE: RETVAL = "GL_HISTOGRAM_RED_SIZE"; break;
      case GL_HISTOGRAM_SINK: RETVAL = "GL_HISTOGRAM_SINK"; break;
      case GL_HISTOGRAM_WIDTH: RETVAL = "GL_HISTOGRAM_WIDTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetMapQuery")) {
    switch (e) {
      case GL_COEFF: RETVAL = "GL_COEFF"; break;
      case GL_DOMAIN: RETVAL = "GL_DOMAIN"; break;
      case GL_ORDER: RETVAL = "GL_ORDER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetMinmaxParameterPNameEXT")) {
    switch (e) {
      case GL_MINMAX_FORMAT: RETVAL = "GL_MINMAX_FORMAT"; break;
      case GL_MINMAX_SINK: RETVAL = "GL_MINMAX_SINK"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetMultisamplePNameNV")) {
    switch (e) {
      case GL_PROGRAMMABLE_SAMPLE_LOCATION_ARB: RETVAL = "GL_PROGRAMMABLE_SAMPLE_LOCATION_ARB"; break;
      case GL_SAMPLE_POSITION: RETVAL = "GL_SAMPLE_POSITION"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetPName")) {
    switch (e) {
      case GL_ACCUM_ALPHA_BITS: RETVAL = "GL_ACCUM_ALPHA_BITS"; break;
      case GL_ACCUM_BLUE_BITS: RETVAL = "GL_ACCUM_BLUE_BITS"; break;
      case GL_ACCUM_CLEAR_VALUE: RETVAL = "GL_ACCUM_CLEAR_VALUE"; break;
      case GL_ACCUM_GREEN_BITS: RETVAL = "GL_ACCUM_GREEN_BITS"; break;
      case GL_ACCUM_RED_BITS: RETVAL = "GL_ACCUM_RED_BITS"; break;
      case GL_ACTIVE_TEXTURE: RETVAL = "GL_ACTIVE_TEXTURE"; break;
      case GL_ALIASED_LINE_WIDTH_RANGE: RETVAL = "GL_ALIASED_LINE_WIDTH_RANGE"; break;
      case GL_ALIASED_POINT_SIZE_RANGE: RETVAL = "GL_ALIASED_POINT_SIZE_RANGE"; break;
      case GL_ALPHA_BIAS: RETVAL = "GL_ALPHA_BIAS"; break;
      case GL_ALPHA_BITS: RETVAL = "GL_ALPHA_BITS"; break;
      case GL_ALPHA_SCALE: RETVAL = "GL_ALPHA_SCALE"; break;
      case GL_ALPHA_TEST: RETVAL = "GL_ALPHA_TEST"; break;
      case GL_ALPHA_TEST_FUNC: RETVAL = "GL_ALPHA_TEST_FUNC"; break;
      case GL_ALPHA_TEST_REF: RETVAL = "GL_ALPHA_TEST_REF"; break;
      case GL_ARRAY_BUFFER_BINDING: RETVAL = "GL_ARRAY_BUFFER_BINDING"; break;
      case GL_ASYNC_DRAW_PIXELS_SGIX: RETVAL = "GL_ASYNC_DRAW_PIXELS_SGIX"; break;
      case GL_ASYNC_HISTOGRAM_SGIX: RETVAL = "GL_ASYNC_HISTOGRAM_SGIX"; break;
      case GL_ASYNC_MARKER_SGIX: RETVAL = "GL_ASYNC_MARKER_SGIX"; break;
      case GL_ASYNC_READ_PIXELS_SGIX: RETVAL = "GL_ASYNC_READ_PIXELS_SGIX"; break;
      case GL_ASYNC_TEX_IMAGE_SGIX: RETVAL = "GL_ASYNC_TEX_IMAGE_SGIX"; break;
      case GL_ATTRIB_STACK_DEPTH: RETVAL = "GL_ATTRIB_STACK_DEPTH"; break;
      case GL_AUTO_NORMAL: RETVAL = "GL_AUTO_NORMAL"; break;
      case GL_AUX_BUFFERS: RETVAL = "GL_AUX_BUFFERS"; break;
      case GL_BLEND: RETVAL = "GL_BLEND"; break;
      case GL_BLEND_COLOR: RETVAL = "GL_BLEND_COLOR"; break;
      case GL_BLEND_DST: RETVAL = "GL_BLEND_DST"; break;
      case GL_BLEND_DST_ALPHA: RETVAL = "GL_BLEND_DST_ALPHA"; break;
      case GL_BLEND_DST_RGB: RETVAL = "GL_BLEND_DST_RGB"; break;
      case GL_BLEND_EQUATION: RETVAL = "GL_BLEND_EQUATION"; break;
      case GL_BLEND_EQUATION_ALPHA: RETVAL = "GL_BLEND_EQUATION_ALPHA"; break;
      case GL_BLEND_SRC: RETVAL = "GL_BLEND_SRC"; break;
      case GL_BLEND_SRC_ALPHA: RETVAL = "GL_BLEND_SRC_ALPHA"; break;
      case GL_BLEND_SRC_RGB: RETVAL = "GL_BLEND_SRC_RGB"; break;
      case GL_BLUE_BIAS: RETVAL = "GL_BLUE_BIAS"; break;
      case GL_BLUE_BITS: RETVAL = "GL_BLUE_BITS"; break;
      case GL_BLUE_SCALE: RETVAL = "GL_BLUE_SCALE"; break;
      case GL_CLIENT_ATTRIB_STACK_DEPTH: RETVAL = "GL_CLIENT_ATTRIB_STACK_DEPTH"; break;
      case GL_CLIP_PLANE0: RETVAL = "GL_CLIP_PLANE0"; break;
      case GL_CLIP_PLANE1: RETVAL = "GL_CLIP_PLANE1"; break;
      case GL_CLIP_PLANE2: RETVAL = "GL_CLIP_PLANE2"; break;
      case GL_CLIP_PLANE3: RETVAL = "GL_CLIP_PLANE3"; break;
      case GL_CLIP_PLANE4: RETVAL = "GL_CLIP_PLANE4"; break;
      case GL_CLIP_PLANE5: RETVAL = "GL_CLIP_PLANE5"; break;
      case GL_COLOR_ARRAY: RETVAL = "GL_COLOR_ARRAY"; break;
      case GL_COLOR_ARRAY_COUNT_EXT: RETVAL = "GL_COLOR_ARRAY_COUNT_EXT"; break;
      case GL_COLOR_ARRAY_SIZE: RETVAL = "GL_COLOR_ARRAY_SIZE"; break;
      case GL_COLOR_ARRAY_STRIDE: RETVAL = "GL_COLOR_ARRAY_STRIDE"; break;
      case GL_COLOR_ARRAY_TYPE: RETVAL = "GL_COLOR_ARRAY_TYPE"; break;
      case GL_COLOR_CLEAR_VALUE: RETVAL = "GL_COLOR_CLEAR_VALUE"; break;
      case GL_COLOR_LOGIC_OP: RETVAL = "GL_COLOR_LOGIC_OP"; break;
      case GL_COLOR_MATERIAL: RETVAL = "GL_COLOR_MATERIAL"; break;
      case GL_COLOR_MATERIAL_FACE: RETVAL = "GL_COLOR_MATERIAL_FACE"; break;
      case GL_COLOR_MATERIAL_PARAMETER: RETVAL = "GL_COLOR_MATERIAL_PARAMETER"; break;
      case GL_COLOR_MATRIX_SGI: RETVAL = "GL_COLOR_MATRIX_SGI"; break;
      case GL_COLOR_MATRIX_STACK_DEPTH_SGI: RETVAL = "GL_COLOR_MATRIX_STACK_DEPTH_SGI"; break;
      case GL_COLOR_TABLE_SGI: RETVAL = "GL_COLOR_TABLE_SGI"; break;
      case GL_COLOR_WRITEMASK: RETVAL = "GL_COLOR_WRITEMASK"; break;
      case GL_COMPRESSED_TEXTURE_FORMATS: RETVAL = "GL_COMPRESSED_TEXTURE_FORMATS"; break;
      case GL_CONTEXT_FLAGS: RETVAL = "GL_CONTEXT_FLAGS"; break;
      case GL_CONTEXT_PROFILE_MASK: RETVAL = "GL_CONTEXT_PROFILE_MASK"; break;
      case GL_CONVOLUTION_1D_EXT: RETVAL = "GL_CONVOLUTION_1D_EXT"; break;
      case GL_CONVOLUTION_2D_EXT: RETVAL = "GL_CONVOLUTION_2D_EXT"; break;
      case GL_CONVOLUTION_HINT_SGIX: RETVAL = "GL_CONVOLUTION_HINT_SGIX"; break;
      case GL_CULL_FACE: RETVAL = "GL_CULL_FACE"; break;
      case GL_CULL_FACE_MODE: RETVAL = "GL_CULL_FACE_MODE"; break;
      case GL_CURRENT_COLOR: RETVAL = "GL_CURRENT_COLOR"; break;
      case GL_CURRENT_INDEX: RETVAL = "GL_CURRENT_INDEX"; break;
      case GL_CURRENT_NORMAL: RETVAL = "GL_CURRENT_NORMAL"; break;
      case GL_CURRENT_PROGRAM: RETVAL = "GL_CURRENT_PROGRAM"; break;
      case GL_CURRENT_RASTER_COLOR: RETVAL = "GL_CURRENT_RASTER_COLOR"; break;
      case GL_CURRENT_RASTER_DISTANCE: RETVAL = "GL_CURRENT_RASTER_DISTANCE"; break;
      case GL_CURRENT_RASTER_INDEX: RETVAL = "GL_CURRENT_RASTER_INDEX"; break;
      case GL_CURRENT_RASTER_POSITION: RETVAL = "GL_CURRENT_RASTER_POSITION"; break;
      case GL_CURRENT_RASTER_POSITION_VALID: RETVAL = "GL_CURRENT_RASTER_POSITION_VALID"; break;
      case GL_CURRENT_RASTER_TEXTURE_COORDS: RETVAL = "GL_CURRENT_RASTER_TEXTURE_COORDS"; break;
      case GL_CURRENT_TEXTURE_COORDS: RETVAL = "GL_CURRENT_TEXTURE_COORDS"; break;
      case GL_DEBUG_GROUP_STACK_DEPTH: RETVAL = "GL_DEBUG_GROUP_STACK_DEPTH"; break;
      case GL_DEPTH_BIAS: RETVAL = "GL_DEPTH_BIAS"; break;
      case GL_DEPTH_BITS: RETVAL = "GL_DEPTH_BITS"; break;
      case GL_DEPTH_CLEAR_VALUE: RETVAL = "GL_DEPTH_CLEAR_VALUE"; break;
      case GL_DEPTH_FUNC: RETVAL = "GL_DEPTH_FUNC"; break;
      case GL_DEPTH_RANGE: RETVAL = "GL_DEPTH_RANGE"; break;
      case GL_DEPTH_SCALE: RETVAL = "GL_DEPTH_SCALE"; break;
      case GL_DEPTH_TEST: RETVAL = "GL_DEPTH_TEST"; break;
      case GL_DEPTH_WRITEMASK: RETVAL = "GL_DEPTH_WRITEMASK"; break;
      case GL_DEVICE_LUID_EXT: RETVAL = "GL_DEVICE_LUID_EXT"; break;
      case GL_DEVICE_NODE_MASK_EXT: RETVAL = "GL_DEVICE_NODE_MASK_EXT"; break;
      case GL_DEVICE_UUID_EXT: RETVAL = "GL_DEVICE_UUID_EXT"; break;
      case GL_DISPATCH_INDIRECT_BUFFER_BINDING: RETVAL = "GL_DISPATCH_INDIRECT_BUFFER_BINDING"; break;
      case GL_DISTANCE_ATTENUATION_EXT: RETVAL = "GL_DISTANCE_ATTENUATION_EXT"; break;
      case GL_DITHER: RETVAL = "GL_DITHER"; break;
      case GL_DOUBLEBUFFER: RETVAL = "GL_DOUBLEBUFFER"; break;
      case GL_DRAW_BUFFER: RETVAL = "GL_DRAW_BUFFER"; break;
      case GL_DRAW_FRAMEBUFFER_BINDING: RETVAL = "GL_DRAW_FRAMEBUFFER_BINDING"; break;
      case GL_DRIVER_UUID_EXT: RETVAL = "GL_DRIVER_UUID_EXT"; break;
      case GL_EDGE_FLAG: RETVAL = "GL_EDGE_FLAG"; break;
      case GL_EDGE_FLAG_ARRAY: RETVAL = "GL_EDGE_FLAG_ARRAY"; break;
      case GL_EDGE_FLAG_ARRAY_COUNT_EXT: RETVAL = "GL_EDGE_FLAG_ARRAY_COUNT_EXT"; break;
      case GL_EDGE_FLAG_ARRAY_STRIDE: RETVAL = "GL_EDGE_FLAG_ARRAY_STRIDE"; break;
      case GL_ELEMENT_ARRAY_BUFFER_BINDING: RETVAL = "GL_ELEMENT_ARRAY_BUFFER_BINDING"; break;
      case GL_FEEDBACK_BUFFER_SIZE: RETVAL = "GL_FEEDBACK_BUFFER_SIZE"; break;
      case GL_FEEDBACK_BUFFER_TYPE: RETVAL = "GL_FEEDBACK_BUFFER_TYPE"; break;
      case GL_FETCH_PER_SAMPLE_ARM: RETVAL = "GL_FETCH_PER_SAMPLE_ARM"; break;
      case GL_FOG: RETVAL = "GL_FOG"; break;
      case GL_FOG_COLOR: RETVAL = "GL_FOG_COLOR"; break;
      case GL_FOG_DENSITY: RETVAL = "GL_FOG_DENSITY"; break;
      case GL_FOG_END: RETVAL = "GL_FOG_END"; break;
      case GL_FOG_HINT: RETVAL = "GL_FOG_HINT"; break;
      case GL_FOG_INDEX: RETVAL = "GL_FOG_INDEX"; break;
      case GL_FOG_MODE: RETVAL = "GL_FOG_MODE"; break;
      case GL_FOG_OFFSET_SGIX: RETVAL = "GL_FOG_OFFSET_SGIX"; break;
      case GL_FOG_OFFSET_VALUE_SGIX: RETVAL = "GL_FOG_OFFSET_VALUE_SGIX"; break;
      case GL_FOG_START: RETVAL = "GL_FOG_START"; break;
      case GL_FRAGMENT_SHADER_ATI: RETVAL = "GL_FRAGMENT_SHADER_ATI"; break;
      case GL_FRAGMENT_SHADER_DERIVATIVE_HINT: RETVAL = "GL_FRAGMENT_SHADER_DERIVATIVE_HINT"; break;
      case GL_FRAGMENT_SHADER_FRAMEBUFFER_FETCH_MRT_ARM: RETVAL = "GL_FRAGMENT_SHADER_FRAMEBUFFER_FETCH_MRT_ARM"; break;
      case GL_FRAGMENT_SHADING_RATE_ATTACHMENT_WITH_DEFAULT_FRAMEBUFFER_SUPPORTED_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_ATTACHMENT_WITH_DEFAULT_FRAMEBUFFER_SUPPORTED_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_NON_TRIVIAL_COMBINERS_SUPPORTED_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_NON_TRIVIAL_COMBINERS_SUPPORTED_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_PRIMITIVE_RATE_WITH_MULTI_VIEWPORT_SUPPORTED_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_PRIMITIVE_RATE_WITH_MULTI_VIEWPORT_SUPPORTED_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_WITH_SAMPLE_MASK_SUPPORTED_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_WITH_SAMPLE_MASK_SUPPORTED_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_WITH_SHADER_DEPTH_STENCIL_WRITES_SUPPORTED_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_WITH_SHADER_DEPTH_STENCIL_WRITES_SUPPORTED_EXT"; break;
      case GL_FRAMEBUFFER_FETCH_NONCOHERENT_QCOM: RETVAL = "GL_FRAMEBUFFER_FETCH_NONCOHERENT_QCOM"; break;
      case GL_FRONT_FACE: RETVAL = "GL_FRONT_FACE"; break;
      case GL_GENERATE_MIPMAP_HINT_SGIS: RETVAL = "GL_GENERATE_MIPMAP_HINT_SGIS"; break;
      case GL_GREEN_BIAS: RETVAL = "GL_GREEN_BIAS"; break;
      case GL_GREEN_BITS: RETVAL = "GL_GREEN_BITS"; break;
      case GL_GREEN_SCALE: RETVAL = "GL_GREEN_SCALE"; break;
      case GL_HISTOGRAM_EXT: RETVAL = "GL_HISTOGRAM_EXT"; break;
      case GL_IMPLEMENTATION_COLOR_READ_FORMAT: RETVAL = "GL_IMPLEMENTATION_COLOR_READ_FORMAT"; break;
      case GL_IMPLEMENTATION_COLOR_READ_TYPE: RETVAL = "GL_IMPLEMENTATION_COLOR_READ_TYPE"; break;
      case GL_INDEX_ARRAY: RETVAL = "GL_INDEX_ARRAY"; break;
      case GL_INDEX_ARRAY_COUNT_EXT: RETVAL = "GL_INDEX_ARRAY_COUNT_EXT"; break;
      case GL_INDEX_ARRAY_STRIDE: RETVAL = "GL_INDEX_ARRAY_STRIDE"; break;
      case GL_INDEX_ARRAY_TYPE: RETVAL = "GL_INDEX_ARRAY_TYPE"; break;
      case GL_INDEX_BITS: RETVAL = "GL_INDEX_BITS"; break;
      case GL_INDEX_CLEAR_VALUE: RETVAL = "GL_INDEX_CLEAR_VALUE"; break;
      case GL_INDEX_MODE: RETVAL = "GL_INDEX_MODE"; break;
      case GL_INDEX_OFFSET: RETVAL = "GL_INDEX_OFFSET"; break;
      case GL_INDEX_SHIFT: RETVAL = "GL_INDEX_SHIFT"; break;
      case GL_INDEX_WRITEMASK: RETVAL = "GL_INDEX_WRITEMASK"; break;
      case GL_INTERLACE_SGIX: RETVAL = "GL_INTERLACE_SGIX"; break;
      case GL_LAYER_PROVOKING_VERTEX: RETVAL = "GL_LAYER_PROVOKING_VERTEX"; break;
      case GL_LIGHT0: RETVAL = "GL_LIGHT0"; break;
      case GL_LIGHT1: RETVAL = "GL_LIGHT1"; break;
      case GL_LIGHT2: RETVAL = "GL_LIGHT2"; break;
      case GL_LIGHT3: RETVAL = "GL_LIGHT3"; break;
      case GL_LIGHT4: RETVAL = "GL_LIGHT4"; break;
      case GL_LIGHT5: RETVAL = "GL_LIGHT5"; break;
      case GL_LIGHT6: RETVAL = "GL_LIGHT6"; break;
      case GL_LIGHT7: RETVAL = "GL_LIGHT7"; break;
      case GL_LIGHTING: RETVAL = "GL_LIGHTING"; break;
      case GL_LIGHT_MODEL_AMBIENT: RETVAL = "GL_LIGHT_MODEL_AMBIENT"; break;
      case GL_LIGHT_MODEL_COLOR_CONTROL: RETVAL = "GL_LIGHT_MODEL_COLOR_CONTROL"; break;
      case GL_LIGHT_MODEL_LOCAL_VIEWER: RETVAL = "GL_LIGHT_MODEL_LOCAL_VIEWER"; break;
      case GL_LIGHT_MODEL_TWO_SIDE: RETVAL = "GL_LIGHT_MODEL_TWO_SIDE"; break;
      case GL_LINE_SMOOTH: RETVAL = "GL_LINE_SMOOTH"; break;
      case GL_LINE_SMOOTH_HINT: RETVAL = "GL_LINE_SMOOTH_HINT"; break;
      case GL_LINE_STIPPLE: RETVAL = "GL_LINE_STIPPLE"; break;
      case GL_LINE_STIPPLE_PATTERN: RETVAL = "GL_LINE_STIPPLE_PATTERN"; break;
      case GL_LINE_STIPPLE_REPEAT: RETVAL = "GL_LINE_STIPPLE_REPEAT"; break;
      case GL_LINE_WIDTH: RETVAL = "GL_LINE_WIDTH"; break;
      case GL_LINE_WIDTH_GRANULARITY: RETVAL = "GL_LINE_WIDTH_GRANULARITY"; break;
      case GL_LINE_WIDTH_RANGE: RETVAL = "GL_LINE_WIDTH_RANGE"; break;
      case GL_LIST_BASE: RETVAL = "GL_LIST_BASE"; break;
      case GL_LIST_INDEX: RETVAL = "GL_LIST_INDEX"; break;
      case GL_LIST_MODE: RETVAL = "GL_LIST_MODE"; break;
      case GL_LOGIC_OP: RETVAL = "GL_LOGIC_OP"; break;
      case GL_LOGIC_OP_MODE: RETVAL = "GL_LOGIC_OP_MODE"; break;
      case GL_MAJOR_VERSION: RETVAL = "GL_MAJOR_VERSION"; break;
      case GL_MAP1_COLOR_4: RETVAL = "GL_MAP1_COLOR_4"; break;
      case GL_MAP1_GRID_DOMAIN: RETVAL = "GL_MAP1_GRID_DOMAIN"; break;
      case GL_MAP1_GRID_SEGMENTS: RETVAL = "GL_MAP1_GRID_SEGMENTS"; break;
      case GL_MAP1_INDEX: RETVAL = "GL_MAP1_INDEX"; break;
      case GL_MAP1_NORMAL: RETVAL = "GL_MAP1_NORMAL"; break;
      case GL_MAP1_TEXTURE_COORD_1: RETVAL = "GL_MAP1_TEXTURE_COORD_1"; break;
      case GL_MAP1_TEXTURE_COORD_2: RETVAL = "GL_MAP1_TEXTURE_COORD_2"; break;
      case GL_MAP1_TEXTURE_COORD_3: RETVAL = "GL_MAP1_TEXTURE_COORD_3"; break;
      case GL_MAP1_TEXTURE_COORD_4: RETVAL = "GL_MAP1_TEXTURE_COORD_4"; break;
      case GL_MAP1_VERTEX_3: RETVAL = "GL_MAP1_VERTEX_3"; break;
      case GL_MAP1_VERTEX_4: RETVAL = "GL_MAP1_VERTEX_4"; break;
      case GL_MAP2_COLOR_4: RETVAL = "GL_MAP2_COLOR_4"; break;
      case GL_MAP2_GRID_DOMAIN: RETVAL = "GL_MAP2_GRID_DOMAIN"; break;
      case GL_MAP2_GRID_SEGMENTS: RETVAL = "GL_MAP2_GRID_SEGMENTS"; break;
      case GL_MAP2_INDEX: RETVAL = "GL_MAP2_INDEX"; break;
      case GL_MAP2_NORMAL: RETVAL = "GL_MAP2_NORMAL"; break;
      case GL_MAP2_TEXTURE_COORD_1: RETVAL = "GL_MAP2_TEXTURE_COORD_1"; break;
      case GL_MAP2_TEXTURE_COORD_2: RETVAL = "GL_MAP2_TEXTURE_COORD_2"; break;
      case GL_MAP2_TEXTURE_COORD_3: RETVAL = "GL_MAP2_TEXTURE_COORD_3"; break;
      case GL_MAP2_TEXTURE_COORD_4: RETVAL = "GL_MAP2_TEXTURE_COORD_4"; break;
      case GL_MAP2_VERTEX_3: RETVAL = "GL_MAP2_VERTEX_3"; break;
      case GL_MAP2_VERTEX_4: RETVAL = "GL_MAP2_VERTEX_4"; break;
      case GL_MAP_COLOR: RETVAL = "GL_MAP_COLOR"; break;
      case GL_MAP_STENCIL: RETVAL = "GL_MAP_STENCIL"; break;
      case GL_MATRIX_MODE: RETVAL = "GL_MATRIX_MODE"; break;
      case GL_MAX_3D_TEXTURE_SIZE: RETVAL = "GL_MAX_3D_TEXTURE_SIZE"; break;
      case GL_MAX_ARRAY_TEXTURE_LAYERS: RETVAL = "GL_MAX_ARRAY_TEXTURE_LAYERS"; break;
      case GL_MAX_ASYNC_DRAW_PIXELS_SGIX: RETVAL = "GL_MAX_ASYNC_DRAW_PIXELS_SGIX"; break;
      case GL_MAX_ASYNC_HISTOGRAM_SGIX: RETVAL = "GL_MAX_ASYNC_HISTOGRAM_SGIX"; break;
      case GL_MAX_ASYNC_READ_PIXELS_SGIX: RETVAL = "GL_MAX_ASYNC_READ_PIXELS_SGIX"; break;
      case GL_MAX_ASYNC_TEX_IMAGE_SGIX: RETVAL = "GL_MAX_ASYNC_TEX_IMAGE_SGIX"; break;
      case GL_MAX_ATTRIB_STACK_DEPTH: RETVAL = "GL_MAX_ATTRIB_STACK_DEPTH"; break;
      case GL_MAX_CLIENT_ATTRIB_STACK_DEPTH: RETVAL = "GL_MAX_CLIENT_ATTRIB_STACK_DEPTH"; break;
      case GL_MAX_CLIP_PLANES: RETVAL = "GL_MAX_CLIP_PLANES"; break;
      case GL_MAX_COLOR_ATTACHMENTS: RETVAL = "GL_MAX_COLOR_ATTACHMENTS"; break;
      case GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI: RETVAL = "GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI"; break;
      case GL_MAX_COLOR_TEXTURE_SAMPLES: RETVAL = "GL_MAX_COLOR_TEXTURE_SAMPLES"; break;
      case GL_MAX_COMBINED_ATOMIC_COUNTERS: RETVAL = "GL_MAX_COMBINED_ATOMIC_COUNTERS"; break;
      case GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS"; break;
      case GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS"; break;
      case GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS"; break;
      case GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS: RETVAL = "GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS"; break;
      case GL_MAX_COMBINED_UNIFORM_BLOCKS: RETVAL = "GL_MAX_COMBINED_UNIFORM_BLOCKS"; break;
      case GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS"; break;
      case GL_MAX_COMPUTE_ATOMIC_COUNTERS: RETVAL = "GL_MAX_COMPUTE_ATOMIC_COUNTERS"; break;
      case GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS: RETVAL = "GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS"; break;
      case GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS: RETVAL = "GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS"; break;
      case GL_MAX_COMPUTE_UNIFORM_BLOCKS: RETVAL = "GL_MAX_COMPUTE_UNIFORM_BLOCKS"; break;
      case GL_MAX_COMPUTE_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_COMPUTE_UNIFORM_COMPONENTS"; break;
      case GL_MAX_COMPUTE_WORK_GROUP_COUNT: RETVAL = "GL_MAX_COMPUTE_WORK_GROUP_COUNT"; break;
      case GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS: RETVAL = "GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS"; break;
      case GL_MAX_COMPUTE_WORK_GROUP_SIZE: RETVAL = "GL_MAX_COMPUTE_WORK_GROUP_SIZE"; break;
      case GL_MAX_CUBE_MAP_TEXTURE_SIZE: RETVAL = "GL_MAX_CUBE_MAP_TEXTURE_SIZE"; break;
      case GL_MAX_DEBUG_GROUP_STACK_DEPTH: RETVAL = "GL_MAX_DEBUG_GROUP_STACK_DEPTH"; break;
      case GL_MAX_DEPTH_TEXTURE_SAMPLES: RETVAL = "GL_MAX_DEPTH_TEXTURE_SAMPLES"; break;
      case GL_MAX_DRAW_BUFFERS: RETVAL = "GL_MAX_DRAW_BUFFERS"; break;
      case GL_MAX_DUAL_SOURCE_DRAW_BUFFERS: RETVAL = "GL_MAX_DUAL_SOURCE_DRAW_BUFFERS"; break;
      case GL_MAX_ELEMENTS_INDICES: RETVAL = "GL_MAX_ELEMENTS_INDICES"; break;
      case GL_MAX_ELEMENTS_VERTICES: RETVAL = "GL_MAX_ELEMENTS_VERTICES"; break;
      case GL_MAX_ELEMENT_INDEX: RETVAL = "GL_MAX_ELEMENT_INDEX"; break;
      case GL_MAX_EVAL_ORDER: RETVAL = "GL_MAX_EVAL_ORDER"; break;
      case GL_MAX_FRAGMENT_ATOMIC_COUNTERS: RETVAL = "GL_MAX_FRAGMENT_ATOMIC_COUNTERS"; break;
      case GL_MAX_FRAGMENT_INPUT_COMPONENTS: RETVAL = "GL_MAX_FRAGMENT_INPUT_COMPONENTS"; break;
      case GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_LAYERS_EXT: RETVAL = "GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_LAYERS_EXT"; break;
      case GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_ASPECT_RATIO_EXT: RETVAL = "GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_ASPECT_RATIO_EXT"; break;
      case GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT: RETVAL = "GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT"; break;
      case GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT: RETVAL = "GL_MAX_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT"; break;
      case GL_MAX_FRAGMENT_UNIFORM_BLOCKS: RETVAL = "GL_MAX_FRAGMENT_UNIFORM_BLOCKS"; break;
      case GL_MAX_FRAGMENT_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_FRAGMENT_UNIFORM_COMPONENTS"; break;
      case GL_MAX_FRAGMENT_UNIFORM_VECTORS: RETVAL = "GL_MAX_FRAGMENT_UNIFORM_VECTORS"; break;
      case GL_MAX_FRAMEBUFFER_HEIGHT: RETVAL = "GL_MAX_FRAMEBUFFER_HEIGHT"; break;
      case GL_MAX_FRAMEBUFFER_LAYERS: RETVAL = "GL_MAX_FRAMEBUFFER_LAYERS"; break;
      case GL_MAX_FRAMEBUFFER_SAMPLES: RETVAL = "GL_MAX_FRAMEBUFFER_SAMPLES"; break;
      case GL_MAX_FRAMEBUFFER_WIDTH: RETVAL = "GL_MAX_FRAMEBUFFER_WIDTH"; break;
      case GL_MAX_GEOMETRY_ATOMIC_COUNTERS: RETVAL = "GL_MAX_GEOMETRY_ATOMIC_COUNTERS"; break;
      case GL_MAX_GEOMETRY_INPUT_COMPONENTS: RETVAL = "GL_MAX_GEOMETRY_INPUT_COMPONENTS"; break;
      case GL_MAX_GEOMETRY_OUTPUT_COMPONENTS: RETVAL = "GL_MAX_GEOMETRY_OUTPUT_COMPONENTS"; break;
      case GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS: RETVAL = "GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS"; break;
      case GL_MAX_GEOMETRY_UNIFORM_BLOCKS: RETVAL = "GL_MAX_GEOMETRY_UNIFORM_BLOCKS"; break;
      case GL_MAX_GEOMETRY_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_GEOMETRY_UNIFORM_COMPONENTS"; break;
      case GL_MAX_INTEGER_SAMPLES: RETVAL = "GL_MAX_INTEGER_SAMPLES"; break;
      case GL_MAX_LABEL_LENGTH: RETVAL = "GL_MAX_LABEL_LENGTH"; break;
      case GL_MAX_LIGHTS: RETVAL = "GL_MAX_LIGHTS"; break;
      case GL_MAX_LIST_NESTING: RETVAL = "GL_MAX_LIST_NESTING"; break;
      case GL_MAX_MESH_OUTPUT_COMPONENTS_EXT: RETVAL = "GL_MAX_MESH_OUTPUT_COMPONENTS_EXT"; break;
      case GL_MAX_MESH_OUTPUT_LAYERS_EXT: RETVAL = "GL_MAX_MESH_OUTPUT_LAYERS_EXT"; break;
      case GL_MAX_MESH_OUTPUT_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_MESH_OUTPUT_MEMORY_SIZE_EXT"; break;
      case GL_MAX_MESH_OUTPUT_PRIMITIVES_EXT: RETVAL = "GL_MAX_MESH_OUTPUT_PRIMITIVES_EXT"; break;
      case GL_MAX_MESH_PAYLOAD_AND_OUTPUT_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_MESH_PAYLOAD_AND_OUTPUT_MEMORY_SIZE_EXT"; break;
      case GL_MAX_MESH_PAYLOAD_AND_SHARED_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_MESH_PAYLOAD_AND_SHARED_MEMORY_SIZE_EXT"; break;
      case GL_MAX_MESH_SHARED_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_MESH_SHARED_MEMORY_SIZE_EXT"; break;
      case GL_MAX_MESH_WORK_GROUP_COUNT_EXT: RETVAL = "GL_MAX_MESH_WORK_GROUP_COUNT_EXT"; break;
      case GL_MAX_MESH_WORK_GROUP_INVOCATIONS_EXT: RETVAL = "GL_MAX_MESH_WORK_GROUP_INVOCATIONS_EXT"; break;
      case GL_MAX_MESH_WORK_GROUP_SIZE_EXT: RETVAL = "GL_MAX_MESH_WORK_GROUP_SIZE_EXT"; break;
      case GL_MAX_MESH_WORK_GROUP_TOTAL_COUNT_EXT: RETVAL = "GL_MAX_MESH_WORK_GROUP_TOTAL_COUNT_EXT"; break;
      case GL_MAX_MODELVIEW_STACK_DEPTH: RETVAL = "GL_MAX_MODELVIEW_STACK_DEPTH"; break;
      case GL_MAX_NAME_STACK_DEPTH: RETVAL = "GL_MAX_NAME_STACK_DEPTH"; break;
      case GL_MAX_PIXEL_MAP_TABLE: RETVAL = "GL_MAX_PIXEL_MAP_TABLE"; break;
      case GL_MAX_PREFERRED_MESH_WORK_GROUP_INVOCATIONS_EXT: RETVAL = "GL_MAX_PREFERRED_MESH_WORK_GROUP_INVOCATIONS_EXT"; break;
      case GL_MAX_PREFERRED_TASK_WORK_GROUP_INVOCATIONS_EXT: RETVAL = "GL_MAX_PREFERRED_TASK_WORK_GROUP_INVOCATIONS_EXT"; break;
      case GL_MAX_PROGRAM_TEXEL_OFFSET: RETVAL = "GL_MAX_PROGRAM_TEXEL_OFFSET"; break;
      case GL_MAX_PROJECTION_STACK_DEPTH: RETVAL = "GL_MAX_PROJECTION_STACK_DEPTH"; break;
      case GL_MAX_RECTANGLE_TEXTURE_SIZE: RETVAL = "GL_MAX_RECTANGLE_TEXTURE_SIZE"; break;
      case GL_MAX_RENDERBUFFER_SIZE: RETVAL = "GL_MAX_RENDERBUFFER_SIZE"; break;
      case GL_MAX_SAMPLE_MASK_WORDS: RETVAL = "GL_MAX_SAMPLE_MASK_WORDS"; break;
      case GL_MAX_SERVER_WAIT_TIMEOUT: RETVAL = "GL_MAX_SERVER_WAIT_TIMEOUT"; break;
      case GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS: RETVAL = "GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS"; break;
      case GL_MAX_TASK_PAYLOAD_AND_SHARED_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_TASK_PAYLOAD_AND_SHARED_MEMORY_SIZE_EXT"; break;
      case GL_MAX_TASK_PAYLOAD_SIZE_EXT: RETVAL = "GL_MAX_TASK_PAYLOAD_SIZE_EXT"; break;
      case GL_MAX_TASK_SHARED_MEMORY_SIZE_EXT: RETVAL = "GL_MAX_TASK_SHARED_MEMORY_SIZE_EXT"; break;
      case GL_MAX_TASK_WORK_GROUP_COUNT_EXT: RETVAL = "GL_MAX_TASK_WORK_GROUP_COUNT_EXT"; break;
      case GL_MAX_TASK_WORK_GROUP_INVOCATIONS_EXT: RETVAL = "GL_MAX_TASK_WORK_GROUP_INVOCATIONS_EXT"; break;
      case GL_MAX_TASK_WORK_GROUP_SIZE_EXT: RETVAL = "GL_MAX_TASK_WORK_GROUP_SIZE_EXT"; break;
      case GL_MAX_TASK_WORK_GROUP_TOTAL_COUNT_EXT: RETVAL = "GL_MAX_TASK_WORK_GROUP_TOTAL_COUNT_EXT"; break;
      case GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS: RETVAL = "GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS"; break;
      case GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS: RETVAL = "GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS"; break;
      case GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS: RETVAL = "GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS"; break;
      case GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS: RETVAL = "GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS"; break;
      case GL_MAX_TEXTURE_BUFFER_SIZE: RETVAL = "GL_MAX_TEXTURE_BUFFER_SIZE"; break;
      case GL_MAX_TEXTURE_IMAGE_UNITS: RETVAL = "GL_MAX_TEXTURE_IMAGE_UNITS"; break;
      case GL_MAX_TEXTURE_LOD_BIAS: RETVAL = "GL_MAX_TEXTURE_LOD_BIAS"; break;
      case GL_MAX_TEXTURE_SIZE: RETVAL = "GL_MAX_TEXTURE_SIZE"; break;
      case GL_MAX_TEXTURE_STACK_DEPTH: RETVAL = "GL_MAX_TEXTURE_STACK_DEPTH"; break;
      case GL_MAX_TIMELINE_SEMAPHORE_VALUE_DIFFERENCE_NV: RETVAL = "GL_MAX_TIMELINE_SEMAPHORE_VALUE_DIFFERENCE_NV"; break;
      case GL_MAX_UNIFORM_BLOCK_SIZE: RETVAL = "GL_MAX_UNIFORM_BLOCK_SIZE"; break;
      case GL_MAX_UNIFORM_BUFFER_BINDINGS: RETVAL = "GL_MAX_UNIFORM_BUFFER_BINDINGS"; break;
      case GL_MAX_UNIFORM_LOCATIONS: RETVAL = "GL_MAX_UNIFORM_LOCATIONS"; break;
      case GL_MAX_VARYING_FLOATS: RETVAL = "GL_MAX_VARYING_FLOATS"; break;
      case GL_MAX_VARYING_VECTORS: RETVAL = "GL_MAX_VARYING_VECTORS"; break;
      case GL_MAX_VERTEX_ATOMIC_COUNTERS: RETVAL = "GL_MAX_VERTEX_ATOMIC_COUNTERS"; break;
      case GL_MAX_VERTEX_ATTRIBS: RETVAL = "GL_MAX_VERTEX_ATTRIBS"; break;
      case GL_MAX_VERTEX_ATTRIB_BINDINGS: RETVAL = "GL_MAX_VERTEX_ATTRIB_BINDINGS"; break;
      case GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET: RETVAL = "GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET"; break;
      case GL_MAX_VERTEX_OUTPUT_COMPONENTS: RETVAL = "GL_MAX_VERTEX_OUTPUT_COMPONENTS"; break;
      case GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS: RETVAL = "GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS"; break;
      case GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS: RETVAL = "GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS"; break;
      case GL_MAX_VERTEX_UNIFORM_BLOCKS: RETVAL = "GL_MAX_VERTEX_UNIFORM_BLOCKS"; break;
      case GL_MAX_VERTEX_UNIFORM_COMPONENTS: RETVAL = "GL_MAX_VERTEX_UNIFORM_COMPONENTS"; break;
      case GL_MAX_VERTEX_UNIFORM_VECTORS: RETVAL = "GL_MAX_VERTEX_UNIFORM_VECTORS"; break;
      case GL_MAX_VIEWPORTS: RETVAL = "GL_MAX_VIEWPORTS"; break;
      case GL_MAX_VIEWPORT_DIMS: RETVAL = "GL_MAX_VIEWPORT_DIMS"; break;
      case GL_MESH_PREFERS_COMPACT_PRIMITIVE_OUTPUT_EXT: RETVAL = "GL_MESH_PREFERS_COMPACT_PRIMITIVE_OUTPUT_EXT"; break;
      case GL_MESH_PREFERS_COMPACT_VERTEX_OUTPUT_EXT: RETVAL = "GL_MESH_PREFERS_COMPACT_VERTEX_OUTPUT_EXT"; break;
      case GL_MESH_PREFERS_LOCAL_INVOCATION_PRIMITIVE_OUTPUT_EXT: RETVAL = "GL_MESH_PREFERS_LOCAL_INVOCATION_PRIMITIVE_OUTPUT_EXT"; break;
      case GL_MESH_PREFERS_LOCAL_INVOCATION_VERTEX_OUTPUT_EXT: RETVAL = "GL_MESH_PREFERS_LOCAL_INVOCATION_VERTEX_OUTPUT_EXT"; break;
      case GL_MINMAX_EXT: RETVAL = "GL_MINMAX_EXT"; break;
      case GL_MINOR_VERSION: RETVAL = "GL_MINOR_VERSION"; break;
      case GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT: RETVAL = "GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_HEIGHT_EXT"; break;
      case GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT: RETVAL = "GL_MIN_FRAGMENT_SHADING_RATE_ATTACHMENT_TEXEL_WIDTH_EXT"; break;
      case GL_MIN_MAP_BUFFER_ALIGNMENT: RETVAL = "GL_MIN_MAP_BUFFER_ALIGNMENT"; break;
      case GL_MIN_PROGRAM_TEXEL_OFFSET: RETVAL = "GL_MIN_PROGRAM_TEXEL_OFFSET"; break;
      case GL_MODELVIEW_MATRIX: RETVAL = "GL_MODELVIEW_MATRIX"; break;
      case GL_MODELVIEW_STACK_DEPTH: RETVAL = "GL_MODELVIEW_STACK_DEPTH"; break;
      case GL_MOTION_ESTIMATION_SEARCH_BLOCK_X_QCOM: RETVAL = "GL_MOTION_ESTIMATION_SEARCH_BLOCK_X_QCOM"; break;
      case GL_MOTION_ESTIMATION_SEARCH_BLOCK_Y_QCOM: RETVAL = "GL_MOTION_ESTIMATION_SEARCH_BLOCK_Y_QCOM"; break;
      case GL_MULTISAMPLE_SGIS: RETVAL = "GL_MULTISAMPLE_SGIS"; break;
      case GL_NAME_STACK_DEPTH: RETVAL = "GL_NAME_STACK_DEPTH"; break;
      case GL_NORMALIZE: RETVAL = "GL_NORMALIZE"; break;
      case GL_NORMAL_ARRAY: RETVAL = "GL_NORMAL_ARRAY"; break;
      case GL_NORMAL_ARRAY_COUNT_EXT: RETVAL = "GL_NORMAL_ARRAY_COUNT_EXT"; break;
      case GL_NORMAL_ARRAY_STRIDE: RETVAL = "GL_NORMAL_ARRAY_STRIDE"; break;
      case GL_NORMAL_ARRAY_TYPE: RETVAL = "GL_NORMAL_ARRAY_TYPE"; break;
      case GL_NUM_COMPRESSED_TEXTURE_FORMATS: RETVAL = "GL_NUM_COMPRESSED_TEXTURE_FORMATS"; break;
      case GL_NUM_DEVICE_UUIDS_EXT: RETVAL = "GL_NUM_DEVICE_UUIDS_EXT"; break;
      case GL_NUM_EXTENSIONS: RETVAL = "GL_NUM_EXTENSIONS"; break;
      case GL_NUM_PROGRAM_BINARY_FORMATS: RETVAL = "GL_NUM_PROGRAM_BINARY_FORMATS"; break;
      case GL_NUM_SHADER_BINARY_FORMATS: RETVAL = "GL_NUM_SHADER_BINARY_FORMATS"; break;
      case GL_PACK_ALIGNMENT: RETVAL = "GL_PACK_ALIGNMENT"; break;
      case GL_PACK_CMYK_HINT_EXT: RETVAL = "GL_PACK_CMYK_HINT_EXT"; break;
      case GL_PACK_IMAGE_HEIGHT: RETVAL = "GL_PACK_IMAGE_HEIGHT"; break;
      case GL_PACK_LSB_FIRST: RETVAL = "GL_PACK_LSB_FIRST"; break;
      case GL_PACK_RESAMPLE_SGIX: RETVAL = "GL_PACK_RESAMPLE_SGIX"; break;
      case GL_PACK_ROW_LENGTH: RETVAL = "GL_PACK_ROW_LENGTH"; break;
      case GL_PACK_SKIP_IMAGES: RETVAL = "GL_PACK_SKIP_IMAGES"; break;
      case GL_PACK_SKIP_PIXELS: RETVAL = "GL_PACK_SKIP_PIXELS"; break;
      case GL_PACK_SKIP_ROWS: RETVAL = "GL_PACK_SKIP_ROWS"; break;
      case GL_PACK_SUBSAMPLE_RATE_SGIX: RETVAL = "GL_PACK_SUBSAMPLE_RATE_SGIX"; break;
      case GL_PACK_SWAP_BYTES: RETVAL = "GL_PACK_SWAP_BYTES"; break;
      case GL_PERSPECTIVE_CORRECTION_HINT: RETVAL = "GL_PERSPECTIVE_CORRECTION_HINT"; break;
      case GL_PIXEL_MAP_A_TO_A_SIZE: RETVAL = "GL_PIXEL_MAP_A_TO_A_SIZE"; break;
      case GL_PIXEL_MAP_B_TO_B_SIZE: RETVAL = "GL_PIXEL_MAP_B_TO_B_SIZE"; break;
      case GL_PIXEL_MAP_G_TO_G_SIZE: RETVAL = "GL_PIXEL_MAP_G_TO_G_SIZE"; break;
      case GL_PIXEL_MAP_I_TO_A_SIZE: RETVAL = "GL_PIXEL_MAP_I_TO_A_SIZE"; break;
      case GL_PIXEL_MAP_I_TO_B_SIZE: RETVAL = "GL_PIXEL_MAP_I_TO_B_SIZE"; break;
      case GL_PIXEL_MAP_I_TO_G_SIZE: RETVAL = "GL_PIXEL_MAP_I_TO_G_SIZE"; break;
      case GL_PIXEL_MAP_I_TO_I_SIZE: RETVAL = "GL_PIXEL_MAP_I_TO_I_SIZE"; break;
      case GL_PIXEL_MAP_I_TO_R_SIZE: RETVAL = "GL_PIXEL_MAP_I_TO_R_SIZE"; break;
      case GL_PIXEL_MAP_R_TO_R_SIZE: RETVAL = "GL_PIXEL_MAP_R_TO_R_SIZE"; break;
      case GL_PIXEL_MAP_S_TO_S_SIZE: RETVAL = "GL_PIXEL_MAP_S_TO_S_SIZE"; break;
      case GL_PIXEL_PACK_BUFFER_BINDING: RETVAL = "GL_PIXEL_PACK_BUFFER_BINDING"; break;
      case GL_PIXEL_UNPACK_BUFFER_BINDING: RETVAL = "GL_PIXEL_UNPACK_BUFFER_BINDING"; break;
      case GL_POINT_FADE_THRESHOLD_SIZE: RETVAL = "GL_POINT_FADE_THRESHOLD_SIZE"; break;
      case GL_POINT_SIZE: RETVAL = "GL_POINT_SIZE"; break;
      case GL_POINT_SIZE_GRANULARITY: RETVAL = "GL_POINT_SIZE_GRANULARITY"; break;
      case GL_POINT_SIZE_MAX: RETVAL = "GL_POINT_SIZE_MAX"; break;
      case GL_POINT_SIZE_MIN: RETVAL = "GL_POINT_SIZE_MIN"; break;
      case GL_POINT_SIZE_RANGE: RETVAL = "GL_POINT_SIZE_RANGE"; break;
      case GL_POINT_SMOOTH: RETVAL = "GL_POINT_SMOOTH"; break;
      case GL_POINT_SMOOTH_HINT: RETVAL = "GL_POINT_SMOOTH_HINT"; break;
      case GL_POLYGON_MODE: RETVAL = "GL_POLYGON_MODE"; break;
      case GL_POLYGON_OFFSET_BIAS_EXT: RETVAL = "GL_POLYGON_OFFSET_BIAS_EXT"; break;
      case GL_POLYGON_OFFSET_FACTOR: RETVAL = "GL_POLYGON_OFFSET_FACTOR"; break;
      case GL_POLYGON_OFFSET_FILL: RETVAL = "GL_POLYGON_OFFSET_FILL"; break;
      case GL_POLYGON_OFFSET_LINE: RETVAL = "GL_POLYGON_OFFSET_LINE"; break;
      case GL_POLYGON_OFFSET_POINT: RETVAL = "GL_POLYGON_OFFSET_POINT"; break;
      case GL_POLYGON_OFFSET_UNITS: RETVAL = "GL_POLYGON_OFFSET_UNITS"; break;
      case GL_POLYGON_SMOOTH: RETVAL = "GL_POLYGON_SMOOTH"; break;
      case GL_POLYGON_SMOOTH_HINT: RETVAL = "GL_POLYGON_SMOOTH_HINT"; break;
      case GL_POLYGON_STIPPLE: RETVAL = "GL_POLYGON_STIPPLE"; break;
      case GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI: RETVAL = "GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI"; break;
      case GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI: RETVAL = "GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI"; break;
      case GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI: RETVAL = "GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI"; break;
      case GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI: RETVAL = "GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI"; break;
      case GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI: RETVAL = "GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI"; break;
      case GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI: RETVAL = "GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI"; break;
      case GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI: RETVAL = "GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI"; break;
      case GL_POST_COLOR_MATRIX_RED_BIAS_SGI: RETVAL = "GL_POST_COLOR_MATRIX_RED_BIAS_SGI"; break;
      case GL_POST_COLOR_MATRIX_RED_SCALE_SGI: RETVAL = "GL_POST_COLOR_MATRIX_RED_SCALE_SGI"; break;
      case GL_POST_CONVOLUTION_ALPHA_BIAS_EXT: RETVAL = "GL_POST_CONVOLUTION_ALPHA_BIAS_EXT"; break;
      case GL_POST_CONVOLUTION_ALPHA_SCALE_EXT: RETVAL = "GL_POST_CONVOLUTION_ALPHA_SCALE_EXT"; break;
      case GL_POST_CONVOLUTION_BLUE_BIAS_EXT: RETVAL = "GL_POST_CONVOLUTION_BLUE_BIAS_EXT"; break;
      case GL_POST_CONVOLUTION_BLUE_SCALE_EXT: RETVAL = "GL_POST_CONVOLUTION_BLUE_SCALE_EXT"; break;
      case GL_POST_CONVOLUTION_COLOR_TABLE_SGI: RETVAL = "GL_POST_CONVOLUTION_COLOR_TABLE_SGI"; break;
      case GL_POST_CONVOLUTION_GREEN_BIAS_EXT: RETVAL = "GL_POST_CONVOLUTION_GREEN_BIAS_EXT"; break;
      case GL_POST_CONVOLUTION_GREEN_SCALE_EXT: RETVAL = "GL_POST_CONVOLUTION_GREEN_SCALE_EXT"; break;
      case GL_POST_CONVOLUTION_RED_BIAS_EXT: RETVAL = "GL_POST_CONVOLUTION_RED_BIAS_EXT"; break;
      case GL_POST_CONVOLUTION_RED_SCALE_EXT: RETVAL = "GL_POST_CONVOLUTION_RED_SCALE_EXT"; break;
      case GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX"; break;
      case GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX"; break;
      case GL_PRIMITIVE_RESTART_INDEX: RETVAL = "GL_PRIMITIVE_RESTART_INDEX"; break;
      case GL_PROGRAM_BINARY_FORMATS: RETVAL = "GL_PROGRAM_BINARY_FORMATS"; break;
      case GL_PROGRAM_PIPELINE_BINDING: RETVAL = "GL_PROGRAM_PIPELINE_BINDING"; break;
      case GL_PROGRAM_POINT_SIZE: RETVAL = "GL_PROGRAM_POINT_SIZE"; break;
      case GL_PROJECTION_MATRIX: RETVAL = "GL_PROJECTION_MATRIX"; break;
      case GL_PROJECTION_STACK_DEPTH: RETVAL = "GL_PROJECTION_STACK_DEPTH"; break;
      case GL_PROVOKING_VERTEX: RETVAL = "GL_PROVOKING_VERTEX"; break;
      case GL_READ_BUFFER: RETVAL = "GL_READ_BUFFER"; break;
      case GL_READ_FRAMEBUFFER_BINDING: RETVAL = "GL_READ_FRAMEBUFFER_BINDING"; break;
      case GL_RED_BIAS: RETVAL = "GL_RED_BIAS"; break;
      case GL_RED_BITS: RETVAL = "GL_RED_BITS"; break;
      case GL_RED_SCALE: RETVAL = "GL_RED_SCALE"; break;
      case GL_RENDERBUFFER_BINDING: RETVAL = "GL_RENDERBUFFER_BINDING"; break;
      case GL_RENDER_MODE: RETVAL = "GL_RENDER_MODE"; break;
      case GL_RESCALE_NORMAL_EXT: RETVAL = "GL_RESCALE_NORMAL_EXT"; break;
      case GL_RGBA_MODE: RETVAL = "GL_RGBA_MODE"; break;
      case GL_SAMPLER_BINDING: RETVAL = "GL_SAMPLER_BINDING"; break;
      case GL_SAMPLES: RETVAL = "GL_SAMPLES"; break;
      case GL_SAMPLE_ALPHA_TO_MASK_SGIS: RETVAL = "GL_SAMPLE_ALPHA_TO_MASK_SGIS"; break;
      case GL_SAMPLE_ALPHA_TO_ONE_SGIS: RETVAL = "GL_SAMPLE_ALPHA_TO_ONE_SGIS"; break;
      case GL_SAMPLE_BUFFERS: RETVAL = "GL_SAMPLE_BUFFERS"; break;
      case GL_SAMPLE_COVERAGE_INVERT: RETVAL = "GL_SAMPLE_COVERAGE_INVERT"; break;
      case GL_SAMPLE_COVERAGE_VALUE: RETVAL = "GL_SAMPLE_COVERAGE_VALUE"; break;
      case GL_SAMPLE_MASK_SGIS: RETVAL = "GL_SAMPLE_MASK_SGIS"; break;
      case GL_SAMPLE_PATTERN_SGIS: RETVAL = "GL_SAMPLE_PATTERN_SGIS"; break;
      case GL_SCISSOR_BOX: RETVAL = "GL_SCISSOR_BOX"; break;
      case GL_SCISSOR_TEST: RETVAL = "GL_SCISSOR_TEST"; break;
      case GL_SELECTION_BUFFER_SIZE: RETVAL = "GL_SELECTION_BUFFER_SIZE"; break;
      case GL_SEPARABLE_2D_EXT: RETVAL = "GL_SEPARABLE_2D_EXT"; break;
      case GL_SHADER_BINARY_FORMATS: RETVAL = "GL_SHADER_BINARY_FORMATS"; break;
      case GL_SHADER_COMPILER: RETVAL = "GL_SHADER_COMPILER"; break;
      case GL_SHADER_CORE_ACTIVE_COUNT_ARM: RETVAL = "GL_SHADER_CORE_ACTIVE_COUNT_ARM"; break;
      case GL_SHADER_CORE_COUNT_ARM: RETVAL = "GL_SHADER_CORE_COUNT_ARM"; break;
      case GL_SHADER_CORE_FMA_RATE_ARM: RETVAL = "GL_SHADER_CORE_FMA_RATE_ARM"; break;
      case GL_SHADER_CORE_MAX_WARP_COUNT_ARM: RETVAL = "GL_SHADER_CORE_MAX_WARP_COUNT_ARM"; break;
      case GL_SHADER_CORE_PIXEL_RATE_ARM: RETVAL = "GL_SHADER_CORE_PIXEL_RATE_ARM"; break;
      case GL_SHADER_CORE_PRESENT_MASK_ARM: RETVAL = "GL_SHADER_CORE_PRESENT_MASK_ARM"; break;
      case GL_SHADER_CORE_TEXEL_RATE_ARM: RETVAL = "GL_SHADER_CORE_TEXEL_RATE_ARM"; break;
      case GL_SHADER_STORAGE_BUFFER_BINDING: RETVAL = "GL_SHADER_STORAGE_BUFFER_BINDING"; break;
      case GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT: RETVAL = "GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT"; break;
      case GL_SHADER_STORAGE_BUFFER_SIZE: RETVAL = "GL_SHADER_STORAGE_BUFFER_SIZE"; break;
      case GL_SHADER_STORAGE_BUFFER_START: RETVAL = "GL_SHADER_STORAGE_BUFFER_START"; break;
      case GL_SHADE_MODEL: RETVAL = "GL_SHADE_MODEL"; break;
      case GL_SHADING_RATE_EXT: RETVAL = "GL_SHADING_RATE_EXT"; break;
      case GL_SHADING_RATE_IMAGE_PALETTE_COUNT_NV: RETVAL = "GL_SHADING_RATE_IMAGE_PALETTE_COUNT_NV"; break;
      case GL_SHADING_RATE_IMAGE_PER_PRIMITIVE_NV: RETVAL = "GL_SHADING_RATE_IMAGE_PER_PRIMITIVE_NV"; break;
      case GL_SHADING_RATE_QCOM: RETVAL = "GL_SHADING_RATE_QCOM"; break;
      case GL_SHARED_TEXTURE_PALETTE_EXT: RETVAL = "GL_SHARED_TEXTURE_PALETTE_EXT"; break;
      case GL_STENCIL_BACK_FAIL: RETVAL = "GL_STENCIL_BACK_FAIL"; break;
      case GL_STENCIL_BACK_FUNC: RETVAL = "GL_STENCIL_BACK_FUNC"; break;
      case GL_STENCIL_BACK_PASS_DEPTH_FAIL: RETVAL = "GL_STENCIL_BACK_PASS_DEPTH_FAIL"; break;
      case GL_STENCIL_BACK_PASS_DEPTH_PASS: RETVAL = "GL_STENCIL_BACK_PASS_DEPTH_PASS"; break;
      case GL_STENCIL_BACK_REF: RETVAL = "GL_STENCIL_BACK_REF"; break;
      case GL_STENCIL_BACK_VALUE_MASK: RETVAL = "GL_STENCIL_BACK_VALUE_MASK"; break;
      case GL_STENCIL_BACK_WRITEMASK: RETVAL = "GL_STENCIL_BACK_WRITEMASK"; break;
      case GL_STENCIL_BITS: RETVAL = "GL_STENCIL_BITS"; break;
      case GL_STENCIL_CLEAR_VALUE: RETVAL = "GL_STENCIL_CLEAR_VALUE"; break;
      case GL_STENCIL_FAIL: RETVAL = "GL_STENCIL_FAIL"; break;
      case GL_STENCIL_FUNC: RETVAL = "GL_STENCIL_FUNC"; break;
      case GL_STENCIL_PASS_DEPTH_FAIL: RETVAL = "GL_STENCIL_PASS_DEPTH_FAIL"; break;
      case GL_STENCIL_PASS_DEPTH_PASS: RETVAL = "GL_STENCIL_PASS_DEPTH_PASS"; break;
      case GL_STENCIL_REF: RETVAL = "GL_STENCIL_REF"; break;
      case GL_STENCIL_TEST: RETVAL = "GL_STENCIL_TEST"; break;
      case GL_STENCIL_VALUE_MASK: RETVAL = "GL_STENCIL_VALUE_MASK"; break;
      case GL_STENCIL_WRITEMASK: RETVAL = "GL_STENCIL_WRITEMASK"; break;
      case GL_STEREO: RETVAL = "GL_STEREO"; break;
      case GL_SUBPIXEL_BITS: RETVAL = "GL_SUBPIXEL_BITS"; break;
      case GL_TEXTURE_1D: RETVAL = "GL_TEXTURE_1D"; break;
      case GL_TEXTURE_2D: RETVAL = "GL_TEXTURE_2D"; break;
      case GL_TEXTURE_3D_EXT: RETVAL = "GL_TEXTURE_3D_EXT"; break;
      case GL_TEXTURE_BINDING_1D: RETVAL = "GL_TEXTURE_BINDING_1D"; break;
      case GL_TEXTURE_BINDING_1D_ARRAY: RETVAL = "GL_TEXTURE_BINDING_1D_ARRAY"; break;
      case GL_TEXTURE_BINDING_2D: RETVAL = "GL_TEXTURE_BINDING_2D"; break;
      case GL_TEXTURE_BINDING_2D_ARRAY: RETVAL = "GL_TEXTURE_BINDING_2D_ARRAY"; break;
      case GL_TEXTURE_BINDING_2D_MULTISAMPLE: RETVAL = "GL_TEXTURE_BINDING_2D_MULTISAMPLE"; break;
      case GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY"; break;
      case GL_TEXTURE_BINDING_3D: RETVAL = "GL_TEXTURE_BINDING_3D"; break;
      case GL_TEXTURE_BINDING_BUFFER: RETVAL = "GL_TEXTURE_BINDING_BUFFER"; break;
      case GL_TEXTURE_BINDING_CUBE_MAP: RETVAL = "GL_TEXTURE_BINDING_CUBE_MAP"; break;
      case GL_TEXTURE_BINDING_RECTANGLE: RETVAL = "GL_TEXTURE_BINDING_RECTANGLE"; break;
      case GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT: RETVAL = "GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT"; break;
      case GL_TEXTURE_COLOR_TABLE_SGI: RETVAL = "GL_TEXTURE_COLOR_TABLE_SGI"; break;
      case GL_TEXTURE_COMPRESSION_HINT: RETVAL = "GL_TEXTURE_COMPRESSION_HINT"; break;
      case GL_TEXTURE_COORD_ARRAY: RETVAL = "GL_TEXTURE_COORD_ARRAY"; break;
      case GL_TEXTURE_COORD_ARRAY_COUNT_EXT: RETVAL = "GL_TEXTURE_COORD_ARRAY_COUNT_EXT"; break;
      case GL_TEXTURE_COORD_ARRAY_SIZE: RETVAL = "GL_TEXTURE_COORD_ARRAY_SIZE"; break;
      case GL_TEXTURE_COORD_ARRAY_STRIDE: RETVAL = "GL_TEXTURE_COORD_ARRAY_STRIDE"; break;
      case GL_TEXTURE_COORD_ARRAY_TYPE: RETVAL = "GL_TEXTURE_COORD_ARRAY_TYPE"; break;
      case GL_TEXTURE_GEN_Q: RETVAL = "GL_TEXTURE_GEN_Q"; break;
      case GL_TEXTURE_GEN_R: RETVAL = "GL_TEXTURE_GEN_R"; break;
      case GL_TEXTURE_GEN_S: RETVAL = "GL_TEXTURE_GEN_S"; break;
      case GL_TEXTURE_GEN_T: RETVAL = "GL_TEXTURE_GEN_T"; break;
      case GL_TEXTURE_MATRIX: RETVAL = "GL_TEXTURE_MATRIX"; break;
      case GL_TEXTURE_STACK_DEPTH: RETVAL = "GL_TEXTURE_STACK_DEPTH"; break;
      case GL_TIMESTAMP: RETVAL = "GL_TIMESTAMP"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_BINDING: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_BINDING"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_SIZE: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_SIZE"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_START: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_START"; break;
      case GL_UNIFORM_BUFFER_BINDING: RETVAL = "GL_UNIFORM_BUFFER_BINDING"; break;
      case GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT: RETVAL = "GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT"; break;
      case GL_UNIFORM_BUFFER_SIZE: RETVAL = "GL_UNIFORM_BUFFER_SIZE"; break;
      case GL_UNIFORM_BUFFER_START: RETVAL = "GL_UNIFORM_BUFFER_START"; break;
      case GL_UNPACK_ALIGNMENT: RETVAL = "GL_UNPACK_ALIGNMENT"; break;
      case GL_UNPACK_CMYK_HINT_EXT: RETVAL = "GL_UNPACK_CMYK_HINT_EXT"; break;
      case GL_UNPACK_IMAGE_HEIGHT: RETVAL = "GL_UNPACK_IMAGE_HEIGHT"; break;
      case GL_UNPACK_LSB_FIRST: RETVAL = "GL_UNPACK_LSB_FIRST"; break;
      case GL_UNPACK_RESAMPLE_SGIX: RETVAL = "GL_UNPACK_RESAMPLE_SGIX"; break;
      case GL_UNPACK_ROW_LENGTH: RETVAL = "GL_UNPACK_ROW_LENGTH"; break;
      case GL_UNPACK_SKIP_IMAGES: RETVAL = "GL_UNPACK_SKIP_IMAGES"; break;
      case GL_UNPACK_SKIP_PIXELS: RETVAL = "GL_UNPACK_SKIP_PIXELS"; break;
      case GL_UNPACK_SKIP_ROWS: RETVAL = "GL_UNPACK_SKIP_ROWS"; break;
      case GL_UNPACK_SUBSAMPLE_RATE_SGIX: RETVAL = "GL_UNPACK_SUBSAMPLE_RATE_SGIX"; break;
      case GL_UNPACK_SWAP_BYTES: RETVAL = "GL_UNPACK_SWAP_BYTES"; break;
      case GL_VERTEX_ARRAY: RETVAL = "GL_VERTEX_ARRAY"; break;
      case GL_VERTEX_ARRAY_BINDING: RETVAL = "GL_VERTEX_ARRAY_BINDING"; break;
      case GL_VERTEX_ARRAY_COUNT_EXT: RETVAL = "GL_VERTEX_ARRAY_COUNT_EXT"; break;
      case GL_VERTEX_ARRAY_SIZE: RETVAL = "GL_VERTEX_ARRAY_SIZE"; break;
      case GL_VERTEX_ARRAY_STRIDE: RETVAL = "GL_VERTEX_ARRAY_STRIDE"; break;
      case GL_VERTEX_ARRAY_TYPE: RETVAL = "GL_VERTEX_ARRAY_TYPE"; break;
      case GL_VERTEX_BINDING_DIVISOR: RETVAL = "GL_VERTEX_BINDING_DIVISOR"; break;
      case GL_VERTEX_BINDING_OFFSET: RETVAL = "GL_VERTEX_BINDING_OFFSET"; break;
      case GL_VERTEX_BINDING_STRIDE: RETVAL = "GL_VERTEX_BINDING_STRIDE"; break;
      case GL_VERTEX_PRECLIP_HINT_SGIX: RETVAL = "GL_VERTEX_PRECLIP_HINT_SGIX"; break;
      case GL_VERTEX_PRECLIP_SGIX: RETVAL = "GL_VERTEX_PRECLIP_SGIX"; break;
      case GL_VIEWPORT: RETVAL = "GL_VIEWPORT"; break;
      case GL_VIEWPORT_BOUNDS_RANGE: RETVAL = "GL_VIEWPORT_BOUNDS_RANGE"; break;
      case GL_VIEWPORT_INDEX_PROVOKING_VERTEX: RETVAL = "GL_VIEWPORT_INDEX_PROVOKING_VERTEX"; break;
      case GL_VIEWPORT_SUBPIXEL_BITS: RETVAL = "GL_VIEWPORT_SUBPIXEL_BITS"; break;
      case GL_ZOOM_X: RETVAL = "GL_ZOOM_X"; break;
      case GL_ZOOM_Y: RETVAL = "GL_ZOOM_Y"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetPointervPName")) {
    switch (e) {
      case GL_COLOR_ARRAY_POINTER: RETVAL = "GL_COLOR_ARRAY_POINTER"; break;
      case GL_DEBUG_CALLBACK_FUNCTION: RETVAL = "GL_DEBUG_CALLBACK_FUNCTION"; break;
      case GL_DEBUG_CALLBACK_USER_PARAM: RETVAL = "GL_DEBUG_CALLBACK_USER_PARAM"; break;
      case GL_EDGE_FLAG_ARRAY_POINTER: RETVAL = "GL_EDGE_FLAG_ARRAY_POINTER"; break;
      case GL_FEEDBACK_BUFFER_POINTER: RETVAL = "GL_FEEDBACK_BUFFER_POINTER"; break;
      case GL_INDEX_ARRAY_POINTER: RETVAL = "GL_INDEX_ARRAY_POINTER"; break;
      case GL_NORMAL_ARRAY_POINTER: RETVAL = "GL_NORMAL_ARRAY_POINTER"; break;
      case GL_SELECTION_BUFFER_POINTER: RETVAL = "GL_SELECTION_BUFFER_POINTER"; break;
      case GL_TEXTURE_COORD_ARRAY_POINTER: RETVAL = "GL_TEXTURE_COORD_ARRAY_POINTER"; break;
      case GL_VERTEX_ARRAY_POINTER: RETVAL = "GL_VERTEX_ARRAY_POINTER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetTexBumpParameterATI")) {
    switch (e) {
      case GL_BUMP_NUM_TEX_UNITS_ATI: RETVAL = "GL_BUMP_NUM_TEX_UNITS_ATI"; break;
      case GL_BUMP_ROT_MATRIX_ATI: RETVAL = "GL_BUMP_ROT_MATRIX_ATI"; break;
      case GL_BUMP_ROT_MATRIX_SIZE_ATI: RETVAL = "GL_BUMP_ROT_MATRIX_SIZE_ATI"; break;
      case GL_BUMP_TEX_UNITS_ATI: RETVAL = "GL_BUMP_TEX_UNITS_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetTextureParameter")) {
    switch (e) {
      case GL_GENERATE_MIPMAP_SGIS: RETVAL = "GL_GENERATE_MIPMAP_SGIS"; break;
      case GL_NORMAL_MAP: RETVAL = "GL_NORMAL_MAP"; break;
      case GL_POST_TEXTURE_FILTER_BIAS_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_BIAS_SGIX"; break;
      case GL_POST_TEXTURE_FILTER_SCALE_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_SCALE_SGIX"; break;
      case GL_REFLECTION_MAP: RETVAL = "GL_REFLECTION_MAP"; break;
      case GL_SHADOW_AMBIENT_SGIX: RETVAL = "GL_SHADOW_AMBIENT_SGIX"; break;
      case GL_SURFACE_COMPRESSION_EXT: RETVAL = "GL_SURFACE_COMPRESSION_EXT"; break;
      case GL_TEXTURE_ALPHA_SIZE: RETVAL = "GL_TEXTURE_ALPHA_SIZE"; break;
      case GL_TEXTURE_BASE_LEVEL_SGIS: RETVAL = "GL_TEXTURE_BASE_LEVEL_SGIS"; break;
      case GL_TEXTURE_BLUE_SIZE: RETVAL = "GL_TEXTURE_BLUE_SIZE"; break;
      case GL_TEXTURE_BORDER: RETVAL = "GL_TEXTURE_BORDER"; break;
      case GL_TEXTURE_BORDER_COLOR: RETVAL = "GL_TEXTURE_BORDER_COLOR"; break;
      case GL_TEXTURE_CBCR_DEGAMMA_QCOM: RETVAL = "GL_TEXTURE_CBCR_DEGAMMA_QCOM"; break;
      case GL_TEXTURE_COMPARE_OPERATOR_SGIX: RETVAL = "GL_TEXTURE_COMPARE_OPERATOR_SGIX"; break;
      case GL_TEXTURE_COMPARE_SGIX: RETVAL = "GL_TEXTURE_COMPARE_SGIX"; break;
      case GL_TEXTURE_COMPONENTS: RETVAL = "GL_TEXTURE_COMPONENTS"; break;
      case GL_TEXTURE_DEPTH_EXT: RETVAL = "GL_TEXTURE_DEPTH_EXT"; break;
      case GL_TEXTURE_GEQUAL_R_SGIX: RETVAL = "GL_TEXTURE_GEQUAL_R_SGIX"; break;
      case GL_TEXTURE_GREEN_SIZE: RETVAL = "GL_TEXTURE_GREEN_SIZE"; break;
      case GL_TEXTURE_HEIGHT: RETVAL = "GL_TEXTURE_HEIGHT"; break;
      case GL_TEXTURE_INTENSITY_SIZE: RETVAL = "GL_TEXTURE_INTENSITY_SIZE"; break;
      case GL_TEXTURE_LEQUAL_R_SGIX: RETVAL = "GL_TEXTURE_LEQUAL_R_SGIX"; break;
      case GL_TEXTURE_LUMINANCE_SIZE: RETVAL = "GL_TEXTURE_LUMINANCE_SIZE"; break;
      case GL_TEXTURE_MAG_FILTER: RETVAL = "GL_TEXTURE_MAG_FILTER"; break;
      case GL_TEXTURE_MAX_CLAMP_R_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_R_SGIX"; break;
      case GL_TEXTURE_MAX_CLAMP_S_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_S_SGIX"; break;
      case GL_TEXTURE_MAX_CLAMP_T_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_T_SGIX"; break;
      case GL_TEXTURE_MAX_LEVEL_SGIS: RETVAL = "GL_TEXTURE_MAX_LEVEL_SGIS"; break;
      case GL_TEXTURE_MAX_LOD_SGIS: RETVAL = "GL_TEXTURE_MAX_LOD_SGIS"; break;
      case GL_TEXTURE_MIN_FILTER: RETVAL = "GL_TEXTURE_MIN_FILTER"; break;
      case GL_TEXTURE_MIN_LOD_SGIS: RETVAL = "GL_TEXTURE_MIN_LOD_SGIS"; break;
      case GL_TEXTURE_PRIORITY: RETVAL = "GL_TEXTURE_PRIORITY"; break;
      case GL_TEXTURE_RED_SIZE: RETVAL = "GL_TEXTURE_RED_SIZE"; break;
      case GL_TEXTURE_RESIDENT: RETVAL = "GL_TEXTURE_RESIDENT"; break;
      case GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM: RETVAL = "GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM"; break;
      case GL_TEXTURE_WIDTH: RETVAL = "GL_TEXTURE_WIDTH"; break;
      case GL_TEXTURE_WRAP_R_EXT: RETVAL = "GL_TEXTURE_WRAP_R_EXT"; break;
      case GL_TEXTURE_WRAP_S: RETVAL = "GL_TEXTURE_WRAP_S"; break;
      case GL_TEXTURE_WRAP_T: RETVAL = "GL_TEXTURE_WRAP_T"; break;
      case GL_TEXTURE_Y_DEGAMMA_QCOM: RETVAL = "GL_TEXTURE_Y_DEGAMMA_QCOM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GetVariantValueEXT")) {
    switch (e) {
      case GL_VARIANT_ARRAY_STRIDE_EXT: RETVAL = "GL_VARIANT_ARRAY_STRIDE_EXT"; break;
      case GL_VARIANT_ARRAY_TYPE_EXT: RETVAL = "GL_VARIANT_ARRAY_TYPE_EXT"; break;
      case GL_VARIANT_DATATYPE_EXT: RETVAL = "GL_VARIANT_DATATYPE_EXT"; break;
      case GL_VARIANT_VALUE_EXT: RETVAL = "GL_VARIANT_VALUE_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "GraphicsResetStatus")) {
    switch (e) {
      case GL_GUILTY_CONTEXT_RESET: RETVAL = "GL_GUILTY_CONTEXT_RESET"; break;
      case GL_INNOCENT_CONTEXT_RESET: RETVAL = "GL_INNOCENT_CONTEXT_RESET"; break;
      case GL_NO_ERROR: RETVAL = "GL_NO_ERROR"; break;
      case GL_UNKNOWN_CONTEXT_RESET: RETVAL = "GL_UNKNOWN_CONTEXT_RESET"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "HintMode")) {
    switch (e) {
      case GL_DONT_CARE: RETVAL = "GL_DONT_CARE"; break;
      case GL_FASTEST: RETVAL = "GL_FASTEST"; break;
      case GL_NICEST: RETVAL = "GL_NICEST"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "HintTarget")) {
    switch (e) {
      case GL_ALLOW_DRAW_FRG_HINT_PGI: RETVAL = "GL_ALLOW_DRAW_FRG_HINT_PGI"; break;
      case GL_ALLOW_DRAW_MEM_HINT_PGI: RETVAL = "GL_ALLOW_DRAW_MEM_HINT_PGI"; break;
      case GL_ALLOW_DRAW_OBJ_HINT_PGI: RETVAL = "GL_ALLOW_DRAW_OBJ_HINT_PGI"; break;
      case GL_ALLOW_DRAW_WIN_HINT_PGI: RETVAL = "GL_ALLOW_DRAW_WIN_HINT_PGI"; break;
      case GL_ALWAYS_FAST_HINT_PGI: RETVAL = "GL_ALWAYS_FAST_HINT_PGI"; break;
      case GL_ALWAYS_SOFT_HINT_PGI: RETVAL = "GL_ALWAYS_SOFT_HINT_PGI"; break;
      case GL_BACK_NORMALS_HINT_PGI: RETVAL = "GL_BACK_NORMALS_HINT_PGI"; break;
      case GL_BINNING_CONTROL_HINT_QCOM: RETVAL = "GL_BINNING_CONTROL_HINT_QCOM"; break;
      case GL_CLIP_FAR_HINT_PGI: RETVAL = "GL_CLIP_FAR_HINT_PGI"; break;
      case GL_CLIP_NEAR_HINT_PGI: RETVAL = "GL_CLIP_NEAR_HINT_PGI"; break;
      case GL_CLIP_VOLUME_CLIPPING_HINT_EXT: RETVAL = "GL_CLIP_VOLUME_CLIPPING_HINT_EXT"; break;
      case GL_CONSERVE_MEMORY_HINT_PGI: RETVAL = "GL_CONSERVE_MEMORY_HINT_PGI"; break;
      case GL_CONVOLUTION_HINT_SGIX: RETVAL = "GL_CONVOLUTION_HINT_SGIX"; break;
      case GL_FOG_HINT: RETVAL = "GL_FOG_HINT"; break;
      case GL_FRAGMENT_SHADER_DERIVATIVE_HINT: RETVAL = "GL_FRAGMENT_SHADER_DERIVATIVE_HINT"; break;
      case GL_FULL_STIPPLE_HINT_PGI: RETVAL = "GL_FULL_STIPPLE_HINT_PGI"; break;
      case GL_GENERATE_MIPMAP_HINT: RETVAL = "GL_GENERATE_MIPMAP_HINT"; break;
      case GL_LINE_QUALITY_HINT_SGIX: RETVAL = "GL_LINE_QUALITY_HINT_SGIX"; break;
      case GL_LINE_SMOOTH_HINT: RETVAL = "GL_LINE_SMOOTH_HINT"; break;
      case GL_MATERIAL_SIDE_HINT_PGI: RETVAL = "GL_MATERIAL_SIDE_HINT_PGI"; break;
      case GL_MAX_VERTEX_HINT_PGI: RETVAL = "GL_MAX_VERTEX_HINT_PGI"; break;
      case GL_MULTISAMPLE_FILTER_HINT_NV: RETVAL = "GL_MULTISAMPLE_FILTER_HINT_NV"; break;
      case GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI: RETVAL = "GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI"; break;
      case GL_NATIVE_GRAPHICS_END_HINT_PGI: RETVAL = "GL_NATIVE_GRAPHICS_END_HINT_PGI"; break;
      case GL_PACK_CMYK_HINT_EXT: RETVAL = "GL_PACK_CMYK_HINT_EXT"; break;
      case GL_PERSPECTIVE_CORRECTION_HINT: RETVAL = "GL_PERSPECTIVE_CORRECTION_HINT"; break;
      case GL_PHONG_HINT_WIN: RETVAL = "GL_PHONG_HINT_WIN"; break;
      case GL_POINT_SMOOTH_HINT: RETVAL = "GL_POINT_SMOOTH_HINT"; break;
      case GL_POLYGON_SMOOTH_HINT: RETVAL = "GL_POLYGON_SMOOTH_HINT"; break;
      case GL_PREFER_DOUBLEBUFFER_HINT_PGI: RETVAL = "GL_PREFER_DOUBLEBUFFER_HINT_PGI"; break;
      case GL_PROGRAM_BINARY_RETRIEVABLE_HINT: RETVAL = "GL_PROGRAM_BINARY_RETRIEVABLE_HINT"; break;
      case GL_RECLAIM_MEMORY_HINT_PGI: RETVAL = "GL_RECLAIM_MEMORY_HINT_PGI"; break;
      case GL_SCALEBIAS_HINT_SGIX: RETVAL = "GL_SCALEBIAS_HINT_SGIX"; break;
      case GL_STRICT_DEPTHFUNC_HINT_PGI: RETVAL = "GL_STRICT_DEPTHFUNC_HINT_PGI"; break;
      case GL_STRICT_LIGHTING_HINT_PGI: RETVAL = "GL_STRICT_LIGHTING_HINT_PGI"; break;
      case GL_STRICT_SCISSOR_HINT_PGI: RETVAL = "GL_STRICT_SCISSOR_HINT_PGI"; break;
      case GL_TEXTURE_COMPRESSION_HINT: RETVAL = "GL_TEXTURE_COMPRESSION_HINT"; break;
      case GL_TEXTURE_MULTI_BUFFER_HINT_SGIX: RETVAL = "GL_TEXTURE_MULTI_BUFFER_HINT_SGIX"; break;
      case GL_TEXTURE_STORAGE_HINT_APPLE: RETVAL = "GL_TEXTURE_STORAGE_HINT_APPLE"; break;
      case GL_TRANSFORM_HINT_APPLE: RETVAL = "GL_TRANSFORM_HINT_APPLE"; break;
      case GL_UNPACK_CMYK_HINT_EXT: RETVAL = "GL_UNPACK_CMYK_HINT_EXT"; break;
      case GL_VERTEX_ARRAY_STORAGE_HINT_APPLE: RETVAL = "GL_VERTEX_ARRAY_STORAGE_HINT_APPLE"; break;
      case GL_VERTEX_CONSISTENT_HINT_PGI: RETVAL = "GL_VERTEX_CONSISTENT_HINT_PGI"; break;
      case GL_VERTEX_DATA_HINT_PGI: RETVAL = "GL_VERTEX_DATA_HINT_PGI"; break;
      case GL_VERTEX_PRECLIP_HINT_SGIX: RETVAL = "GL_VERTEX_PRECLIP_HINT_SGIX"; break;
      case GL_VERTEX_PRECLIP_SGIX: RETVAL = "GL_VERTEX_PRECLIP_SGIX"; break;
      case GL_WIDE_LINE_HINT_PGI: RETVAL = "GL_WIDE_LINE_HINT_PGI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "HintTargetPGI")) {
    switch (e) {
      case GL_MATERIAL_SIDE_HINT_PGI: RETVAL = "GL_MATERIAL_SIDE_HINT_PGI"; break;
      case GL_MAX_VERTEX_HINT_PGI: RETVAL = "GL_MAX_VERTEX_HINT_PGI"; break;
      case GL_VERTEX_CONSISTENT_HINT_PGI: RETVAL = "GL_VERTEX_CONSISTENT_HINT_PGI"; break;
      case GL_VERTEX_DATA_HINT_PGI: RETVAL = "GL_VERTEX_DATA_HINT_PGI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "HistogramTarget")) {
    switch (e) {
      case GL_HISTOGRAM: RETVAL = "GL_HISTOGRAM"; break;
      case GL_PROXY_HISTOGRAM: RETVAL = "GL_PROXY_HISTOGRAM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "HistogramTargetEXT")) {
    switch (e) {
      case GL_HISTOGRAM: RETVAL = "GL_HISTOGRAM"; break;
      case GL_PROXY_HISTOGRAM: RETVAL = "GL_PROXY_HISTOGRAM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "IndexFunctionEXT")) {
    switch (e) {
      case GL_ALWAYS: RETVAL = "GL_ALWAYS"; break;
      case GL_EQUAL: RETVAL = "GL_EQUAL"; break;
      case GL_GEQUAL: RETVAL = "GL_GEQUAL"; break;
      case GL_GREATER: RETVAL = "GL_GREATER"; break;
      case GL_LEQUAL: RETVAL = "GL_LEQUAL"; break;
      case GL_LESS: RETVAL = "GL_LESS"; break;
      case GL_NEVER: RETVAL = "GL_NEVER"; break;
      case GL_NOTEQUAL: RETVAL = "GL_NOTEQUAL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "IndexMaterialParameterEXT")) {
    switch (e) {
      case GL_INDEX_OFFSET: RETVAL = "GL_INDEX_OFFSET"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "IndexPointerType")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "InstancedPathCoverMode")) {
    switch (e) {
      case GL_BOUNDING_BOX_NV: RETVAL = "GL_BOUNDING_BOX_NV"; break;
      case GL_BOUNDING_BOX_OF_BOUNDING_BOXES_NV: RETVAL = "GL_BOUNDING_BOX_OF_BOUNDING_BOXES_NV"; break;
      case GL_CONVEX_HULL_NV: RETVAL = "GL_CONVEX_HULL_NV"; break;
      case GL_PATH_FILL_COVER_MODE_NV: RETVAL = "GL_PATH_FILL_COVER_MODE_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "InterleavedArrayFormat")) {
    switch (e) {
      case GL_C3F_V3F: RETVAL = "GL_C3F_V3F"; break;
      case GL_C4F_N3F_V3F: RETVAL = "GL_C4F_N3F_V3F"; break;
      case GL_C4UB_V2F: RETVAL = "GL_C4UB_V2F"; break;
      case GL_C4UB_V3F: RETVAL = "GL_C4UB_V3F"; break;
      case GL_N3F_V3F: RETVAL = "GL_N3F_V3F"; break;
      case GL_T2F_C3F_V3F: RETVAL = "GL_T2F_C3F_V3F"; break;
      case GL_T2F_C4F_N3F_V3F: RETVAL = "GL_T2F_C4F_N3F_V3F"; break;
      case GL_T2F_C4UB_V3F: RETVAL = "GL_T2F_C4UB_V3F"; break;
      case GL_T2F_N3F_V3F: RETVAL = "GL_T2F_N3F_V3F"; break;
      case GL_T2F_V3F: RETVAL = "GL_T2F_V3F"; break;
      case GL_T4F_C4F_N3F_V4F: RETVAL = "GL_T4F_C4F_N3F_V4F"; break;
      case GL_T4F_V4F: RETVAL = "GL_T4F_V4F"; break;
      case GL_V2F: RETVAL = "GL_V2F"; break;
      case GL_V3F: RETVAL = "GL_V3F"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "InternalFormat")) {
    switch (e) {
      case GL_ALPHA12: RETVAL = "GL_ALPHA12"; break;
      case GL_ALPHA16: RETVAL = "GL_ALPHA16"; break;
      case GL_ALPHA16I_EXT: RETVAL = "GL_ALPHA16I_EXT"; break;
      case GL_ALPHA16UI_EXT: RETVAL = "GL_ALPHA16UI_EXT"; break;
      case GL_ALPHA32I_EXT: RETVAL = "GL_ALPHA32I_EXT"; break;
      case GL_ALPHA32UI_EXT: RETVAL = "GL_ALPHA32UI_EXT"; break;
      case GL_ALPHA4: RETVAL = "GL_ALPHA4"; break;
      case GL_ALPHA8: RETVAL = "GL_ALPHA8"; break;
      case GL_ALPHA8I_EXT: RETVAL = "GL_ALPHA8I_EXT"; break;
      case GL_ALPHA8UI_EXT: RETVAL = "GL_ALPHA8UI_EXT"; break;
      case GL_COMPRESSED_R11_EAC: RETVAL = "GL_COMPRESSED_R11_EAC"; break;
      case GL_COMPRESSED_RED: RETVAL = "GL_COMPRESSED_RED"; break;
      case GL_COMPRESSED_RED_RGTC1: RETVAL = "GL_COMPRESSED_RED_RGTC1"; break;
      case GL_COMPRESSED_RG: RETVAL = "GL_COMPRESSED_RG"; break;
      case GL_COMPRESSED_RG11_EAC: RETVAL = "GL_COMPRESSED_RG11_EAC"; break;
      case GL_COMPRESSED_RGB: RETVAL = "GL_COMPRESSED_RGB"; break;
      case GL_COMPRESSED_RGB8_ETC2: RETVAL = "GL_COMPRESSED_RGB8_ETC2"; break;
      case GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2: RETVAL = "GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2"; break;
      case GL_COMPRESSED_RGBA: RETVAL = "GL_COMPRESSED_RGBA"; break;
      case GL_COMPRESSED_RGBA8_ETC2_EAC: RETVAL = "GL_COMPRESSED_RGBA8_ETC2_EAC"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x10_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x10_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x8_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x8_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_12x10_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_12x10_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_12x12_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_12x12_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_4x4_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_4x4_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_5x4_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_5x4_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_5x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_5x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_6x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_6x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_6x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_6x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x8_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x8_KHR"; break;
      case GL_COMPRESSED_RGBA_BPTC_UNORM: RETVAL = "GL_COMPRESSED_RGBA_BPTC_UNORM"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT1_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT1_EXT"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT3_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT3_EXT"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT5_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT5_EXT"; break;
      case GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT: RETVAL = "GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT"; break;
      case GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT: RETVAL = "GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT"; break;
      case GL_COMPRESSED_RGB_S3TC_DXT1_EXT: RETVAL = "GL_COMPRESSED_RGB_S3TC_DXT1_EXT"; break;
      case GL_COMPRESSED_RG_RGTC2: RETVAL = "GL_COMPRESSED_RG_RGTC2"; break;
      case GL_COMPRESSED_SIGNED_R11_EAC: RETVAL = "GL_COMPRESSED_SIGNED_R11_EAC"; break;
      case GL_COMPRESSED_SIGNED_RED_RGTC1: RETVAL = "GL_COMPRESSED_SIGNED_RED_RGTC1"; break;
      case GL_COMPRESSED_SIGNED_RG11_EAC: RETVAL = "GL_COMPRESSED_SIGNED_RG11_EAC"; break;
      case GL_COMPRESSED_SIGNED_RG_RGTC2: RETVAL = "GL_COMPRESSED_SIGNED_RG_RGTC2"; break;
      case GL_COMPRESSED_SRGB: RETVAL = "GL_COMPRESSED_SRGB"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC"; break;
      case GL_COMPRESSED_SRGB8_ETC2: RETVAL = "GL_COMPRESSED_SRGB8_ETC2"; break;
      case GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2: RETVAL = "GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2"; break;
      case GL_COMPRESSED_SRGB_ALPHA: RETVAL = "GL_COMPRESSED_SRGB_ALPHA"; break;
      case GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV"; break;
      case GL_COMPRESSED_SRGB_S3TC_DXT1_NV: RETVAL = "GL_COMPRESSED_SRGB_S3TC_DXT1_NV"; break;
      case GL_DEPTH24_STENCIL8: RETVAL = "GL_DEPTH24_STENCIL8"; break;
      case GL_DEPTH32F_STENCIL8: RETVAL = "GL_DEPTH32F_STENCIL8"; break;
      case GL_DEPTH32F_STENCIL8_NV: RETVAL = "GL_DEPTH32F_STENCIL8_NV"; break;
      case GL_DEPTH_COMPONENT: RETVAL = "GL_DEPTH_COMPONENT"; break;
      case GL_DEPTH_COMPONENT16: RETVAL = "GL_DEPTH_COMPONENT16"; break;
      case GL_DEPTH_COMPONENT24: RETVAL = "GL_DEPTH_COMPONENT24"; break;
      case GL_DEPTH_COMPONENT32: RETVAL = "GL_DEPTH_COMPONENT32"; break;
      case GL_DEPTH_COMPONENT32F: RETVAL = "GL_DEPTH_COMPONENT32F"; break;
      case GL_DEPTH_COMPONENT32F_NV: RETVAL = "GL_DEPTH_COMPONENT32F_NV"; break;
      case GL_DEPTH_STENCIL: RETVAL = "GL_DEPTH_STENCIL"; break;
      case GL_INTENSITY: RETVAL = "GL_INTENSITY"; break;
      case GL_INTENSITY12: RETVAL = "GL_INTENSITY12"; break;
      case GL_INTENSITY16: RETVAL = "GL_INTENSITY16"; break;
      case GL_INTENSITY16I_EXT: RETVAL = "GL_INTENSITY16I_EXT"; break;
      case GL_INTENSITY16UI_EXT: RETVAL = "GL_INTENSITY16UI_EXT"; break;
      case GL_INTENSITY32I_EXT: RETVAL = "GL_INTENSITY32I_EXT"; break;
      case GL_INTENSITY32UI_EXT: RETVAL = "GL_INTENSITY32UI_EXT"; break;
      case GL_INTENSITY4: RETVAL = "GL_INTENSITY4"; break;
      case GL_INTENSITY8: RETVAL = "GL_INTENSITY8"; break;
      case GL_INTENSITY8I_EXT: RETVAL = "GL_INTENSITY8I_EXT"; break;
      case GL_INTENSITY8UI_EXT: RETVAL = "GL_INTENSITY8UI_EXT"; break;
      case GL_LUMINANCE12: RETVAL = "GL_LUMINANCE12"; break;
      case GL_LUMINANCE12_ALPHA12: RETVAL = "GL_LUMINANCE12_ALPHA12"; break;
      case GL_LUMINANCE12_ALPHA4: RETVAL = "GL_LUMINANCE12_ALPHA4"; break;
      case GL_LUMINANCE16: RETVAL = "GL_LUMINANCE16"; break;
      case GL_LUMINANCE16I_EXT: RETVAL = "GL_LUMINANCE16I_EXT"; break;
      case GL_LUMINANCE16UI_EXT: RETVAL = "GL_LUMINANCE16UI_EXT"; break;
      case GL_LUMINANCE16_ALPHA16: RETVAL = "GL_LUMINANCE16_ALPHA16"; break;
      case GL_LUMINANCE32I_EXT: RETVAL = "GL_LUMINANCE32I_EXT"; break;
      case GL_LUMINANCE32UI_EXT: RETVAL = "GL_LUMINANCE32UI_EXT"; break;
      case GL_LUMINANCE4: RETVAL = "GL_LUMINANCE4"; break;
      case GL_LUMINANCE4_ALPHA4: RETVAL = "GL_LUMINANCE4_ALPHA4"; break;
      case GL_LUMINANCE6_ALPHA2: RETVAL = "GL_LUMINANCE6_ALPHA2"; break;
      case GL_LUMINANCE8: RETVAL = "GL_LUMINANCE8"; break;
      case GL_LUMINANCE8I_EXT: RETVAL = "GL_LUMINANCE8I_EXT"; break;
      case GL_LUMINANCE8UI_EXT: RETVAL = "GL_LUMINANCE8UI_EXT"; break;
      case GL_LUMINANCE8_ALPHA8: RETVAL = "GL_LUMINANCE8_ALPHA8"; break;
      case GL_LUMINANCE_ALPHA16I_EXT: RETVAL = "GL_LUMINANCE_ALPHA16I_EXT"; break;
      case GL_LUMINANCE_ALPHA16UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA16UI_EXT"; break;
      case GL_LUMINANCE_ALPHA32I_EXT: RETVAL = "GL_LUMINANCE_ALPHA32I_EXT"; break;
      case GL_LUMINANCE_ALPHA32UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA32UI_EXT"; break;
      case GL_LUMINANCE_ALPHA8I_EXT: RETVAL = "GL_LUMINANCE_ALPHA8I_EXT"; break;
      case GL_LUMINANCE_ALPHA8UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA8UI_EXT"; break;
      case GL_R11F_G11F_B10F: RETVAL = "GL_R11F_G11F_B10F"; break;
      case GL_R16: RETVAL = "GL_R16"; break;
      case GL_R16F: RETVAL = "GL_R16F"; break;
      case GL_R16I: RETVAL = "GL_R16I"; break;
      case GL_R16UI: RETVAL = "GL_R16UI"; break;
      case GL_R16_SNORM: RETVAL = "GL_R16_SNORM"; break;
      case GL_R32F: RETVAL = "GL_R32F"; break;
      case GL_R32I: RETVAL = "GL_R32I"; break;
      case GL_R32UI: RETVAL = "GL_R32UI"; break;
      case GL_R3_G3_B2: RETVAL = "GL_R3_G3_B2"; break;
      case GL_R8: RETVAL = "GL_R8"; break;
      case GL_R8I: RETVAL = "GL_R8I"; break;
      case GL_R8UI: RETVAL = "GL_R8UI"; break;
      case GL_R8_SNORM: RETVAL = "GL_R8_SNORM"; break;
      case GL_RED: RETVAL = "GL_RED"; break;
      case GL_RG: RETVAL = "GL_RG"; break;
      case GL_RG16: RETVAL = "GL_RG16"; break;
      case GL_RG16F: RETVAL = "GL_RG16F"; break;
      case GL_RG16I: RETVAL = "GL_RG16I"; break;
      case GL_RG16UI: RETVAL = "GL_RG16UI"; break;
      case GL_RG16_SNORM: RETVAL = "GL_RG16_SNORM"; break;
      case GL_RG32F: RETVAL = "GL_RG32F"; break;
      case GL_RG32I: RETVAL = "GL_RG32I"; break;
      case GL_RG32UI: RETVAL = "GL_RG32UI"; break;
      case GL_RG8: RETVAL = "GL_RG8"; break;
      case GL_RG8I: RETVAL = "GL_RG8I"; break;
      case GL_RG8UI: RETVAL = "GL_RG8UI"; break;
      case GL_RG8_SNORM: RETVAL = "GL_RG8_SNORM"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      case GL_RGB10: RETVAL = "GL_RGB10"; break;
      case GL_RGB10_A2: RETVAL = "GL_RGB10_A2"; break;
      case GL_RGB10_A2UI: RETVAL = "GL_RGB10_A2UI"; break;
      case GL_RGB12: RETVAL = "GL_RGB12"; break;
      case GL_RGB16: RETVAL = "GL_RGB16"; break;
      case GL_RGB16F: RETVAL = "GL_RGB16F"; break;
      case GL_RGB16I: RETVAL = "GL_RGB16I"; break;
      case GL_RGB16UI: RETVAL = "GL_RGB16UI"; break;
      case GL_RGB16_SNORM: RETVAL = "GL_RGB16_SNORM"; break;
      case GL_RGB2_EXT: RETVAL = "GL_RGB2_EXT"; break;
      case GL_RGB32F: RETVAL = "GL_RGB32F"; break;
      case GL_RGB32I: RETVAL = "GL_RGB32I"; break;
      case GL_RGB32UI: RETVAL = "GL_RGB32UI"; break;
      case GL_RGB4: RETVAL = "GL_RGB4"; break;
      case GL_RGB5: RETVAL = "GL_RGB5"; break;
      case GL_RGB565: RETVAL = "GL_RGB565"; break;
      case GL_RGB5_A1: RETVAL = "GL_RGB5_A1"; break;
      case GL_RGB8: RETVAL = "GL_RGB8"; break;
      case GL_RGB8I: RETVAL = "GL_RGB8I"; break;
      case GL_RGB8UI: RETVAL = "GL_RGB8UI"; break;
      case GL_RGB8_SNORM: RETVAL = "GL_RGB8_SNORM"; break;
      case GL_RGB9_E5: RETVAL = "GL_RGB9_E5"; break;
      case GL_RGBA: RETVAL = "GL_RGBA"; break;
      case GL_RGBA12: RETVAL = "GL_RGBA12"; break;
      case GL_RGBA16: RETVAL = "GL_RGBA16"; break;
      case GL_RGBA16F: RETVAL = "GL_RGBA16F"; break;
      case GL_RGBA16I: RETVAL = "GL_RGBA16I"; break;
      case GL_RGBA16UI: RETVAL = "GL_RGBA16UI"; break;
      case GL_RGBA16_SNORM: RETVAL = "GL_RGBA16_SNORM"; break;
      case GL_RGBA2: RETVAL = "GL_RGBA2"; break;
      case GL_RGBA32F: RETVAL = "GL_RGBA32F"; break;
      case GL_RGBA32I: RETVAL = "GL_RGBA32I"; break;
      case GL_RGBA32UI: RETVAL = "GL_RGBA32UI"; break;
      case GL_RGBA4: RETVAL = "GL_RGBA4"; break;
      case GL_RGBA8: RETVAL = "GL_RGBA8"; break;
      case GL_RGBA8I: RETVAL = "GL_RGBA8I"; break;
      case GL_RGBA8UI: RETVAL = "GL_RGBA8UI"; break;
      case GL_RGBA8_SNORM: RETVAL = "GL_RGBA8_SNORM"; break;
      case GL_SR8_EXT: RETVAL = "GL_SR8_EXT"; break;
      case GL_SRG8_EXT: RETVAL = "GL_SRG8_EXT"; break;
      case GL_SRGB: RETVAL = "GL_SRGB"; break;
      case GL_SRGB8: RETVAL = "GL_SRGB8"; break;
      case GL_SRGB8_ALPHA8: RETVAL = "GL_SRGB8_ALPHA8"; break;
      case GL_SRGB_ALPHA: RETVAL = "GL_SRGB_ALPHA"; break;
      case GL_STENCIL_INDEX: RETVAL = "GL_STENCIL_INDEX"; break;
      case GL_STENCIL_INDEX1: RETVAL = "GL_STENCIL_INDEX1"; break;
      case GL_STENCIL_INDEX16: RETVAL = "GL_STENCIL_INDEX16"; break;
      case GL_STENCIL_INDEX4: RETVAL = "GL_STENCIL_INDEX4"; break;
      case GL_STENCIL_INDEX8: RETVAL = "GL_STENCIL_INDEX8"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "InternalFormatPName")) {
    switch (e) {
      case GL_AUTO_GENERATE_MIPMAP: RETVAL = "GL_AUTO_GENERATE_MIPMAP"; break;
      case GL_CLEAR_BUFFER: RETVAL = "GL_CLEAR_BUFFER"; break;
      case GL_CLEAR_TEXTURE: RETVAL = "GL_CLEAR_TEXTURE"; break;
      case GL_COLOR_COMPONENTS: RETVAL = "GL_COLOR_COMPONENTS"; break;
      case GL_COLOR_ENCODING: RETVAL = "GL_COLOR_ENCODING"; break;
      case GL_COLOR_RENDERABLE: RETVAL = "GL_COLOR_RENDERABLE"; break;
      case GL_COMPUTE_TEXTURE: RETVAL = "GL_COMPUTE_TEXTURE"; break;
      case GL_DEPTH_RENDERABLE: RETVAL = "GL_DEPTH_RENDERABLE"; break;
      case GL_FILTER: RETVAL = "GL_FILTER"; break;
      case GL_FRAGMENT_TEXTURE: RETVAL = "GL_FRAGMENT_TEXTURE"; break;
      case GL_FRAMEBUFFER_BLEND: RETVAL = "GL_FRAMEBUFFER_BLEND"; break;
      case GL_FRAMEBUFFER_RENDERABLE: RETVAL = "GL_FRAMEBUFFER_RENDERABLE"; break;
      case GL_FRAMEBUFFER_RENDERABLE_LAYERED: RETVAL = "GL_FRAMEBUFFER_RENDERABLE_LAYERED"; break;
      case GL_GENERATE_MIPMAP: RETVAL = "GL_GENERATE_MIPMAP"; break;
      case GL_GEOMETRY_TEXTURE: RETVAL = "GL_GEOMETRY_TEXTURE"; break;
      case GL_GET_TEXTURE_IMAGE_FORMAT: RETVAL = "GL_GET_TEXTURE_IMAGE_FORMAT"; break;
      case GL_GET_TEXTURE_IMAGE_TYPE: RETVAL = "GL_GET_TEXTURE_IMAGE_TYPE"; break;
      case GL_IMAGE_COMPATIBILITY_CLASS: RETVAL = "GL_IMAGE_COMPATIBILITY_CLASS"; break;
      case GL_IMAGE_FORMAT_COMPATIBILITY_TYPE: RETVAL = "GL_IMAGE_FORMAT_COMPATIBILITY_TYPE"; break;
      case GL_IMAGE_PIXEL_FORMAT: RETVAL = "GL_IMAGE_PIXEL_FORMAT"; break;
      case GL_IMAGE_PIXEL_TYPE: RETVAL = "GL_IMAGE_PIXEL_TYPE"; break;
      case GL_IMAGE_TEXEL_SIZE: RETVAL = "GL_IMAGE_TEXEL_SIZE"; break;
      case GL_INTERNALFORMAT_ALPHA_SIZE: RETVAL = "GL_INTERNALFORMAT_ALPHA_SIZE"; break;
      case GL_INTERNALFORMAT_ALPHA_TYPE: RETVAL = "GL_INTERNALFORMAT_ALPHA_TYPE"; break;
      case GL_INTERNALFORMAT_BLUE_SIZE: RETVAL = "GL_INTERNALFORMAT_BLUE_SIZE"; break;
      case GL_INTERNALFORMAT_BLUE_TYPE: RETVAL = "GL_INTERNALFORMAT_BLUE_TYPE"; break;
      case GL_INTERNALFORMAT_DEPTH_SIZE: RETVAL = "GL_INTERNALFORMAT_DEPTH_SIZE"; break;
      case GL_INTERNALFORMAT_DEPTH_TYPE: RETVAL = "GL_INTERNALFORMAT_DEPTH_TYPE"; break;
      case GL_INTERNALFORMAT_GREEN_SIZE: RETVAL = "GL_INTERNALFORMAT_GREEN_SIZE"; break;
      case GL_INTERNALFORMAT_GREEN_TYPE: RETVAL = "GL_INTERNALFORMAT_GREEN_TYPE"; break;
      case GL_INTERNALFORMAT_PREFERRED: RETVAL = "GL_INTERNALFORMAT_PREFERRED"; break;
      case GL_INTERNALFORMAT_RED_SIZE: RETVAL = "GL_INTERNALFORMAT_RED_SIZE"; break;
      case GL_INTERNALFORMAT_RED_TYPE: RETVAL = "GL_INTERNALFORMAT_RED_TYPE"; break;
      case GL_INTERNALFORMAT_SHARED_SIZE: RETVAL = "GL_INTERNALFORMAT_SHARED_SIZE"; break;
      case GL_INTERNALFORMAT_STENCIL_SIZE: RETVAL = "GL_INTERNALFORMAT_STENCIL_SIZE"; break;
      case GL_INTERNALFORMAT_STENCIL_TYPE: RETVAL = "GL_INTERNALFORMAT_STENCIL_TYPE"; break;
      case GL_INTERNALFORMAT_SUPPORTED: RETVAL = "GL_INTERNALFORMAT_SUPPORTED"; break;
      case GL_MAX_DEPTH: RETVAL = "GL_MAX_DEPTH"; break;
      case GL_MAX_HEIGHT: RETVAL = "GL_MAX_HEIGHT"; break;
      case GL_MAX_LAYERS: RETVAL = "GL_MAX_LAYERS"; break;
      case GL_MAX_WIDTH: RETVAL = "GL_MAX_WIDTH"; break;
      case GL_MIPMAP: RETVAL = "GL_MIPMAP"; break;
      case GL_NUM_SAMPLE_COUNTS: RETVAL = "GL_NUM_SAMPLE_COUNTS"; break;
      case GL_NUM_SURFACE_COMPRESSION_FIXED_RATES_EXT: RETVAL = "GL_NUM_SURFACE_COMPRESSION_FIXED_RATES_EXT"; break;
      case GL_READ_PIXELS: RETVAL = "GL_READ_PIXELS"; break;
      case GL_READ_PIXELS_FORMAT: RETVAL = "GL_READ_PIXELS_FORMAT"; break;
      case GL_READ_PIXELS_TYPE: RETVAL = "GL_READ_PIXELS_TYPE"; break;
      case GL_SAMPLES: RETVAL = "GL_SAMPLES"; break;
      case GL_SHADER_IMAGE_ATOMIC: RETVAL = "GL_SHADER_IMAGE_ATOMIC"; break;
      case GL_SHADER_IMAGE_LOAD: RETVAL = "GL_SHADER_IMAGE_LOAD"; break;
      case GL_SHADER_IMAGE_STORE: RETVAL = "GL_SHADER_IMAGE_STORE"; break;
      case GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_TEST: RETVAL = "GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_TEST"; break;
      case GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_WRITE: RETVAL = "GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_WRITE"; break;
      case GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_TEST: RETVAL = "GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_TEST"; break;
      case GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_WRITE: RETVAL = "GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_WRITE"; break;
      case GL_SRGB_READ: RETVAL = "GL_SRGB_READ"; break;
      case GL_SRGB_WRITE: RETVAL = "GL_SRGB_WRITE"; break;
      case GL_STENCIL_RENDERABLE: RETVAL = "GL_STENCIL_RENDERABLE"; break;
      case GL_TESS_CONTROL_TEXTURE: RETVAL = "GL_TESS_CONTROL_TEXTURE"; break;
      case GL_TESS_EVALUATION_TEXTURE: RETVAL = "GL_TESS_EVALUATION_TEXTURE"; break;
      case GL_TEXTURE_COMPRESSED: RETVAL = "GL_TEXTURE_COMPRESSED"; break;
      case GL_TEXTURE_COMPRESSED_BLOCK_HEIGHT: RETVAL = "GL_TEXTURE_COMPRESSED_BLOCK_HEIGHT"; break;
      case GL_TEXTURE_COMPRESSED_BLOCK_SIZE: RETVAL = "GL_TEXTURE_COMPRESSED_BLOCK_SIZE"; break;
      case GL_TEXTURE_COMPRESSED_BLOCK_WIDTH: RETVAL = "GL_TEXTURE_COMPRESSED_BLOCK_WIDTH"; break;
      case GL_TEXTURE_GATHER: RETVAL = "GL_TEXTURE_GATHER"; break;
      case GL_TEXTURE_GATHER_SHADOW: RETVAL = "GL_TEXTURE_GATHER_SHADOW"; break;
      case GL_TEXTURE_IMAGE_FORMAT: RETVAL = "GL_TEXTURE_IMAGE_FORMAT"; break;
      case GL_TEXTURE_IMAGE_TYPE: RETVAL = "GL_TEXTURE_IMAGE_TYPE"; break;
      case GL_TEXTURE_SHADOW: RETVAL = "GL_TEXTURE_SHADOW"; break;
      case GL_TEXTURE_VIEW: RETVAL = "GL_TEXTURE_VIEW"; break;
      case GL_VERTEX_TEXTURE: RETVAL = "GL_VERTEX_TEXTURE"; break;
      case GL_VIEW_COMPATIBILITY_CLASS: RETVAL = "GL_VIEW_COMPATIBILITY_CLASS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "InvalidateFramebufferAttachment")) {
    switch (e) {
      case GL_COLOR: RETVAL = "GL_COLOR"; break;
      case GL_COLOR_ATTACHMENT0: RETVAL = "GL_COLOR_ATTACHMENT0"; break;
      case GL_COLOR_ATTACHMENT1: RETVAL = "GL_COLOR_ATTACHMENT1"; break;
      case GL_COLOR_ATTACHMENT10: RETVAL = "GL_COLOR_ATTACHMENT10"; break;
      case GL_COLOR_ATTACHMENT11: RETVAL = "GL_COLOR_ATTACHMENT11"; break;
      case GL_COLOR_ATTACHMENT12: RETVAL = "GL_COLOR_ATTACHMENT12"; break;
      case GL_COLOR_ATTACHMENT13: RETVAL = "GL_COLOR_ATTACHMENT13"; break;
      case GL_COLOR_ATTACHMENT14: RETVAL = "GL_COLOR_ATTACHMENT14"; break;
      case GL_COLOR_ATTACHMENT15: RETVAL = "GL_COLOR_ATTACHMENT15"; break;
      case GL_COLOR_ATTACHMENT2: RETVAL = "GL_COLOR_ATTACHMENT2"; break;
      case GL_COLOR_ATTACHMENT3: RETVAL = "GL_COLOR_ATTACHMENT3"; break;
      case GL_COLOR_ATTACHMENT4: RETVAL = "GL_COLOR_ATTACHMENT4"; break;
      case GL_COLOR_ATTACHMENT5: RETVAL = "GL_COLOR_ATTACHMENT5"; break;
      case GL_COLOR_ATTACHMENT6: RETVAL = "GL_COLOR_ATTACHMENT6"; break;
      case GL_COLOR_ATTACHMENT7: RETVAL = "GL_COLOR_ATTACHMENT7"; break;
      case GL_COLOR_ATTACHMENT8: RETVAL = "GL_COLOR_ATTACHMENT8"; break;
      case GL_COLOR_ATTACHMENT9: RETVAL = "GL_COLOR_ATTACHMENT9"; break;
      case GL_DEPTH: RETVAL = "GL_DEPTH"; break;
      case GL_DEPTH_ATTACHMENT: RETVAL = "GL_DEPTH_ATTACHMENT"; break;
      case GL_DEPTH_STENCIL_ATTACHMENT: RETVAL = "GL_DEPTH_STENCIL_ATTACHMENT"; break;
      case GL_STENCIL: RETVAL = "GL_STENCIL"; break;
      case GL_STENCIL_ATTACHMENT_EXT: RETVAL = "GL_STENCIL_ATTACHMENT_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightEnvModeSGIX")) {
    switch (e) {
      case GL_ADD: RETVAL = "GL_ADD"; break;
      case GL_MODULATE: RETVAL = "GL_MODULATE"; break;
      case GL_REPLACE: RETVAL = "GL_REPLACE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightModelColorControl")) {
    switch (e) {
      case GL_SEPARATE_SPECULAR_COLOR: RETVAL = "GL_SEPARATE_SPECULAR_COLOR"; break;
      case GL_SINGLE_COLOR: RETVAL = "GL_SINGLE_COLOR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightModelParameter")) {
    switch (e) {
      case GL_LIGHT_MODEL_AMBIENT: RETVAL = "GL_LIGHT_MODEL_AMBIENT"; break;
      case GL_LIGHT_MODEL_COLOR_CONTROL: RETVAL = "GL_LIGHT_MODEL_COLOR_CONTROL"; break;
      case GL_LIGHT_MODEL_LOCAL_VIEWER: RETVAL = "GL_LIGHT_MODEL_LOCAL_VIEWER"; break;
      case GL_LIGHT_MODEL_TWO_SIDE: RETVAL = "GL_LIGHT_MODEL_TWO_SIDE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightName")) {
    switch (e) {
      case GL_LIGHT0: RETVAL = "GL_LIGHT0"; break;
      case GL_LIGHT1: RETVAL = "GL_LIGHT1"; break;
      case GL_LIGHT2: RETVAL = "GL_LIGHT2"; break;
      case GL_LIGHT3: RETVAL = "GL_LIGHT3"; break;
      case GL_LIGHT4: RETVAL = "GL_LIGHT4"; break;
      case GL_LIGHT5: RETVAL = "GL_LIGHT5"; break;
      case GL_LIGHT6: RETVAL = "GL_LIGHT6"; break;
      case GL_LIGHT7: RETVAL = "GL_LIGHT7"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightParameter")) {
    switch (e) {
      case GL_AMBIENT: RETVAL = "GL_AMBIENT"; break;
      case GL_CONSTANT_ATTENUATION: RETVAL = "GL_CONSTANT_ATTENUATION"; break;
      case GL_DIFFUSE: RETVAL = "GL_DIFFUSE"; break;
      case GL_LINEAR_ATTENUATION: RETVAL = "GL_LINEAR_ATTENUATION"; break;
      case GL_POSITION: RETVAL = "GL_POSITION"; break;
      case GL_QUADRATIC_ATTENUATION: RETVAL = "GL_QUADRATIC_ATTENUATION"; break;
      case GL_SPECULAR: RETVAL = "GL_SPECULAR"; break;
      case GL_SPOT_CUTOFF: RETVAL = "GL_SPOT_CUTOFF"; break;
      case GL_SPOT_DIRECTION: RETVAL = "GL_SPOT_DIRECTION"; break;
      case GL_SPOT_EXPONENT: RETVAL = "GL_SPOT_EXPONENT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightTextureModeEXT")) {
    switch (e) {
      case GL_FRAGMENT_COLOR_EXT: RETVAL = "GL_FRAGMENT_COLOR_EXT"; break;
      case GL_FRAGMENT_DEPTH: RETVAL = "GL_FRAGMENT_DEPTH"; break;
      case GL_FRAGMENT_MATERIAL_EXT: RETVAL = "GL_FRAGMENT_MATERIAL_EXT"; break;
      case GL_FRAGMENT_NORMAL_EXT: RETVAL = "GL_FRAGMENT_NORMAL_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LightTexturePNameEXT")) {
    switch (e) {
      case GL_ATTENUATION_EXT: RETVAL = "GL_ATTENUATION_EXT"; break;
      case GL_SHADOW_ATTENUATION_EXT: RETVAL = "GL_SHADOW_ATTENUATION_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ListMode")) {
    switch (e) {
      case GL_COMPILE: RETVAL = "GL_COMPILE"; break;
      case GL_COMPILE_AND_EXECUTE: RETVAL = "GL_COMPILE_AND_EXECUTE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ListNameType")) {
    switch (e) {
      case GL_2_BYTES: RETVAL = "GL_2_BYTES"; break;
      case GL_3_BYTES: RETVAL = "GL_3_BYTES"; break;
      case GL_4_BYTES: RETVAL = "GL_4_BYTES"; break;
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "LogicOp")) {
    switch (e) {
      case GL_AND: RETVAL = "GL_AND"; break;
      case GL_AND_INVERTED: RETVAL = "GL_AND_INVERTED"; break;
      case GL_AND_REVERSE: RETVAL = "GL_AND_REVERSE"; break;
      case GL_CLEAR: RETVAL = "GL_CLEAR"; break;
      case GL_COPY: RETVAL = "GL_COPY"; break;
      case GL_COPY_INVERTED: RETVAL = "GL_COPY_INVERTED"; break;
      case GL_EQUIV: RETVAL = "GL_EQUIV"; break;
      case GL_INVERT: RETVAL = "GL_INVERT"; break;
      case GL_NAND: RETVAL = "GL_NAND"; break;
      case GL_NOOP: RETVAL = "GL_NOOP"; break;
      case GL_NOR: RETVAL = "GL_NOR"; break;
      case GL_OR: RETVAL = "GL_OR"; break;
      case GL_OR_INVERTED: RETVAL = "GL_OR_INVERTED"; break;
      case GL_OR_REVERSE: RETVAL = "GL_OR_REVERSE"; break;
      case GL_SET: RETVAL = "GL_SET"; break;
      case GL_XOR: RETVAL = "GL_XOR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapAttribParameterNV")) {
    switch (e) {
      case GL_MAP_ATTRIB_U_ORDER_NV: RETVAL = "GL_MAP_ATTRIB_U_ORDER_NV"; break;
      case GL_MAP_ATTRIB_V_ORDER_NV: RETVAL = "GL_MAP_ATTRIB_V_ORDER_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapBufferAccessMask")) {
    switch (e) {
      case GL_MAP_COHERENT_BIT: RETVAL = "GL_MAP_COHERENT_BIT"; break;
      case GL_MAP_FLUSH_EXPLICIT_BIT: RETVAL = "GL_MAP_FLUSH_EXPLICIT_BIT"; break;
      case GL_MAP_INVALIDATE_BUFFER_BIT: RETVAL = "GL_MAP_INVALIDATE_BUFFER_BIT"; break;
      case GL_MAP_INVALIDATE_RANGE_BIT: RETVAL = "GL_MAP_INVALIDATE_RANGE_BIT"; break;
      case GL_MAP_PERSISTENT_BIT: RETVAL = "GL_MAP_PERSISTENT_BIT"; break;
      case GL_MAP_READ_BIT: RETVAL = "GL_MAP_READ_BIT"; break;
      case GL_MAP_UNSYNCHRONIZED_BIT: RETVAL = "GL_MAP_UNSYNCHRONIZED_BIT"; break;
      case GL_MAP_WRITE_BIT: RETVAL = "GL_MAP_WRITE_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapParameterNV")) {
    switch (e) {
      case GL_MAP_TESSELLATION_NV: RETVAL = "GL_MAP_TESSELLATION_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapQuery")) {
    switch (e) {
      case GL_COEFF: RETVAL = "GL_COEFF"; break;
      case GL_DOMAIN: RETVAL = "GL_DOMAIN"; break;
      case GL_ORDER: RETVAL = "GL_ORDER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapTarget")) {
    switch (e) {
      case GL_MAP1_COLOR_4: RETVAL = "GL_MAP1_COLOR_4"; break;
      case GL_MAP1_INDEX: RETVAL = "GL_MAP1_INDEX"; break;
      case GL_MAP1_NORMAL: RETVAL = "GL_MAP1_NORMAL"; break;
      case GL_MAP1_TEXTURE_COORD_1: RETVAL = "GL_MAP1_TEXTURE_COORD_1"; break;
      case GL_MAP1_TEXTURE_COORD_2: RETVAL = "GL_MAP1_TEXTURE_COORD_2"; break;
      case GL_MAP1_TEXTURE_COORD_3: RETVAL = "GL_MAP1_TEXTURE_COORD_3"; break;
      case GL_MAP1_TEXTURE_COORD_4: RETVAL = "GL_MAP1_TEXTURE_COORD_4"; break;
      case GL_MAP1_VERTEX_3: RETVAL = "GL_MAP1_VERTEX_3"; break;
      case GL_MAP1_VERTEX_4: RETVAL = "GL_MAP1_VERTEX_4"; break;
      case GL_MAP2_COLOR_4: RETVAL = "GL_MAP2_COLOR_4"; break;
      case GL_MAP2_INDEX: RETVAL = "GL_MAP2_INDEX"; break;
      case GL_MAP2_NORMAL: RETVAL = "GL_MAP2_NORMAL"; break;
      case GL_MAP2_TEXTURE_COORD_1: RETVAL = "GL_MAP2_TEXTURE_COORD_1"; break;
      case GL_MAP2_TEXTURE_COORD_2: RETVAL = "GL_MAP2_TEXTURE_COORD_2"; break;
      case GL_MAP2_TEXTURE_COORD_3: RETVAL = "GL_MAP2_TEXTURE_COORD_3"; break;
      case GL_MAP2_TEXTURE_COORD_4: RETVAL = "GL_MAP2_TEXTURE_COORD_4"; break;
      case GL_MAP2_VERTEX_3: RETVAL = "GL_MAP2_VERTEX_3"; break;
      case GL_MAP2_VERTEX_4: RETVAL = "GL_MAP2_VERTEX_4"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapTextureFormatINTEL")) {
    switch (e) {
      case GL_LAYOUT_DEFAULT_INTEL: RETVAL = "GL_LAYOUT_DEFAULT_INTEL"; break;
      case GL_LAYOUT_LINEAR_CPU_CACHED_INTEL: RETVAL = "GL_LAYOUT_LINEAR_CPU_CACHED_INTEL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MapTypeNV")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MaterialParameter")) {
    switch (e) {
      case GL_AMBIENT: RETVAL = "GL_AMBIENT"; break;
      case GL_AMBIENT_AND_DIFFUSE: RETVAL = "GL_AMBIENT_AND_DIFFUSE"; break;
      case GL_COLOR_INDEXES: RETVAL = "GL_COLOR_INDEXES"; break;
      case GL_DIFFUSE: RETVAL = "GL_DIFFUSE"; break;
      case GL_EMISSION: RETVAL = "GL_EMISSION"; break;
      case GL_SHININESS: RETVAL = "GL_SHININESS"; break;
      case GL_SPECULAR: RETVAL = "GL_SPECULAR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MatrixIndexPointerTypeARB")) {
    switch (e) {
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MatrixMode")) {
    switch (e) {
      case GL_MODELVIEW: RETVAL = "GL_MODELVIEW"; break;
      case GL_PROJECTION: RETVAL = "GL_PROJECTION"; break;
      case GL_TEXTURE: RETVAL = "GL_TEXTURE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MemoryBarrierMask")) {
    switch (e) {
      case GL_ALL_BARRIER_BITS: RETVAL = "GL_ALL_BARRIER_BITS"; break;
      case GL_ATOMIC_COUNTER_BARRIER_BIT: RETVAL = "GL_ATOMIC_COUNTER_BARRIER_BIT"; break;
      case GL_BUFFER_UPDATE_BARRIER_BIT: RETVAL = "GL_BUFFER_UPDATE_BARRIER_BIT"; break;
      case GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT: RETVAL = "GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT"; break;
      case GL_COMMAND_BARRIER_BIT: RETVAL = "GL_COMMAND_BARRIER_BIT"; break;
      case GL_ELEMENT_ARRAY_BARRIER_BIT: RETVAL = "GL_ELEMENT_ARRAY_BARRIER_BIT"; break;
      case GL_FRAMEBUFFER_BARRIER_BIT: RETVAL = "GL_FRAMEBUFFER_BARRIER_BIT"; break;
      case GL_PIXEL_BUFFER_BARRIER_BIT: RETVAL = "GL_PIXEL_BUFFER_BARRIER_BIT"; break;
      case GL_QUERY_BUFFER_BARRIER_BIT: RETVAL = "GL_QUERY_BUFFER_BARRIER_BIT"; break;
      case GL_SHADER_IMAGE_ACCESS_BARRIER_BIT: RETVAL = "GL_SHADER_IMAGE_ACCESS_BARRIER_BIT"; break;
      case GL_SHADER_STORAGE_BARRIER_BIT: RETVAL = "GL_SHADER_STORAGE_BARRIER_BIT"; break;
      case GL_TEXTURE_FETCH_BARRIER_BIT: RETVAL = "GL_TEXTURE_FETCH_BARRIER_BIT"; break;
      case GL_TEXTURE_UPDATE_BARRIER_BIT: RETVAL = "GL_TEXTURE_UPDATE_BARRIER_BIT"; break;
      case GL_TRANSFORM_FEEDBACK_BARRIER_BIT: RETVAL = "GL_TRANSFORM_FEEDBACK_BARRIER_BIT"; break;
      case GL_UNIFORM_BARRIER_BIT: RETVAL = "GL_UNIFORM_BARRIER_BIT"; break;
      case GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MemoryObjectParameterName")) {
    switch (e) {
      case GL_DEDICATED_MEMORY_OBJECT_EXT: RETVAL = "GL_DEDICATED_MEMORY_OBJECT_EXT"; break;
      case GL_PROTECTED_MEMORY_OBJECT_EXT: RETVAL = "GL_PROTECTED_MEMORY_OBJECT_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MeshMode1")) {
    switch (e) {
      case GL_LINE: RETVAL = "GL_LINE"; break;
      case GL_POINT: RETVAL = "GL_POINT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MeshMode2")) {
    switch (e) {
      case GL_FILL: RETVAL = "GL_FILL"; break;
      case GL_LINE: RETVAL = "GL_LINE"; break;
      case GL_POINT: RETVAL = "GL_POINT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MinmaxTarget")) {
    switch (e) {
      case GL_MINMAX: RETVAL = "GL_MINMAX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "MinmaxTargetEXT")) {
    switch (e) {
      case GL_MINMAX: RETVAL = "GL_MINMAX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "NormalPointerType")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ObjectIdentifier")) {
    switch (e) {
      case GL_BUFFER: RETVAL = "GL_BUFFER"; break;
      case GL_FRAMEBUFFER: RETVAL = "GL_FRAMEBUFFER"; break;
      case GL_PROGRAM: RETVAL = "GL_PROGRAM"; break;
      case GL_PROGRAM_PIPELINE: RETVAL = "GL_PROGRAM_PIPELINE"; break;
      case GL_QUERY: RETVAL = "GL_QUERY"; break;
      case GL_RENDERBUFFER: RETVAL = "GL_RENDERBUFFER"; break;
      case GL_SAMPLER: RETVAL = "GL_SAMPLER"; break;
      case GL_SHADER: RETVAL = "GL_SHADER"; break;
      case GL_TEXTURE: RETVAL = "GL_TEXTURE"; break;
      case GL_TRANSFORM_FEEDBACK: RETVAL = "GL_TRANSFORM_FEEDBACK"; break;
      case GL_VERTEX_ARRAY: RETVAL = "GL_VERTEX_ARRAY"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ObjectTypeAPPLE")) {
    switch (e) {
      case GL_DRAW_PIXELS_APPLE: RETVAL = "GL_DRAW_PIXELS_APPLE"; break;
      case GL_FENCE_APPLE: RETVAL = "GL_FENCE_APPLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "OcclusionQueryEventMaskAMD")) {
    switch (e) {
      case GL_QUERY_ALL_EVENT_BITS_AMD: RETVAL = "GL_QUERY_ALL_EVENT_BITS_AMD"; break;
      case GL_QUERY_DEPTH_BOUNDS_FAIL_EVENT_BIT_AMD: RETVAL = "GL_QUERY_DEPTH_BOUNDS_FAIL_EVENT_BIT_AMD"; break;
      case GL_QUERY_DEPTH_FAIL_EVENT_BIT_AMD: RETVAL = "GL_QUERY_DEPTH_FAIL_EVENT_BIT_AMD"; break;
      case GL_QUERY_DEPTH_PASS_EVENT_BIT_AMD: RETVAL = "GL_QUERY_DEPTH_PASS_EVENT_BIT_AMD"; break;
      case GL_QUERY_STENCIL_FAIL_EVENT_BIT_AMD: RETVAL = "GL_QUERY_STENCIL_FAIL_EVENT_BIT_AMD"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "OcclusionQueryParameterNameNV")) {
    switch (e) {
      case GL_PIXEL_COUNT_AVAILABLE_NV: RETVAL = "GL_PIXEL_COUNT_AVAILABLE_NV"; break;
      case GL_PIXEL_COUNT_NV: RETVAL = "GL_PIXEL_COUNT_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PNTrianglesPNameATI")) {
    switch (e) {
      case GL_PN_TRIANGLES_NORMAL_MODE_ATI: RETVAL = "GL_PN_TRIANGLES_NORMAL_MODE_ATI"; break;
      case GL_PN_TRIANGLES_POINT_MODE_ATI: RETVAL = "GL_PN_TRIANGLES_POINT_MODE_ATI"; break;
      case GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI: RETVAL = "GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ParameterRangeEXT")) {
    switch (e) {
      case GL_FULL_RANGE_EXT: RETVAL = "GL_FULL_RANGE_EXT"; break;
      case GL_NORMALIZED_RANGE_EXT: RETVAL = "GL_NORMALIZED_RANGE_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PatchParameterName")) {
    switch (e) {
      case GL_PATCH_DEFAULT_INNER_LEVEL: RETVAL = "GL_PATCH_DEFAULT_INNER_LEVEL"; break;
      case GL_PATCH_DEFAULT_OUTER_LEVEL: RETVAL = "GL_PATCH_DEFAULT_OUTER_LEVEL"; break;
      case GL_PATCH_VERTICES: RETVAL = "GL_PATCH_VERTICES"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathColor")) {
    switch (e) {
      case GL_PRIMARY_COLOR: RETVAL = "GL_PRIMARY_COLOR"; break;
      case GL_PRIMARY_COLOR_NV: RETVAL = "GL_PRIMARY_COLOR_NV"; break;
      case GL_SECONDARY_COLOR_NV: RETVAL = "GL_SECONDARY_COLOR_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathColorFormat")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_INTENSITY: RETVAL = "GL_INTENSITY"; break;
      case GL_LUMINANCE: RETVAL = "GL_LUMINANCE"; break;
      case GL_LUMINANCE_ALPHA: RETVAL = "GL_LUMINANCE_ALPHA"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      case GL_RGBA: RETVAL = "GL_RGBA"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathCoordType")) {
    switch (e) {
      case GL_ARC_TO_NV: RETVAL = "GL_ARC_TO_NV"; break;
      case GL_CIRCULAR_CCW_ARC_TO_NV: RETVAL = "GL_CIRCULAR_CCW_ARC_TO_NV"; break;
      case GL_CIRCULAR_CW_ARC_TO_NV: RETVAL = "GL_CIRCULAR_CW_ARC_TO_NV"; break;
      case GL_CIRCULAR_TANGENT_ARC_TO_NV: RETVAL = "GL_CIRCULAR_TANGENT_ARC_TO_NV"; break;
      case GL_CLOSE_PATH_NV: RETVAL = "GL_CLOSE_PATH_NV"; break;
      case GL_CONIC_CURVE_TO_NV: RETVAL = "GL_CONIC_CURVE_TO_NV"; break;
      case GL_CUBIC_CURVE_TO_NV: RETVAL = "GL_CUBIC_CURVE_TO_NV"; break;
      case GL_DUP_FIRST_CUBIC_CURVE_TO_NV: RETVAL = "GL_DUP_FIRST_CUBIC_CURVE_TO_NV"; break;
      case GL_DUP_LAST_CUBIC_CURVE_TO_NV: RETVAL = "GL_DUP_LAST_CUBIC_CURVE_TO_NV"; break;
      case GL_HORIZONTAL_LINE_TO_NV: RETVAL = "GL_HORIZONTAL_LINE_TO_NV"; break;
      case GL_LARGE_CCW_ARC_TO_NV: RETVAL = "GL_LARGE_CCW_ARC_TO_NV"; break;
      case GL_LARGE_CW_ARC_TO_NV: RETVAL = "GL_LARGE_CW_ARC_TO_NV"; break;
      case GL_LINE_TO_NV: RETVAL = "GL_LINE_TO_NV"; break;
      case GL_MOVE_TO_NV: RETVAL = "GL_MOVE_TO_NV"; break;
      case GL_QUADRATIC_CURVE_TO_NV: RETVAL = "GL_QUADRATIC_CURVE_TO_NV"; break;
      case GL_RECT_NV: RETVAL = "GL_RECT_NV"; break;
      case GL_RELATIVE_ARC_TO_NV: RETVAL = "GL_RELATIVE_ARC_TO_NV"; break;
      case GL_RELATIVE_CONIC_CURVE_TO_NV: RETVAL = "GL_RELATIVE_CONIC_CURVE_TO_NV"; break;
      case GL_RELATIVE_CUBIC_CURVE_TO_NV: RETVAL = "GL_RELATIVE_CUBIC_CURVE_TO_NV"; break;
      case GL_RELATIVE_HORIZONTAL_LINE_TO_NV: RETVAL = "GL_RELATIVE_HORIZONTAL_LINE_TO_NV"; break;
      case GL_RELATIVE_LARGE_CCW_ARC_TO_NV: RETVAL = "GL_RELATIVE_LARGE_CCW_ARC_TO_NV"; break;
      case GL_RELATIVE_LARGE_CW_ARC_TO_NV: RETVAL = "GL_RELATIVE_LARGE_CW_ARC_TO_NV"; break;
      case GL_RELATIVE_LINE_TO_NV: RETVAL = "GL_RELATIVE_LINE_TO_NV"; break;
      case GL_RELATIVE_MOVE_TO_NV: RETVAL = "GL_RELATIVE_MOVE_TO_NV"; break;
      case GL_RELATIVE_QUADRATIC_CURVE_TO_NV: RETVAL = "GL_RELATIVE_QUADRATIC_CURVE_TO_NV"; break;
      case GL_RELATIVE_RECT_NV: RETVAL = "GL_RELATIVE_RECT_NV"; break;
      case GL_RELATIVE_ROUNDED_RECT2_NV: RETVAL = "GL_RELATIVE_ROUNDED_RECT2_NV"; break;
      case GL_RELATIVE_ROUNDED_RECT4_NV: RETVAL = "GL_RELATIVE_ROUNDED_RECT4_NV"; break;
      case GL_RELATIVE_ROUNDED_RECT8_NV: RETVAL = "GL_RELATIVE_ROUNDED_RECT8_NV"; break;
      case GL_RELATIVE_ROUNDED_RECT_NV: RETVAL = "GL_RELATIVE_ROUNDED_RECT_NV"; break;
      case GL_RELATIVE_SMALL_CCW_ARC_TO_NV: RETVAL = "GL_RELATIVE_SMALL_CCW_ARC_TO_NV"; break;
      case GL_RELATIVE_SMALL_CW_ARC_TO_NV: RETVAL = "GL_RELATIVE_SMALL_CW_ARC_TO_NV"; break;
      case GL_RELATIVE_SMOOTH_CUBIC_CURVE_TO_NV: RETVAL = "GL_RELATIVE_SMOOTH_CUBIC_CURVE_TO_NV"; break;
      case GL_RELATIVE_SMOOTH_QUADRATIC_CURVE_TO_NV: RETVAL = "GL_RELATIVE_SMOOTH_QUADRATIC_CURVE_TO_NV"; break;
      case GL_RELATIVE_VERTICAL_LINE_TO_NV: RETVAL = "GL_RELATIVE_VERTICAL_LINE_TO_NV"; break;
      case GL_RESTART_PATH_NV: RETVAL = "GL_RESTART_PATH_NV"; break;
      case GL_ROUNDED_RECT2_NV: RETVAL = "GL_ROUNDED_RECT2_NV"; break;
      case GL_ROUNDED_RECT4_NV: RETVAL = "GL_ROUNDED_RECT4_NV"; break;
      case GL_ROUNDED_RECT8_NV: RETVAL = "GL_ROUNDED_RECT8_NV"; break;
      case GL_ROUNDED_RECT_NV: RETVAL = "GL_ROUNDED_RECT_NV"; break;
      case GL_SMALL_CCW_ARC_TO_NV: RETVAL = "GL_SMALL_CCW_ARC_TO_NV"; break;
      case GL_SMALL_CW_ARC_TO_NV: RETVAL = "GL_SMALL_CW_ARC_TO_NV"; break;
      case GL_SMOOTH_CUBIC_CURVE_TO_NV: RETVAL = "GL_SMOOTH_CUBIC_CURVE_TO_NV"; break;
      case GL_SMOOTH_QUADRATIC_CURVE_TO_NV: RETVAL = "GL_SMOOTH_QUADRATIC_CURVE_TO_NV"; break;
      case GL_VERTICAL_LINE_TO_NV: RETVAL = "GL_VERTICAL_LINE_TO_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathCoverMode")) {
    switch (e) {
      case GL_BOUNDING_BOX_NV: RETVAL = "GL_BOUNDING_BOX_NV"; break;
      case GL_CONVEX_HULL_NV: RETVAL = "GL_CONVEX_HULL_NV"; break;
      case GL_PATH_FILL_COVER_MODE_NV: RETVAL = "GL_PATH_FILL_COVER_MODE_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathElementType")) {
    switch (e) {
      case GL_UTF16_NV: RETVAL = "GL_UTF16_NV"; break;
      case GL_UTF8_NV: RETVAL = "GL_UTF8_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathFillMode")) {
    switch (e) {
      case GL_COUNT_DOWN_NV: RETVAL = "GL_COUNT_DOWN_NV"; break;
      case GL_COUNT_UP_NV: RETVAL = "GL_COUNT_UP_NV"; break;
      case GL_INVERT: RETVAL = "GL_INVERT"; break;
      case GL_PATH_FILL_MODE_NV: RETVAL = "GL_PATH_FILL_MODE_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathFontStyle")) {
    switch (e) {
      case GL_BOLD_BIT_NV: RETVAL = "GL_BOLD_BIT_NV"; break;
      case GL_ITALIC_BIT_NV: RETVAL = "GL_ITALIC_BIT_NV"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathFontTarget")) {
    switch (e) {
      case GL_FILE_NAME_NV: RETVAL = "GL_FILE_NAME_NV"; break;
      case GL_STANDARD_FONT_NAME_NV: RETVAL = "GL_STANDARD_FONT_NAME_NV"; break;
      case GL_SYSTEM_FONT_NAME_NV: RETVAL = "GL_SYSTEM_FONT_NAME_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathGenMode")) {
    switch (e) {
      case GL_CONSTANT: RETVAL = "GL_CONSTANT"; break;
      case GL_EYE_LINEAR: RETVAL = "GL_EYE_LINEAR"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_OBJECT_LINEAR: RETVAL = "GL_OBJECT_LINEAR"; break;
      case GL_PATH_OBJECT_BOUNDING_BOX_NV: RETVAL = "GL_PATH_OBJECT_BOUNDING_BOX_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathHandleMissingGlyphs")) {
    switch (e) {
      case GL_SKIP_MISSING_GLYPH_NV: RETVAL = "GL_SKIP_MISSING_GLYPH_NV"; break;
      case GL_USE_MISSING_GLYPH_NV: RETVAL = "GL_USE_MISSING_GLYPH_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathListMode")) {
    switch (e) {
      case GL_ACCUM_ADJACENT_PAIRS_NV: RETVAL = "GL_ACCUM_ADJACENT_PAIRS_NV"; break;
      case GL_ADJACENT_PAIRS_NV: RETVAL = "GL_ADJACENT_PAIRS_NV"; break;
      case GL_FIRST_TO_REST_NV: RETVAL = "GL_FIRST_TO_REST_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathMetricMask")) {
    switch (e) {
      case GL_FONT_ASCENDER_BIT_NV: RETVAL = "GL_FONT_ASCENDER_BIT_NV"; break;
      case GL_FONT_DESCENDER_BIT_NV: RETVAL = "GL_FONT_DESCENDER_BIT_NV"; break;
      case GL_FONT_HAS_KERNING_BIT_NV: RETVAL = "GL_FONT_HAS_KERNING_BIT_NV"; break;
      case GL_FONT_HEIGHT_BIT_NV: RETVAL = "GL_FONT_HEIGHT_BIT_NV"; break;
      case GL_FONT_MAX_ADVANCE_HEIGHT_BIT_NV: RETVAL = "GL_FONT_MAX_ADVANCE_HEIGHT_BIT_NV"; break;
      case GL_FONT_MAX_ADVANCE_WIDTH_BIT_NV: RETVAL = "GL_FONT_MAX_ADVANCE_WIDTH_BIT_NV"; break;
      case GL_FONT_NUM_GLYPH_INDICES_BIT_NV: RETVAL = "GL_FONT_NUM_GLYPH_INDICES_BIT_NV"; break;
      case GL_FONT_UNDERLINE_POSITION_BIT_NV: RETVAL = "GL_FONT_UNDERLINE_POSITION_BIT_NV"; break;
      case GL_FONT_UNDERLINE_THICKNESS_BIT_NV: RETVAL = "GL_FONT_UNDERLINE_THICKNESS_BIT_NV"; break;
      case GL_FONT_UNITS_PER_EM_BIT_NV: RETVAL = "GL_FONT_UNITS_PER_EM_BIT_NV"; break;
      case GL_FONT_X_MAX_BOUNDS_BIT_NV: RETVAL = "GL_FONT_X_MAX_BOUNDS_BIT_NV"; break;
      case GL_FONT_X_MIN_BOUNDS_BIT_NV: RETVAL = "GL_FONT_X_MIN_BOUNDS_BIT_NV"; break;
      case GL_FONT_Y_MAX_BOUNDS_BIT_NV: RETVAL = "GL_FONT_Y_MAX_BOUNDS_BIT_NV"; break;
      case GL_FONT_Y_MIN_BOUNDS_BIT_NV: RETVAL = "GL_FONT_Y_MIN_BOUNDS_BIT_NV"; break;
      case GL_GLYPH_HAS_KERNING_BIT_NV: RETVAL = "GL_GLYPH_HAS_KERNING_BIT_NV"; break;
      case GL_GLYPH_HEIGHT_BIT_NV: RETVAL = "GL_GLYPH_HEIGHT_BIT_NV"; break;
      case GL_GLYPH_HORIZONTAL_BEARING_ADVANCE_BIT_NV: RETVAL = "GL_GLYPH_HORIZONTAL_BEARING_ADVANCE_BIT_NV"; break;
      case GL_GLYPH_HORIZONTAL_BEARING_X_BIT_NV: RETVAL = "GL_GLYPH_HORIZONTAL_BEARING_X_BIT_NV"; break;
      case GL_GLYPH_HORIZONTAL_BEARING_Y_BIT_NV: RETVAL = "GL_GLYPH_HORIZONTAL_BEARING_Y_BIT_NV"; break;
      case GL_GLYPH_VERTICAL_BEARING_ADVANCE_BIT_NV: RETVAL = "GL_GLYPH_VERTICAL_BEARING_ADVANCE_BIT_NV"; break;
      case GL_GLYPH_VERTICAL_BEARING_X_BIT_NV: RETVAL = "GL_GLYPH_VERTICAL_BEARING_X_BIT_NV"; break;
      case GL_GLYPH_VERTICAL_BEARING_Y_BIT_NV: RETVAL = "GL_GLYPH_VERTICAL_BEARING_Y_BIT_NV"; break;
      case GL_GLYPH_WIDTH_BIT_NV: RETVAL = "GL_GLYPH_WIDTH_BIT_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathParameter")) {
    switch (e) {
      case GL_PATH_CLIENT_LENGTH_NV: RETVAL = "GL_PATH_CLIENT_LENGTH_NV"; break;
      case GL_PATH_COMMAND_COUNT_NV: RETVAL = "GL_PATH_COMMAND_COUNT_NV"; break;
      case GL_PATH_COMPUTED_LENGTH_NV: RETVAL = "GL_PATH_COMPUTED_LENGTH_NV"; break;
      case GL_PATH_COORD_COUNT_NV: RETVAL = "GL_PATH_COORD_COUNT_NV"; break;
      case GL_PATH_DASH_ARRAY_COUNT_NV: RETVAL = "GL_PATH_DASH_ARRAY_COUNT_NV"; break;
      case GL_PATH_DASH_CAPS_NV: RETVAL = "GL_PATH_DASH_CAPS_NV"; break;
      case GL_PATH_DASH_OFFSET_NV: RETVAL = "GL_PATH_DASH_OFFSET_NV"; break;
      case GL_PATH_DASH_OFFSET_RESET_NV: RETVAL = "GL_PATH_DASH_OFFSET_RESET_NV"; break;
      case GL_PATH_END_CAPS_NV: RETVAL = "GL_PATH_END_CAPS_NV"; break;
      case GL_PATH_FILL_BOUNDING_BOX_NV: RETVAL = "GL_PATH_FILL_BOUNDING_BOX_NV"; break;
      case GL_PATH_FILL_COVER_MODE_NV: RETVAL = "GL_PATH_FILL_COVER_MODE_NV"; break;
      case GL_PATH_FILL_MASK_NV: RETVAL = "GL_PATH_FILL_MASK_NV"; break;
      case GL_PATH_FILL_MODE_NV: RETVAL = "GL_PATH_FILL_MODE_NV"; break;
      case GL_PATH_INITIAL_DASH_CAP_NV: RETVAL = "GL_PATH_INITIAL_DASH_CAP_NV"; break;
      case GL_PATH_INITIAL_END_CAP_NV: RETVAL = "GL_PATH_INITIAL_END_CAP_NV"; break;
      case GL_PATH_JOIN_STYLE_NV: RETVAL = "GL_PATH_JOIN_STYLE_NV"; break;
      case GL_PATH_MITER_LIMIT_NV: RETVAL = "GL_PATH_MITER_LIMIT_NV"; break;
      case GL_PATH_OBJECT_BOUNDING_BOX_NV: RETVAL = "GL_PATH_OBJECT_BOUNDING_BOX_NV"; break;
      case GL_PATH_STROKE_BOUNDING_BOX_NV: RETVAL = "GL_PATH_STROKE_BOUNDING_BOX_NV"; break;
      case GL_PATH_STROKE_COVER_MODE_NV: RETVAL = "GL_PATH_STROKE_COVER_MODE_NV"; break;
      case GL_PATH_STROKE_MASK_NV: RETVAL = "GL_PATH_STROKE_MASK_NV"; break;
      case GL_PATH_STROKE_WIDTH_NV: RETVAL = "GL_PATH_STROKE_WIDTH_NV"; break;
      case GL_PATH_TERMINAL_DASH_CAP_NV: RETVAL = "GL_PATH_TERMINAL_DASH_CAP_NV"; break;
      case GL_PATH_TERMINAL_END_CAP_NV: RETVAL = "GL_PATH_TERMINAL_END_CAP_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathStringFormat")) {
    switch (e) {
      case GL_PATH_FORMAT_PS_NV: RETVAL = "GL_PATH_FORMAT_PS_NV"; break;
      case GL_PATH_FORMAT_SVG_NV: RETVAL = "GL_PATH_FORMAT_SVG_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PathTransformType")) {
    switch (e) {
      case GL_AFFINE_2D_NV: RETVAL = "GL_AFFINE_2D_NV"; break;
      case GL_AFFINE_3D_NV: RETVAL = "GL_AFFINE_3D_NV"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_TRANSLATE_2D_NV: RETVAL = "GL_TRANSLATE_2D_NV"; break;
      case GL_TRANSLATE_3D_NV: RETVAL = "GL_TRANSLATE_3D_NV"; break;
      case GL_TRANSLATE_X_NV: RETVAL = "GL_TRANSLATE_X_NV"; break;
      case GL_TRANSLATE_Y_NV: RETVAL = "GL_TRANSLATE_Y_NV"; break;
      case GL_TRANSPOSE_AFFINE_2D_NV: RETVAL = "GL_TRANSPOSE_AFFINE_2D_NV"; break;
      case GL_TRANSPOSE_AFFINE_3D_NV: RETVAL = "GL_TRANSPOSE_AFFINE_3D_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PerfQueryDataFlags")) {
    switch (e) {
      case GL_PERFQUERY_DONOT_FLUSH_INTEL: RETVAL = "GL_PERFQUERY_DONOT_FLUSH_INTEL"; break;
      case GL_PERFQUERY_FLUSH_INTEL: RETVAL = "GL_PERFQUERY_FLUSH_INTEL"; break;
      case GL_PERFQUERY_WAIT_INTEL: RETVAL = "GL_PERFQUERY_WAIT_INTEL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PerformanceQueryCapsMaskINTEL")) {
    switch (e) {
      case GL_PERFQUERY_GLOBAL_CONTEXT_INTEL: RETVAL = "GL_PERFQUERY_GLOBAL_CONTEXT_INTEL"; break;
      case GL_PERFQUERY_SINGLE_CONTEXT_INTEL: RETVAL = "GL_PERFQUERY_SINGLE_CONTEXT_INTEL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PipelineParameterName")) {
    switch (e) {
      case GL_ACTIVE_PROGRAM: RETVAL = "GL_ACTIVE_PROGRAM"; break;
      case GL_FRAGMENT_SHADER: RETVAL = "GL_FRAGMENT_SHADER"; break;
      case GL_GEOMETRY_SHADER: RETVAL = "GL_GEOMETRY_SHADER"; break;
      case GL_INFO_LOG_LENGTH: RETVAL = "GL_INFO_LOG_LENGTH"; break;
      case GL_TESS_CONTROL_SHADER: RETVAL = "GL_TESS_CONTROL_SHADER"; break;
      case GL_TESS_EVALUATION_SHADER: RETVAL = "GL_TESS_EVALUATION_SHADER"; break;
      case GL_VERTEX_SHADER: RETVAL = "GL_VERTEX_SHADER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelCopyType")) {
    switch (e) {
      case GL_COLOR: RETVAL = "GL_COLOR"; break;
      case GL_DEPTH: RETVAL = "GL_DEPTH"; break;
      case GL_STENCIL: RETVAL = "GL_STENCIL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelDataRangeTargetNV")) {
    switch (e) {
      case GL_READ_PIXEL_DATA_RANGE_NV: RETVAL = "GL_READ_PIXEL_DATA_RANGE_NV"; break;
      case GL_WRITE_PIXEL_DATA_RANGE_NV: RETVAL = "GL_WRITE_PIXEL_DATA_RANGE_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelFormat")) {
    switch (e) {
      case GL_ABGR_EXT: RETVAL = "GL_ABGR_EXT"; break;
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_BGR: RETVAL = "GL_BGR"; break;
      case GL_BGRA: RETVAL = "GL_BGRA"; break;
      case GL_BGRA_INTEGER: RETVAL = "GL_BGRA_INTEGER"; break;
      case GL_BGR_INTEGER: RETVAL = "GL_BGR_INTEGER"; break;
      case GL_BLUE: RETVAL = "GL_BLUE"; break;
      case GL_BLUE_INTEGER: RETVAL = "GL_BLUE_INTEGER"; break;
      case GL_CMYKA_EXT: RETVAL = "GL_CMYKA_EXT"; break;
      case GL_CMYK_EXT: RETVAL = "GL_CMYK_EXT"; break;
      case GL_COLOR_INDEX: RETVAL = "GL_COLOR_INDEX"; break;
      case GL_DEPTH_COMPONENT: RETVAL = "GL_DEPTH_COMPONENT"; break;
      case GL_DEPTH_STENCIL: RETVAL = "GL_DEPTH_STENCIL"; break;
      case GL_GREEN: RETVAL = "GL_GREEN"; break;
      case GL_GREEN_INTEGER: RETVAL = "GL_GREEN_INTEGER"; break;
      case GL_LUMINANCE: RETVAL = "GL_LUMINANCE"; break;
      case GL_LUMINANCE_ALPHA: RETVAL = "GL_LUMINANCE_ALPHA"; break;
      case GL_RED: RETVAL = "GL_RED"; break;
      case GL_RED_INTEGER: RETVAL = "GL_RED_INTEGER"; break;
      case GL_RG: RETVAL = "GL_RG"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      case GL_RGBA: RETVAL = "GL_RGBA"; break;
      case GL_RGBA_INTEGER: RETVAL = "GL_RGBA_INTEGER"; break;
      case GL_RGB_INTEGER: RETVAL = "GL_RGB_INTEGER"; break;
      case GL_RG_INTEGER: RETVAL = "GL_RG_INTEGER"; break;
      case GL_STENCIL_INDEX: RETVAL = "GL_STENCIL_INDEX"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelMap")) {
    switch (e) {
      case GL_PIXEL_MAP_A_TO_A: RETVAL = "GL_PIXEL_MAP_A_TO_A"; break;
      case GL_PIXEL_MAP_B_TO_B: RETVAL = "GL_PIXEL_MAP_B_TO_B"; break;
      case GL_PIXEL_MAP_G_TO_G: RETVAL = "GL_PIXEL_MAP_G_TO_G"; break;
      case GL_PIXEL_MAP_I_TO_A: RETVAL = "GL_PIXEL_MAP_I_TO_A"; break;
      case GL_PIXEL_MAP_I_TO_B: RETVAL = "GL_PIXEL_MAP_I_TO_B"; break;
      case GL_PIXEL_MAP_I_TO_G: RETVAL = "GL_PIXEL_MAP_I_TO_G"; break;
      case GL_PIXEL_MAP_I_TO_I: RETVAL = "GL_PIXEL_MAP_I_TO_I"; break;
      case GL_PIXEL_MAP_I_TO_R: RETVAL = "GL_PIXEL_MAP_I_TO_R"; break;
      case GL_PIXEL_MAP_R_TO_R: RETVAL = "GL_PIXEL_MAP_R_TO_R"; break;
      case GL_PIXEL_MAP_S_TO_S: RETVAL = "GL_PIXEL_MAP_S_TO_S"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelStoreParameter")) {
    switch (e) {
      case GL_PACK_ALIGNMENT: RETVAL = "GL_PACK_ALIGNMENT"; break;
      case GL_PACK_IMAGE_HEIGHT: RETVAL = "GL_PACK_IMAGE_HEIGHT"; break;
      case GL_PACK_LSB_FIRST: RETVAL = "GL_PACK_LSB_FIRST"; break;
      case GL_PACK_RESAMPLE_OML: RETVAL = "GL_PACK_RESAMPLE_OML"; break;
      case GL_PACK_RESAMPLE_SGIX: RETVAL = "GL_PACK_RESAMPLE_SGIX"; break;
      case GL_PACK_ROW_LENGTH: RETVAL = "GL_PACK_ROW_LENGTH"; break;
      case GL_PACK_SKIP_IMAGES: RETVAL = "GL_PACK_SKIP_IMAGES"; break;
      case GL_PACK_SKIP_PIXELS: RETVAL = "GL_PACK_SKIP_PIXELS"; break;
      case GL_PACK_SKIP_ROWS: RETVAL = "GL_PACK_SKIP_ROWS"; break;
      case GL_PACK_SUBSAMPLE_RATE_SGIX: RETVAL = "GL_PACK_SUBSAMPLE_RATE_SGIX"; break;
      case GL_PACK_SWAP_BYTES: RETVAL = "GL_PACK_SWAP_BYTES"; break;
      case GL_UNPACK_ALIGNMENT: RETVAL = "GL_UNPACK_ALIGNMENT"; break;
      case GL_UNPACK_IMAGE_HEIGHT: RETVAL = "GL_UNPACK_IMAGE_HEIGHT"; break;
      case GL_UNPACK_LSB_FIRST: RETVAL = "GL_UNPACK_LSB_FIRST"; break;
      case GL_UNPACK_RESAMPLE_OML: RETVAL = "GL_UNPACK_RESAMPLE_OML"; break;
      case GL_UNPACK_RESAMPLE_SGIX: RETVAL = "GL_UNPACK_RESAMPLE_SGIX"; break;
      case GL_UNPACK_ROW_LENGTH: RETVAL = "GL_UNPACK_ROW_LENGTH"; break;
      case GL_UNPACK_SKIP_IMAGES: RETVAL = "GL_UNPACK_SKIP_IMAGES"; break;
      case GL_UNPACK_SKIP_PIXELS: RETVAL = "GL_UNPACK_SKIP_PIXELS"; break;
      case GL_UNPACK_SKIP_ROWS: RETVAL = "GL_UNPACK_SKIP_ROWS"; break;
      case GL_UNPACK_SUBSAMPLE_RATE_SGIX: RETVAL = "GL_UNPACK_SUBSAMPLE_RATE_SGIX"; break;
      case GL_UNPACK_SWAP_BYTES: RETVAL = "GL_UNPACK_SWAP_BYTES"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelStoreResampleMode")) {
    switch (e) {
      case GL_RESAMPLE_DECIMATE_SGIX: RETVAL = "GL_RESAMPLE_DECIMATE_SGIX"; break;
      case GL_RESAMPLE_REPLICATE_SGIX: RETVAL = "GL_RESAMPLE_REPLICATE_SGIX"; break;
      case GL_RESAMPLE_ZERO_FILL_SGIX: RETVAL = "GL_RESAMPLE_ZERO_FILL_SGIX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelStoreSubsampleRate")) {
    switch (e) {
      case GL_PIXEL_SUBSAMPLE_2424_SGIX: RETVAL = "GL_PIXEL_SUBSAMPLE_2424_SGIX"; break;
      case GL_PIXEL_SUBSAMPLE_4242_SGIX: RETVAL = "GL_PIXEL_SUBSAMPLE_4242_SGIX"; break;
      case GL_PIXEL_SUBSAMPLE_4444_SGIX: RETVAL = "GL_PIXEL_SUBSAMPLE_4444_SGIX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelTexGenModeSGIX")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RGB: RETVAL = "GL_RGB"; break;
      case GL_RGBA: RETVAL = "GL_RGBA"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelTransferParameter")) {
    switch (e) {
      case GL_ALPHA_BIAS: RETVAL = "GL_ALPHA_BIAS"; break;
      case GL_ALPHA_SCALE: RETVAL = "GL_ALPHA_SCALE"; break;
      case GL_BLUE_BIAS: RETVAL = "GL_BLUE_BIAS"; break;
      case GL_BLUE_SCALE: RETVAL = "GL_BLUE_SCALE"; break;
      case GL_DEPTH_BIAS: RETVAL = "GL_DEPTH_BIAS"; break;
      case GL_DEPTH_SCALE: RETVAL = "GL_DEPTH_SCALE"; break;
      case GL_GREEN_BIAS: RETVAL = "GL_GREEN_BIAS"; break;
      case GL_GREEN_SCALE: RETVAL = "GL_GREEN_SCALE"; break;
      case GL_INDEX_OFFSET: RETVAL = "GL_INDEX_OFFSET"; break;
      case GL_INDEX_SHIFT: RETVAL = "GL_INDEX_SHIFT"; break;
      case GL_MAP_COLOR: RETVAL = "GL_MAP_COLOR"; break;
      case GL_MAP_STENCIL: RETVAL = "GL_MAP_STENCIL"; break;
      case GL_POST_COLOR_MATRIX_ALPHA_BIAS: RETVAL = "GL_POST_COLOR_MATRIX_ALPHA_BIAS"; break;
      case GL_POST_COLOR_MATRIX_ALPHA_SCALE: RETVAL = "GL_POST_COLOR_MATRIX_ALPHA_SCALE"; break;
      case GL_POST_COLOR_MATRIX_BLUE_BIAS: RETVAL = "GL_POST_COLOR_MATRIX_BLUE_BIAS"; break;
      case GL_POST_COLOR_MATRIX_BLUE_SCALE: RETVAL = "GL_POST_COLOR_MATRIX_BLUE_SCALE"; break;
      case GL_POST_COLOR_MATRIX_GREEN_BIAS: RETVAL = "GL_POST_COLOR_MATRIX_GREEN_BIAS"; break;
      case GL_POST_COLOR_MATRIX_GREEN_SCALE: RETVAL = "GL_POST_COLOR_MATRIX_GREEN_SCALE"; break;
      case GL_POST_COLOR_MATRIX_RED_BIAS: RETVAL = "GL_POST_COLOR_MATRIX_RED_BIAS"; break;
      case GL_POST_COLOR_MATRIX_RED_SCALE: RETVAL = "GL_POST_COLOR_MATRIX_RED_SCALE"; break;
      case GL_POST_CONVOLUTION_ALPHA_BIAS: RETVAL = "GL_POST_CONVOLUTION_ALPHA_BIAS"; break;
      case GL_POST_CONVOLUTION_ALPHA_SCALE: RETVAL = "GL_POST_CONVOLUTION_ALPHA_SCALE"; break;
      case GL_POST_CONVOLUTION_BLUE_BIAS: RETVAL = "GL_POST_CONVOLUTION_BLUE_BIAS"; break;
      case GL_POST_CONVOLUTION_BLUE_SCALE: RETVAL = "GL_POST_CONVOLUTION_BLUE_SCALE"; break;
      case GL_POST_CONVOLUTION_GREEN_BIAS: RETVAL = "GL_POST_CONVOLUTION_GREEN_BIAS"; break;
      case GL_POST_CONVOLUTION_GREEN_SCALE: RETVAL = "GL_POST_CONVOLUTION_GREEN_SCALE"; break;
      case GL_POST_CONVOLUTION_RED_BIAS: RETVAL = "GL_POST_CONVOLUTION_RED_BIAS"; break;
      case GL_POST_CONVOLUTION_RED_SCALE: RETVAL = "GL_POST_CONVOLUTION_RED_SCALE"; break;
      case GL_RED_BIAS: RETVAL = "GL_RED_BIAS"; break;
      case GL_RED_SCALE: RETVAL = "GL_RED_SCALE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelTransformPNameEXT")) {
    switch (e) {
      case GL_PIXEL_CUBIC_WEIGHT_EXT: RETVAL = "GL_PIXEL_CUBIC_WEIGHT_EXT"; break;
      case GL_PIXEL_MAG_FILTER_EXT: RETVAL = "GL_PIXEL_MAG_FILTER_EXT"; break;
      case GL_PIXEL_MIN_FILTER_EXT: RETVAL = "GL_PIXEL_MIN_FILTER_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelTransformTargetEXT")) {
    switch (e) {
      case GL_PIXEL_TRANSFORM_2D_EXT: RETVAL = "GL_PIXEL_TRANSFORM_2D_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PixelType")) {
    switch (e) {
      case GL_BITMAP: RETVAL = "GL_BITMAP"; break;
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_FLOAT_32_UNSIGNED_INT_24_8_REV: RETVAL = "GL_FLOAT_32_UNSIGNED_INT_24_8_REV"; break;
      case GL_HALF_FLOAT: RETVAL = "GL_HALF_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_BYTE_2_3_3_REV: RETVAL = "GL_UNSIGNED_BYTE_2_3_3_REV"; break;
      case GL_UNSIGNED_BYTE_3_3_2: RETVAL = "GL_UNSIGNED_BYTE_3_3_2"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_INT_10F_11F_11F_REV: RETVAL = "GL_UNSIGNED_INT_10F_11F_11F_REV"; break;
      case GL_UNSIGNED_INT_10_10_10_2: RETVAL = "GL_UNSIGNED_INT_10_10_10_2"; break;
      case GL_UNSIGNED_INT_24_8: RETVAL = "GL_UNSIGNED_INT_24_8"; break;
      case GL_UNSIGNED_INT_2_10_10_10_REV: RETVAL = "GL_UNSIGNED_INT_2_10_10_10_REV"; break;
      case GL_UNSIGNED_INT_5_9_9_9_REV: RETVAL = "GL_UNSIGNED_INT_5_9_9_9_REV"; break;
      case GL_UNSIGNED_INT_8_8_8_8: RETVAL = "GL_UNSIGNED_INT_8_8_8_8"; break;
      case GL_UNSIGNED_INT_8_8_8_8_REV: RETVAL = "GL_UNSIGNED_INT_8_8_8_8_REV"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      case GL_UNSIGNED_SHORT_1_5_5_5_REV: RETVAL = "GL_UNSIGNED_SHORT_1_5_5_5_REV"; break;
      case GL_UNSIGNED_SHORT_4_4_4_4: RETVAL = "GL_UNSIGNED_SHORT_4_4_4_4"; break;
      case GL_UNSIGNED_SHORT_4_4_4_4_REV: RETVAL = "GL_UNSIGNED_SHORT_4_4_4_4_REV"; break;
      case GL_UNSIGNED_SHORT_5_5_5_1: RETVAL = "GL_UNSIGNED_SHORT_5_5_5_1"; break;
      case GL_UNSIGNED_SHORT_5_6_5: RETVAL = "GL_UNSIGNED_SHORT_5_6_5"; break;
      case GL_UNSIGNED_SHORT_5_6_5_REV: RETVAL = "GL_UNSIGNED_SHORT_5_6_5_REV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PointParameterNameARB")) {
    switch (e) {
      case GL_DISTANCE_ATTENUATION_EXT: RETVAL = "GL_DISTANCE_ATTENUATION_EXT"; break;
      case GL_POINT_FADE_THRESHOLD_SIZE: RETVAL = "GL_POINT_FADE_THRESHOLD_SIZE"; break;
      case GL_POINT_SIZE_MAX: RETVAL = "GL_POINT_SIZE_MAX"; break;
      case GL_POINT_SIZE_MIN: RETVAL = "GL_POINT_SIZE_MIN"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PolygonMode")) {
    switch (e) {
      case GL_FILL: RETVAL = "GL_FILL"; break;
      case GL_LINE: RETVAL = "GL_LINE"; break;
      case GL_POINT: RETVAL = "GL_POINT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PrecisionType")) {
    switch (e) {
      case GL_HIGH_FLOAT: RETVAL = "GL_HIGH_FLOAT"; break;
      case GL_HIGH_INT: RETVAL = "GL_HIGH_INT"; break;
      case GL_LOW_FLOAT: RETVAL = "GL_LOW_FLOAT"; break;
      case GL_LOW_INT: RETVAL = "GL_LOW_INT"; break;
      case GL_MEDIUM_FLOAT: RETVAL = "GL_MEDIUM_FLOAT"; break;
      case GL_MEDIUM_INT: RETVAL = "GL_MEDIUM_INT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PreserveModeATI")) {
    switch (e) {
      case GL_DISCARD_ATI: RETVAL = "GL_DISCARD_ATI"; break;
      case GL_PRESERVE_ATI: RETVAL = "GL_PRESERVE_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "PrimitiveType")) {
    switch (e) {
      case GL_LINES: RETVAL = "GL_LINES"; break;
      case GL_LINES_ADJACENCY: RETVAL = "GL_LINES_ADJACENCY"; break;
      case GL_LINE_LOOP: RETVAL = "GL_LINE_LOOP"; break;
      case GL_LINE_STRIP: RETVAL = "GL_LINE_STRIP"; break;
      case GL_LINE_STRIP_ADJACENCY: RETVAL = "GL_LINE_STRIP_ADJACENCY"; break;
      case GL_PATCHES: RETVAL = "GL_PATCHES"; break;
      case GL_POINTS: RETVAL = "GL_POINTS"; break;
      case GL_POLYGON: RETVAL = "GL_POLYGON"; break;
      case GL_QUADS: RETVAL = "GL_QUADS"; break;
      case GL_QUAD_STRIP: RETVAL = "GL_QUAD_STRIP"; break;
      case GL_TRIANGLES: RETVAL = "GL_TRIANGLES"; break;
      case GL_TRIANGLES_ADJACENCY: RETVAL = "GL_TRIANGLES_ADJACENCY"; break;
      case GL_TRIANGLE_FAN: RETVAL = "GL_TRIANGLE_FAN"; break;
      case GL_TRIANGLE_STRIP: RETVAL = "GL_TRIANGLE_STRIP"; break;
      case GL_TRIANGLE_STRIP_ADJACENCY: RETVAL = "GL_TRIANGLE_STRIP_ADJACENCY"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramFormat")) {
    switch (e) {
      case GL_PROGRAM_FORMAT_ASCII_ARB: RETVAL = "GL_PROGRAM_FORMAT_ASCII_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramInterface")) {
    switch (e) {
      case GL_BUFFER_VARIABLE: RETVAL = "GL_BUFFER_VARIABLE"; break;
      case GL_COMPUTE_SUBROUTINE: RETVAL = "GL_COMPUTE_SUBROUTINE"; break;
      case GL_COMPUTE_SUBROUTINE_UNIFORM: RETVAL = "GL_COMPUTE_SUBROUTINE_UNIFORM"; break;
      case GL_FRAGMENT_SUBROUTINE: RETVAL = "GL_FRAGMENT_SUBROUTINE"; break;
      case GL_FRAGMENT_SUBROUTINE_UNIFORM: RETVAL = "GL_FRAGMENT_SUBROUTINE_UNIFORM"; break;
      case GL_GEOMETRY_SUBROUTINE: RETVAL = "GL_GEOMETRY_SUBROUTINE"; break;
      case GL_GEOMETRY_SUBROUTINE_UNIFORM: RETVAL = "GL_GEOMETRY_SUBROUTINE_UNIFORM"; break;
      case GL_PROGRAM_INPUT: RETVAL = "GL_PROGRAM_INPUT"; break;
      case GL_PROGRAM_OUTPUT: RETVAL = "GL_PROGRAM_OUTPUT"; break;
      case GL_SHADER_STORAGE_BLOCK: RETVAL = "GL_SHADER_STORAGE_BLOCK"; break;
      case GL_TESS_CONTROL_SUBROUTINE: RETVAL = "GL_TESS_CONTROL_SUBROUTINE"; break;
      case GL_TESS_CONTROL_SUBROUTINE_UNIFORM: RETVAL = "GL_TESS_CONTROL_SUBROUTINE_UNIFORM"; break;
      case GL_TESS_EVALUATION_SUBROUTINE: RETVAL = "GL_TESS_EVALUATION_SUBROUTINE"; break;
      case GL_TESS_EVALUATION_SUBROUTINE_UNIFORM: RETVAL = "GL_TESS_EVALUATION_SUBROUTINE_UNIFORM"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER"; break;
      case GL_TRANSFORM_FEEDBACK_VARYING: RETVAL = "GL_TRANSFORM_FEEDBACK_VARYING"; break;
      case GL_UNIFORM: RETVAL = "GL_UNIFORM"; break;
      case GL_UNIFORM_BLOCK: RETVAL = "GL_UNIFORM_BLOCK"; break;
      case GL_VERTEX_SUBROUTINE: RETVAL = "GL_VERTEX_SUBROUTINE"; break;
      case GL_VERTEX_SUBROUTINE_UNIFORM: RETVAL = "GL_VERTEX_SUBROUTINE_UNIFORM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramInterfacePName")) {
    switch (e) {
      case GL_ACTIVE_RESOURCES: RETVAL = "GL_ACTIVE_RESOURCES"; break;
      case GL_MAX_NAME_LENGTH: RETVAL = "GL_MAX_NAME_LENGTH"; break;
      case GL_MAX_NUM_ACTIVE_VARIABLES: RETVAL = "GL_MAX_NUM_ACTIVE_VARIABLES"; break;
      case GL_MAX_NUM_COMPATIBLE_SUBROUTINES: RETVAL = "GL_MAX_NUM_COMPATIBLE_SUBROUTINES"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramParameterPName")) {
    switch (e) {
      case GL_PROGRAM_BINARY_RETRIEVABLE_HINT: RETVAL = "GL_PROGRAM_BINARY_RETRIEVABLE_HINT"; break;
      case GL_PROGRAM_SEPARABLE: RETVAL = "GL_PROGRAM_SEPARABLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramPropertyARB")) {
    switch (e) {
      case GL_ACTIVE_ATOMIC_COUNTER_BUFFERS: RETVAL = "GL_ACTIVE_ATOMIC_COUNTER_BUFFERS"; break;
      case GL_ACTIVE_ATTRIBUTES: RETVAL = "GL_ACTIVE_ATTRIBUTES"; break;
      case GL_ACTIVE_ATTRIBUTE_MAX_LENGTH: RETVAL = "GL_ACTIVE_ATTRIBUTE_MAX_LENGTH"; break;
      case GL_ACTIVE_UNIFORMS: RETVAL = "GL_ACTIVE_UNIFORMS"; break;
      case GL_ACTIVE_UNIFORM_BLOCKS: RETVAL = "GL_ACTIVE_UNIFORM_BLOCKS"; break;
      case GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH: RETVAL = "GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH"; break;
      case GL_ACTIVE_UNIFORM_MAX_LENGTH: RETVAL = "GL_ACTIVE_UNIFORM_MAX_LENGTH"; break;
      case GL_ATTACHED_SHADERS: RETVAL = "GL_ATTACHED_SHADERS"; break;
      case GL_COMPUTE_WORK_GROUP_SIZE: RETVAL = "GL_COMPUTE_WORK_GROUP_SIZE"; break;
      case GL_DELETE_STATUS: RETVAL = "GL_DELETE_STATUS"; break;
      case GL_GEOMETRY_INPUT_TYPE: RETVAL = "GL_GEOMETRY_INPUT_TYPE"; break;
      case GL_GEOMETRY_OUTPUT_TYPE: RETVAL = "GL_GEOMETRY_OUTPUT_TYPE"; break;
      case GL_GEOMETRY_VERTICES_OUT: RETVAL = "GL_GEOMETRY_VERTICES_OUT"; break;
      case GL_INFO_LOG_LENGTH: RETVAL = "GL_INFO_LOG_LENGTH"; break;
      case GL_LINK_STATUS: RETVAL = "GL_LINK_STATUS"; break;
      case GL_PROGRAM_BINARY_LENGTH: RETVAL = "GL_PROGRAM_BINARY_LENGTH"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_MODE: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_MODE"; break;
      case GL_TRANSFORM_FEEDBACK_VARYINGS: RETVAL = "GL_TRANSFORM_FEEDBACK_VARYINGS"; break;
      case GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH: RETVAL = "GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH"; break;
      case GL_VALIDATE_STATUS: RETVAL = "GL_VALIDATE_STATUS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramResourceProperty")) {
    switch (e) {
      case GL_ACTIVE_VARIABLES: RETVAL = "GL_ACTIVE_VARIABLES"; break;
      case GL_ARRAY_SIZE: RETVAL = "GL_ARRAY_SIZE"; break;
      case GL_ARRAY_STRIDE: RETVAL = "GL_ARRAY_STRIDE"; break;
      case GL_ATOMIC_COUNTER_BUFFER_INDEX: RETVAL = "GL_ATOMIC_COUNTER_BUFFER_INDEX"; break;
      case GL_BLOCK_INDEX: RETVAL = "GL_BLOCK_INDEX"; break;
      case GL_BUFFER_BINDING: RETVAL = "GL_BUFFER_BINDING"; break;
      case GL_BUFFER_DATA_SIZE: RETVAL = "GL_BUFFER_DATA_SIZE"; break;
      case GL_COMPATIBLE_SUBROUTINES: RETVAL = "GL_COMPATIBLE_SUBROUTINES"; break;
      case GL_IS_PER_PATCH: RETVAL = "GL_IS_PER_PATCH"; break;
      case GL_IS_ROW_MAJOR: RETVAL = "GL_IS_ROW_MAJOR"; break;
      case GL_LOCATION: RETVAL = "GL_LOCATION"; break;
      case GL_LOCATION_COMPONENT: RETVAL = "GL_LOCATION_COMPONENT"; break;
      case GL_LOCATION_INDEX: RETVAL = "GL_LOCATION_INDEX"; break;
      case GL_MATRIX_STRIDE: RETVAL = "GL_MATRIX_STRIDE"; break;
      case GL_NAME_LENGTH: RETVAL = "GL_NAME_LENGTH"; break;
      case GL_NUM_ACTIVE_VARIABLES: RETVAL = "GL_NUM_ACTIVE_VARIABLES"; break;
      case GL_NUM_COMPATIBLE_SUBROUTINES: RETVAL = "GL_NUM_COMPATIBLE_SUBROUTINES"; break;
      case GL_OFFSET: RETVAL = "GL_OFFSET"; break;
      case GL_REFERENCED_BY_COMPUTE_SHADER: RETVAL = "GL_REFERENCED_BY_COMPUTE_SHADER"; break;
      case GL_REFERENCED_BY_FRAGMENT_SHADER: RETVAL = "GL_REFERENCED_BY_FRAGMENT_SHADER"; break;
      case GL_REFERENCED_BY_GEOMETRY_SHADER: RETVAL = "GL_REFERENCED_BY_GEOMETRY_SHADER"; break;
      case GL_REFERENCED_BY_TESS_CONTROL_SHADER: RETVAL = "GL_REFERENCED_BY_TESS_CONTROL_SHADER"; break;
      case GL_REFERENCED_BY_TESS_EVALUATION_SHADER: RETVAL = "GL_REFERENCED_BY_TESS_EVALUATION_SHADER"; break;
      case GL_REFERENCED_BY_VERTEX_SHADER: RETVAL = "GL_REFERENCED_BY_VERTEX_SHADER"; break;
      case GL_TOP_LEVEL_ARRAY_SIZE: RETVAL = "GL_TOP_LEVEL_ARRAY_SIZE"; break;
      case GL_TOP_LEVEL_ARRAY_STRIDE: RETVAL = "GL_TOP_LEVEL_ARRAY_STRIDE"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_INDEX: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_INDEX"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE"; break;
      case GL_TYPE: RETVAL = "GL_TYPE"; break;
      case GL_UNIFORM: RETVAL = "GL_UNIFORM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramStagePName")) {
    switch (e) {
      case GL_ACTIVE_SUBROUTINES: RETVAL = "GL_ACTIVE_SUBROUTINES"; break;
      case GL_ACTIVE_SUBROUTINE_MAX_LENGTH: RETVAL = "GL_ACTIVE_SUBROUTINE_MAX_LENGTH"; break;
      case GL_ACTIVE_SUBROUTINE_UNIFORMS: RETVAL = "GL_ACTIVE_SUBROUTINE_UNIFORMS"; break;
      case GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS: RETVAL = "GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS"; break;
      case GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH: RETVAL = "GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramStringProperty")) {
    switch (e) {
      case GL_PROGRAM_STRING_ARB: RETVAL = "GL_PROGRAM_STRING_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ProgramTarget")) {
    switch (e) {
      case GL_COMPUTE_PROGRAM_NV: RETVAL = "GL_COMPUTE_PROGRAM_NV"; break;
      case GL_FRAGMENT_PROGRAM_ARB: RETVAL = "GL_FRAGMENT_PROGRAM_ARB"; break;
      case GL_GEOMETRY_PROGRAM_NV: RETVAL = "GL_GEOMETRY_PROGRAM_NV"; break;
      case GL_TESS_CONTROL_PROGRAM_NV: RETVAL = "GL_TESS_CONTROL_PROGRAM_NV"; break;
      case GL_TESS_EVALUATION_PROGRAM_NV: RETVAL = "GL_TESS_EVALUATION_PROGRAM_NV"; break;
      case GL_TEXT_FRAGMENT_SHADER_ATI: RETVAL = "GL_TEXT_FRAGMENT_SHADER_ATI"; break;
      case GL_VERTEX_PROGRAM_ARB: RETVAL = "GL_VERTEX_PROGRAM_ARB"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "QueryCounterTarget")) {
    switch (e) {
      case GL_TIMESTAMP: RETVAL = "GL_TIMESTAMP"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "QueryObjectParameterName")) {
    switch (e) {
      case GL_QUERY_RESULT: RETVAL = "GL_QUERY_RESULT"; break;
      case GL_QUERY_RESULT_AVAILABLE: RETVAL = "GL_QUERY_RESULT_AVAILABLE"; break;
      case GL_QUERY_RESULT_NO_WAIT: RETVAL = "GL_QUERY_RESULT_NO_WAIT"; break;
      case GL_QUERY_TARGET: RETVAL = "GL_QUERY_TARGET"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "QueryParameterName")) {
    switch (e) {
      case GL_CURRENT_QUERY: RETVAL = "GL_CURRENT_QUERY"; break;
      case GL_QUERY_COUNTER_BITS: RETVAL = "GL_QUERY_COUNTER_BITS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "QueryTarget")) {
    switch (e) {
      case GL_ANY_SAMPLES_PASSED: RETVAL = "GL_ANY_SAMPLES_PASSED"; break;
      case GL_ANY_SAMPLES_PASSED_CONSERVATIVE: RETVAL = "GL_ANY_SAMPLES_PASSED_CONSERVATIVE"; break;
      case GL_MESH_PRIMITIVES_GENERATED_EXT: RETVAL = "GL_MESH_PRIMITIVES_GENERATED_EXT"; break;
      case GL_MESH_SHADER_INVOCATIONS_EXT: RETVAL = "GL_MESH_SHADER_INVOCATIONS_EXT"; break;
      case GL_PRIMITIVES_GENERATED: RETVAL = "GL_PRIMITIVES_GENERATED"; break;
      case GL_PRIMITIVES_SUBMITTED: RETVAL = "GL_PRIMITIVES_SUBMITTED"; break;
      case GL_SAMPLES_PASSED: RETVAL = "GL_SAMPLES_PASSED"; break;
      case GL_TASK_SHADER_INVOCATIONS_EXT: RETVAL = "GL_TASK_SHADER_INVOCATIONS_EXT"; break;
      case GL_TIME_ELAPSED: RETVAL = "GL_TIME_ELAPSED"; break;
      case GL_TRANSFORM_FEEDBACK_OVERFLOW: RETVAL = "GL_TRANSFORM_FEEDBACK_OVERFLOW"; break;
      case GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN: RETVAL = "GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN"; break;
      case GL_VERTEX_SHADER_INVOCATIONS: RETVAL = "GL_VERTEX_SHADER_INVOCATIONS"; break;
      case GL_VERTICES_SUBMITTED: RETVAL = "GL_VERTICES_SUBMITTED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ReadBufferMode")) {
    switch (e) {
      case GL_AUX0: RETVAL = "GL_AUX0"; break;
      case GL_AUX1: RETVAL = "GL_AUX1"; break;
      case GL_AUX2: RETVAL = "GL_AUX2"; break;
      case GL_AUX3: RETVAL = "GL_AUX3"; break;
      case GL_BACK: RETVAL = "GL_BACK"; break;
      case GL_BACK_LEFT: RETVAL = "GL_BACK_LEFT"; break;
      case GL_BACK_RIGHT: RETVAL = "GL_BACK_RIGHT"; break;
      case GL_COLOR_ATTACHMENT0: RETVAL = "GL_COLOR_ATTACHMENT0"; break;
      case GL_COLOR_ATTACHMENT1: RETVAL = "GL_COLOR_ATTACHMENT1"; break;
      case GL_COLOR_ATTACHMENT10: RETVAL = "GL_COLOR_ATTACHMENT10"; break;
      case GL_COLOR_ATTACHMENT11: RETVAL = "GL_COLOR_ATTACHMENT11"; break;
      case GL_COLOR_ATTACHMENT12: RETVAL = "GL_COLOR_ATTACHMENT12"; break;
      case GL_COLOR_ATTACHMENT13: RETVAL = "GL_COLOR_ATTACHMENT13"; break;
      case GL_COLOR_ATTACHMENT14: RETVAL = "GL_COLOR_ATTACHMENT14"; break;
      case GL_COLOR_ATTACHMENT15: RETVAL = "GL_COLOR_ATTACHMENT15"; break;
      case GL_COLOR_ATTACHMENT2: RETVAL = "GL_COLOR_ATTACHMENT2"; break;
      case GL_COLOR_ATTACHMENT3: RETVAL = "GL_COLOR_ATTACHMENT3"; break;
      case GL_COLOR_ATTACHMENT4: RETVAL = "GL_COLOR_ATTACHMENT4"; break;
      case GL_COLOR_ATTACHMENT5: RETVAL = "GL_COLOR_ATTACHMENT5"; break;
      case GL_COLOR_ATTACHMENT6: RETVAL = "GL_COLOR_ATTACHMENT6"; break;
      case GL_COLOR_ATTACHMENT7: RETVAL = "GL_COLOR_ATTACHMENT7"; break;
      case GL_COLOR_ATTACHMENT8: RETVAL = "GL_COLOR_ATTACHMENT8"; break;
      case GL_COLOR_ATTACHMENT9: RETVAL = "GL_COLOR_ATTACHMENT9"; break;
      case GL_FRONT: RETVAL = "GL_FRONT"; break;
      case GL_FRONT_LEFT: RETVAL = "GL_FRONT_LEFT"; break;
      case GL_FRONT_RIGHT: RETVAL = "GL_FRONT_RIGHT"; break;
      case GL_LEFT: RETVAL = "GL_LEFT"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      case GL_RIGHT: RETVAL = "GL_RIGHT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "RenderbufferParameterName")) {
    switch (e) {
      case GL_RENDERBUFFER_ALPHA_SIZE: RETVAL = "GL_RENDERBUFFER_ALPHA_SIZE"; break;
      case GL_RENDERBUFFER_BLUE_SIZE: RETVAL = "GL_RENDERBUFFER_BLUE_SIZE"; break;
      case GL_RENDERBUFFER_COLOR_SAMPLES_NV: RETVAL = "GL_RENDERBUFFER_COLOR_SAMPLES_NV"; break;
      case GL_RENDERBUFFER_DEPTH_SIZE: RETVAL = "GL_RENDERBUFFER_DEPTH_SIZE"; break;
      case GL_RENDERBUFFER_GREEN_SIZE: RETVAL = "GL_RENDERBUFFER_GREEN_SIZE"; break;
      case GL_RENDERBUFFER_HEIGHT: RETVAL = "GL_RENDERBUFFER_HEIGHT"; break;
      case GL_RENDERBUFFER_INTERNAL_FORMAT: RETVAL = "GL_RENDERBUFFER_INTERNAL_FORMAT"; break;
      case GL_RENDERBUFFER_RED_SIZE: RETVAL = "GL_RENDERBUFFER_RED_SIZE"; break;
      case GL_RENDERBUFFER_SAMPLES: RETVAL = "GL_RENDERBUFFER_SAMPLES"; break;
      case GL_RENDERBUFFER_SAMPLES_IMG: RETVAL = "GL_RENDERBUFFER_SAMPLES_IMG"; break;
      case GL_RENDERBUFFER_STENCIL_SIZE: RETVAL = "GL_RENDERBUFFER_STENCIL_SIZE"; break;
      case GL_RENDERBUFFER_STORAGE_SAMPLES_AMD: RETVAL = "GL_RENDERBUFFER_STORAGE_SAMPLES_AMD"; break;
      case GL_RENDERBUFFER_WIDTH: RETVAL = "GL_RENDERBUFFER_WIDTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "RenderbufferTarget")) {
    switch (e) {
      case GL_RENDERBUFFER: RETVAL = "GL_RENDERBUFFER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "RenderingMode")) {
    switch (e) {
      case GL_FEEDBACK: RETVAL = "GL_FEEDBACK"; break;
      case GL_RENDER: RETVAL = "GL_RENDER"; break;
      case GL_SELECT: RETVAL = "GL_SELECT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ReplacementCodeTypeSUN")) {
    switch (e) {
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SamplePatternEXT")) {
    switch (e) {
      case GL_1PASS_EXT: RETVAL = "GL_1PASS_EXT"; break;
      case GL_2PASS_0_EXT: RETVAL = "GL_2PASS_0_EXT"; break;
      case GL_2PASS_1_EXT: RETVAL = "GL_2PASS_1_EXT"; break;
      case GL_4PASS_0_EXT: RETVAL = "GL_4PASS_0_EXT"; break;
      case GL_4PASS_1_EXT: RETVAL = "GL_4PASS_1_EXT"; break;
      case GL_4PASS_2_EXT: RETVAL = "GL_4PASS_2_EXT"; break;
      case GL_4PASS_3_EXT: RETVAL = "GL_4PASS_3_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SamplePatternSGIS")) {
    switch (e) {
      case GL_1PASS_EXT: RETVAL = "GL_1PASS_EXT"; break;
      case GL_2PASS_0_EXT: RETVAL = "GL_2PASS_0_EXT"; break;
      case GL_2PASS_1_EXT: RETVAL = "GL_2PASS_1_EXT"; break;
      case GL_4PASS_0_EXT: RETVAL = "GL_4PASS_0_EXT"; break;
      case GL_4PASS_1_EXT: RETVAL = "GL_4PASS_1_EXT"; break;
      case GL_4PASS_2_EXT: RETVAL = "GL_4PASS_2_EXT"; break;
      case GL_4PASS_3_EXT: RETVAL = "GL_4PASS_3_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SamplerParameterF")) {
    switch (e) {
      case GL_TEXTURE_BORDER_COLOR: RETVAL = "GL_TEXTURE_BORDER_COLOR"; break;
      case GL_TEXTURE_LOD_BIAS: RETVAL = "GL_TEXTURE_LOD_BIAS"; break;
      case GL_TEXTURE_MAX_ANISOTROPY: RETVAL = "GL_TEXTURE_MAX_ANISOTROPY"; break;
      case GL_TEXTURE_MAX_LOD: RETVAL = "GL_TEXTURE_MAX_LOD"; break;
      case GL_TEXTURE_MIN_LOD: RETVAL = "GL_TEXTURE_MIN_LOD"; break;
      case GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM: RETVAL = "GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SamplerParameterI")) {
    switch (e) {
      case GL_TEXTURE_COMPARE_FUNC: RETVAL = "GL_TEXTURE_COMPARE_FUNC"; break;
      case GL_TEXTURE_COMPARE_MODE: RETVAL = "GL_TEXTURE_COMPARE_MODE"; break;
      case GL_TEXTURE_MAG_FILTER: RETVAL = "GL_TEXTURE_MAG_FILTER"; break;
      case GL_TEXTURE_MIN_FILTER: RETVAL = "GL_TEXTURE_MIN_FILTER"; break;
      case GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM: RETVAL = "GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM"; break;
      case GL_TEXTURE_WRAP_R: RETVAL = "GL_TEXTURE_WRAP_R"; break;
      case GL_TEXTURE_WRAP_S: RETVAL = "GL_TEXTURE_WRAP_S"; break;
      case GL_TEXTURE_WRAP_T: RETVAL = "GL_TEXTURE_WRAP_T"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ScalarType")) {
    switch (e) {
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SecondaryColorPointerTypeIBM")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SemaphoreParameterName")) {
    switch (e) {
      case GL_D3D12_FENCE_VALUE_EXT: RETVAL = "GL_D3D12_FENCE_VALUE_EXT"; break;
      case GL_SEMAPHORE_TYPE_BINARY_NV: RETVAL = "GL_SEMAPHORE_TYPE_BINARY_NV"; break;
      case GL_SEMAPHORE_TYPE_NV: RETVAL = "GL_SEMAPHORE_TYPE_NV"; break;
      case GL_SEMAPHORE_TYPE_TIMELINE_NV: RETVAL = "GL_SEMAPHORE_TYPE_TIMELINE_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SeparableTarget")) {
    switch (e) {
      case GL_SEPARABLE_2D: RETVAL = "GL_SEPARABLE_2D"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SeparableTargetEXT")) {
    switch (e) {
      case GL_SEPARABLE_2D: RETVAL = "GL_SEPARABLE_2D"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShaderBinaryFormat")) {
    switch (e) {
      case GL_GCCSO_SHADER_BINARY_FJ: RETVAL = "GL_GCCSO_SHADER_BINARY_FJ"; break;
      case GL_MALI_SHADER_BINARY_ARM: RETVAL = "GL_MALI_SHADER_BINARY_ARM"; break;
      case GL_SGX_BINARY_IMG: RETVAL = "GL_SGX_BINARY_IMG"; break;
      case GL_SHADER_BINARY_DMP: RETVAL = "GL_SHADER_BINARY_DMP"; break;
      case GL_SHADER_BINARY_FORMAT_SPIR_V: RETVAL = "GL_SHADER_BINARY_FORMAT_SPIR_V"; break;
      case GL_SHADER_BINARY_VIV: RETVAL = "GL_SHADER_BINARY_VIV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShaderParameterName")) {
    switch (e) {
      case GL_COMPILE_STATUS: RETVAL = "GL_COMPILE_STATUS"; break;
      case GL_DELETE_STATUS: RETVAL = "GL_DELETE_STATUS"; break;
      case GL_INFO_LOG_LENGTH: RETVAL = "GL_INFO_LOG_LENGTH"; break;
      case GL_SHADER_SOURCE_LENGTH: RETVAL = "GL_SHADER_SOURCE_LENGTH"; break;
      case GL_SHADER_TYPE: RETVAL = "GL_SHADER_TYPE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShaderType")) {
    switch (e) {
      case GL_COMPUTE_SHADER: RETVAL = "GL_COMPUTE_SHADER"; break;
      case GL_FRAGMENT_SHADER: RETVAL = "GL_FRAGMENT_SHADER"; break;
      case GL_GEOMETRY_SHADER: RETVAL = "GL_GEOMETRY_SHADER"; break;
      case GL_TESS_CONTROL_SHADER: RETVAL = "GL_TESS_CONTROL_SHADER"; break;
      case GL_TESS_EVALUATION_SHADER: RETVAL = "GL_TESS_EVALUATION_SHADER"; break;
      case GL_VERTEX_SHADER: RETVAL = "GL_VERTEX_SHADER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShadingModel")) {
    switch (e) {
      case GL_FLAT: RETVAL = "GL_FLAT"; break;
      case GL_SMOOTH: RETVAL = "GL_SMOOTH"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShadingRate")) {
    switch (e) {
      case GL_SHADING_RATE_1X1_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_1X1_PIXELS_EXT"; break;
      case GL_SHADING_RATE_1X2_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_1X2_PIXELS_EXT"; break;
      case GL_SHADING_RATE_1X4_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_1X4_PIXELS_EXT"; break;
      case GL_SHADING_RATE_2X1_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_2X1_PIXELS_EXT"; break;
      case GL_SHADING_RATE_2X2_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_2X2_PIXELS_EXT"; break;
      case GL_SHADING_RATE_2X4_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_2X4_PIXELS_EXT"; break;
      case GL_SHADING_RATE_4X1_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_4X1_PIXELS_EXT"; break;
      case GL_SHADING_RATE_4X2_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_4X2_PIXELS_EXT"; break;
      case GL_SHADING_RATE_4X4_PIXELS_EXT: RETVAL = "GL_SHADING_RATE_4X4_PIXELS_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShadingRateCombinerOp")) {
    switch (e) {
      case GL_FRAGMENT_SHADING_RATE_COMBINER_OP_KEEP_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_COMBINER_OP_KEEP_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MAX_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MAX_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MIN_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MIN_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MUL_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_COMBINER_OP_MUL_EXT"; break;
      case GL_FRAGMENT_SHADING_RATE_COMBINER_OP_REPLACE_EXT: RETVAL = "GL_FRAGMENT_SHADING_RATE_COMBINER_OP_REPLACE_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "ShadingRateQCOM")) {
    switch (e) {
      case GL_SHADING_RATE_1X1_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_1X1_PIXELS_QCOM"; break;
      case GL_SHADING_RATE_1X2_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_1X2_PIXELS_QCOM"; break;
      case GL_SHADING_RATE_2X1_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_2X1_PIXELS_QCOM"; break;
      case GL_SHADING_RATE_2X2_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_2X2_PIXELS_QCOM"; break;
      case GL_SHADING_RATE_4X2_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_4X2_PIXELS_QCOM"; break;
      case GL_SHADING_RATE_4X4_PIXELS_QCOM: RETVAL = "GL_SHADING_RATE_4X4_PIXELS_QCOM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SizedInternalFormat")) {
    switch (e) {
      case GL_ALPHA12: RETVAL = "GL_ALPHA12"; break;
      case GL_ALPHA16: RETVAL = "GL_ALPHA16"; break;
      case GL_ALPHA16I_EXT: RETVAL = "GL_ALPHA16I_EXT"; break;
      case GL_ALPHA16UI_EXT: RETVAL = "GL_ALPHA16UI_EXT"; break;
      case GL_ALPHA32I_EXT: RETVAL = "GL_ALPHA32I_EXT"; break;
      case GL_ALPHA32UI_EXT: RETVAL = "GL_ALPHA32UI_EXT"; break;
      case GL_ALPHA4: RETVAL = "GL_ALPHA4"; break;
      case GL_ALPHA8: RETVAL = "GL_ALPHA8"; break;
      case GL_ALPHA8I_EXT: RETVAL = "GL_ALPHA8I_EXT"; break;
      case GL_ALPHA8UI_EXT: RETVAL = "GL_ALPHA8UI_EXT"; break;
      case GL_COMPRESSED_R11_EAC: RETVAL = "GL_COMPRESSED_R11_EAC"; break;
      case GL_COMPRESSED_RED_RGTC1: RETVAL = "GL_COMPRESSED_RED_RGTC1"; break;
      case GL_COMPRESSED_RG11_EAC: RETVAL = "GL_COMPRESSED_RG11_EAC"; break;
      case GL_COMPRESSED_RGB8_ETC2: RETVAL = "GL_COMPRESSED_RGB8_ETC2"; break;
      case GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2: RETVAL = "GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2"; break;
      case GL_COMPRESSED_RGBA8_ETC2_EAC: RETVAL = "GL_COMPRESSED_RGBA8_ETC2_EAC"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x10_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x10_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_10x8_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_10x8_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_12x10_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_12x10_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_12x12_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_12x12_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_4x4_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_4x4_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_5x4_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_5x4_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_5x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_5x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_6x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_6x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_6x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_6x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x5_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x5_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x6_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x6_KHR"; break;
      case GL_COMPRESSED_RGBA_ASTC_8x8_KHR: RETVAL = "GL_COMPRESSED_RGBA_ASTC_8x8_KHR"; break;
      case GL_COMPRESSED_RGBA_BPTC_UNORM: RETVAL = "GL_COMPRESSED_RGBA_BPTC_UNORM"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT1_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT1_EXT"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT3_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT3_EXT"; break;
      case GL_COMPRESSED_RGBA_S3TC_DXT5_EXT: RETVAL = "GL_COMPRESSED_RGBA_S3TC_DXT5_EXT"; break;
      case GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT: RETVAL = "GL_COMPRESSED_RGB_BPTC_SIGNED_FLOAT"; break;
      case GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT: RETVAL = "GL_COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT"; break;
      case GL_COMPRESSED_RGB_S3TC_DXT1_EXT: RETVAL = "GL_COMPRESSED_RGB_S3TC_DXT1_EXT"; break;
      case GL_COMPRESSED_RG_RGTC2: RETVAL = "GL_COMPRESSED_RG_RGTC2"; break;
      case GL_COMPRESSED_SIGNED_R11_EAC: RETVAL = "GL_COMPRESSED_SIGNED_R11_EAC"; break;
      case GL_COMPRESSED_SIGNED_RED_RGTC1: RETVAL = "GL_COMPRESSED_SIGNED_RED_RGTC1"; break;
      case GL_COMPRESSED_SIGNED_RG11_EAC: RETVAL = "GL_COMPRESSED_SIGNED_RG11_EAC"; break;
      case GL_COMPRESSED_SIGNED_RG_RGTC2: RETVAL = "GL_COMPRESSED_SIGNED_RG_RGTC2"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_10x8_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR"; break;
      case GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC: RETVAL = "GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC"; break;
      case GL_COMPRESSED_SRGB8_ETC2: RETVAL = "GL_COMPRESSED_SRGB8_ETC2"; break;
      case GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2: RETVAL = "GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2"; break;
      case GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_BPTC_UNORM"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV"; break;
      case GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV: RETVAL = "GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV"; break;
      case GL_COMPRESSED_SRGB_S3TC_DXT1_NV: RETVAL = "GL_COMPRESSED_SRGB_S3TC_DXT1_NV"; break;
      case GL_DEPTH24_STENCIL8: RETVAL = "GL_DEPTH24_STENCIL8"; break;
      case GL_DEPTH32F_STENCIL8: RETVAL = "GL_DEPTH32F_STENCIL8"; break;
      case GL_DEPTH32F_STENCIL8_NV: RETVAL = "GL_DEPTH32F_STENCIL8_NV"; break;
      case GL_DEPTH_COMPONENT16: RETVAL = "GL_DEPTH_COMPONENT16"; break;
      case GL_DEPTH_COMPONENT24: RETVAL = "GL_DEPTH_COMPONENT24"; break;
      case GL_DEPTH_COMPONENT32: RETVAL = "GL_DEPTH_COMPONENT32"; break;
      case GL_DEPTH_COMPONENT32F: RETVAL = "GL_DEPTH_COMPONENT32F"; break;
      case GL_DEPTH_COMPONENT32F_NV: RETVAL = "GL_DEPTH_COMPONENT32F_NV"; break;
      case GL_INTENSITY12: RETVAL = "GL_INTENSITY12"; break;
      case GL_INTENSITY16: RETVAL = "GL_INTENSITY16"; break;
      case GL_INTENSITY16I_EXT: RETVAL = "GL_INTENSITY16I_EXT"; break;
      case GL_INTENSITY16UI_EXT: RETVAL = "GL_INTENSITY16UI_EXT"; break;
      case GL_INTENSITY32I_EXT: RETVAL = "GL_INTENSITY32I_EXT"; break;
      case GL_INTENSITY32UI_EXT: RETVAL = "GL_INTENSITY32UI_EXT"; break;
      case GL_INTENSITY4: RETVAL = "GL_INTENSITY4"; break;
      case GL_INTENSITY8: RETVAL = "GL_INTENSITY8"; break;
      case GL_INTENSITY8I_EXT: RETVAL = "GL_INTENSITY8I_EXT"; break;
      case GL_INTENSITY8UI_EXT: RETVAL = "GL_INTENSITY8UI_EXT"; break;
      case GL_LUMINANCE12: RETVAL = "GL_LUMINANCE12"; break;
      case GL_LUMINANCE12_ALPHA12: RETVAL = "GL_LUMINANCE12_ALPHA12"; break;
      case GL_LUMINANCE12_ALPHA4: RETVAL = "GL_LUMINANCE12_ALPHA4"; break;
      case GL_LUMINANCE16: RETVAL = "GL_LUMINANCE16"; break;
      case GL_LUMINANCE16I_EXT: RETVAL = "GL_LUMINANCE16I_EXT"; break;
      case GL_LUMINANCE16UI_EXT: RETVAL = "GL_LUMINANCE16UI_EXT"; break;
      case GL_LUMINANCE16_ALPHA16: RETVAL = "GL_LUMINANCE16_ALPHA16"; break;
      case GL_LUMINANCE32I_EXT: RETVAL = "GL_LUMINANCE32I_EXT"; break;
      case GL_LUMINANCE32UI_EXT: RETVAL = "GL_LUMINANCE32UI_EXT"; break;
      case GL_LUMINANCE4: RETVAL = "GL_LUMINANCE4"; break;
      case GL_LUMINANCE4_ALPHA4: RETVAL = "GL_LUMINANCE4_ALPHA4"; break;
      case GL_LUMINANCE6_ALPHA2: RETVAL = "GL_LUMINANCE6_ALPHA2"; break;
      case GL_LUMINANCE8: RETVAL = "GL_LUMINANCE8"; break;
      case GL_LUMINANCE8I_EXT: RETVAL = "GL_LUMINANCE8I_EXT"; break;
      case GL_LUMINANCE8UI_EXT: RETVAL = "GL_LUMINANCE8UI_EXT"; break;
      case GL_LUMINANCE8_ALPHA8: RETVAL = "GL_LUMINANCE8_ALPHA8"; break;
      case GL_LUMINANCE_ALPHA16I_EXT: RETVAL = "GL_LUMINANCE_ALPHA16I_EXT"; break;
      case GL_LUMINANCE_ALPHA16UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA16UI_EXT"; break;
      case GL_LUMINANCE_ALPHA32I_EXT: RETVAL = "GL_LUMINANCE_ALPHA32I_EXT"; break;
      case GL_LUMINANCE_ALPHA32UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA32UI_EXT"; break;
      case GL_LUMINANCE_ALPHA8I_EXT: RETVAL = "GL_LUMINANCE_ALPHA8I_EXT"; break;
      case GL_LUMINANCE_ALPHA8UI_EXT: RETVAL = "GL_LUMINANCE_ALPHA8UI_EXT"; break;
      case GL_R11F_G11F_B10F: RETVAL = "GL_R11F_G11F_B10F"; break;
      case GL_R16: RETVAL = "GL_R16"; break;
      case GL_R16F: RETVAL = "GL_R16F"; break;
      case GL_R16I: RETVAL = "GL_R16I"; break;
      case GL_R16UI: RETVAL = "GL_R16UI"; break;
      case GL_R16_SNORM: RETVAL = "GL_R16_SNORM"; break;
      case GL_R32F: RETVAL = "GL_R32F"; break;
      case GL_R32I: RETVAL = "GL_R32I"; break;
      case GL_R32UI: RETVAL = "GL_R32UI"; break;
      case GL_R3_G3_B2: RETVAL = "GL_R3_G3_B2"; break;
      case GL_R8: RETVAL = "GL_R8"; break;
      case GL_R8I: RETVAL = "GL_R8I"; break;
      case GL_R8UI: RETVAL = "GL_R8UI"; break;
      case GL_R8_SNORM: RETVAL = "GL_R8_SNORM"; break;
      case GL_RG16: RETVAL = "GL_RG16"; break;
      case GL_RG16F: RETVAL = "GL_RG16F"; break;
      case GL_RG16I: RETVAL = "GL_RG16I"; break;
      case GL_RG16UI: RETVAL = "GL_RG16UI"; break;
      case GL_RG16_SNORM: RETVAL = "GL_RG16_SNORM"; break;
      case GL_RG32F: RETVAL = "GL_RG32F"; break;
      case GL_RG32I: RETVAL = "GL_RG32I"; break;
      case GL_RG32UI: RETVAL = "GL_RG32UI"; break;
      case GL_RG8: RETVAL = "GL_RG8"; break;
      case GL_RG8I: RETVAL = "GL_RG8I"; break;
      case GL_RG8UI: RETVAL = "GL_RG8UI"; break;
      case GL_RG8_SNORM: RETVAL = "GL_RG8_SNORM"; break;
      case GL_RGB10: RETVAL = "GL_RGB10"; break;
      case GL_RGB10_A2: RETVAL = "GL_RGB10_A2"; break;
      case GL_RGB10_A2UI: RETVAL = "GL_RGB10_A2UI"; break;
      case GL_RGB12: RETVAL = "GL_RGB12"; break;
      case GL_RGB16: RETVAL = "GL_RGB16"; break;
      case GL_RGB16F: RETVAL = "GL_RGB16F"; break;
      case GL_RGB16I: RETVAL = "GL_RGB16I"; break;
      case GL_RGB16UI: RETVAL = "GL_RGB16UI"; break;
      case GL_RGB16_SNORM: RETVAL = "GL_RGB16_SNORM"; break;
      case GL_RGB2_EXT: RETVAL = "GL_RGB2_EXT"; break;
      case GL_RGB32F: RETVAL = "GL_RGB32F"; break;
      case GL_RGB32I: RETVAL = "GL_RGB32I"; break;
      case GL_RGB32UI: RETVAL = "GL_RGB32UI"; break;
      case GL_RGB4: RETVAL = "GL_RGB4"; break;
      case GL_RGB5: RETVAL = "GL_RGB5"; break;
      case GL_RGB565: RETVAL = "GL_RGB565"; break;
      case GL_RGB5_A1: RETVAL = "GL_RGB5_A1"; break;
      case GL_RGB8: RETVAL = "GL_RGB8"; break;
      case GL_RGB8I: RETVAL = "GL_RGB8I"; break;
      case GL_RGB8UI: RETVAL = "GL_RGB8UI"; break;
      case GL_RGB8_SNORM: RETVAL = "GL_RGB8_SNORM"; break;
      case GL_RGB9_E5: RETVAL = "GL_RGB9_E5"; break;
      case GL_RGBA12: RETVAL = "GL_RGBA12"; break;
      case GL_RGBA16: RETVAL = "GL_RGBA16"; break;
      case GL_RGBA16F: RETVAL = "GL_RGBA16F"; break;
      case GL_RGBA16I: RETVAL = "GL_RGBA16I"; break;
      case GL_RGBA16UI: RETVAL = "GL_RGBA16UI"; break;
      case GL_RGBA16_SNORM: RETVAL = "GL_RGBA16_SNORM"; break;
      case GL_RGBA2: RETVAL = "GL_RGBA2"; break;
      case GL_RGBA32F: RETVAL = "GL_RGBA32F"; break;
      case GL_RGBA32I: RETVAL = "GL_RGBA32I"; break;
      case GL_RGBA32UI: RETVAL = "GL_RGBA32UI"; break;
      case GL_RGBA4: RETVAL = "GL_RGBA4"; break;
      case GL_RGBA8: RETVAL = "GL_RGBA8"; break;
      case GL_RGBA8I: RETVAL = "GL_RGBA8I"; break;
      case GL_RGBA8UI: RETVAL = "GL_RGBA8UI"; break;
      case GL_RGBA8_SNORM: RETVAL = "GL_RGBA8_SNORM"; break;
      case GL_SRGB8: RETVAL = "GL_SRGB8"; break;
      case GL_SRGB8_ALPHA8: RETVAL = "GL_SRGB8_ALPHA8"; break;
      case GL_STENCIL_INDEX1: RETVAL = "GL_STENCIL_INDEX1"; break;
      case GL_STENCIL_INDEX16: RETVAL = "GL_STENCIL_INDEX16"; break;
      case GL_STENCIL_INDEX4: RETVAL = "GL_STENCIL_INDEX4"; break;
      case GL_STENCIL_INDEX8: RETVAL = "GL_STENCIL_INDEX8"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "StencilFunction")) {
    switch (e) {
      case GL_ALWAYS: RETVAL = "GL_ALWAYS"; break;
      case GL_EQUAL: RETVAL = "GL_EQUAL"; break;
      case GL_GEQUAL: RETVAL = "GL_GEQUAL"; break;
      case GL_GREATER: RETVAL = "GL_GREATER"; break;
      case GL_LEQUAL: RETVAL = "GL_LEQUAL"; break;
      case GL_LESS: RETVAL = "GL_LESS"; break;
      case GL_NEVER: RETVAL = "GL_NEVER"; break;
      case GL_NOTEQUAL: RETVAL = "GL_NOTEQUAL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "StencilOp")) {
    switch (e) {
      case GL_DECR: RETVAL = "GL_DECR"; break;
      case GL_DECR_WRAP: RETVAL = "GL_DECR_WRAP"; break;
      case GL_INCR: RETVAL = "GL_INCR"; break;
      case GL_INCR_WRAP: RETVAL = "GL_INCR_WRAP"; break;
      case GL_INVERT: RETVAL = "GL_INVERT"; break;
      case GL_KEEP: RETVAL = "GL_KEEP"; break;
      case GL_REPLACE: RETVAL = "GL_REPLACE"; break;
      case GL_ZERO: RETVAL = "GL_ZERO"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "StringName")) {
    switch (e) {
      case GL_EXTENSIONS: RETVAL = "GL_EXTENSIONS"; break;
      case GL_RENDERER: RETVAL = "GL_RENDERER"; break;
      case GL_SHADING_LANGUAGE_VERSION: RETVAL = "GL_SHADING_LANGUAGE_VERSION"; break;
      case GL_VENDOR: RETVAL = "GL_VENDOR"; break;
      case GL_VERSION: RETVAL = "GL_VERSION"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SubgroupSupportedFeatures")) {
    switch (e) {
      case GL_SUBGROUP_FEATURE_ARITHMETIC_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_ARITHMETIC_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_BALLOT_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_BALLOT_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_BASIC_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_BASIC_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_CLUSTERED_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_CLUSTERED_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_PARTITIONED_BIT_NV: RETVAL = "GL_SUBGROUP_FEATURE_PARTITIONED_BIT_NV"; break;
      case GL_SUBGROUP_FEATURE_QUAD_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_QUAD_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_SHUFFLE_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_SHUFFLE_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_SHUFFLE_RELATIVE_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_SHUFFLE_RELATIVE_BIT_KHR"; break;
      case GL_SUBGROUP_FEATURE_VOTE_BIT_KHR: RETVAL = "GL_SUBGROUP_FEATURE_VOTE_BIT_KHR"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SubroutineParameterName")) {
    switch (e) {
      case GL_COMPATIBLE_SUBROUTINES: RETVAL = "GL_COMPATIBLE_SUBROUTINES"; break;
      case GL_NUM_COMPATIBLE_SUBROUTINES: RETVAL = "GL_NUM_COMPATIBLE_SUBROUTINES"; break;
      case GL_UNIFORM_NAME_LENGTH: RETVAL = "GL_UNIFORM_NAME_LENGTH"; break;
      case GL_UNIFORM_SIZE: RETVAL = "GL_UNIFORM_SIZE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SwizzleOpATI")) {
    switch (e) {
      case GL_SWIZZLE_STQ_ATI: RETVAL = "GL_SWIZZLE_STQ_ATI"; break;
      case GL_SWIZZLE_STQ_DQ_ATI: RETVAL = "GL_SWIZZLE_STQ_DQ_ATI"; break;
      case GL_SWIZZLE_STR_ATI: RETVAL = "GL_SWIZZLE_STR_ATI"; break;
      case GL_SWIZZLE_STR_DR_ATI: RETVAL = "GL_SWIZZLE_STR_DR_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SyncBehaviorFlags")) {
    switch (e) {
      case GL_NONE: RETVAL = "GL_NONE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SyncCondition")) {
    switch (e) {
      case GL_SYNC_GPU_COMMANDS_COMPLETE: RETVAL = "GL_SYNC_GPU_COMMANDS_COMPLETE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SyncObjectMask")) {
    switch (e) {
      case GL_SYNC_FLUSH_COMMANDS_BIT: RETVAL = "GL_SYNC_FLUSH_COMMANDS_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SyncParameterName")) {
    switch (e) {
      case GL_OBJECT_TYPE: RETVAL = "GL_OBJECT_TYPE"; break;
      case GL_SYNC_CONDITION: RETVAL = "GL_SYNC_CONDITION"; break;
      case GL_SYNC_FLAGS: RETVAL = "GL_SYNC_FLAGS"; break;
      case GL_SYNC_STATUS: RETVAL = "GL_SYNC_STATUS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "SyncStatus")) {
    switch (e) {
      case GL_ALREADY_SIGNALED: RETVAL = "GL_ALREADY_SIGNALED"; break;
      case GL_CONDITION_SATISFIED: RETVAL = "GL_CONDITION_SATISFIED"; break;
      case GL_TIMEOUT_EXPIRED: RETVAL = "GL_TIMEOUT_EXPIRED"; break;
      case GL_WAIT_FAILED: RETVAL = "GL_WAIT_FAILED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TangentPointerTypeEXT")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TexBumpParameterATI")) {
    switch (e) {
      case GL_BUMP_ROT_MATRIX_ATI: RETVAL = "GL_BUMP_ROT_MATRIX_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TexCoordPointerType")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TexStorageAttribs")) {
    switch (e) {
      case GL_SURFACE_COMPRESSION_EXT: RETVAL = "GL_SURFACE_COMPRESSION_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_10BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_10BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_11BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_11BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_12BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_12BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_1BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_1BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_2BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_2BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_3BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_3BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_4BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_4BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_5BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_5BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_6BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_6BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_7BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_7BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_8BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_8BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_9BPC_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_9BPC_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_DEFAULT_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_DEFAULT_EXT"; break;
      case GL_SURFACE_COMPRESSION_FIXED_RATE_NONE_EXT: RETVAL = "GL_SURFACE_COMPRESSION_FIXED_RATE_NONE_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureCompareMode")) {
    switch (e) {
      case GL_COMPARE_R_TO_TEXTURE: RETVAL = "GL_COMPARE_R_TO_TEXTURE"; break;
      case GL_NONE: RETVAL = "GL_NONE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureCoordName")) {
    switch (e) {
      case GL_Q: RETVAL = "GL_Q"; break;
      case GL_R: RETVAL = "GL_R"; break;
      case GL_S: RETVAL = "GL_S"; break;
      case GL_T: RETVAL = "GL_T"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureEnvMode")) {
    switch (e) {
      case GL_ADD: RETVAL = "GL_ADD"; break;
      case GL_BLEND: RETVAL = "GL_BLEND"; break;
      case GL_COMBINE: RETVAL = "GL_COMBINE"; break;
      case GL_DECAL: RETVAL = "GL_DECAL"; break;
      case GL_MODULATE: RETVAL = "GL_MODULATE"; break;
      case GL_REPLACE: RETVAL = "GL_REPLACE"; break;
      case GL_REPLACE_EXT: RETVAL = "GL_REPLACE_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureEnvParameter")) {
    switch (e) {
      case GL_ADD_SIGNED: RETVAL = "GL_ADD_SIGNED"; break;
      case GL_ALPHA_SCALE: RETVAL = "GL_ALPHA_SCALE"; break;
      case GL_COMBINE: RETVAL = "GL_COMBINE"; break;
      case GL_COMBINE_ALPHA: RETVAL = "GL_COMBINE_ALPHA"; break;
      case GL_COMBINE_RGB: RETVAL = "GL_COMBINE_RGB"; break;
      case GL_CONSTANT: RETVAL = "GL_CONSTANT"; break;
      case GL_COORD_REPLACE: RETVAL = "GL_COORD_REPLACE"; break;
      case GL_INTERPOLATE: RETVAL = "GL_INTERPOLATE"; break;
      case GL_OPERAND0_ALPHA: RETVAL = "GL_OPERAND0_ALPHA"; break;
      case GL_OPERAND0_RGB: RETVAL = "GL_OPERAND0_RGB"; break;
      case GL_OPERAND1_ALPHA: RETVAL = "GL_OPERAND1_ALPHA"; break;
      case GL_OPERAND1_RGB: RETVAL = "GL_OPERAND1_RGB"; break;
      case GL_OPERAND2_ALPHA: RETVAL = "GL_OPERAND2_ALPHA"; break;
      case GL_OPERAND2_RGB: RETVAL = "GL_OPERAND2_RGB"; break;
      case GL_OPERAND3_ALPHA_NV: RETVAL = "GL_OPERAND3_ALPHA_NV"; break;
      case GL_OPERAND3_RGB_NV: RETVAL = "GL_OPERAND3_RGB_NV"; break;
      case GL_PREVIOUS: RETVAL = "GL_PREVIOUS"; break;
      case GL_PRIMARY_COLOR: RETVAL = "GL_PRIMARY_COLOR"; break;
      case GL_RGB_SCALE: RETVAL = "GL_RGB_SCALE"; break;
      case GL_SOURCE3_ALPHA_NV: RETVAL = "GL_SOURCE3_ALPHA_NV"; break;
      case GL_SOURCE3_RGB_NV: RETVAL = "GL_SOURCE3_RGB_NV"; break;
      case GL_SRC0_ALPHA: RETVAL = "GL_SRC0_ALPHA"; break;
      case GL_SRC0_RGB: RETVAL = "GL_SRC0_RGB"; break;
      case GL_SRC1_ALPHA: RETVAL = "GL_SRC1_ALPHA"; break;
      case GL_SRC1_RGB: RETVAL = "GL_SRC1_RGB"; break;
      case GL_SRC2_ALPHA: RETVAL = "GL_SRC2_ALPHA"; break;
      case GL_SRC2_RGB: RETVAL = "GL_SRC2_RGB"; break;
      case GL_TEXTURE_ENV_COLOR: RETVAL = "GL_TEXTURE_ENV_COLOR"; break;
      case GL_TEXTURE_ENV_MODE: RETVAL = "GL_TEXTURE_ENV_MODE"; break;
      case GL_TEXTURE_LOD_BIAS: RETVAL = "GL_TEXTURE_LOD_BIAS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureEnvTarget")) {
    switch (e) {
      case GL_POINT_SPRITE: RETVAL = "GL_POINT_SPRITE"; break;
      case GL_TEXTURE_ENV: RETVAL = "GL_TEXTURE_ENV"; break;
      case GL_TEXTURE_FILTER_CONTROL: RETVAL = "GL_TEXTURE_FILTER_CONTROL"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureGenMode")) {
    switch (e) {
      case GL_EYE_DISTANCE_TO_LINE_SGIS: RETVAL = "GL_EYE_DISTANCE_TO_LINE_SGIS"; break;
      case GL_EYE_DISTANCE_TO_POINT_SGIS: RETVAL = "GL_EYE_DISTANCE_TO_POINT_SGIS"; break;
      case GL_EYE_LINEAR: RETVAL = "GL_EYE_LINEAR"; break;
      case GL_OBJECT_DISTANCE_TO_LINE_SGIS: RETVAL = "GL_OBJECT_DISTANCE_TO_LINE_SGIS"; break;
      case GL_OBJECT_DISTANCE_TO_POINT_SGIS: RETVAL = "GL_OBJECT_DISTANCE_TO_POINT_SGIS"; break;
      case GL_OBJECT_LINEAR: RETVAL = "GL_OBJECT_LINEAR"; break;
      case GL_SPHERE_MAP: RETVAL = "GL_SPHERE_MAP"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureGenParameter")) {
    switch (e) {
      case GL_EYE_LINE_SGIS: RETVAL = "GL_EYE_LINE_SGIS"; break;
      case GL_EYE_PLANE: RETVAL = "GL_EYE_PLANE"; break;
      case GL_EYE_POINT_SGIS: RETVAL = "GL_EYE_POINT_SGIS"; break;
      case GL_OBJECT_LINE_SGIS: RETVAL = "GL_OBJECT_LINE_SGIS"; break;
      case GL_OBJECT_PLANE: RETVAL = "GL_OBJECT_PLANE"; break;
      case GL_OBJECT_POINT_SGIS: RETVAL = "GL_OBJECT_POINT_SGIS"; break;
      case GL_TEXTURE_GEN_MODE: RETVAL = "GL_TEXTURE_GEN_MODE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureLayout")) {
    switch (e) {
      case GL_LAYOUT_COLOR_ATTACHMENT_EXT: RETVAL = "GL_LAYOUT_COLOR_ATTACHMENT_EXT"; break;
      case GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT: RETVAL = "GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT"; break;
      case GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT: RETVAL = "GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT"; break;
      case GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT: RETVAL = "GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT"; break;
      case GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT: RETVAL = "GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT"; break;
      case GL_LAYOUT_GENERAL_EXT: RETVAL = "GL_LAYOUT_GENERAL_EXT"; break;
      case GL_LAYOUT_SHADER_READ_ONLY_EXT: RETVAL = "GL_LAYOUT_SHADER_READ_ONLY_EXT"; break;
      case GL_LAYOUT_TRANSFER_DST_EXT: RETVAL = "GL_LAYOUT_TRANSFER_DST_EXT"; break;
      case GL_LAYOUT_TRANSFER_SRC_EXT: RETVAL = "GL_LAYOUT_TRANSFER_SRC_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureMagFilter")) {
    switch (e) {
      case GL_LINEAR: RETVAL = "GL_LINEAR"; break;
      case GL_NEAREST: RETVAL = "GL_NEAREST"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureMinFilter")) {
    switch (e) {
      case GL_LINEAR: RETVAL = "GL_LINEAR"; break;
      case GL_LINEAR_MIPMAP_LINEAR: RETVAL = "GL_LINEAR_MIPMAP_LINEAR"; break;
      case GL_LINEAR_MIPMAP_NEAREST: RETVAL = "GL_LINEAR_MIPMAP_NEAREST"; break;
      case GL_NEAREST: RETVAL = "GL_NEAREST"; break;
      case GL_NEAREST_MIPMAP_LINEAR: RETVAL = "GL_NEAREST_MIPMAP_LINEAR"; break;
      case GL_NEAREST_MIPMAP_NEAREST: RETVAL = "GL_NEAREST_MIPMAP_NEAREST"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureNormalModeEXT")) {
    switch (e) {
      case GL_PERTURB_EXT: RETVAL = "GL_PERTURB_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureParameterName")) {
    switch (e) {
      case GL_DEPTH_STENCIL_TEXTURE_MODE: RETVAL = "GL_DEPTH_STENCIL_TEXTURE_MODE"; break;
      case GL_GENERATE_MIPMAP: RETVAL = "GL_GENERATE_MIPMAP"; break;
      case GL_POST_TEXTURE_FILTER_BIAS_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_BIAS_SGIX"; break;
      case GL_POST_TEXTURE_FILTER_SCALE_SGIX: RETVAL = "GL_POST_TEXTURE_FILTER_SCALE_SGIX"; break;
      case GL_SHADOW_AMBIENT_SGIX: RETVAL = "GL_SHADOW_AMBIENT_SGIX"; break;
      case GL_TEXTURE_ALPHA_SIZE: RETVAL = "GL_TEXTURE_ALPHA_SIZE"; break;
      case GL_TEXTURE_BASE_LEVEL: RETVAL = "GL_TEXTURE_BASE_LEVEL"; break;
      case GL_TEXTURE_BLUE_SIZE: RETVAL = "GL_TEXTURE_BLUE_SIZE"; break;
      case GL_TEXTURE_BORDER: RETVAL = "GL_TEXTURE_BORDER"; break;
      case GL_TEXTURE_BORDER_COLOR: RETVAL = "GL_TEXTURE_BORDER_COLOR"; break;
      case GL_TEXTURE_CBCR_DEGAMMA_QCOM: RETVAL = "GL_TEXTURE_CBCR_DEGAMMA_QCOM"; break;
      case GL_TEXTURE_COMPARE_FUNC: RETVAL = "GL_TEXTURE_COMPARE_FUNC"; break;
      case GL_TEXTURE_COMPARE_MODE: RETVAL = "GL_TEXTURE_COMPARE_MODE"; break;
      case GL_TEXTURE_COMPARE_OPERATOR_SGIX: RETVAL = "GL_TEXTURE_COMPARE_OPERATOR_SGIX"; break;
      case GL_TEXTURE_COMPARE_SGIX: RETVAL = "GL_TEXTURE_COMPARE_SGIX"; break;
      case GL_TEXTURE_COMPONENTS: RETVAL = "GL_TEXTURE_COMPONENTS"; break;
      case GL_TEXTURE_DEPTH_EXT: RETVAL = "GL_TEXTURE_DEPTH_EXT"; break;
      case GL_TEXTURE_FOVEATED_CUTOFF_DENSITY_QCOM: RETVAL = "GL_TEXTURE_FOVEATED_CUTOFF_DENSITY_QCOM"; break;
      case GL_TEXTURE_GEQUAL_R_SGIX: RETVAL = "GL_TEXTURE_GEQUAL_R_SGIX"; break;
      case GL_TEXTURE_GREEN_SIZE: RETVAL = "GL_TEXTURE_GREEN_SIZE"; break;
      case GL_TEXTURE_HEIGHT: RETVAL = "GL_TEXTURE_HEIGHT"; break;
      case GL_TEXTURE_INTENSITY_SIZE: RETVAL = "GL_TEXTURE_INTENSITY_SIZE"; break;
      case GL_TEXTURE_LEQUAL_R_SGIX: RETVAL = "GL_TEXTURE_LEQUAL_R_SGIX"; break;
      case GL_TEXTURE_LOD_BIAS: RETVAL = "GL_TEXTURE_LOD_BIAS"; break;
      case GL_TEXTURE_LUMINANCE_SIZE: RETVAL = "GL_TEXTURE_LUMINANCE_SIZE"; break;
      case GL_TEXTURE_MAG_FILTER: RETVAL = "GL_TEXTURE_MAG_FILTER"; break;
      case GL_TEXTURE_MAX_ANISOTROPY: RETVAL = "GL_TEXTURE_MAX_ANISOTROPY"; break;
      case GL_TEXTURE_MAX_CLAMP_R_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_R_SGIX"; break;
      case GL_TEXTURE_MAX_CLAMP_S_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_S_SGIX"; break;
      case GL_TEXTURE_MAX_CLAMP_T_SGIX: RETVAL = "GL_TEXTURE_MAX_CLAMP_T_SGIX"; break;
      case GL_TEXTURE_MAX_LEVEL: RETVAL = "GL_TEXTURE_MAX_LEVEL"; break;
      case GL_TEXTURE_MAX_LOD: RETVAL = "GL_TEXTURE_MAX_LOD"; break;
      case GL_TEXTURE_MEMORY_LAYOUT_INTEL: RETVAL = "GL_TEXTURE_MEMORY_LAYOUT_INTEL"; break;
      case GL_TEXTURE_MIN_FILTER: RETVAL = "GL_TEXTURE_MIN_FILTER"; break;
      case GL_TEXTURE_MIN_LOD: RETVAL = "GL_TEXTURE_MIN_LOD"; break;
      case GL_TEXTURE_PRIORITY: RETVAL = "GL_TEXTURE_PRIORITY"; break;
      case GL_TEXTURE_RED_SIZE: RETVAL = "GL_TEXTURE_RED_SIZE"; break;
      case GL_TEXTURE_RESIDENT: RETVAL = "GL_TEXTURE_RESIDENT"; break;
      case GL_TEXTURE_SWIZZLE_A: RETVAL = "GL_TEXTURE_SWIZZLE_A"; break;
      case GL_TEXTURE_SWIZZLE_B: RETVAL = "GL_TEXTURE_SWIZZLE_B"; break;
      case GL_TEXTURE_SWIZZLE_G: RETVAL = "GL_TEXTURE_SWIZZLE_G"; break;
      case GL_TEXTURE_SWIZZLE_R: RETVAL = "GL_TEXTURE_SWIZZLE_R"; break;
      case GL_TEXTURE_SWIZZLE_RGBA: RETVAL = "GL_TEXTURE_SWIZZLE_RGBA"; break;
      case GL_TEXTURE_TILING_EXT: RETVAL = "GL_TEXTURE_TILING_EXT"; break;
      case GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM: RETVAL = "GL_TEXTURE_UNNORMALIZED_COORDINATES_ARM"; break;
      case GL_TEXTURE_WIDTH: RETVAL = "GL_TEXTURE_WIDTH"; break;
      case GL_TEXTURE_WRAP_R: RETVAL = "GL_TEXTURE_WRAP_R"; break;
      case GL_TEXTURE_WRAP_S: RETVAL = "GL_TEXTURE_WRAP_S"; break;
      case GL_TEXTURE_WRAP_T: RETVAL = "GL_TEXTURE_WRAP_T"; break;
      case GL_TEXTURE_Y_DEGAMMA_QCOM: RETVAL = "GL_TEXTURE_Y_DEGAMMA_QCOM"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureStorageMaskAMD")) {
    switch (e) {
      case GL_TEXTURE_STORAGE_SPARSE_BIT_AMD: RETVAL = "GL_TEXTURE_STORAGE_SPARSE_BIT_AMD"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureSwizzle")) {
    switch (e) {
      case GL_ALPHA: RETVAL = "GL_ALPHA"; break;
      case GL_BLUE: RETVAL = "GL_BLUE"; break;
      case GL_GREEN: RETVAL = "GL_GREEN"; break;
      case GL_ONE: RETVAL = "GL_ONE"; break;
      case GL_RED: RETVAL = "GL_RED"; break;
      case GL_ZERO: RETVAL = "GL_ZERO"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureTarget")) {
    switch (e) {
      case GL_PROXY_TEXTURE_1D: RETVAL = "GL_PROXY_TEXTURE_1D"; break;
      case GL_PROXY_TEXTURE_1D_ARRAY: RETVAL = "GL_PROXY_TEXTURE_1D_ARRAY"; break;
      case GL_PROXY_TEXTURE_2D: RETVAL = "GL_PROXY_TEXTURE_2D"; break;
      case GL_PROXY_TEXTURE_2D_ARRAY: RETVAL = "GL_PROXY_TEXTURE_2D_ARRAY"; break;
      case GL_PROXY_TEXTURE_2D_MULTISAMPLE: RETVAL = "GL_PROXY_TEXTURE_2D_MULTISAMPLE"; break;
      case GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_PROXY_TEXTURE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_PROXY_TEXTURE_3D: RETVAL = "GL_PROXY_TEXTURE_3D"; break;
      case GL_PROXY_TEXTURE_CUBE_MAP: RETVAL = "GL_PROXY_TEXTURE_CUBE_MAP"; break;
      case GL_PROXY_TEXTURE_CUBE_MAP_ARRAY: RETVAL = "GL_PROXY_TEXTURE_CUBE_MAP_ARRAY"; break;
      case GL_PROXY_TEXTURE_RECTANGLE: RETVAL = "GL_PROXY_TEXTURE_RECTANGLE"; break;
      case GL_RENDERBUFFER: RETVAL = "GL_RENDERBUFFER"; break;
      case GL_TEXTURE_1D: RETVAL = "GL_TEXTURE_1D"; break;
      case GL_TEXTURE_1D_ARRAY: RETVAL = "GL_TEXTURE_1D_ARRAY"; break;
      case GL_TEXTURE_2D: RETVAL = "GL_TEXTURE_2D"; break;
      case GL_TEXTURE_2D_ARRAY: RETVAL = "GL_TEXTURE_2D_ARRAY"; break;
      case GL_TEXTURE_2D_MULTISAMPLE: RETVAL = "GL_TEXTURE_2D_MULTISAMPLE"; break;
      case GL_TEXTURE_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_TEXTURE_2D_MULTISAMPLE_ARRAY"; break;
      case GL_TEXTURE_3D: RETVAL = "GL_TEXTURE_3D"; break;
      case GL_TEXTURE_BUFFER: RETVAL = "GL_TEXTURE_BUFFER"; break;
      case GL_TEXTURE_CUBE_MAP: RETVAL = "GL_TEXTURE_CUBE_MAP"; break;
      case GL_TEXTURE_CUBE_MAP_ARRAY: RETVAL = "GL_TEXTURE_CUBE_MAP_ARRAY"; break;
      case GL_TEXTURE_CUBE_MAP_NEGATIVE_X: RETVAL = "GL_TEXTURE_CUBE_MAP_NEGATIVE_X"; break;
      case GL_TEXTURE_CUBE_MAP_NEGATIVE_Y: RETVAL = "GL_TEXTURE_CUBE_MAP_NEGATIVE_Y"; break;
      case GL_TEXTURE_CUBE_MAP_NEGATIVE_Z: RETVAL = "GL_TEXTURE_CUBE_MAP_NEGATIVE_Z"; break;
      case GL_TEXTURE_CUBE_MAP_POSITIVE_X: RETVAL = "GL_TEXTURE_CUBE_MAP_POSITIVE_X"; break;
      case GL_TEXTURE_CUBE_MAP_POSITIVE_Y: RETVAL = "GL_TEXTURE_CUBE_MAP_POSITIVE_Y"; break;
      case GL_TEXTURE_CUBE_MAP_POSITIVE_Z: RETVAL = "GL_TEXTURE_CUBE_MAP_POSITIVE_Z"; break;
      case GL_TEXTURE_RECTANGLE: RETVAL = "GL_TEXTURE_RECTANGLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureUnit")) {
    switch (e) {
      case GL_TEXTURE0: RETVAL = "GL_TEXTURE0"; break;
      case GL_TEXTURE1: RETVAL = "GL_TEXTURE1"; break;
      case GL_TEXTURE10: RETVAL = "GL_TEXTURE10"; break;
      case GL_TEXTURE11: RETVAL = "GL_TEXTURE11"; break;
      case GL_TEXTURE12: RETVAL = "GL_TEXTURE12"; break;
      case GL_TEXTURE13: RETVAL = "GL_TEXTURE13"; break;
      case GL_TEXTURE14: RETVAL = "GL_TEXTURE14"; break;
      case GL_TEXTURE15: RETVAL = "GL_TEXTURE15"; break;
      case GL_TEXTURE16: RETVAL = "GL_TEXTURE16"; break;
      case GL_TEXTURE17: RETVAL = "GL_TEXTURE17"; break;
      case GL_TEXTURE18: RETVAL = "GL_TEXTURE18"; break;
      case GL_TEXTURE19: RETVAL = "GL_TEXTURE19"; break;
      case GL_TEXTURE2: RETVAL = "GL_TEXTURE2"; break;
      case GL_TEXTURE20: RETVAL = "GL_TEXTURE20"; break;
      case GL_TEXTURE21: RETVAL = "GL_TEXTURE21"; break;
      case GL_TEXTURE22: RETVAL = "GL_TEXTURE22"; break;
      case GL_TEXTURE23: RETVAL = "GL_TEXTURE23"; break;
      case GL_TEXTURE24: RETVAL = "GL_TEXTURE24"; break;
      case GL_TEXTURE25: RETVAL = "GL_TEXTURE25"; break;
      case GL_TEXTURE26: RETVAL = "GL_TEXTURE26"; break;
      case GL_TEXTURE27: RETVAL = "GL_TEXTURE27"; break;
      case GL_TEXTURE28: RETVAL = "GL_TEXTURE28"; break;
      case GL_TEXTURE29: RETVAL = "GL_TEXTURE29"; break;
      case GL_TEXTURE3: RETVAL = "GL_TEXTURE3"; break;
      case GL_TEXTURE30: RETVAL = "GL_TEXTURE30"; break;
      case GL_TEXTURE31: RETVAL = "GL_TEXTURE31"; break;
      case GL_TEXTURE4: RETVAL = "GL_TEXTURE4"; break;
      case GL_TEXTURE5: RETVAL = "GL_TEXTURE5"; break;
      case GL_TEXTURE6: RETVAL = "GL_TEXTURE6"; break;
      case GL_TEXTURE7: RETVAL = "GL_TEXTURE7"; break;
      case GL_TEXTURE8: RETVAL = "GL_TEXTURE8"; break;
      case GL_TEXTURE9: RETVAL = "GL_TEXTURE9"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TextureWrapMode")) {
    switch (e) {
      case GL_CLAMP: RETVAL = "GL_CLAMP"; break;
      case GL_CLAMP_TO_BORDER: RETVAL = "GL_CLAMP_TO_BORDER"; break;
      case GL_CLAMP_TO_EDGE: RETVAL = "GL_CLAMP_TO_EDGE"; break;
      case GL_MIRRORED_REPEAT: RETVAL = "GL_MIRRORED_REPEAT"; break;
      case GL_REPEAT: RETVAL = "GL_REPEAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TransformFeedbackBufferMode")) {
    switch (e) {
      case GL_INTERLEAVED_ATTRIBS: RETVAL = "GL_INTERLEAVED_ATTRIBS"; break;
      case GL_SEPARATE_ATTRIBS: RETVAL = "GL_SEPARATE_ATTRIBS"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TransformFeedbackPName")) {
    switch (e) {
      case GL_TRANSFORM_FEEDBACK_ACTIVE: RETVAL = "GL_TRANSFORM_FEEDBACK_ACTIVE"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_BINDING: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_BINDING"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_SIZE: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_SIZE"; break;
      case GL_TRANSFORM_FEEDBACK_BUFFER_START: RETVAL = "GL_TRANSFORM_FEEDBACK_BUFFER_START"; break;
      case GL_TRANSFORM_FEEDBACK_PAUSED: RETVAL = "GL_TRANSFORM_FEEDBACK_PAUSED"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TriangleFace")) {
    switch (e) {
      case GL_BACK: RETVAL = "GL_BACK"; break;
      case GL_FRONT: RETVAL = "GL_FRONT"; break;
      case GL_FRONT_AND_BACK: RETVAL = "GL_FRONT_AND_BACK"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "TriangleListSUN")) {
    switch (e) {
      case GL_REPLACE_MIDDLE_SUN: RETVAL = "GL_REPLACE_MIDDLE_SUN"; break;
      case GL_REPLACE_OLDEST_SUN: RETVAL = "GL_REPLACE_OLDEST_SUN"; break;
      case GL_RESTART_SUN: RETVAL = "GL_RESTART_SUN"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "UniformBlockPName")) {
    switch (e) {
      case GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS: RETVAL = "GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS"; break;
      case GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES: RETVAL = "GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES"; break;
      case GL_UNIFORM_BLOCK_BINDING: RETVAL = "GL_UNIFORM_BLOCK_BINDING"; break;
      case GL_UNIFORM_BLOCK_DATA_SIZE: RETVAL = "GL_UNIFORM_BLOCK_DATA_SIZE"; break;
      case GL_UNIFORM_BLOCK_NAME_LENGTH: RETVAL = "GL_UNIFORM_BLOCK_NAME_LENGTH"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_COMPUTE_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_COMPUTE_SHADER"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_CONTROL_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_CONTROL_SHADER"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_EVALUATION_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_EVALUATION_SHADER"; break;
      case GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER: RETVAL = "GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "UniformPName")) {
    switch (e) {
      case GL_UNIFORM_ARRAY_STRIDE: RETVAL = "GL_UNIFORM_ARRAY_STRIDE"; break;
      case GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX: RETVAL = "GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX"; break;
      case GL_UNIFORM_BLOCK_INDEX: RETVAL = "GL_UNIFORM_BLOCK_INDEX"; break;
      case GL_UNIFORM_IS_ROW_MAJOR: RETVAL = "GL_UNIFORM_IS_ROW_MAJOR"; break;
      case GL_UNIFORM_MATRIX_STRIDE: RETVAL = "GL_UNIFORM_MATRIX_STRIDE"; break;
      case GL_UNIFORM_NAME_LENGTH: RETVAL = "GL_UNIFORM_NAME_LENGTH"; break;
      case GL_UNIFORM_OFFSET: RETVAL = "GL_UNIFORM_OFFSET"; break;
      case GL_UNIFORM_SIZE: RETVAL = "GL_UNIFORM_SIZE"; break;
      case GL_UNIFORM_TYPE: RETVAL = "GL_UNIFORM_TYPE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "UniformType")) {
    switch (e) {
      case GL_BOOL: RETVAL = "GL_BOOL"; break;
      case GL_BOOL_VEC2: RETVAL = "GL_BOOL_VEC2"; break;
      case GL_BOOL_VEC3: RETVAL = "GL_BOOL_VEC3"; break;
      case GL_BOOL_VEC4: RETVAL = "GL_BOOL_VEC4"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_DOUBLE_MAT2: RETVAL = "GL_DOUBLE_MAT2"; break;
      case GL_DOUBLE_MAT2x3: RETVAL = "GL_DOUBLE_MAT2x3"; break;
      case GL_DOUBLE_MAT2x4: RETVAL = "GL_DOUBLE_MAT2x4"; break;
      case GL_DOUBLE_MAT3: RETVAL = "GL_DOUBLE_MAT3"; break;
      case GL_DOUBLE_MAT3x2: RETVAL = "GL_DOUBLE_MAT3x2"; break;
      case GL_DOUBLE_MAT3x4: RETVAL = "GL_DOUBLE_MAT3x4"; break;
      case GL_DOUBLE_MAT4: RETVAL = "GL_DOUBLE_MAT4"; break;
      case GL_DOUBLE_MAT4x2: RETVAL = "GL_DOUBLE_MAT4x2"; break;
      case GL_DOUBLE_MAT4x3: RETVAL = "GL_DOUBLE_MAT4x3"; break;
      case GL_DOUBLE_VEC2: RETVAL = "GL_DOUBLE_VEC2"; break;
      case GL_DOUBLE_VEC3: RETVAL = "GL_DOUBLE_VEC3"; break;
      case GL_DOUBLE_VEC4: RETVAL = "GL_DOUBLE_VEC4"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_FLOAT_MAT2: RETVAL = "GL_FLOAT_MAT2"; break;
      case GL_FLOAT_MAT2x3: RETVAL = "GL_FLOAT_MAT2x3"; break;
      case GL_FLOAT_MAT2x4: RETVAL = "GL_FLOAT_MAT2x4"; break;
      case GL_FLOAT_MAT3: RETVAL = "GL_FLOAT_MAT3"; break;
      case GL_FLOAT_MAT3x2: RETVAL = "GL_FLOAT_MAT3x2"; break;
      case GL_FLOAT_MAT3x4: RETVAL = "GL_FLOAT_MAT3x4"; break;
      case GL_FLOAT_MAT4: RETVAL = "GL_FLOAT_MAT4"; break;
      case GL_FLOAT_MAT4x2: RETVAL = "GL_FLOAT_MAT4x2"; break;
      case GL_FLOAT_MAT4x3: RETVAL = "GL_FLOAT_MAT4x3"; break;
      case GL_FLOAT_VEC2: RETVAL = "GL_FLOAT_VEC2"; break;
      case GL_FLOAT_VEC3: RETVAL = "GL_FLOAT_VEC3"; break;
      case GL_FLOAT_VEC4: RETVAL = "GL_FLOAT_VEC4"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_INT_SAMPLER_1D: RETVAL = "GL_INT_SAMPLER_1D"; break;
      case GL_INT_SAMPLER_1D_ARRAY: RETVAL = "GL_INT_SAMPLER_1D_ARRAY"; break;
      case GL_INT_SAMPLER_2D: RETVAL = "GL_INT_SAMPLER_2D"; break;
      case GL_INT_SAMPLER_2D_ARRAY: RETVAL = "GL_INT_SAMPLER_2D_ARRAY"; break;
      case GL_INT_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_INT_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_INT_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_INT_SAMPLER_2D_RECT: RETVAL = "GL_INT_SAMPLER_2D_RECT"; break;
      case GL_INT_SAMPLER_3D: RETVAL = "GL_INT_SAMPLER_3D"; break;
      case GL_INT_SAMPLER_BUFFER: RETVAL = "GL_INT_SAMPLER_BUFFER"; break;
      case GL_INT_SAMPLER_CUBE: RETVAL = "GL_INT_SAMPLER_CUBE"; break;
      case GL_INT_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_INT_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_INT_VEC2: RETVAL = "GL_INT_VEC2"; break;
      case GL_INT_VEC3: RETVAL = "GL_INT_VEC3"; break;
      case GL_INT_VEC4: RETVAL = "GL_INT_VEC4"; break;
      case GL_SAMPLER_1D: RETVAL = "GL_SAMPLER_1D"; break;
      case GL_SAMPLER_1D_ARRAY: RETVAL = "GL_SAMPLER_1D_ARRAY"; break;
      case GL_SAMPLER_1D_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_1D_ARRAY_SHADOW"; break;
      case GL_SAMPLER_1D_SHADOW: RETVAL = "GL_SAMPLER_1D_SHADOW"; break;
      case GL_SAMPLER_2D: RETVAL = "GL_SAMPLER_2D"; break;
      case GL_SAMPLER_2D_ARRAY: RETVAL = "GL_SAMPLER_2D_ARRAY"; break;
      case GL_SAMPLER_2D_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_2D_ARRAY_SHADOW"; break;
      case GL_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_SAMPLER_2D_RECT: RETVAL = "GL_SAMPLER_2D_RECT"; break;
      case GL_SAMPLER_2D_RECT_SHADOW: RETVAL = "GL_SAMPLER_2D_RECT_SHADOW"; break;
      case GL_SAMPLER_2D_SHADOW: RETVAL = "GL_SAMPLER_2D_SHADOW"; break;
      case GL_SAMPLER_3D: RETVAL = "GL_SAMPLER_3D"; break;
      case GL_SAMPLER_BUFFER: RETVAL = "GL_SAMPLER_BUFFER"; break;
      case GL_SAMPLER_CUBE: RETVAL = "GL_SAMPLER_CUBE"; break;
      case GL_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW: RETVAL = "GL_SAMPLER_CUBE_MAP_ARRAY_SHADOW"; break;
      case GL_SAMPLER_CUBE_SHADOW: RETVAL = "GL_SAMPLER_CUBE_SHADOW"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_INT_SAMPLER_1D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_1D"; break;
      case GL_UNSIGNED_INT_SAMPLER_1D_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_1D_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE_ARRAY"; break;
      case GL_UNSIGNED_INT_SAMPLER_2D_RECT: RETVAL = "GL_UNSIGNED_INT_SAMPLER_2D_RECT"; break;
      case GL_UNSIGNED_INT_SAMPLER_3D: RETVAL = "GL_UNSIGNED_INT_SAMPLER_3D"; break;
      case GL_UNSIGNED_INT_SAMPLER_BUFFER: RETVAL = "GL_UNSIGNED_INT_SAMPLER_BUFFER"; break;
      case GL_UNSIGNED_INT_SAMPLER_CUBE: RETVAL = "GL_UNSIGNED_INT_SAMPLER_CUBE"; break;
      case GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY: RETVAL = "GL_UNSIGNED_INT_SAMPLER_CUBE_MAP_ARRAY"; break;
      case GL_UNSIGNED_INT_VEC2: RETVAL = "GL_UNSIGNED_INT_VEC2"; break;
      case GL_UNSIGNED_INT_VEC3: RETVAL = "GL_UNSIGNED_INT_VEC3"; break;
      case GL_UNSIGNED_INT_VEC4: RETVAL = "GL_UNSIGNED_INT_VEC4"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "UseProgramStageMask")) {
    switch (e) {
      case GL_ALL_SHADER_BITS: RETVAL = "GL_ALL_SHADER_BITS"; break;
      case GL_COMPUTE_SHADER_BIT: RETVAL = "GL_COMPUTE_SHADER_BIT"; break;
      case GL_FRAGMENT_SHADER_BIT: RETVAL = "GL_FRAGMENT_SHADER_BIT"; break;
      case GL_GEOMETRY_SHADER_BIT: RETVAL = "GL_GEOMETRY_SHADER_BIT"; break;
      case GL_MESH_SHADER_BIT_NV: RETVAL = "GL_MESH_SHADER_BIT_NV"; break;
      case GL_TASK_SHADER_BIT_NV: RETVAL = "GL_TASK_SHADER_BIT_NV"; break;
      case GL_TESS_CONTROL_SHADER_BIT: RETVAL = "GL_TESS_CONTROL_SHADER_BIT"; break;
      case GL_TESS_EVALUATION_SHADER_BIT: RETVAL = "GL_TESS_EVALUATION_SHADER_BIT"; break;
      case GL_VERTEX_SHADER_BIT: RETVAL = "GL_VERTEX_SHADER_BIT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VariantCapEXT")) {
    switch (e) {
      case GL_VARIANT_ARRAY_EXT: RETVAL = "GL_VARIANT_ARRAY_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexArrayPName")) {
    switch (e) {
      case GL_VERTEX_ATTRIB_ARRAY_DIVISOR: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_DIVISOR"; break;
      case GL_VERTEX_ATTRIB_ARRAY_ENABLED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_ENABLED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_INTEGER: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_INTEGER"; break;
      case GL_VERTEX_ATTRIB_ARRAY_LONG: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_LONG"; break;
      case GL_VERTEX_ATTRIB_ARRAY_NORMALIZED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_NORMALIZED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_SIZE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_SIZE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_STRIDE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_STRIDE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_TYPE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_TYPE"; break;
      case GL_VERTEX_ATTRIB_RELATIVE_OFFSET: RETVAL = "GL_VERTEX_ATTRIB_RELATIVE_OFFSET"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexArrayPNameAPPLE")) {
    switch (e) {
      case GL_STORAGE_CACHED_APPLE: RETVAL = "GL_STORAGE_CACHED_APPLE"; break;
      case GL_STORAGE_CLIENT_APPLE: RETVAL = "GL_STORAGE_CLIENT_APPLE"; break;
      case GL_STORAGE_SHARED_APPLE: RETVAL = "GL_STORAGE_SHARED_APPLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribEnum")) {
    switch (e) {
      case GL_CURRENT_VERTEX_ATTRIB: RETVAL = "GL_CURRENT_VERTEX_ATTRIB"; break;
      case GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING"; break;
      case GL_VERTEX_ATTRIB_ARRAY_DIVISOR: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_DIVISOR"; break;
      case GL_VERTEX_ATTRIB_ARRAY_ENABLED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_ENABLED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_INTEGER: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_INTEGER"; break;
      case GL_VERTEX_ATTRIB_ARRAY_NORMALIZED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_NORMALIZED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_SIZE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_SIZE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_STRIDE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_STRIDE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_TYPE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_TYPE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribEnumNV")) {
    switch (e) {
      case GL_PROGRAM_PARAMETER_NV: RETVAL = "GL_PROGRAM_PARAMETER_NV"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribIType")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribLType")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribPointerPropertyARB")) {
    switch (e) {
      case GL_VERTEX_ATTRIB_ARRAY_POINTER: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_POINTER"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribPointerType")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FIXED: RETVAL = "GL_FIXED"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_HALF_FLOAT: RETVAL = "GL_HALF_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_INT64_NV: RETVAL = "GL_INT64_NV"; break;
      case GL_INT_2_10_10_10_REV: RETVAL = "GL_INT_2_10_10_10_REV"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_INT64_NV: RETVAL = "GL_UNSIGNED_INT64_NV"; break;
      case GL_UNSIGNED_INT_10F_11F_11F_REV: RETVAL = "GL_UNSIGNED_INT_10F_11F_11F_REV"; break;
      case GL_UNSIGNED_INT_2_10_10_10_REV: RETVAL = "GL_UNSIGNED_INT_2_10_10_10_REV"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribPropertyARB")) {
    switch (e) {
      case GL_CURRENT_VERTEX_ATTRIB: RETVAL = "GL_CURRENT_VERTEX_ATTRIB"; break;
      case GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING"; break;
      case GL_VERTEX_ATTRIB_ARRAY_DIVISOR: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_DIVISOR"; break;
      case GL_VERTEX_ATTRIB_ARRAY_ENABLED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_ENABLED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_INTEGER: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_INTEGER"; break;
      case GL_VERTEX_ATTRIB_ARRAY_LONG: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_LONG"; break;
      case GL_VERTEX_ATTRIB_ARRAY_NORMALIZED: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_NORMALIZED"; break;
      case GL_VERTEX_ATTRIB_ARRAY_SIZE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_SIZE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_STRIDE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_STRIDE"; break;
      case GL_VERTEX_ATTRIB_ARRAY_TYPE: RETVAL = "GL_VERTEX_ATTRIB_ARRAY_TYPE"; break;
      case GL_VERTEX_ATTRIB_BINDING: RETVAL = "GL_VERTEX_ATTRIB_BINDING"; break;
      case GL_VERTEX_ATTRIB_RELATIVE_OFFSET: RETVAL = "GL_VERTEX_ATTRIB_RELATIVE_OFFSET"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexAttribType")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FIXED: RETVAL = "GL_FIXED"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_HALF_FLOAT: RETVAL = "GL_HALF_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_INT_2_10_10_10_REV: RETVAL = "GL_INT_2_10_10_10_REV"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_INT_10F_11F_11F_REV: RETVAL = "GL_UNSIGNED_INT_10F_11F_11F_REV"; break;
      case GL_UNSIGNED_INT_2_10_10_10_REV: RETVAL = "GL_UNSIGNED_INT_2_10_10_10_REV"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexHintsMaskPGI")) {
    switch (e) {
      case GL_COLOR3_BIT_PGI: RETVAL = "GL_COLOR3_BIT_PGI"; break;
      case GL_COLOR4_BIT_PGI: RETVAL = "GL_COLOR4_BIT_PGI"; break;
      case GL_EDGEFLAG_BIT_PGI: RETVAL = "GL_EDGEFLAG_BIT_PGI"; break;
      case GL_INDEX_BIT_PGI: RETVAL = "GL_INDEX_BIT_PGI"; break;
      case GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI: RETVAL = "GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI"; break;
      case GL_MAT_AMBIENT_BIT_PGI: RETVAL = "GL_MAT_AMBIENT_BIT_PGI"; break;
      case GL_MAT_COLOR_INDEXES_BIT_PGI: RETVAL = "GL_MAT_COLOR_INDEXES_BIT_PGI"; break;
      case GL_MAT_DIFFUSE_BIT_PGI: RETVAL = "GL_MAT_DIFFUSE_BIT_PGI"; break;
      case GL_MAT_EMISSION_BIT_PGI: RETVAL = "GL_MAT_EMISSION_BIT_PGI"; break;
      case GL_MAT_SHININESS_BIT_PGI: RETVAL = "GL_MAT_SHININESS_BIT_PGI"; break;
      case GL_MAT_SPECULAR_BIT_PGI: RETVAL = "GL_MAT_SPECULAR_BIT_PGI"; break;
      case GL_NORMAL_BIT_PGI: RETVAL = "GL_NORMAL_BIT_PGI"; break;
      case GL_TEXCOORD1_BIT_PGI: RETVAL = "GL_TEXCOORD1_BIT_PGI"; break;
      case GL_TEXCOORD2_BIT_PGI: RETVAL = "GL_TEXCOORD2_BIT_PGI"; break;
      case GL_TEXCOORD3_BIT_PGI: RETVAL = "GL_TEXCOORD3_BIT_PGI"; break;
      case GL_TEXCOORD4_BIT_PGI: RETVAL = "GL_TEXCOORD4_BIT_PGI"; break;
      case GL_VERTEX23_BIT_PGI: RETVAL = "GL_VERTEX23_BIT_PGI"; break;
      case GL_VERTEX4_BIT_PGI: RETVAL = "GL_VERTEX4_BIT_PGI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexPointerType")) {
    switch (e) {
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexProvokingMode")) {
    switch (e) {
      case GL_FIRST_VERTEX_CONVENTION: RETVAL = "GL_FIRST_VERTEX_CONVENTION"; break;
      case GL_LAST_VERTEX_CONVENTION: RETVAL = "GL_LAST_VERTEX_CONVENTION"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderCoordOutEXT")) {
    switch (e) {
      case GL_NEGATIVE_ONE_EXT: RETVAL = "GL_NEGATIVE_ONE_EXT"; break;
      case GL_NEGATIVE_W_EXT: RETVAL = "GL_NEGATIVE_W_EXT"; break;
      case GL_NEGATIVE_X_EXT: RETVAL = "GL_NEGATIVE_X_EXT"; break;
      case GL_NEGATIVE_Y_EXT: RETVAL = "GL_NEGATIVE_Y_EXT"; break;
      case GL_NEGATIVE_Z_EXT: RETVAL = "GL_NEGATIVE_Z_EXT"; break;
      case GL_ONE_EXT: RETVAL = "GL_ONE_EXT"; break;
      case GL_W_EXT: RETVAL = "GL_W_EXT"; break;
      case GL_X_EXT: RETVAL = "GL_X_EXT"; break;
      case GL_Y_EXT: RETVAL = "GL_Y_EXT"; break;
      case GL_ZERO_EXT: RETVAL = "GL_ZERO_EXT"; break;
      case GL_Z_EXT: RETVAL = "GL_Z_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderOpEXT")) {
    switch (e) {
      case GL_OP_ADD_EXT: RETVAL = "GL_OP_ADD_EXT"; break;
      case GL_OP_CLAMP_EXT: RETVAL = "GL_OP_CLAMP_EXT"; break;
      case GL_OP_CROSS_PRODUCT_EXT: RETVAL = "GL_OP_CROSS_PRODUCT_EXT"; break;
      case GL_OP_DOT3_EXT: RETVAL = "GL_OP_DOT3_EXT"; break;
      case GL_OP_DOT4_EXT: RETVAL = "GL_OP_DOT4_EXT"; break;
      case GL_OP_EXP_BASE_2_EXT: RETVAL = "GL_OP_EXP_BASE_2_EXT"; break;
      case GL_OP_FLOOR_EXT: RETVAL = "GL_OP_FLOOR_EXT"; break;
      case GL_OP_FRAC_EXT: RETVAL = "GL_OP_FRAC_EXT"; break;
      case GL_OP_INDEX_EXT: RETVAL = "GL_OP_INDEX_EXT"; break;
      case GL_OP_LOG_BASE_2_EXT: RETVAL = "GL_OP_LOG_BASE_2_EXT"; break;
      case GL_OP_MADD_EXT: RETVAL = "GL_OP_MADD_EXT"; break;
      case GL_OP_MAX_EXT: RETVAL = "GL_OP_MAX_EXT"; break;
      case GL_OP_MIN_EXT: RETVAL = "GL_OP_MIN_EXT"; break;
      case GL_OP_MOV_EXT: RETVAL = "GL_OP_MOV_EXT"; break;
      case GL_OP_MULTIPLY_MATRIX_EXT: RETVAL = "GL_OP_MULTIPLY_MATRIX_EXT"; break;
      case GL_OP_MUL_EXT: RETVAL = "GL_OP_MUL_EXT"; break;
      case GL_OP_NEGATE_EXT: RETVAL = "GL_OP_NEGATE_EXT"; break;
      case GL_OP_POWER_EXT: RETVAL = "GL_OP_POWER_EXT"; break;
      case GL_OP_RECIP_EXT: RETVAL = "GL_OP_RECIP_EXT"; break;
      case GL_OP_RECIP_SQRT_EXT: RETVAL = "GL_OP_RECIP_SQRT_EXT"; break;
      case GL_OP_ROUND_EXT: RETVAL = "GL_OP_ROUND_EXT"; break;
      case GL_OP_SET_GE_EXT: RETVAL = "GL_OP_SET_GE_EXT"; break;
      case GL_OP_SET_LT_EXT: RETVAL = "GL_OP_SET_LT_EXT"; break;
      case GL_OP_SUB_EXT: RETVAL = "GL_OP_SUB_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderParameterEXT")) {
    switch (e) {
      case GL_CURRENT_VERTEX_EXT: RETVAL = "GL_CURRENT_VERTEX_EXT"; break;
      case GL_MVP_MATRIX_EXT: RETVAL = "GL_MVP_MATRIX_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderStorageTypeEXT")) {
    switch (e) {
      case GL_INVARIANT_EXT: RETVAL = "GL_INVARIANT_EXT"; break;
      case GL_LOCAL_CONSTANT_EXT: RETVAL = "GL_LOCAL_CONSTANT_EXT"; break;
      case GL_LOCAL_EXT: RETVAL = "GL_LOCAL_EXT"; break;
      case GL_VARIANT_EXT: RETVAL = "GL_VARIANT_EXT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderTextureUnitParameter")) {
    switch (e) {
      case GL_CURRENT_TEXTURE_COORDS: RETVAL = "GL_CURRENT_TEXTURE_COORDS"; break;
      case GL_TEXTURE_MATRIX: RETVAL = "GL_TEXTURE_MATRIX"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexShaderWriteMaskEXT")) {
    switch (e) {
      case GL_FALSE: RETVAL = "GL_FALSE"; break;
      case GL_TRUE: RETVAL = "GL_TRUE"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexStreamATI")) {
    switch (e) {
      case GL_VERTEX_STREAM0_ATI: RETVAL = "GL_VERTEX_STREAM0_ATI"; break;
      case GL_VERTEX_STREAM1_ATI: RETVAL = "GL_VERTEX_STREAM1_ATI"; break;
      case GL_VERTEX_STREAM2_ATI: RETVAL = "GL_VERTEX_STREAM2_ATI"; break;
      case GL_VERTEX_STREAM3_ATI: RETVAL = "GL_VERTEX_STREAM3_ATI"; break;
      case GL_VERTEX_STREAM4_ATI: RETVAL = "GL_VERTEX_STREAM4_ATI"; break;
      case GL_VERTEX_STREAM5_ATI: RETVAL = "GL_VERTEX_STREAM5_ATI"; break;
      case GL_VERTEX_STREAM6_ATI: RETVAL = "GL_VERTEX_STREAM6_ATI"; break;
      case GL_VERTEX_STREAM7_ATI: RETVAL = "GL_VERTEX_STREAM7_ATI"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "VertexWeightPointerTypeEXT")) {
    switch (e) {
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!strcmp(g, "WeightPointerTypeARB")) {
    switch (e) {
      case GL_BYTE: RETVAL = "GL_BYTE"; break;
      case GL_DOUBLE: RETVAL = "GL_DOUBLE"; break;
      case GL_FLOAT: RETVAL = "GL_FLOAT"; break;
      case GL_INT: RETVAL = "GL_INT"; break;
      case GL_SHORT: RETVAL = "GL_SHORT"; break;
      case GL_UNSIGNED_BYTE: RETVAL = "GL_UNSIGNED_BYTE"; break;
      case GL_UNSIGNED_INT: RETVAL = "GL_UNSIGNED_INT"; break;
      case GL_UNSIGNED_SHORT: RETVAL = "GL_UNSIGNED_SHORT"; break;
      default: RETVAL = "UNKNOWN ENUM";
    }
    goto alldone;
  }
  if (!RETVAL) RETVAL = "UNKNOWN GROUP";
  alldone:
OUTPUT:
  RETVAL
